/*****************************************************************************************
* VBECS Patch	(Build 1.5.1.1)
*****************************************************************************************/

USE VBECS_V1_PROD
GO

/*****************************************************************************************
* 	TABLE CHANGES
*****************************************************************************************/
/*****************************************************************************************
   Create a temporary BloodProduct table and save the original data
*****************************************************************************************/
IF OBJECT_ID(N'tempdb..#BloodProduct') IS NOT NULL
	DROP TABLE #BloodProduct
GO

CREATE TABLE dbo.#BloodProduct
	(
	BloodProductGuid uniqueidentifier NOT NULL,
	ProductName varchar(175) NOT NULL,
	ProductShortName varchar(50) NOT NULL,
	ProductTypeCode char(4) NOT NULL,
	ProductAttributeForm varchar(40) NOT NULL,
	ProductVolume smallint NULL,
	ProductCode char(5) NOT NULL,
	MaximumStorageTime decimal(9, 0) NOT NULL,
	CrossmatchRequiredIndicator bit NOT NULL,
	ProductModificationIndicator bit NOT NULL,
	ProductCodeIndicator  bit  NOT NULL,
	RecordStatusCode char(1) NOT NULL,
	LastUpdateDate datetime NOT NULL,
	LastUpdateUser varchar(30) NOT NULL,
	LastUpdateFunctionId int NOT NULL
	)  ON [PRIMARY]
GO

INSERT INTO #BloodProduct 
	(BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, 
	 MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, 
	 LastUpdateDate, LastUpdateUser, LastUpdateFunctionId)
SELECT 	 BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, 
	 MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, 
	 LastUpdateDate, LastUpdateUser, LastUpdateFunctionId
  FROM dbo.BloodProduct
GO

/*****************************************************************************************
   Drop the constraints from the BloodProduct table
*****************************************************************************************/
if exists (select * from dbo.sysobjects where id = object_id(N'dbo.FK_BloodUnit_BloodProduct') and OBJECTPROPERTY(id, N'IsForeignKey') = 1)
ALTER TABLE dbo.BloodUnit DROP CONSTRAINT FK_BloodUnit_BloodProduct
GO

if exists (select * from dbo.sysobjects where id = object_id(N'dbo.FK_BloodUnitShipment_BloodProduct') and OBJECTPROPERTY(id, N'IsForeignKey') = 1)
ALTER TABLE dbo.BloodUnitShipment DROP CONSTRAINT FK_BloodUnitShipment_BloodProduct
GO

if exists (select * from dbo.sysobjects where id = object_id(N'dbo.FK_HcpcsAssignment_BloodProduct') and OBJECTPROPERTY(id, N'IsForeignKey') = 1)
ALTER TABLE dbo.HcpcsAssignment DROP CONSTRAINT FK_HcpcsAssignment_BloodProduct
GO

if exists (select * from dbo.sysobjects where id = object_id(N'dbo.FK_ProductShipper_BloodProduct') and OBJECTPROPERTY(id, N'IsForeignKey') = 1)
ALTER TABLE dbo.ProductShipper DROP CONSTRAINT FK_ProductShipper_BloodProduct
GO

if exists (select * from dbo.sysobjects where id = object_id(N'dbo.FK_BloodProduct_ProductType') and OBJECTPROPERTY(id, N'IsForeignKey') = 1)
ALTER TABLE dbo.BloodProduct DROP CONSTRAINT FK_BloodProduct_ProductType
GO

/*****************************************************************************************
   Create the updated BloodProduct table
*****************************************************************************************/
if exists (select * from dbo.sysobjects where id = object_id(N'dbo.BloodProduct') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
DROP TABLE dbo.BloodProduct
GO

CREATE TABLE dbo.BloodProduct (
	BloodProductGuid uniqueidentifier NOT NULL,
	ProductName varchar(175) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL,
	ProductShortName varchar(50) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL,
	ProductTypeCode char(4) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL,
	ProductAttributeForm varchar(40) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL,
	ProductVolume smallint NULL,
	ProductCode char(5) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL,
	MaximumStorageTime decimal(9, 0) NOT NULL,
	CrossmatchRequiredIndicator bit NOT NULL,
	ProductModificationIndicator bit NOT NULL,
	ProductCodeIndicator bit NOT NULL,
	RetireDate datetime NULL,
	RecordStatusCode char(1) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL,
	LastUpdateDate datetime NOT NULL,
	LastUpdateUser varchar(30) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL,
	[RowVersion] timestamp NOT NULL,
	LastUpdateFunctionId int NOT NULL CONSTRAINT DF_BloodProduct_LastUpdateFunctionId DEFAULT(0)
) ON [PRIMARY]
GO

sp_addextendedproperty N'MS_Description', N'Identifies a specific instance of a blood product.', 'USER', N'dbo', 'TABLE', N'BloodProduct', 'COLUMN', N'BloodProductGuid'
GO
sp_addextendedproperty N'MS_Description', N'The specifically formatted, full text name of a blood product.', 'USER', N'dbo', 'TABLE', N'BloodProduct', 'COLUMN', N'ProductName'
GO
sp_addextendedproperty N'MS_Description', N'A shortened version of the full name of a blood product.', 'USER', N'dbo', 'TABLE', N'BloodProduct', 'COLUMN', N'ProductShortName'
GO
sp_addextendedproperty N'MS_Description', N'A classification of blood products. Also known as Blood Component.', 'USER', N'dbo', 'TABLE', N'BloodProduct', 'COLUMN', N'ProductTypeCode'
GO
sp_addextendedproperty N'MS_Description', N'Abbreviated attribute codes that identify core conditions and other attributes for the blood product.', 'USER', N'dbo', 'TABLE', N'BloodProduct', 'COLUMN', N'ProductAttributeForm'
GO
sp_addextendedproperty N'MS_Description', N'The average amount of a unit of this blood product measured in milliliters.', 'USER', N'dbo', 'TABLE', N'BloodProduct', 'COLUMN', N'ProductVolume'
GO
sp_addextendedproperty N'MS_Description', N'The standard 5-digit code for the blood product.', 'USER', N'dbo', 'TABLE', N'BloodProduct', 'COLUMN', N'ProductCode'
GO
sp_addextendedproperty N'MS_Description', N'The maximum number of hours that a unit of this blood product can remain in storage.', 'USER', N'dbo', 'TABLE', N'BloodProduct', 'COLUMN', N'MaximumStorageTime'
GO
sp_addextendedproperty N'MS_Description', N'Indicates whether units of this blood product type require crossmatching.', 'USER', N'dbo', 'TABLE', N'BloodProduct', 'COLUMN', N'CrossmatchRequiredIndicator'
GO
sp_addextendedproperty N'MS_Description', N'Indicates whether the blood product can be modified.', 'USER', N'dbo', 'TABLE', N'BloodProduct', 'COLUMN', N'ProductModificationIndicator'
GO
sp_addextendedproperty N'MS_Description', N'Indicates whether the record is for an ISBT128 product code or a Codabar product code.', 'USER', N'dbo', 'TABLE', N'BloodProduct', 'COLUMN', N'ProductCodeIndicator'
GO
sp_addextendedproperty N'MS_Description', N'The date the blood product was retired from use.', 'USER', N'dbo', 'TABLE', N'BloodProduct', 'COLUMN', N'RetireDate'
GO
sp_addextendedproperty N'MS_Description', N'Indicates the state of the associated record.', 'USER', N'dbo', 'TABLE', N'BloodProduct', 'COLUMN', N'RecordStatusCode'
GO
sp_addextendedproperty N'MS_Description', N'The date and time the record was last updated.', 'USER', N'dbo', 'TABLE', N'BloodProduct', 'COLUMN', N'LastUpdateDate'
GO
sp_addextendedproperty N'MS_Description', N'The logon id of the user who performed the last update.', 'USER', N'dbo', 'TABLE', N'BloodProduct', 'COLUMN', N'LastUpdateUser'
GO
sp_addextendedproperty N'MS_Description', N'This is used in the C# code as a mechanism for version-stamping table rows, which provides a means for concurrency control.', 'USER', N'dbo', 'TABLE', N'BloodProduct', 'COLUMN', N'RowVersion'
GO
sp_addextendedproperty N'MS_Description', N'The identifier of the VBECS function that performed the last update.', 'USER', N'dbo', 'TABLE', N'BloodProduct', 'COLUMN', N'LastUpdateFunctionId'
GO

ALTER TABLE dbo.BloodProduct ADD 
	CONSTRAINT PK_BloodProduct PRIMARY KEY CLUSTERED 
	(
		BloodProductGuid
	) ON [PRIMARY] 
GO

/*****************************************************************************************
   Reload the updated BloodProduct table 
*****************************************************************************************/
INSERT INTO dbo.BloodProduct 
	(BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, 
	 MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, 
	 LastUpdateDate, LastUpdateUser, LastUpdateFunctionId)
SELECT 	 BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, 
	 MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RecordStatusCode, 
	 LastUpdateDate, LastUpdateUser, LastUpdateFunctionId
  FROM #BloodProduct
GO


/*****************************************************************************************
   Create a temporary ProductAttribute table and save the original data
*****************************************************************************************/
IF OBJECT_ID(N'tempdb..#ProductAttribute') IS NOT NULL
	DROP TABLE #ProductAttribute
GO

CREATE TABLE dbo.#ProductAttribute
	(
	ProductAttributeId char(3) NOT NULL,
	ProductAttributeText varchar(40) NOT NULL,
	ProductAttributePrintName varchar(20) NULL,
	SortColumn smallint NOT NULL,
	LastUpdateDate datetime NOT NULL,
	LastUpdateUser varchar(30) NOT NULL,
	LastUpdateFunctionId int NOT NULL
	)  ON [PRIMARY]
GO

INSERT INTO #ProductAttribute 
	(ProductAttributeId, ProductAttributeText, ProductAttributePrintName, SortColumn, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId)
SELECT 	 ProductAttributeId, ProductAttributeText, ProductAttributePrintName, SortColumn, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId
  FROM dbo.ProductAttribute
GO

/*****************************************************************************************
   Drop the constraints from the ProductAttribute table
*****************************************************************************************/

/*****************************************************************************************
   Create the updated ProductAttribute table
*****************************************************************************************/
if exists (select * from dbo.sysobjects where id = object_id(N'dbo.ProductAttribute') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
DROP TABLE dbo.ProductAttribute
GO

CREATE TABLE dbo.ProductAttribute (
	ProductAttributeId char(3) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL,
	ProductAttributeText varchar(40) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL,
	ProductAttributePrintName varchar(20) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
	ModificationAllowedIndicator bit NOT NULL CONSTRAINT DF_ProductAttribute_ModificationAllowedIndicator DEFAULT(0),
	RetireDate datetime NULL,
	SortColumn smallint NOT NULL,
	LastUpdateDate datetime NOT NULL,
	LastUpdateUser varchar(30) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL,
	[RowVersion] timestamp NOT NULL,
	LastUpdateFunctionId int NOT NULL CONSTRAINT DF_ProductAttribute_LastUpdateFunctionId DEFAULT(0)
) ON [PRIMARY]
GO

sp_addextendedproperty N'MS_Description', N'Identifies a specific blood product characteristic.', 'USER', N'dbo', 'TABLE', N'ProductAttribute', 'COLUMN', N'ProductAttributeId'
GO
sp_addextendedproperty N'MS_Description', N'The meaning of the blood product attribute.', 'USER', N'dbo', 'TABLE', N'ProductAttribute', 'COLUMN', N'ProductAttributeText'
GO
sp_addextendedproperty N'MS_Description', N'The short name for the attribute that is used in printing online.', 'USER', N'dbo', 'TABLE', N'ProductAttribute', 'COLUMN', N'ProductAttributePrintName'
GO
sp_addextendedproperty N'MS_Description', N'Indicates whether the product attribute allows modification.', 'USER', N'dbo', 'TABLE', N'ProductAttribute', 'COLUMN', N'ModificationAllowedIndicator'
GO
sp_addextendedproperty N'MS_Description', N'The date the product attribute was retired from use.', 'USER', N'dbo', 'TABLE', N'ProductAttribute', 'COLUMN', N'RetireDate'
GO
sp_addextendedproperty N'MS_Description', N'A number that facilitates presenting values in a specified order.', 'USER', N'dbo', 'TABLE', N'ProductAttribute', 'COLUMN', N'SortColumn'
GO
sp_addextendedproperty N'MS_Description', N'The date and time the record was last updated.', 'USER', N'dbo', 'TABLE', N'ProductAttribute', 'COLUMN', N'LastUpdateDate'
GO
sp_addextendedproperty N'MS_Description', N'The logon id of the user who performed the last update.', 'USER', N'dbo', 'TABLE', N'ProductAttribute', 'COLUMN', N'LastUpdateUser'
GO
sp_addextendedproperty N'MS_Description', N'This is used in the C# code as a mechanism for version-stamping table rows, which provides a means for concurrency control.', 'USER', N'dbo', 'TABLE', N'ProductAttribute', 'COLUMN', N'RowVersion'
GO
sp_addextendedproperty N'MS_Description', N'The identifier of the VBECS function that performed the last update.', 'USER', N'dbo', 'TABLE', N'ProductAttribute', 'COLUMN', N'LastUpdateFunctionId'
GO

ALTER TABLE dbo.ProductAttribute ADD 
	CONSTRAINT [PK_ProductAttribute] PRIMARY KEY  CLUSTERED 
	(
		ProductAttributeId
	)  ON [PRIMARY] 
GO

/*****************************************************************************************
   Reload the updated ProductAttribute table 
*****************************************************************************************/
INSERT INTO dbo.ProductAttribute 
	(ProductAttributeId, ProductAttributeText, ProductAttributePrintName, SortColumn, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId)
SELECT 	 ProductAttributeId, ProductAttributeText, ProductAttributePrintName, SortColumn, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId
  FROM #ProductAttribute
GO


/*****************************************************************************************
   Create a temporary ProductType table and save the original data
*****************************************************************************************/
IF OBJECT_ID(N'tempdb..#ProductType') IS NOT NULL
	DROP TABLE #ProductType
GO

CREATE TABLE dbo.#ProductType
	(
	ProductTypeCode char(4) NOT NULL,
	ProductTypeName varchar(60) NOT NULL,
	ProductTypePrintName varchar(35) NOT NULL,
	ComponentClassId int NOT NULL,
	IccbbaComponentClassId int NULL,
	SplitAllowedIndicator bit NULL,
	SortColumn smallint NOT NULL,
	LastUpdateDate datetime NOT NULL,
	LastUpdateUser varchar(30) NOT NULL,
	LastUpdateFunctionId int NOT NULL
	)  ON [PRIMARY]
GO

INSERT INTO #ProductType 
	(ProductTypeCode, ProductTypeName, ProductTypePrintName, ComponentClassId, IccbbaComponentClassId, SplitAllowedIndicator, 
	 SortColumn, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId)
SELECT 	 ProductTypeCode, ProductTypeName, ProductTypePrintName, ComponentClassId, IccbbaComponentClassId, SplitAllowedIndicator, 
	 SortColumn, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId
  FROM dbo.ProductType
GO

/*****************************************************************************************
   Drop the constraints from the ProductType table
*****************************************************************************************/
if exists (select * from dbo.sysobjects where id = object_id(N'dbo.FK_PermittedProductModification_FromProductType') and OBJECTPROPERTY(id, N'IsForeignKey') = 1)
ALTER TABLE dbo.PermittedProductModification DROP CONSTRAINT FK_PermittedProductModification_FromProductType
GO

if exists (select * from dbo.sysobjects where id = object_id(N'dbo.FK_PermittedProductModification_ToProductType') and OBJECTPROPERTY(id, N'IsForeignKey') = 1)
ALTER TABLE dbo.PermittedProductModification DROP CONSTRAINT FK_PermittedProductModification_ToProductType
GO

/*****************************************************************************************
   Create the updated ProductType table
*****************************************************************************************/
if exists (select * from dbo.sysobjects where id = object_id(N'dbo.ProductType') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
DROP TABLE dbo.ProductType
GO

CREATE TABLE dbo.ProductType (
	ProductTypeCode char(4) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL,
	ProductTypeName varchar(60) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL,
	ProductTypePrintName varchar(35) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL,
	ComponentClassId int NOT NULL,
	IccbbaComponentClassId int NULL,
	SplitAllowedIndicator bit NULL,
	RetireDate datetime NULL,
	SortColumn smallint NOT NULL CONSTRAINT DF_ProductType_SortColumn DEFAULT(0),
	LastUpdateDate datetime NOT NULL,
	LastUpdateUser varchar(30) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL,
	[RowVersion] timestamp NOT NULL,
	LastUpdateFunctionId int NOT NULL CONSTRAINT DF_ProductType_LastUpdateFunctionId DEFAULT(0)
) ON [PRIMARY]
GO

sp_addextendedproperty N'MS_Description', N'A classification of blood products.', 'USER', N'dbo', 'TABLE', N'ProductType', 'COLUMN', N'ProductTypeCode'
GO
sp_addextendedproperty N'MS_Description', N'Describes the blood product type code.', 'USER', N'dbo', 'TABLE', N'ProductType', 'COLUMN', N'ProductTypeName'
GO
sp_addextendedproperty N'MS_Description', N'The short name for the blood product type used for printing labels.', 'USER', N'dbo', 'TABLE', N'ProductType', 'COLUMN', N'ProductTypePrintName'
GO
sp_addextendedproperty N'MS_Description', N'Identifies a higher-level blood component.', 'USER', N'dbo', 'TABLE', N'ProductType', 'COLUMN', N'ComponentClassId'
GO
sp_addextendedproperty N'MS_Description', N'Identifies a higher-level blood component.', 'USER', N'dbo', 'TABLE', N'ProductType', 'COLUMN', N'IccbbaComponentClassId'
GO
sp_addextendedproperty N'MS_Description', N'Indicates whether the product type allows a split modification.', 'USER', N'dbo', 'TABLE', N'ProductType', 'COLUMN', N'SplitAllowedIndicator'
GO
sp_addextendedproperty N'MS_Description', N'The date the product type was retired from use.', 'USER', N'dbo', 'TABLE', N'ProductType', 'COLUMN', N'RetireDate'
GO
sp_addextendedproperty N'MS_Description', N'A number that facilitates presenting values in a specified order.', 'USER', N'dbo', 'TABLE', N'ProductType', 'COLUMN', N'SortColumn'
GO
sp_addextendedproperty N'MS_Description', N'The date and time the record was last updated.', 'USER', N'dbo', 'TABLE', N'ProductType', 'COLUMN', N'LastUpdateDate'
GO
sp_addextendedproperty N'MS_Description', N'The logon id of the user who performed the last update.', 'USER', N'dbo', 'TABLE', N'ProductType', 'COLUMN', N'LastUpdateUser'
GO
sp_addextendedproperty N'MS_Description', N'This is used in the C# code as a mechanism for version-stamping table rows, which provides a means for concurrency control.', 'USER', N'dbo', 'TABLE', N'ProductType', 'COLUMN', N'RowVersion'
GO
sp_addextendedproperty N'MS_Description', N'The identifier of the VBECS function that performed the last update.', 'USER', N'dbo', 'TABLE', N'ProductType', 'COLUMN', N'LastUpdateFunctionId'
GO

ALTER TABLE dbo.ProductType ADD 
	CONSTRAINT [PK_ProductType] PRIMARY KEY  CLUSTERED 
	(
		ProductTypeCode
	)  ON [PRIMARY] 
GO

/*****************************************************************************************
   Reload the updated ProductAttribute table 
*****************************************************************************************/
INSERT INTO dbo.ProductType 
	(ProductTypeCode, ProductTypeName, ProductTypePrintName, ComponentClassId, IccbbaComponentClassId, SplitAllowedIndicator, 
	 SortColumn, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId)
SELECT 	 ProductTypeCode, ProductTypeName, ProductTypePrintName, ComponentClassId, IccbbaComponentClassId, SplitAllowedIndicator, 
	 SortColumn, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId
  FROM #ProductType
GO

/*****************************************************************************************
   Add the indexes and foreign keys 
*****************************************************************************************/
ALTER TABLE [dbo].[ProductShipper] WITH NOCHECK ADD CONSTRAINT [FK_ProductShipper_BloodProduct] FOREIGN KEY ([BloodProductGuid]) REFERENCES [dbo].[BloodProduct] ([BloodProductGuid])
GO

CREATE NONCLUSTERED INDEX [IX_ProductType_ComponentClassId] ON [dbo].[ProductType] ([ComponentClassId]) ON [PRIMARY]
GO
CREATE NONCLUSTERED INDEX [IX_ProductType_IccbbaComponentClassId] ON [dbo].[ProductType] ([IccbbaComponentClassId]) ON [PRIMARY]
GO
ALTER TABLE [dbo].[ProductType] WITH NOCHECK ADD CONSTRAINT [FK_ProductType_ComponentClass] FOREIGN KEY ([ComponentClassId]) REFERENCES [dbo].[ComponentClass] ([ComponentClassId])
GO
ALTER TABLE [dbo].[ProductType] WITH NOCHECK ADD CONSTRAINT [FK_ProductType_IccbbaComponentClass] FOREIGN KEY ([IccbbaComponentClassId]) REFERENCES [dbo].[IccbbaComponentClass] ([IccbbaComponentClassId])
GO

CREATE UNIQUE NONCLUSTERED INDEX [CK_BloodProduct] ON [dbo].[BloodProduct] ([ProductTypeCode], [ProductCode]) ON [PRIMARY]
GO
CREATE NONCLUSTERED INDEX [IX_BloodProduct_ProductTypeCode] ON [dbo].[BloodProduct] ([ProductTypeCode]) ON [PRIMARY]
GO

ALTER TABLE [dbo].[BloodProduct] WITH NOCHECK ADD CONSTRAINT [FK_BloodProduct_ProductType] FOREIGN KEY ([ProductTypeCode]) REFERENCES [dbo].[ProductType] ([ProductTypeCode])
GO
ALTER TABLE [dbo].[BloodUnit] WITH NOCHECK ADD CONSTRAINT [FK_BloodUnit_BloodProduct] FOREIGN KEY ([BloodProductGuid]) REFERENCES [dbo].[BloodProduct] ([BloodProductGuid])
GO
ALTER TABLE [dbo].[BloodUnitShipment] WITH NOCHECK ADD CONSTRAINT [FK_BloodUnitShipment_BloodProduct] FOREIGN KEY ([LoginBloodProductGuid]) REFERENCES [dbo].[BloodProduct] ([BloodProductGuid])
GO
ALTER TABLE [dbo].[HcpcsAssignment] WITH NOCHECK ADD CONSTRAINT [FK_HcpcsAssignment_BloodProduct] FOREIGN KEY ([BloodProductGuid]) REFERENCES [dbo].[BloodProduct] ([BloodProductGuid])
GO
ALTER TABLE [dbo].[PermittedProductModification] WITH NOCHECK ADD CONSTRAINT [FK_PermittedProductModification_FromProductType] FOREIGN KEY ([FromProductTypeCode]) REFERENCES [dbo].[ProductType] ([ProductTypeCode])
GO
ALTER TABLE [dbo].[PermittedProductModification] WITH NOCHECK ADD CONSTRAINT [FK_PermittedProductModification_ToProductType] FOREIGN KEY ([ToProductTypeCode]) REFERENCES [dbo].[ProductType] ([ProductTypeCode])
GO

ALTER TABLE [dbo].[AntiseraWorklist] ADD CONSTRAINT [FK_AntiseraWorklist_TaskStatus] FOREIGN KEY ([TaskStatusCode]) REFERENCES [dbo].[TaskStatus] ([TaskStatusCode])
GO
CREATE NONCLUSTERED INDEX [IX_AntiseraWorklist_TaskStatusCode] ON [dbo].[AntiseraWorklist] ([TaskStatusCode]) WITH FILLFACTOR=90 ON [PRIMARY]
GO

ALTER TABLE [dbo].[AntiseraWorklistTyping] ADD CONSTRAINT [FK_AntiseraWorklistTyping_OrderableTest] FOREIGN KEY ([OrderableTestId]) REFERENCES [dbo].[OrderableTest] ([OrderableTestId])
GO
CREATE NONCLUSTERED INDEX [IX_AntiseraWorklistTyping_OrderableTestId] ON [dbo].[AntiseraWorklistTyping] ([OrderableTestId]) WITH FILLFACTOR=90 ON [PRIMARY]
GO

ALTER TABLE [dbo].[BloodUnitModification] ADD CONSTRAINT [FK_BloodUnitModification_FromBloodUnit] FOREIGN KEY ([FromBloodUnitGuid]) REFERENCES [dbo].[BloodUnit] ([BloodUnitGuid])
GO
ALTER TABLE [dbo].[BloodUnitModification] ADD CONSTRAINT [FK_BloodUnitModification_ModificationMethod] FOREIGN KEY ([ModificationMethodCode]) REFERENCES [dbo].[ModificationMethod] ([ModificationMethodCode])
GO
ALTER TABLE [dbo].[BloodUnitModification] ADD CONSTRAINT [FK_BloodUnitModification_ProductModification] FOREIGN KEY ([ProductModificationCode]) REFERENCES [dbo].[ProductModification] ([ProductModificationCode])
GO
ALTER TABLE [dbo].[BloodUnitModification] ADD CONSTRAINT [FK_BloodUnitModification_ToBloodUnit] FOREIGN KEY ([ToBloodUnitGuid]) REFERENCES [dbo].[BloodUnit] ([BloodUnitGuid])
GO
ALTER TABLE [dbo].[BloodUnitModification] ADD CONSTRAINT [FK_BloodUnitModification_VamcDivision] FOREIGN KEY ([DivisionCode]) REFERENCES [dbo].[VamcDivision] ([DivisionCode])
GO

ALTER TABLE [dbo].[BloodUnitStatus] ADD CONSTRAINT [FK_BloodUnitStatus_BloodUnit] FOREIGN KEY ([BloodUnitGUID]) REFERENCES [dbo].[BloodUnit] ([BloodUnitGuid])
GO
ALTER TABLE [dbo].[BloodUnitStatus] ADD CONSTRAINT [FK_BloodUnitStatus_DiscardCannedComment] FOREIGN KEY ([DiscardCannedCommentGuid]) REFERENCES [dbo].[CannedComment] ([CannedCommentGuid])
GO
ALTER TABLE [dbo].[BloodUnitStatus] ADD CONSTRAINT [FK_BloodUnitStatus_QuarantineCannedComment] FOREIGN KEY ([QuarantineCannedCommentGuid]) REFERENCES [dbo].[CannedComment] ([CannedCommentGuid])
GO

ALTER TABLE [dbo].[PatientChange] ADD CONSTRAINT [FK_PatientChange_FromPatient] FOREIGN KEY ([FromPatientGuid]) REFERENCES [dbo].[Patient] ([PatientGuid])
GO
ALTER TABLE [dbo].[PatientChange] ADD CONSTRAINT [FK_PatientChange_ToPatient] FOREIGN KEY ([ToPatientGuid]) REFERENCES [dbo].[Patient] ([PatientGuid])
GO

ALTER TABLE [dbo].[PatientTransfusionRequirement] ADD CONSTRAINT [FK_PatientTransfusionRequirement_AntibodyType] FOREIGN KEY ([AntibodyTypeId]) REFERENCES [dbo].[AntibodyType] ([AntibodyTypeId])
GO
ALTER TABLE [dbo].[PatientTransfusionRequirement] ADD CONSTRAINT [FK_PatientTransfusionRequirement_AntigenType] FOREIGN KEY ([AntigenTypeId]) REFERENCES [dbo].[AntigenType] ([AntigenTypeId])
GO
ALTER TABLE [dbo].[PatientTransfusionRequirement] ADD CONSTRAINT [FK_PatientTransfusionRequirement_ComponentRequirement] FOREIGN KEY ([ComponentRequirementId]) REFERENCES [dbo].[ComponentRequirement] ([ComponentRequirementId])
GO
ALTER TABLE [dbo].[PatientTransfusionRequirement] ADD CONSTRAINT [FK_PatientTransfusionRequirement_CreateDivision] FOREIGN KEY ([CreateDivisionCode]) REFERENCES [dbo].[VamcDivision] ([DivisionCode])
GO
ALTER TABLE [dbo].[PatientTransfusionRequirement] ADD CONSTRAINT [FK_PatientTransfusionRequirement_InactivateDivision] FOREIGN KEY ([InactivateDivisionCode]) REFERENCES [dbo].[VamcDivision] ([DivisionCode])
GO
ALTER TABLE [dbo].[PatientTransfusionRequirement] ADD CONSTRAINT [FK_PatientTransfusionRequirement_Patient] FOREIGN KEY ([PatientGuid]) REFERENCES [dbo].[Patient] ([PatientGuid])
GO
ALTER TABLE [dbo].[PatientTransfusionRequirement] ADD CONSTRAINT [FK_PatientTransfusionRequirement_SpecimenTest] FOREIGN KEY ([SpecimenTestGuid]) REFERENCES [dbo].[SpecimenTest] ([SpecimenTestGuid])
GO
ALTER TABLE [dbo].[PatientTransfusionRequirement] ADD CONSTRAINT [FK_PatientTransfusionRequirement_TransfusionRequirementCategory] FOREIGN KEY ([TransfusionRequirementCategoryCode]) REFERENCES [dbo].[TransfusionRequirementCategory] ([TransfusionRequirementCategoryCode])
GO
CREATE NONCLUSTERED INDEX [IX_PatientTransfusionRequirement_AntigenTypeId] ON [dbo].[PatientTransfusionRequirement] ([AntigenTypeId]) WITH FILLFACTOR=90 ON [PRIMARY]
GO

ALTER TABLE [dbo].[WorkloadProcess] WITH NOCHECK ADD CONSTRAINT [FK_WorkloadProcess_VamcDivision] FOREIGN KEY ([DivisionCode]) REFERENCES [dbo].[VamcDivision] ([DivisionCode])
GO
ALTER TABLE [dbo].[WorkloadProcess] WITH NOCHECK ADD CONSTRAINT [FK_WorkloadProcess_VbecsProcess] FOREIGN KEY ([VbecsProcessId]) REFERENCES [dbo].[VbecsProcess] ([VbecsProcessId])
GO

/*****************************************************************************************
   Create the new BloodUnitStatusCodeCurrent table
*****************************************************************************************/
if exists (select * from dbo.sysobjects where id = object_id(N'dbo.BloodUnitStatusCodeCurrent') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
drop table dbo.BloodUnitStatusCodeCurrent
GO

CREATE TABLE dbo.BloodUnitStatusCodeCurrent (
	BloodUnitStatusCodeCurrentGuid  uniqueidentifier NOT NULL ,
	BloodUnitGuid uniqueidentifier NOT NULL ,
	UnitStatusCode char (1) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	LastUpdateDate datetime NOT NULL ,
	LastUpdateUser varchar (30) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	[RowVersion] timestamp NOT NULL ,
	LastUpdateFunctionId int NOT NULL 
) ON [PRIMARY]
GO

sp_addextendedproperty N'MS_Description', N'Identifies a specific instance of the state of a specific blood unit.', 'USER', N'dbo', 'TABLE', N'BloodUnitStatusCodeCurrent', 'COLUMN', N'BloodUnitStatusCodeCurrentGuid'
GO
sp_addextendedproperty N'MS_Description', N'Identifies a specific unit of blood.', 'USER', N'dbo', 'TABLE', N'BloodUnitStatusCodeCurrent', 'COLUMN', N'BloodUnitGuid'
GO
sp_addextendedproperty N'MS_Description', N'The actual state of the blood unit at any one time.', 'USER', N'dbo', 'TABLE', N'BloodUnitStatusCodeCurrent', 'COLUMN', N'UnitStatusCode'
GO
sp_addextendedproperty N'MS_Description', N'The date and time the record was last updated.', 'USER', N'dbo', 'TABLE', N'BloodUnitStatusCodeCurrent', 'COLUMN', N'LastUpdateDate'
GO
sp_addextendedproperty N'MS_Description', N'The logon id of the user who performed the last update.', 'USER', N'dbo', 'TABLE', N'BloodUnitStatusCodeCurrent', 'COLUMN', N'LastUpdateUser'
GO
sp_addextendedproperty N'MS_Description', N'This is used in the C# code as a mechanism for version-stamping table rows, which provides a means for concurrency control.', 'USER', N'dbo', 'TABLE', N'BloodUnitStatusCodeCurrent', 'COLUMN', N'RowVersion'
GO
sp_addextendedproperty N'MS_Description', N'The identifier of the VBECS function that performed the last update.', 'USER', N'dbo', 'TABLE', N'BloodUnitStatusCodeCurrent', 'COLUMN', N'LastUpdateFunctionId'
GO

CREATE  CLUSTERED  INDEX [IX_BloodUnitStatusCodeCurrent_BloodUnitGuid] ON [dbo].[BloodUnitStatusCodeCurrent]([BloodUnitGuid]) WITH  FILLFACTOR = 80 ON [PRIMARY]
GO

ALTER TABLE [dbo].[BloodUnitStatusCodeCurrent] 
	ADD CONSTRAINT [DF_BloodUnitStatusCodeCurrent_LastUpdateFunctionId] DEFAULT (0) FOR [LastUpdateFunctionId],
	CONSTRAINT [PK_BloodUnitStatusCodeCurrent] PRIMARY KEY  NONCLUSTERED 
	(
		[BloodUnitStatusCodeCurrentGuid]
	)  ON [PRIMARY] 
GO

ALTER TABLE [dbo].[BloodUnitStatusCodeCurrent] ADD 
	CONSTRAINT [FK_BloodUnitStatusCodeCurrent_BloodUnit] FOREIGN KEY 
	(
		[BloodUnitGuid]
	) REFERENCES [dbo].[BloodUnit] (
		[BloodUnitGuid]
	)
GO

/*****************************************************************************************
   Save the UnitStatusCode information in the new table and drop the computed column
   from the BloodUnitStatus table.
*****************************************************************************************/
INSERT INTO BloodUnitStatusCodeCurrent (BloodUnitStatusCodeCurrentGuid, BloodUnitGuid, UnitStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId)
	SELECT DISTINCT newid(), BloodUnitGuid, dbo.fnUnitStatusCode (BloodUnitGuid, 0),  LastUpdateDate, LastUpdateUser,  LastUpdateFunctionId
 	FROM  BloodUnit
GO

ALTER TABLE BloodUnitStatus
  DROP COLUMN UnitStatusCode
GO

USE VBECS_V1_PROD_MIRROR
GO
SET QUOTED_IDENTIFIER ON
GO

/*****************************************************************************************
**	Create the new BloodUnitStatusCodeCurrent table
*****************************************************************************************/
if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[BloodUnitStatusCodeCurrent]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
drop table [dbo].[BloodUnitStatusCodeCurrent]
GO

CREATE TABLE [dbo].[BloodUnitStatusCodeCurrent] (
	MirrorId INT IDENTITY (1, 1) NOT NULL ,
	BloodUnitStatusCodeCurrentGuid  uniqueidentifier NOT NULL ,
	BloodUnitGuid uniqueidentifier NOT NULL ,
	UnitStatusCode char (1) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	LastUpdateDate datetime NOT NULL ,
	LastUpdateUser varchar (30) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	[RowVersion] binary NOT NULL ,
	LastUpdateFunctionId int NOT NULL ,
	MirrorDate datetime NOT NULL 
) ON [PRIMARY]
GO

SET ANSI_WARNINGS OFF
GO

/*****************************************************************************************
**   	Save the mirror table information to the new BloodUnitStatusCodeCurrent table 
**	and drop the UnitStatusCode from the BloodUnitStatus table.
*****************************************************************************************/
INSERT INTO BloodUnitStatusCodeCurrent (BloodUnitStatusCodeCurrentGuid, BloodUnitGuid, UnitStatusCode, LastUpdateDate, LastUpdateUser, RowVersion, LastUpdateFunctionId, MirrorDate)
	SELECT DISTINCT newid(), BloodUnitGuid, UnitStatusCode, LastUpdateDate, LastUpdateUser, [RowVersion], LastUpdateFunctionId, MirrorDate
 	FROM  BloodUnitStatus
GO

SET ANSI_WARNINGS ON
GO

DROP INDEX BloodUnitStatus.IX_BloodUnitStatus_UnitStatusCode

ALTER TABLE BloodUnitStatus
  DROP COLUMN UnitStatusCode
GO

/*****************************************************************************************
**	Create the updated view for the BloodUnitStatus table and the new view 
**	for the BloodUnitStatusCodeCurrent table.
*****************************************************************************************/
if exists (select * from dbo.sysobjects where id = object_id(N'dbo.V_BloodUnitStatus') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_BloodUnitStatus
GO

CREATE VIEW dbo.V_BloodUnitStatus
AS
SELECT     Source = 'MIRROR', MirrorId, BloodUnitStatusGuid, BloodUnitGUID, UnitStatusDate, UnitStatusComments, DiscardCannedCommentGuid, 
                      BiohazardousWarningIndicator, QuarantineIndicator, QuarantineCannedCommentGuid, PresumedTransfusedIndicator, EmergencyIssueIndicator, 
                      TestingLimitIndicator, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, MirrorDate
FROM         dbo.BloodUnitStatus
UNION ALL
SELECT     Source = 'ACTIVE', 0, BloodUnitStatusGuid, BloodUnitGUID, UnitStatusDate, UnitStatusComments, DiscardCannedCommentGuid, 
                      BiohazardousWarningIndicator, QuarantineIndicator, QuarantineCannedCommentGuid, PresumedTransfusedIndicator, EmergencyIssueIndicator, 
                      TestingLimitIndicator, LastUpdateDate, LastUpdateUser, [ROWVERSION], LastUpdateFunctionId, LastUpdateDate AS MirrorDate
FROM         VBECS_V1_PROD.dbo.BloodUnitStatus
GO

if exists (select * from dbo.sysobjects where id = object_id(N'dbo.V_BloodUnitStatusCodeCurrent') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_BloodUnitStatusCodeCurrent
GO

CREATE VIEW dbo.V_BloodUnitStatusCodeCurrent
AS
SELECT     Source = 'MIRROR', MirrorId, BloodUnitStatusCodeCurrentGuid, BloodUnitGUID, UnitStatusCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], 
			LastUpdateFunctionId, MirrorDate
FROM         dbo.BloodUnitStatusCodeCurrent
UNION ALL
SELECT     Source = 'ACTIVE', 0, BloodUnitStatusCodeCurrentGuid, BloodUnitGUID, UnitStatusCode, LastUpdateDate, LastUpdateUser, [ROWVERSION], 
			LastUpdateFunctionId, LastUpdateDate AS MirrorDate
FROM         VBECS_V1_PROD.dbo.BloodUnitStatusCodeCurrent
GO

/*****************************************************************************************
**	Grant permissions on tables and views.
*****************************************************************************************/
GRANT SELECT, INSERT ON dbo.BloodUnitStatusCodeCurrent TO VbecsAppMirrorUser
GRANT SELECT ON dbo.V_BloodUnitStatus TO VbecsAppMirrorUser
GRANT SELECT ON dbo.V_BloodUnitStatusCodeCurrent TO VbecsAppMirrorUser

USE VBECS_V1_PROD
GO
/*****************************************************************************************
**	Create the new unit status triggers
*****************************************************************************************/
if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trBloodUnitStatusCodeCurrent]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger [dbo].[trBloodUnitStatusCodeCurrent]
GO
CREATE TRIGGER dbo.trBloodUnitStatusCodeCurrent
ON dbo.BloodUnitStatusCodeCurrent
FOR UPDATE 
AS 
BEGIN
	INSERT INTO VBECS_V1_PROD_MIRROR.dbo.BloodUnitStatusCodeCurrent
	SELECT *, GETUTCDATE()
	FROM DELETED
END

GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trBloodUnitUnitStatusCode]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger [dbo].[trBloodUnitUnitStatusCode]
GO
/******************************************************************************************************
**	Desc: 	Trigger to update BloodUnitStatusCodeCurrent table. (CR 1174)
**
**	Author: Mike Smith
**
**	Date: 	01/04/10
*******************************************************************************************************
**	Modified:
**	Date		Name		Description
**	--------	-------------	------------------------------------------------------------
******************************************************************************************************/
CREATE TRIGGER dbo.trBloodUnitUnitStatusCode
	 ON [dbo].[BloodUnit] 
FOR INSERT, UPDATE 
AS

IF EXISTS(SELECT 1 FROM dbo.BloodUnitStatusCodeCurrent BUSCC JOIN Inserted I ON BUSCC.BloodUnitGuid = I.BloodUnitGuid)
BEGIN
	UPDATE BUSCC
	   SET UnitStatusCode = dbo.fnUnitStatusCode (Inserted.BloodUnitGuid, 0),
		LastUpdateDate = Inserted.LastUpdateDate,
		LastUpdateUser = Inserted.LastUpdateUser,
		LastUpdateFunctionId = Inserted.LastUpdateFunctionId
	 FROM dbo.BloodUnitStatusCodeCurrent BUSCC
		JOIN Inserted 
			ON BUSCC.BloodUnitGuid = Inserted.BloodUnitGuid
	WHERE UnitStatusCode <> dbo.fnUnitStatusCode (Inserted.BloodUnitGuid, 0)
END
ELSE
BEGIN
	INSERT INTO BloodUnitStatusCodeCurrent (BloodUnitStatusCodeCurrentGuid, BloodUnitGuid, UnitStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId)
		SELECT newid(), BloodUnitGuid, dbo.fnUnitStatusCode (Inserted.BloodUnitGuid, 0), LastUpdateDate, LastUpdateUser, LastUpdateFunctionId
	 	FROM  Inserted 
END
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trBloodUnitCurrentShipmentUnitStatusCode]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger [dbo].[trBloodUnitCurrentShipmentUnitStatusCode]
GO
/******************************************************************************************************
**	Desc: 	Trigger to update BloodUnitStatusCodeCurrent table. (CR 1174)
**
**	Author: Mike Smith
**
**	Date: 	01/04/10
*******************************************************************************************************
**	Modified:
**	Date		Name		Description
**	--------	-------------	------------------------------------------------------------
******************************************************************************************************/
CREATE TRIGGER dbo.trBloodUnitCurrentShipmentUnitStatusCode
	 ON [dbo].[BloodUnitCurrentShipment] 
FOR INSERT, UPDATE 
AS

UPDATE BUS
   SET UnitStatusCode = dbo.fnUnitStatusCode (Inserted.BloodUnitGuid, 0),
	LastUpdateDate = Inserted.LastUpdateDate,
	LastUpdateFunctionId = Inserted.LastUpdateFunctionId
 FROM dbo.BloodUnitStatusCodeCurrent BUS
	JOIN Inserted 
		ON BUS.BloodUnitGuid = Inserted.BloodUnitGuid
WHERE UnitStatusCode <> dbo.fnUnitStatusCode (Inserted.BloodUnitGuid, 0)
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trBloodUnitMediaUnitStatusCode]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger [dbo].[trBloodUnitMediaUnitStatusCode]
GO
/******************************************************************************************************
**	Desc: 	Trigger to update BloodUnitStatusCodeCurrent table. (CR 1174)
**
**	Author: Mike Smith
**
**	Date: 	01/04/10
*******************************************************************************************************
**	Modified:
**	Date		Name		Description
**	--------	-------------	------------------------------------------------------------
******************************************************************************************************/
CREATE TRIGGER dbo.trBloodUnitMediaUnitStatusCode
	 ON [dbo].[BloodUnitMedia] 
FOR INSERT, UPDATE 
AS

UPDATE BUS
   SET UnitStatusCode = dbo.fnUnitStatusCode (Inserted.BloodUnitGuid, 0),
	LastUpdateDate = Inserted.LastUpdateDate,
	LastUpdateFunctionId = Inserted.LastUpdateFunctionId
 FROM dbo.BloodUnitStatusCodeCurrent BUS
	JOIN Inserted 
		ON BUS.BloodUnitGuid = Inserted.BloodUnitGuid
WHERE UnitStatusCode <> dbo.fnUnitStatusCode (Inserted.BloodUnitGuid, 0)
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trBloodUnitModificationUnitStatusCode]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger [dbo].[trBloodUnitModificationUnitStatusCode]
GO
/******************************************************************************************************
**	Desc: 	Trigger to update BloodUnitStatusCodeCurrent table. (CR 1174)
**
**	Author: Mike Smith
**
**	Date: 	01/04/10
*******************************************************************************************************
**	Modified:
**	Date		Name		Description
**	--------	-------------	------------------------------------------------------------
******************************************************************************************************/
CREATE TRIGGER dbo.trBloodUnitModificationUnitStatusCode
	 ON [dbo].[BloodUnitModification] 
FOR INSERT, UPDATE 
AS

UPDATE BUS
   SET UnitStatusCode = dbo.fnUnitStatusCode (Inserted.FromBloodUnitGuid, 0),
	LastUpdateDate = Inserted.LastUpdateDate,
	LastUpdateFunctionId = Inserted.LastUpdateFunctionId
 FROM dbo.BloodUnitStatusCodeCurrent BUS
	JOIN Inserted 
		ON BUS.BloodUnitGuid = Inserted.FromBloodUnitGuid
WHERE UnitStatusCode <> dbo.fnUnitStatusCode (Inserted.FromBloodUnitGuid, 0)
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trBloodUnitStatusUnitStatusCode]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger [dbo].[trBloodUnitStatusUnitStatusCode]
GO
/******************************************************************************************************
**	Desc: 	Trigger to update BloodUnitStatusCodeCurrent table. (CR 1174)
**
**	Author: Mike Smith
**
**	Date: 	01/04/10
*******************************************************************************************************
**	Modified:
**	Date		Name		Description
**	--------	-------------	------------------------------------------------------------
******************************************************************************************************/
CREATE TRIGGER dbo.trBloodUnitStatusUnitStatusCode
	 ON [dbo].[BloodUnitStatus] 
FOR INSERT, UPDATE 
AS

UPDATE BUS
   SET UnitStatusCode = dbo.fnUnitStatusCode (Inserted.BloodUnitGuid, 0),
	LastUpdateDate = Inserted.LastUpdateDate,
	LastUpdateFunctionId = Inserted.LastUpdateFunctionId
 FROM dbo.BloodUnitStatusCodeCurrent BUS
	JOIN Inserted 
		ON BUS.BloodUnitGuid = Inserted.BloodUnitGuid
WHERE BUS.UnitStatusCode <> dbo.fnUnitStatusCode (Inserted.BloodUnitGuid, 0)
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trBloodUnitTestUnitStatusCode]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger [dbo].[trBloodUnitTestUnitStatusCode]
GO
/******************************************************************************************************
**	Desc: 	Trigger to update BloodUnitStatusCodeCurrent table. (CR 1174)
**
**	Author: Mike Smith
**
**	Date: 	01/04/10
*******************************************************************************************************
**	Modified:
**	Date		Name		Description
**	--------	-------------	------------------------------------------------------------
******************************************************************************************************/
CREATE TRIGGER dbo.trBloodUnitTestUnitStatusCode
	 ON [dbo].[BloodUnitTest] 
FOR INSERT, UPDATE 
AS

UPDATE BUS
   SET UnitStatusCode = dbo.fnUnitStatusCode (Inserted.BloodUnitGuid, 0),
	LastUpdateDate = Inserted.LastUpdateDate,
	LastUpdateFunctionId = Inserted.LastUpdateFunctionId
 FROM dbo.BloodUnitStatusCodeCurrent BUS
	JOIN Inserted 
		ON BUS.BloodUnitGuid = Inserted.BloodUnitGuid
WHERE UnitStatusCode <> dbo.fnUnitStatusCode (Inserted.BloodUnitGuid, 0)
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trIssuedUnitUnitStatusCode]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger [dbo].[trIssuedUnitUnitStatusCode]
GO
/******************************************************************************************************
**	Desc: 	Trigger to update BloodUnitStatusCodeCurrent table. (CR 1174)
**
**	Author: Mike Smith
**
**	Date: 	01/04/10
*******************************************************************************************************
**	Modified:
**	Date		Name		Description
**	--------	-------------	------------------------------------------------------------
******************************************************************************************************/
CREATE TRIGGER dbo.trIssuedUnitUnitStatusCode
	 ON [dbo].[IssuedUnit] 
FOR INSERT, UPDATE 
AS

UPDATE BUS
   SET UnitStatusCode = dbo.fnUnitStatusCode (Inserted.BloodUnitGuid, 0),
	LastUpdateDate = Inserted.LastUpdateDate,
	LastUpdateFunctionId = Inserted.LastUpdateFunctionId
 FROM dbo.BloodUnitStatusCodeCurrent BUS
	JOIN Inserted 
		ON BUS.BloodUnitGuid = Inserted.BloodUnitGuid
WHERE UnitStatusCode <> dbo.fnUnitStatusCode (Inserted.BloodUnitGuid, 0)
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trOrderedUnitUnitStatusCode]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger [dbo].[trOrderedUnitUnitStatusCode]
GO
/******************************************************************************************************
**	Desc: 	Trigger to update BloodUnitStatusCodeCurrent table. (CR 1174)
**
**	Author: Mike Smith
**
**	Date: 	01/04/10
*******************************************************************************************************
**	Modified:
**	Date		Name		Description
**	--------	-------------	------------------------------------------------------------
******************************************************************************************************/
CREATE TRIGGER dbo.trOrderedUnitUnitStatusCode
	 ON [dbo].[OrderedUnit] 
FOR INSERT, UPDATE 
AS

UPDATE BUS
   SET UnitStatusCode = dbo.fnUnitStatusCode (Inserted.BloodUnitGuid, 0),
	LastUpdateDate = Inserted.LastUpdateDate,
	LastUpdateFunctionId = Inserted.LastUpdateFunctionId
 FROM dbo.BloodUnitStatusCodeCurrent BUS
	JOIN Inserted 
		ON BUS.BloodUnitGuid = Inserted.BloodUnitGuid
WHERE UnitStatusCode <> dbo.fnUnitStatusCode (Inserted.BloodUnitGuid, 0)
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trPatientTransfusionUnitStatusCode]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger [dbo].[trPatientTransfusionUnitStatusCode]
GO
/******************************************************************************************************
**	Desc: 	Trigger to update BloodUnitStatusCodeCurrent table. (CR 1174)
**
**	Author: Mike Smith
**
**	Date: 	01/04/10
*******************************************************************************************************
**	Modified:
**	Date		Name		Description
**	--------	-------------	------------------------------------------------------------
******************************************************************************************************/
CREATE TRIGGER dbo.trPatientTransfusionUnitStatusCode
	 ON [dbo].[PatientTransfusion] 
FOR INSERT, UPDATE 
AS

UPDATE BUS
   SET UnitStatusCode = dbo.fnUnitStatusCode (Inserted.BloodUnitGuid, 0),
	LastUpdateDate = Inserted.LastUpdateDate,
	LastUpdateUser = Inserted.LastUpdateUser,
	LastUpdateFunctionId = Inserted.LastUpdateFunctionId
 FROM dbo.BloodUnitStatusCodeCurrent BUS
	JOIN Inserted 
		ON BUS.BloodUnitGuid = Inserted.BloodUnitGuid
WHERE UnitStatusCode <> dbo.fnUnitStatusCode (Inserted.BloodUnitGuid, 0)
GO


/*****************************************************************************************
* 	Views and Stored Procedures
*****************************************************************************************/
if exists (select * from dbo.sysobjects where id = object_id(N'dbo.spVistaGetWorkloadData') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure dbo.spVistaGetWorkloadData
GO

if exists (select * from dbo.sysobjects where id = object_id(N'dbo.V_BloodUnit') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.V_BloodUnit
GO
/****************************************************************************************************************************************************************
**	Name: 	V_BloodUnit
**
**	Desc: 	Returns data for a BloodUnit
**
**	Author:	??
**
**	Date: 	11/01/2004
**
******************************************************************************************************************************************************************
**	Modified:
**	Date		Name		Description
**	-------------	---------	------------------
**	04/24/2005	Lohse		Reformatted.  Added BloodUnitStatus columns and UnitStatus table join to carry fields to V_BloodUnits
**	05/26/2005	Lohse		Removed PreviouslyPooledIndicator, OriginalContainerIndicator and PooledUnitsCount. 
**	09/07/2005	S. Antropov	Replaced subquery with TOP 1 to BloodUnitShipment with a JOIN to BloodUnitCurrentShipment to increase performance
**	01/04/2010	M. Smith	Changed to get UnitStatusCode from the BloodUnitStatusCodeCurrent table. (CR 1174)
**	01/21/2010	K. Adu-Poku	** Reviewed for compliance with database standards and recommendations **
******************************************************************************************************************************************************************
*/
CREATE VIEW dbo.V_BloodUnit
AS
SELECT
		--BloodUnit fields
		BU.BloodUnitGuid,		BU.OriginalVolume,		BU.DiscardedPlasmaVolume,	BU.UnitProductCode,	BU.UnitInDate,
		BU.UnitFdaRegistrationNumber,	BU.UnitContainerLotNumber,	BU.DonationTypeId, 		BU.UnitDivisionId,	BU.LabelTypeCode, 
		BU.LabelUnitId,			BU.EyeReadableUnitId,		BU.BloodProductGuid,		BU.DivisionCode, 	BU.EntryMethodCode,
		BU.RecordStatusCode,		BU.ProcessingTechId,		BU.LastUpdateDate, 		BU.LastUpdateUser,	BU.RowVersion,

		--BloodUnitMedia fields
		BUM.BloodUnitMediaGuid,	BUM.BloodTypeCode,		BUM.RhFactorCode,		BUM.UnitExpirationDate,	BUM.Comments,
		BUM.TestingStatusId,		dbo.fnGetPatientGuid(BUM.DirectedPatientGuid) AS DirectedPatientGUID, 
		BUM.LastUpdateDate AS MediaLastUpdateDate, 			BUM.LastUpdateUser AS MediaLastUpdateUser,
		BUM.RowVersion AS UnitMediaRowVersion,

		--BloodUnitFinance fields
		BUF.BloodUnitFinanceGuid,	BUF.UnitCost,			BUF.SpecialTestingCost,		BUF.ReturnCreditAmount,
		BUF.LastUpdateDate AS FinanceLastupdateDate, 		BUF.LastUpdateUser AS FinanceLastUpdateUser, 
		BUF.RowVersion AS UnitFinanceRowVersion,
		
		--BloodUnitShipment fields
		CURSHIP.IncomingShipmentGuid,	CURSHIP.OutgoingShipmentGuid,

		--BloodUnitStatus fields
		BUS.BloodUnitStatusGuid,	BUS.DiscardCannedCommentGuid,	BUS.QuarantineIndicator,	BUS.UnitStatusComments,
		BUSCC.UnitStatusCode,		BUS.BiohazardousWarningIndicator,	ISNULL(BUS.PresumedTransfusedIndicator, 0) AS PresumedTransfusedIndicator, 
		BUS.RowVersion AS UnitStatusRowVersion,				BUS.LastUpdateDate AS UnitStatusLastUpdateDate,
		BUS.LastUpdateUser AS UnitStatusLastUpdateUser,		

		--System Tables
		RhFactor.RhFactorText,
		UnitStatus.UnitStatusText

FROM
	dbo.BloodUnit BU
	LEFT OUTER JOIN dbo.BloodUnitStatus BUS ON BU.BloodUnitGuid = BUS.BloodUnitGUID
	JOIN dbo.BloodUnitStatusCodeCurrent BUSCC ON BU.BloodUnitGuid = BUSCC.BloodUnitGuid
	LEFT OUTER JOIN dbo.BloodUnitMedia BUM ON BU.BloodUnitGuid = BUM.BloodUnitGuid
	LEFT OUTER JOIN dbo.BloodUnitFinance BUF ON BU.BloodUnitGuid = BUF.BloodUnitGuid
	INNER JOIN dbo.UnitStatus ON BUSCC.UnitStatusCode = UnitStatus.UnitStatusCode 
	INNER JOIN dbo.RhFactor ON BUM.RhFactorCode = RhFactor.RhFactorCode
	INNER JOIN dbo.BloodUnitCurrentShipment CURSHIP ON BU.BloodUnitGuid = CURSHIP.BloodUnitGuid

GO

if exists (select * from dbo.sysobjects where id = object_id(N'dbo.vw_ActiveAndInactiveBloodUnits') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.vw_ActiveAndInactiveBloodUnits
GO
/*******************************************************************************************************************************************************************************
**	Name: 	vw_ActiveAndInactiveBloodUnits
**
**	Desc: 	Returns data for a BloodUnit regardless of RecordStatusCode -- (same exact view as vw_BloodUnits
**
**	Author:	David Askew
**
**	Date: 	11/01/2004
**
*******************************************************************************************************************************************************************************
**	Modified:
**	Date		Name		Description
**	-------------		---------		------------------
**	04/24/2005	Lohse		Adding BUS columns for vw_ActiveAndInactiveBloodUnitsWithCurrentStatus. Removed BUS logic from vw_ANIBUWCS because
**					it was logic that assumed BUS records were insert and not maintained. Denoted by --01
**	06/21/2005	NPaterson	Modified to use new sql for increasted performance
**	09/07/2005	S. Antropov	Replaced subquery with TOP 1 to BloodUnitShipment with a JOIN to BloodUnitCurrentShipment to increase performance
**	09/08/2005	S. Antropov	Replaced INNER JOIN to Shipment table with LEFT OUTER JOIN to bring all blood unit records
**	10/13/2005	N.Paterson	Added comments regarding LocalSupplier join
**	01/23/2006	M Smith		** Reviewed for compliance with database standards and recommendations **
**	11/28/2008	M. Smith	Added dbo prefix to BloodUnit table (CR 2503)
**	12/17/2008	K. Adu-Poku	** Reviewed for compliance with database standards and recommendations **
**	01/04/2010	M. Smith	Changed to get UnitStatusCode from the BloodUnitStatusCodeCurrent table. (CR 1174)
**	01/21/2010	K. Adu-Poku	** Reviewed for compliance with database standards and recommendations **
*******************************************************************************************************************************************************************************/

CREATE VIEW dbo.vw_ActiveAndInactiveBloodUnits
AS
SELECT     
	BUS.BiohazardousWarningIndicator, 
	BUM.BloodTypeCode, 
	BU.BloodProductGUID, 
	BU.BloodUnitGuid, 
	BF.BloodUnitFinanceGuid,
	BUM.BloodUnitMediaGuid,
	BUS.BloodUnitStatusGuid,
	BUM.Comments, 
	BUM.DirectedPatientGUID, 
	BUS.DiscardCannedCommentGuid, 	--01
	BU.DivisionCode, 
	BU.DonationTypeID, 
	BU.EyeReadableUnitID, 
	CURSHIP.IncomingShipmentGUID, 
	BU.LabelTypeCode,
	BU.LabelUnitID, 
	BU.LastUpdateDate, 
	BU.LastUpdateUser, 
	BU.OriginalVolume, 	                      
	CURSHIP.OutgoingShipmentGUID, 
	BUS.PresumedTransfusedIndicator,
	BU.ProcessingTechID, 
	BUS.QuarantineIndicator, 			--01
	BU.RecordStatusCode, 
	BF.ReturnCreditAmount, 
	RH.RhFactorCode, 
	RH.RhFactorText, 
	BU.RowVersion, 
	BF.SpecialTestingCost, 
	BUM.TestingStatusID, 
	BU.UnitContainerLotNumber, 
	BF.UnitCost,
	BU.UnitDivisionID, 
	BUM.UnitExpirationDate, 
	BU.UnitFdaRegistrationNumber, 
	BF.RowVersion AS UnitFinanceRowVersion, 
	BU.UnitInDate, 
	BUM.RowVersion AS UnitMediaRowVersion, 
	BU.UnitProductCode, 
	BUSCC.UnitStatusCode, 			--01
	BUS.UnitStatusComments, 		--01
	BUS.RowVersion AS UnitStatusRowVersion, 
	US.UnitStatusText,			--01

	BP.MaximumStorageTime, 
	BP.ProductName, 
	BP.ProductShortName, 
	BP.ProductTypeCode, 
	                      
	DT.DonationTypeCode, 
	DT.DonationTypeText, 

	LS.FacilityName, 

	PT.ComponentClassId, 
	PT.IccbbaComponentClassId, 
	PT.ProductTypeName, 	                      
	PT.SplitAllowedIndicator,

	Ship.ShipmentDate

FROM
    	dbo.BloodUnit BU   
INNER JOIN
	dbo.BloodUnitCurrentShipment CURSHIP  ON BU.BloodUnitGuid = CURSHIP.BloodUnitGuid 
LEFT OUTER JOIN
	dbo.BloodUnitMedia BUM   ON BU.BloodUnitGuid = BUM.BloodUnitGuid 
INNER JOIN
	dbo.BloodProduct BP ON BU.BloodProductGuid = BP.BloodProductGuid 
INNER JOIN
	dbo.DonationType DT ON BU.DonationTypeId = DT.DonationTypeId 
INNER JOIN
	dbo.ProductType PT   ON BP.ProductTypeCode = PT.ProductTypeCode 
LEFT OUTER JOIN
	dbo.Shipment Ship ON CURSHIP.IncomingShipmentGuid = Ship.ShipmentGuid 
LEFT OUTER JOIN
	dbo.BloodUnitStatus BUS ON BU.BloodUnitGuid = BUS.BloodUnitGUID
JOIN	dbo.BloodUnitStatusCodeCurrent BUSCC 
		ON BU.BloodUnitGuid = BUSCC.BloodUnitGuid
INNER JOIN
	dbo.UnitStatus US ON BUSCC.UnitStatusCode = US.UnitStatusCode 
/* Per Cameron Taylor:
"When blood comes in, there are two facilities that we need to know about - the facility that shipped the unit, which we get from Shipment via the IncomingShipmentGuid.
The other is the collection facility, the facility that labelled the blood, this we get from FdaRegistrationNumber because that's what is on the bag"
*/
LEFT OUTER JOIN
	dbo.LocalSupplier LS ON BU.UnitFdaRegistrationNumber = LS.FdaRegistrationNumber AND BU.DivisionCode = LS.DivisionCode
INNER JOIN
	dbo.RhFactor RH ON BUM.RhFactorCode = RH.RhFactorCode
LEFT OUTER JOIN
	dbo.BloodUnitFinance BF ON BU.BloodUnitGuid = BF.BloodUnitGuid 

GO

if exists (select * from dbo.sysobjects where id = object_id(N'dbo.vw_BloodShipAllCurrent') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.vw_BloodShipAllCurrent
GO
CREATE VIEW dbo.vw_BloodShipAllCurrent  
/*******************************************************************************************************************************************************************************
**	Name: 	vw_BloodShipAllCurrent  
**
**	Desc: 	Replacement for view vw_BloodUnitsWithCurrentStatus which had poor performance
**
**	Author:	Norm Paterson
**
**	Date:  	06/15/2005
**
*******************************************************************************************************************************************************************************
**	Modified:
**	Date		Name		Description
**	---------------	---------		-----------------
**	06/27/2005	Npaterson	Modified  DirectedPatientGuid  to use function that was in original view - missed this
**	06/28/2005	Npaterson	Modified unitstatuscode to use data from bloodUnit Table rather than caluclated field from the table 
**					BloodUnitStatus
**	09/07/2005	S. Antropov	Replaced subquery with TOP 1 to BloodUnitShipment with a JOIN to BloodUnitCurrentShipment to 
**					increase performance
**	10/03/2005	D. Askew	Removed CASE statement for DirectedPatientGuid; added LEFT OUTER join to Patient to select either 
**					the FinalMergeToPatient if the patient has one or more merges (choosing the final merge record) or simply 
**					the patient guid if there are none; changed formatting slightly for readibility; removed unused code
**	10/04/2005	N.Paterson	Removed function call to use calculated field BUS.UnitStatusCode
**	10/13/2005	N.Paterson	Added comments regarding LocalSupplier join
**	01/23/2006	M Smith		** Reviewed for compliance with database standards and recommendations **
**	03/07/2006	Lohse		Adding DiscardedPlasmaVolume for BloodAvailabilityReport
**	01/04/2010	M. Smith	Changed to get UnitStatusCode from the BloodUnitStatusCodeCurrent table. (CR 1174)
**	01/21/2010	K. Adu-Poku	** Reviewed for compliance with database standards and recommendations **
*******************************************************************************************************************************************************************************/
AS

SELECT   
	BU.BloodUnitGuid,
	BU.UnitProductCode,
	BU.OriginalVolume,
	BU.UnitInDate,
	BU.UnitFdaRegistrationNumber,
	BU.UnitContainerLotNumber,
	BU.UnitDivisionId,
	BU.LabelTypeCode,
	BU.LabelUnitId,
	BU.EyeReadableUnitId,
	BU.BloodProductGuid,
	BU.DivisionCode,
	BU.ProcessingTechId,
	BU.RecordStatusCode,
	BU.LastUpdateDate,
	BU.LastUpdateUser,
	BU.[RowVersion],
	BU.LastUpdateFunctionId,
	BU.DiscardedPlasmaVolume,
	CURSHIP.IncomingShipmentGuid,
	CURSHIP.OutgoingShipmentGuid,
	BUM.BloodTypeCode,
	BUM.RhFactorCode,
	RH.RhFactorText,
	BUM.UnitExpirationDate,
	BUM.TestingStatusId,
	P.PatientGuid AS DirectedPatientGUID,
	BUM.Comments,
	BP.ProductName,
	BP.ProductShortName,
	BP.ProductTypeCode,
	BP.ProductAttributeForm,
	BP.ProductCode,
	BP.MaximumStorageTime,
	BP.CrossmatchRequiredIndicator,
	DT.DonationTypeId,
	DT.DonationTypeCode,
	DT.DonationTypeText,
	PT.ProductTypeName,
	PT.ComponentClassId,
	PT.SplitAllowedIndicator,
	Ship.ShipmentGuid,
	Ship.LocalSupplierGuid,
	Ship.InvoiceNumber,
	Ship.ShipmentDate,
	BUS.BloodUnitStatusGuid,
	BUSCC.UnitStatusCode,
	BUS.UnitStatusComments,
	BUS.DiscardCannedCommentGuid,
	BUS.BiohazardousWarningIndicator,
	BUS.QuarantineIndicator,
	ISNULL(BUS.PresumedTransfusedIndicator, 0) AS PresumedTransfusedIndicator,
	LS.FacilityName,
	LS.FdaRegistrationNumber,
	 LS.FacilityPrefix,
	LS.LabelUnitIdTrimIndicator,
	BUS.[RowVersion] AS UnitStatusRowVersion,
	US.UnitStatusText
	
	FROM         		dbo.BloodUnit BU   
	
	INNER JOIN 		dbo.BloodUnitCurrentShipment CURSHIP	ON BU.BloodUnitGuid = CURSHIP.BloodUnitGuid 
	
	LEFT OUTER JOIN	dbo.BloodUnitMedia BUM  		ON BU.BloodUnitGuid = BUM.BloodUnitGuid 
	INNER JOIN 		dbo.BloodProduct BP   			ON BU.BloodProductGuid = BP.BloodProductGuid 
	INNER JOIN 		dbo.DonationType DT    			ON BU.DonationTypeId = DT.DonationTypeId 
	INNER JOIN 		dbo.ProductType PT   			ON BP.ProductTypeCode = PT.ProductTypeCode 
	INNER JOIN 		dbo.Shipment Ship   			ON CURSHIP.IncomingShipmentGuid = Ship.ShipmentGuid 
	LEFT OUTER JOIN 	dbo.BloodUnitStatus BUS    		ON BU.BloodUnitGuid = BUS.BloodUnitGUID
	JOIN 			dbo.BloodUnitStatusCodeCurrent BUSCC	ON BU.BloodUnitGuid = BUSCC.BloodUnitGUID  
	INNER JOIN 		dbo.UnitStatus US 			ON BUSCC.UnitStatusCode = US.UnitStatusCode 
/*Per Cameron Taylor:
"When blood comes in, there are two facilities that we need to know about - the facility that shipped the unit, which we get from Shipment via the IncomingShipmentGuid.
The other is the collection facility, the facility that labelled the blood, this we get from FdaRegistrationNumber because that's what is on the bag"
*/
	LEFT OUTER JOIN 	dbo.LocalSupplier LS   			ON BU.UnitFdaRegistrationNumber = LS.FdaRegistrationNumber AND BU.DivisionCode = LS.DivisionCode
	INNER JOIN	 	dbo.RhFactor RH 			ON BUM.RhFactorCode = RH.RhFactorCode
	
	-- This will return the most recent patient data, regardless of how many times the patient has been merged (most likely zero times).
	LEFT OUTER JOIN 	dbo.Patient LinkPatient 		ON BUM.DirectedPatientGuid = LinkPatient.PatientGuid
	LEFT OUTER JOIN	dbo.Patient P 				ON P.PatientGuid = COALESCE(LinkPatient.FinalMergeToPatient, LinkPatient.PatientGuid)
	
	WHERE    
		
	(BU.RecordStatusCode !='E' AND BU.RecordStatusCode !='X')

GO

if exists (select * from dbo.sysobjects where id = object_id(N'dbo.vw_BloodShipFinanceAllCurrent') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.vw_BloodShipFinanceAllCurrent
GO
CREATE VIEW dbo.vw_BloodShipFinanceAllCurrent  
/*******************************************************************************************************************************************************************************
**	Name: 	vw_BloodShipAllCurrent  
**
**	Desc: 	Replacement for view vw_BloodUnitsWithCurrentStatus which had poor performance
**
**	Author:	Norm Paterson
**
**	Date:   	06/15/2005
**
*******************************************************************************************************************************************************************************
**	Modified:
**	Date		Name		Description
**	---------------	---------		-----------------
**	06/27/2005	Npaterson	Modified   DirectedPatientGUID to use function as in original view, missed this 
**	06/28/2005	Npaterson	Modified unitstatuscode to use data from bloodUnit Table rather than caluclated field from the table 
**					BloodUnitStatus
**	09/07/2005	S. Antropov	Replaced subquery with TOP 1 to BloodUnitShipment with a JOIN to BloodUnitCurrentShipment to 
**					increase performance
**	10/03/2005	D. Askew	Removed CASE statement for DirectedPatientGuid; added LEFT OUTER join to Patient to select either 
**					the FinalMergeToPatient if the patient has one or more merges (choosing the final merge record) or simply 
**					the patient guid if there are none; changed formatting slightly for readibility; removed unused code
**	10/04/2005	N.Paterson	Removed function call to use calculated table column for BUS.UnitStatusCode
**	10/13/2005	N.Paterson	Added comments regarding LocalSupplier join
**	01/23/2006	M Smith		** Reviewed for compliance with database standards and recommendations **
**	01/04/2010	M. Smith	Changed to get UnitStatusCode from the BloodUnitStatusCodeCurrent table. (CR 1174)
**	01/21/2010	K. Adu-Poku	** Reviewed for compliance with database standards and recommendations **
*******************************************************************************************************************************************************************************/
AS

SELECT   
	BU.BloodUnitGuid,
	BU.UnitProductCode,
	BU.OriginalVolume,
	BU.UnitInDate,
	BU.UnitFdaRegistrationNumber,
	BU.UnitContainerLotNumber,
	BU.UnitDivisionId,
	BU.LabelTypeCode,
	BU.LabelUnitId,
	BU.EyeReadableUnitId,
	BU.BloodProductGuid,
	BU.DivisionCode,
	BU.ProcessingTechId,
	BU.RecordStatusCode,
	BU.LastUpdateDate,
	BU.LastUpdateUser,
	BU.[RowVersion],
	BU.LastUpdateFunctionId,
	CURSHIP.IncomingShipmentGuid,
	CURSHIP.OutgoingShipmentGuid,
	BUM.BloodTypeCode,
	BUM.RhFactorCode,
	RH.RhFactorText,
	BUM.UnitExpirationDate,
	BUM.TestingStatusId,
	P.PatientGuid AS DirectedPatientGUID,
	BUM.Comments,
	BP.ProductName,
	BP.ProductShortName,
	BP.ProductTypeCode,
	BP.ProductAttributeForm,
	BP.ProductCode,
	BP.MaximumStorageTime,
	BP.CrossmatchRequiredIndicator,
	DT.DonationTypeId,
	DT.DonationTypeCode,
	DT.DonationTypeText,
	PT.ProductTypeName,
	PT.ComponentClassId,
	PT.SplitAllowedIndicator,
	Ship.ShipmentGuid,
	Ship.LocalSupplierGuid,
	Ship.InvoiceNumber,
	Ship.ShipmentDate,
	BUS.BloodUnitStatusGuid,
	BUSCC.UnitStatusCode,
	BUS.UnitStatusComments,
	BUS.DiscardCannedCommentGuid,
	BUS.BiohazardousWarningIndicator,
	BUS.QuarantineIndicator,
	ISNULL(BUS.PresumedTransfusedIndicator, 0) AS PresumedTransfusedIndicator,
	LS.FacilityName,
	LS.FdaRegistrationNumber,
	 LS.FacilityPrefix,
	LS.LabelUnitIdTrimIndicator,
	BUS.RowVersion AS UnitStatusRowVersion,
	US.UnitStatusText,
	/*Financial */
	BF.BloodUnitFinanceGuid, 
	BF.UnitCost, 
	BF.SpecialTestingCost, 
	BF.ReturnCreditAmount, 
	BF.LastUpdateDate AS FinanceLastupdateDate, 
	BF.LastUpdateUser AS FinanceLastUpdateUser, 
	BF.[RowVersion] AS UnitFinanceRowVersion
	
	FROM         		dbo.BloodUnit BU   
	
	INNER JOIN  		dbo.BloodUnitCurrentShipment CURSHIP ON BU.BloodUnitGuid = CURSHIP.BloodUnitGuid 
	LEFT OUTER JOIN 	dbo.BloodUnitMedia BUM   		ON BU.BloodUnitGuid = BUM.BloodUnitGuid 
	INNER JOIN		dbo.BloodProduct BP  			ON BU.BloodProductGuid = BP.BloodProductGuid 
	INNER JOIN		dbo.DonationType DT   	 		ON BU.DonationTypeId = DT.DonationTypeId 
	INNER JOIN	 	dbo.ProductType PT   			ON BP.ProductTypeCode = PT.ProductTypeCode 
	INNER JOIN		dbo.Shipment Ship   			ON CURSHIP.IncomingShipmentGuid = Ship.ShipmentGuid 
	LEFT OUTER JOIN 	dbo.BloodUnitStatus BUS    		ON BU.BloodUnitGuid = BUS.BloodUnitGUID
 	JOIN 			dbo.BloodUnitStatusCodeCurrent BUSCC    ON BU.BloodUnitGuid = BUSCC.BloodUnitGuid
	INNER JOIN		dbo.UnitStatus US 			ON BUSCC.UnitStatusCode = US.UnitStatusCode 
/* Per Cameron Taylor:
"When blood comes in, there are two facilities that we need to know about - the facility that shipped the unit, which we get from Shipment via the IncomingShipmentGuid.
The other is the collection facility, the facility that labelled the blood, this we get from FdaRegistrationNumber because that's what is on the bag"
*/
	LEFT OUTER JOIN	dbo.LocalSupplier LS   			ON BU.UnitFdaRegistrationNumber = LS.FdaRegistrationNumber AND BU.DivisionCode = LS.DivisionCode
	INNER JOIN		dbo.RhFactor RH 			ON BUM.RhFactorCode = RH.RhFactorCode
	 LEFT OUTER JOIN	dbo.BloodUnitFinance BF 		ON BU.BloodUnitGuid = BF.BloodUnitGuid 

	-- This will return the most recent patient data, regardless of how many times the patient has been merged (most likely zero times).
	LEFT OUTER JOIN 	dbo.Patient LinkPatient 			ON BUM.DirectedPatientGuid = LinkPatient.PatientGuid
	LEFT OUTER JOIN	dbo.Patient P 				ON P.PatientGuid = COALESCE(LinkPatient.FinalMergeToPatient, LinkPatient.PatientGuid)

	WHERE     
		
	(BU.RecordStatusCode !='E' AND BU.RecordStatusCode !='X')

GO

if exists (select * from dbo.sysobjects where id = object_id(N'dbo.vw_BloodShipPatientAllCurrent') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.vw_BloodShipPatientAllCurrent
GO
CREATE VIEW dbo.vw_BloodShipPatientAllCurrent  
/*******************************************************************************************************************************************************************************
**	Name: 	vw_BloodShipPatientAllCurrent  
**
**	Desc: 	Replacement for view vw_BloodUnitsWithCurrentStatus which had poor performance
**
**
**	Author:	Norm Paterson
**
**	Date:   	06/15/2005
**
*******************************************************************************************************************************************************************************
**	Modified:
**	Date		Name		Description
**	---------------	---------		-----------------
**	06/27/2005	NPaterson	Modified DirectedPatientGUID to use function as was in original view, missed this
**	06/28/2005	Npaterson	Modified unitstatuscode to use data from bloodUnit Table rather than caluclated field from the table 
**					BloodUnitStatus
**	09/07/2005	S. Antropov	Replaced subquery with TOP 1 to BloodUnitShipment with a JOIN to BloodUnitCurrentShipment to 
**					increase performance
**	10/03/2005	D. Askew	Removed CASE statement for DirectedPatientGuid; changed LEFT OUTER join to Patient to select either 
**					the FinalMergeToPatient if the patient has one or more merges (choosing the final merge record) or simply 
**					the patient guid if there are none; changed formatting slightly for readibility; removed unused code
**	10/04/2005	N.Paterson	Removed function call using calculated column in table instead BUS.UnitStatusCode
**	10/13/2005	N.Paterson	Added comments regarding the strange join on LocalSupplier
**	01/23/2006	M Smith		** Reviewed for compliance with database standards and recommendations **
**	03/07/2006	Lohse		Adding DiscardedPlasmaVolume for BloodAvailablilityReport
**	03/09/2006	Lohse		Adding PendingTransferIndicator to help determine if unit is in "final" status
**	01/04/2010	M. Smith	Changed to get UnitStatusCode from the BloodUnitStatusCodeCurrent table. (CR 1174)
**	01/21/2010	K. Adu-Poku	** Reviewed for compliance with database standards and recommendations **
*******************************************************************************************************************************************************************************/
AS
	
SELECT   
	BU.BloodUnitGuid,
	BU.UnitProductCode,
	BU.OriginalVolume,
	BU.UnitInDate,
	BU.UnitFdaRegistrationNumber,
	BU.UnitContainerLotNumber,
	BU.UnitDivisionId,
	BU.LabelTypeCode,
	BU.LabelUnitId,
	BU.EyeReadableUnitId,
	BU.BloodProductGuid,
	BU.DivisionCode,
	BU.ProcessingTechId,
	BU.RecordStatusCode,
	BU.LastUpdateDate,
	BU.LastUpdateUser,
	BU.[RowVersion],
	BU.LastUpdateFunctionId,
	BU.DiscardedPlasmaVolume,
	CURSHIP.IncomingShipmentGuid,
	CURSHIP.OutgoingShipmentGuid,
	BUM.BloodTypeCode,
	BUM.RhFactorCode,
	RH.RhFactorText,
	BUM.UnitExpirationDate,
	BUM.TestingStatusId,
	P.PatientGuid AS DirectedPatientGUID,
	BUM.Comments,
	BP.ProductName,
	BP.ProductShortName,
	BP.ProductTypeCode,
	BP.ProductAttributeForm,
	BP.ProductCode,
	BP.MaximumStorageTime,
	BP.CrossmatchRequiredIndicator,
	DT.DonationTypeId,
	DT.DonationTypeCode,
	DT.DonationTypeText,
	PT.ProductTypeName,
	PT.ComponentClassId,
	PT.SplitAllowedIndicator,
	Ship.ShipmentGuid,
	Ship.LocalSupplierGuid,
	Ship.InvoiceNumber,
	Ship.ShipmentDate,
	BUS.BloodUnitStatusGuid,
	BUSCC.UnitStatusCode,
	BUS.UnitStatusComments,
	BUS.DiscardCannedCommentGuid,
	BUS.BiohazardousWarningIndicator,
	BUS.QuarantineIndicator,
	ISNULL(BUS.PresumedTransfusedIndicator, 0) AS PresumedTransfusedIndicator,
	LS.FacilityName,
	LS.FdaRegistrationNumber,
	 LS.FacilityPrefix,
	LS.LabelUnitIdTrimIndicator,
	BUS.RowVersion AS UnitStatusRowVersion,
	US.UnitStatusText,
	/*Patient Data */
	P.PatientFirstName, 
	P.PatientMiddleName, 
	P.PatientLastName, 
	P.VistaPatientId, 
	P.PatientSsn, 
	P.DisplayVistaPatientId,
	P.PatientGUID,
	dbo.fnIsUnitPendingTransfer(BU.BloodUnitGuid) AS PendingTransferIndicator

	FROM         		dbo.BloodUnit BU   

	INNER JOIN 		dbo.BloodUnitCurrentShipment CURSHIP  	ON BU.BloodUnitGuid = CURSHIP.BloodUnitGuid 
	LEFT OUTER JOIN 	dbo.BloodUnitMedia BUM  		 	ON BU.BloodUnitGuid = BUM.BloodUnitGuid 
	INNER JOIN		dbo.BloodProduct BP   				ON BU.BloodProductGuid = BP.BloodProductGuid 
	INNER JOIN 		dbo.DonationType DT    				ON BU.DonationTypeId = DT.DonationTypeId 
	INNER JOIN 		dbo.ProductType PT   				ON BP.ProductTypeCode = PT.ProductTypeCode 
	INNER JOIN 		dbo.Shipment Ship   				ON CURSHIP.IncomingShipmentGuid = Ship.ShipmentGuid 
	LEFT OUTER JOIN		dbo.BloodUnitStatus BUS    			ON BU.BloodUnitGuid = BUS.BloodUnitGUID
 	JOIN 			dbo.BloodUnitStatusCodeCurrent BUSCC    	ON BU.BloodUnitGuid = BUSCC.BloodUnitGuid
	INNER JOIN		dbo.UnitStatus US 				ON BUSCC.UnitStatusCode = US.UnitStatusCode 
/* Per Cameron Taylor:
"When blood comes in, there are two facilities that we need to know about - the facility that shipped the unit, which we get from Shipment via the IncomingShipmentGuid.
The other is the collection facility, the facility that labelled the blood, this we get from FdaRegistrationNumber because that's what is on the bag*/
	LEFT OUTER JOIN	dbo.LocalSupplier LS   				ON BU.UnitFdaRegistrationNumber = LS.FdaRegistrationNumber AND BU.DivisionCode = LS.DivisionCode
	INNER JOIN		dbo.RhFactor RH 				ON BUM.RhFactorCode = RH.RhFactorCode
	
	-- This will return the most recent patient data, regardless of how many times the patient has been merged (most likely zero times).
	LEFT OUTER JOIN 	dbo.Patient LinkPatient 				ON BUM.DirectedPatientGuid = LinkPatient.PatientGuid
	LEFT OUTER JOIN	dbo.Patient P 					ON P.PatientGuid = COALESCE(LinkPatient.FinalMergeToPatient, LinkPatient.PatientGuid)
	
	WHERE     
		
	(BU.RecordStatusCode !='E' AND BU.RecordStatusCode !='X')

GO

if exists (select * from dbo.sysobjects where id = object_id(N'dbo.vw_GetAdminReportBase') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view dbo.vw_GetAdminReportBase
GO
/*******************************************************************************************************************************************************************************
**	Desc: 	Several Stored Procedures ( i.e. spGetAdminReportBloodUnits????? ) used for Admin Report Generation use this common dataset
**	Table	BloodUnitModification,BloodUnitShipment, PatientTransfusion  can be joined on .BloodUnitGUID
**	Table 	ProductModification can be joined on ProductModificationCode
**
**	Author:Norm Paterson
**
**	Date:   07/15/2005
**
*******************************************************************************************************************************************************************************
**	Modified:
**	Date		Name		Description
**	----------	-------------	-----------------------------------------------------------------------------------------------
**	01/04/2010	M. Smith	Changed to get UnitStatusCode from the BloodUnitStatusCodeCurrent table. (CR 1174)
**	01/21/2010	K. Adu-Poku	** Reviewed for compliance with database standards and recommendations **
*******************************************************************************************************************************************************************************/
CREATE VIEW dbo.vw_GetAdminReportBase
AS

	SELECT     
	
		BU.DivisionCode, 
		BU.BloodUnitGuid, 
		BU.DonationTypeId, 
		BU.UnitDivisionId, 
		BU.LabelTypeCode, 
		BU.EyeReadableUnitId, 
		BU.DiscardedPlasmaVolume, 
		
		PT.ComponentClassId, 
		CC.ComponentClassName, 
		
		BU.UnitProductCode, 
		
		BP.ProductTypeCode, 
		BP.ProductAttributeForm,

		BUSCC.UnitStatusCode,
		BUS.UnitStatusDate,
		BU.UnitInDate,
		BUT.CMVNegative,
		BUT.SCNegative
	
	FROM         dbo.BloodUnit BU
	
		JOIN dbo.BloodUnitStatus BUS ON BU.BloodUnitGuid = BUS.BloodUnitGUID

	 	JOIN dbo.BloodUnitStatusCodeCurrent BUSCC ON BU.BloodUnitGuid = BUSCC.BloodUnitGuid

		JOIN dbo.BloodProduct BP ON BU.BloodProductGuid = BP.BloodProductGuid

		JOIN dbo.ProductType PT ON BP.ProductTypeCode = PT.ProductTypeCode

		JOIN dbo.ComponentClass CC ON PT.ComponentClassId = CC.ComponentClassId
	LEFT JOIN (SELECT BloodUnitGUID, DivisionCode, 
			MAX(CASE WHEN BloodTestTypeId = 103 
				THEN 1
				ELSE 0
			     END) AS CMVNegative,
			MAX(CASE WHEN BloodTestTypeId = 104
				THEN 1
				ELSE 0
			     END) AS SCNegative
		     FROM dbo.BloodUnitTest 
		    WHERE RecordStatusCode != 'X'
		      AND BloodTestTypeId IN (103, 104)
		    GROUP BY BloodUnitGUID, DivisionCode) BUT
		ON BU.BloodUnitGuid = BUT.BloodUnitGuid
		AND BU.DivisionCode = BUT.DivisionCode

GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[fnGetProlongedTransfusionsForSpecifiedRange]') and xtype in (N'FN', N'IF', N'TF'))
drop function [dbo].[fnGetProlongedTransfusionsForSpecifiedRange]
GO
/*********************************************************************************************************************
**
**  Desc:  Gets all prolonged transfusions in a division within a specified datetime range. Supplies unsorted 
**         data for the report sproc that sorts the data according to report criterion.
**
**  Author: Stas Antropov
**
**  Date:   10/25/2004
**
**********************************************************************************************************************
**  	Modified:
**  	Date        	Name			Description
**	--------------	------------			-------------------
**  	06/27/2005   	NPaterson	Changed to use new view
**  	07/11/2005	S. Antropov    	** Reviewed for compliance with database standards and recommendations **
**                                       reformatted SQL, added object owners, removed unneeded local variable
**  	09/29/05	J. Engstrom	Modified join on TreatingSpecialty to be LEFT OUTER instead of INNER
**					in order to return patients that are outgoing and therefore have no treating specialty.				
**	01/17/2006	C. Taylor	Added FullProductCode (UnitProductCode, DonationTypeCode, UnitDivisionId) to ProductShortName (DR 1729)
**	01/23/2006	M Smith		** Reviewed for compliance with database standards and recommendations **
**	01/04/2010	M. Smith	Checked UnitStatusCode from the BloodUnitStatusCodeCurrent table to determine
**					transfused units. (CR 1174)
**	01/25/2010	K. Adu-Poku	** Reviewed for compliance with database standards and recommendations **
*********************************************************************************************************************/
CREATE FUNCTION dbo.fnGetProlongedTransfusionsForSpecifiedRange
(
        @startdate                              		DATETIME,
        @enddate                                		DATETIME,
        @delayedtransfusiontimethresholdminutes 	INT,
        @divisioncode                           		CHAR(5)
)
RETURNS TABLE AS  
RETURN
    SELECT	
            IssueToLocationName,
            PatientFullName,
            DisplayVistAPatientId,
            EyeReadableUnitId,
            ProductShortName,
            IssueDateTime,
            TransfusionStartDateTime,
            TransfusionEndDateTime,
            DelayedTransfusionTime,
            ProlongedTransfusionTime,
            TotalAdministrationTime,
            TreatingSpecialtyName
    FROM
    (		
            SELECT	
                    dbo.IssuedUnit.IssueToLocationName,
                    dbo.Patient.PatientLastName + ', ' + dbo.Patient.PatientFirstName + ISNULL( ', ' + dbo.Patient.PatientMiddleName, '' ) 	AS PatientFullName,
                    ISNULL( dbo.Patient.DisplayVistAPatientId, '' ) 				AS DisplayVistAPatientId,
                    ISNULL( dbo.vw_BloodShipAllCurrent.EyeReadableUnitId, '' ) 			AS EyeReadableUnitId,
                    CASE dbo.vw_BloodShipAllCurrent.LabelTypeCode
						WHEN 'I' THEN dbo.vw_BloodShipAllCurrent.ProductShortName+', '+dbo.vw_BloodShipAllCurrent.UnitProductCode + dbo.vw_BloodShipAllCurrent.DonationTypeCode COLLATE SQL_Latin1_General_CP1_CS_AS + dbo.vw_BloodShipAllCurrent.UnitDivisionId 
						ELSE dbo.vw_BloodShipAllCurrent.ProductShortName+', '+dbo.vw_BloodShipAllCurrent.UnitProductCode
					END AS ProductShortName,
                    dbo.fnTimeZoneConversionDateTime( @divisioncode, 0, dbo.IssuedUnit.IssueDateTime ) 			AS IssueDateTime,
                    dbo.fnTimeZoneConversionDateTime( @divisioncode, 0, dbo.PatientTransfusion.TransfusionStartDateTime ) 	AS TransfusionStartDateTime,
                    dbo.fnTimeZoneConversionDateTime( @divisioncode, 0, dbo.PatientTransfusion.TransfusionEndDateTime ) 	AS TransfusionEndDateTime,
                    DATEDIFF( mi, dbo.IssuedUnit.IssueDateTime, dbo.PatientTransfusion.TransfusionStartDateTime ) 		AS DelayedTransfusionTime, --BR_105.04
                    DATEDIFF( mi, ISNULL( dbo.PatientTransfusion.TransfusionStartDateTime, dbo.IssuedUnit.IssueDateTime ), dbo.PatientTransfusion.TransfusionEndDateTime ) 	AS ProlongedTransfusionTime, -- BR_105.03
                    DATEDIFF( mi, dbo.IssuedUnit.IssueDateTime, dbo.PatientTransfusion.TransfusionEndDateTime ) 		AS TotalAdministrationTime, -- BR_105.06

                    dbo.ComponentClassParameter.MaximumTransfusionTime,
                    dbo.TreatingSpecialty.TreatingSpecialtyName
            FROM    
                    dbo.PatientTransfusion
            INNER JOIN	
                    dbo.Patient ON dbo.Patient.PatientGuid = dbo.PatientTransfusion.PatientGuid
            INNER JOIN	
                    dbo.IssuedUnit ON dbo.IssuedUnit.BloodUnitGuid = dbo.PatientTransfusion.BloodUnitGuid 
            	AND dbo.IssuedUnit.ReturnDateTime IS NULL
            INNER JOIN	
                    dbo.vw_BloodShipAllCurrent ON vw_BloodShipAllCurrent.BloodUnitGuid = PatientTransfusion.BloodUnitGuid
            INNER JOIN	
                    dbo.ComponentClassParameter ON dbo.ComponentClassParameter.ComponentClassId = dbo.vw_BloodShipAllCurrent.ComponentClassId 
                AND dbo.ComponentClassParameter.DivisionCode = @divisioncode
	    JOIN dbo.BloodUnitStatusCodeCurrent	BUSCC
			ON dbo.PatientTransfusion.BloodUnitGuid = BUSCC.BloodUnitGuid
            INNER JOIN	
                    dbo.OrderedUnit ON dbo.OrderedUnit.BloodUnitGuid = dbo.PatientTransfusion.BloodUnitGuid
            INNER JOIN
                    dbo.OrderedComponent ON dbo.OrderedComponent.OrderedComponentGuid = dbo.OrderedUnit.OrderedComponentGuid
            INNER JOIN 
                    dbo.PatientOrder ON dbo.PatientOrder.PatientOrderGuid = dbo.OrderedComponent.PatientOrderGuid
            INNER JOIN 
                    dbo.PatientTreatment ON dbo.PatientTreatment.PatientTreatmentGuid = dbo.PatientOrder.PatientTreatmentGuid
            LEFT OUTER JOIN 
                    dbo.TreatingSpecialty ON TreatingSpecialty.TreatingSpecialtyCode = dbo.PatientTreatment.TreatingSpecialtyCode
            WHERE	
    		    -- Presumed transfused should not be included in the report
                    NOT EXISTS	( SELECT TOP 1 1 
                                  FROM   dbo.BloodUnitStatus
                                  WHERE  dbo.BloodUnitStatus.BloodUnitGuid = dbo.vw_BloodShipAllCurrent.BloodUnitGuid 
                    	             AND dbo.BloodUnitStatus.PresumedTransfusedIndicator = 1 )
                    -- We're interested in transfused units only
                    AND BUSCC.UnitStatusCode = 'T' 
                    AND dbo.OrderedUnit.ReleaseDate IS NULL
                    AND dbo.PatientTransfusion.DivisionCode = @divisioncode
                    AND dbo.PatientTransfusion.RecordStatusCode = 'A'
                    -- We don't care about patient record status - patient can be dead by the time report is pulled
                    -- We also don't care about ComponentClassParameter record status since we need data at a time report is created
                    -- And... IssuedUnit doesn't have RecordStatusCode column!
                    AND dbo.IssuedUnit.IssueDateTime BETWEEN dbo.fnTimeZoneConversionDateTime( @divisioncode, 1, @startdate ) AND dbo.fnTimeZoneConversionDateTime( @divisioncode, 1, @enddate )
    ) AllUnitsTransfusedInSpecifiedTimeFrame
    WHERE		
    		DelayedTransfusionTime > @delayedtransfusiontimethresholdminutes -- BR_105.04
    	OR	ProlongedTransfusionTime > MaximumTransfusionTime -- BR_105.03;
GO

if exists (select * from dbo.sysobjects where id = object_id(N'dbo.batchspRunMarkUnitsPresumedTransfused') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure dbo.batchspRunMarkUnitsPresumedTransfused
GO
/*******************************************************************************************************************************************************************************
**	Desc: 	Background job that marks units as presumed transfused
**		if transfusion or bedside verification info was not returned
**		to the blood bank within 48 hours.
**		Based on BR_69.01
**
**	Author: Margaret Jablonski
**
**	Date: 	07/01/2004
**
*******************************************************************************************************************************************************************************
**	Modified:
**	Date		Name		Description
**	----------	------------	-----------------------------------------------------------------------------------------------------------------
**	08/27/04	M.Jablonski	Added UnitStatusCode = 'T to SET statement (per Krzys)
**	12/03/04	C. Taylor	Rewrote sproc to insert 'blank' PatientTransfusion record
**	02/08/2005	S. Antropov	Changed BACKGROUNDJOB user name to VBECS, removed commented out code. 
**	04/20/2005	D. McHugh	Added locking
**	04/21/2005	S. Antropov 	Minor variable renamings
**	06/03/2005	C. Taylor	Removed UnitStatusCode update
**	06/29/2005	NPaterson	** Reviewed for compliance with database standards and recommendations **
**					Comment Header Adjusted, Added NOCOUNT, Specified table owners, spaced out SQL,
**					Placed TRANSACTIONS in areas that do actual Inserts/Updates/Deletes and gave Transactions names to clarify
**	08/26/2005	N.Paterson	Added ,'',@divisionCode  to the end of the call to sp_DeleteLock as divisioncode is required.
**	12/06/2005	Lohse		Adding SessionGuid  parameter to spInsertlock call
**	01/22/2006	M Smith		** Reviewed for compliance with database standards and recommendations **
**	02/21/2006	Lohse		Adding default to the sessionguid
**	03/23/2006	Lohse		CR1741 - The PatientTransufion record should contain the Volume of the Unit being marked, adding code to save and load
**	01/04/2010	M. Smith	Checked UnitStatusCode on the BloodUnitStatusCodeCurrent table for issued units. (CR 1174)
**	01/21/2010	K. Adu-Poku	** Reviewed for compliance with database standards and recommendations **
*******************************************************************************************************************************************************************************/
CREATE PROCEDURE dbo.batchspRunMarkUnitsPresumedTransfused

AS

DECLARE 

	@bloodUnitStatusGuid 			UNIQUEIDENTIFIER,
	@bloodUnitGuid				UNIQUEIDENTIFIER,
	@divisionCode				CHAR(5),
	@issuedDateTime			DATETIME,
	@patientGuid				UNIQUEIDENTIFIER,
	@formInstanceGuid			UNIQUEIDENTIFIER,
	@lastError				INT,
	@presumedTransfusedOrderCount 	INT,
	@sessionguid				UNIQUEIDENTIFIER,
	@originalvolume				DECIMAL

	DECLARE @PresumedTransfusedOrders TABLE
			( 

			[Id] 			INT IDENTITY(1,1) NOT NULL PRIMARY KEY,
			BloodUnitStatusGuid 	UNIQUEIDENTIFIER,
			BloodUnitGuid 		UNIQUEIDENTIFIER,
			DivisionCode 		CHAR(5),
			IssueDateTime 		DATETIME,
			PatientGuid 		UNIQUEIDENTIFIER,
			OriginalVolume 		DECIMAL

			);	

	SET @formInstanceGuid = NEWID()
	SET @sessionguid = newid()

	INSERT INTO @PresumedTransfusedOrders
	(
			BloodUnitStatusGuid,
			BloodUnitGuid,
			DivisionCode,
			IssueDateTime,
			PatientGuid,
			OriginalVolume
	)	
	SELECT 
			BUS.BloodUnitStatusGuid,
			BU.BloodUnitGuid,
			BU.DivisionCode,
			IU.IssueDateTime,
			PT.PatientGuid,
			BU.OriginalVolume
	FROM	
			dbo.IssuedUnit IU

	JOIN 	dbo.BloodUnit BU ON IU.BloodUnitGuid = BU.BloodUnitGuid

	JOIN	dbo.BloodUnitStatus BUS ON BU.BloodUnitGUID = BUS.BloodUnitGUID

	JOIN	dbo.BloodUnitStatusCodeCurrent BUSCC ON BU.BloodUnitGUID = BUSCC.BloodUnitGUID

	JOIN	dbo.OrderedUnit OU ON IU.BloodUnitGUID = OU.BloodUnitGUID AND OU.ReleaseDate IS NULL AND OU.RecordStatusCode = 'A'

	JOIN	dbo.OrderedComponent OC ON OU.OrderedComponentGUID = OC.OrderedComponentGUID

	JOIN	dbo.PatientOrder PO ON OC.PatientOrderGUID = PO.PatientOrderGUID

	JOIN	dbo.PatientTreatment PT ON PO.PatientTreatmentGUID = PT.PatientTreatmentGUID

	WHERE
			BUSCC.UnitStatusCode = 'I' AND

			BU.RecordStatusCode NOT IN ('E', 'X') AND

			IU.ReturnDateTime IS NULL AND

			GETUTCDATE() > DATEADD(HOUR, 48, IU.IssueDateTime)

	ORDER BY BloodUnitStatusGuid;


	SELECT @lastError = @@ERROR, @presumedTransfusedOrderCount = @@ROWCOUNT

	IF @lastError <> 0 

			BEGIN 
	
				RETURN @lastError 
	
			END

	DECLARE @currentPresumedTransfusedOrderId INT;
	SET @currentPresumedTransfusedOrderId = 1;

/*===================>>>>  START OF WHILE LOOP <<<<===========================*/

	WHILE @currentPresumedTransfusedOrderId <= @presumedTransfusedOrderCount

	BEGIN


				
		SELECT	@bloodUnitStatusGuid = BloodUnitStatusGuid, 
				@bloodUnitGuid = BloodUnitGuid, 
				@divisionCode = DivisionCode, 
				@issuedDateTime = IssueDateTime, 
				@patientGuid = PatientGuid,
				@originalvolume = OriginalVolume

		FROM	@PresumedTransfusedOrders

		WHERE 	[Id] = @currentPresumedTransfusedOrderId;



		BEGIN TRANSACTION UpdBUS



		EXECUTE @lastError = dbo.spInsertLock @bloodUnitStatusGuid, @formInstanceGuid, 998, 'VBECS', 998, @divisionCode, @sessionguid

		SELECT @lastError = COALESCE(NULLIF(@lastError, 0), @@ERROR)
/*###########################################################################################################################*/	
		--If the record failed to get the lock, spInsertLock will return non-0
		IF @lastError = 0
/*###########################################################################################################################*/
			BEGIN
				
	
				UPDATE	
					dbo.BloodUnitStatus
				SET
					PresumedTransfusedIndicator = 1,
					LastUpdateDate = GETUTCDATE(),
					LastUpdateUser = 'VBECS',
					LastUpdateFunctionId = 998
				WHERE
					BloodUnitStatusGuid = @bloodUnitStatusGuid		
				
				SELECT @lastError = @@ERROR

					IF @lastError <> 0 
		
						BEGIN 
			
							ROLLBACK TRANSACTION  UpdBUS
							RETURN @lastError 
			
						END

	
				INSERT INTO

					dbo.PatientTransfusion
				(
					PatientTransfusionGuid,
					PatientGuid,
					BloodUnitGuid,
					TransfusionStartDateTime,
					TransfusionEndDateTime,
					ReactionIndicator,
					OtherDifficultyIndicator,
					TransfusedVolume,
					DivisionCode,
					LastUpdateDate,
					LastUpdateUser,
					LastUpdateFunctionId
				)
				VALUES
				(
					NEWID(),
					@patientGuid,
					@bloodUnitGuid,
					@issuedDateTime,
					@issuedDateTime,
					0,
					0,
					@originalvolume,
					@divisionCode,
					GETUTCDATE(),
					'VBECS',
					998
				)
	
				SELECT @lastError = @@ERROR 
				IF @lastError <> 0 
	
					BEGIN 
	
						ROLLBACK TRANSACTION UpdBUS
						RETURN @lastError 
	
					END
	
		
				EXECUTE @lastError = dbo.spDeleteLock @bloodUnitStatusGuid, @formInstanceGuid, 998, 'VBECS','',@divisionCode
	
				SELECT @lastError = COALESCE(NULLIF(@lastError, 0), @@ERROR)		
		
				IF @lastError <> 0 
	
					BEGIN 
	
						ROLLBACK TRANSACTION UpdBUS
						RETURN @lastError 
	
					END

				ELSE

				-- ALL OF OUR ACTIONS HAVE NOT RESULTED IN ANY ERRORS, COMMIT THE LOCK/UNLOCK, UPDATE/INSERT

					BEGIN
						COMMIT TRANSACTION  UpdBUS
					END
			END

/*###########################################################################################################################*/
	--An Error Occurred at INSERT LOCK:

		ELSE

/*###########################################################################################################################*/
			BEGIN
					ROLLBACK TRANSACTION UpdBUS
					RETURN @lastError 
			END

/*=========================>>>>  END  OF WHILE LOOP <<<<===========================*/

		SET @currentPresumedTransfusedOrderId = @currentPresumedTransfusedOrderId + 1;
	END	


RETURN(@lastError)
GO

if exists (select * from dbo.sysobjects where id = object_id(N'dbo.spGetAuditBloodUnitStatus') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure dbo.spGetAuditBloodUnitStatus
GO
/*******************************************************************************************************************************************************************************
**	Desc: 	Get the blood unit status audit information
**
**	Author: Krzysztof Dobranowski
**
**	Date:   03/05/2004
**
*******************************************************************************************************************************************************************************
**	Modified:
**	Date		Name			Description
**	--------------------	-----------------------	------------------------------------------------------------------------------------------------------------------------------------------------------------------------
**	04/27/2004	M. Jablonski		Call fnTimeZoneConversionDateTime function on all dates
**	07/13/2005	N.Paterson	** Reviewed for compliance with database standards and recommendations **
**					Removed Name/input/output from comment header, added SET NOCOUNT, formatted SQL
**					Changed date filter from => <= to using BETWEEN, placed input paramerters in brackets, error check input dates
**	08/18/2005	N.Paterson	Implemented differences between Review_Start and DEV before porting changes to DEV
**	01/04/2010	M. Smith	Changed to get UnitStatusCode from the V_BloodUnitStatusCodeCurrent view. (CR 1174)
**	01/27/2010	K. Adu-Poku	** Reviewed for compliance with database standards and recommendations **
*******************************************************************************************************************************************************************************/

CREATE PROCEDURE dbo.spGetAuditBloodUnitStatus
(
	@startdate 	DATETIME,
	@enddate	DATETIME,
	@divisioncode	CHAR(5)
)
 AS

/*	@ERROR VARIABLE  USED BECAUSE SET NOCOUNT OFF RESETS THE @@ERROR TO ZERO 	*/
DECLARE @ERROR INT

SET NOCOUNT ON
--Since all the dates are saved in UTC, start and end data has to be adjusted first for correct comparison
SET @startdate = dbo.fnTimeZoneConversionDateTime(@divisioncode, 1, @startdate)

SET @ERROR = @@ERROR
	IF @ERROR !=0 GOTO ERR_HANDLER

SET @enddate = dbo.fnTimeZoneConversionDateTime(@divisioncode, 1, @enddate)

SET @ERROR = @@ERROR
	IF @ERROR !=0 GOTO ERR_HANDLER

	SELECT
		BUS.BloodUnitGuid,
		BUS.MirrorId,

		dbo.fnTimeZoneConversionDateTime(@divisioncode, 0, BUS.LastUpdateDate) AS MirrorDate,

		BUS.LastUpdateUser,
		BUS.UnitStatusComments,
		BUSCC.UnitStatusCode,
		BUS.BiohazardousWarningIndicator,
		BUS.LastUpdateFunctionId,
		dbo.UnitStatus.UnitStatusText,
		dbo.BloodUnit.EyeReadableUnitID,
		dbo.BloodProduct.ProductName,
		dbo.BloodProduct.ProductCode

	FROM VBECS_V1_PROD_MIRROR.dbo.V_BloodUnitStatus BUS

	JOIN VBECS_V1_PROD_MIRROR.dbo.V_BloodUnitStatusCodeCurrent BUSCC
				ON BUS.BloodUnitGuid = BUSCC.BloodUnitGuid
				AND BUS.LastUpdateDate >= BUSCC.LastUpdateDate
				AND BUSCC.LastUpdateDate = (SELECT MAX(LastUpdateDate) FROM VBECS_V1_PROD_MIRROR.dbo.V_BloodUnitStatusCodeCurrent MBUSCC 
							     WHERE BUS.BloodUnitGuid = MBUSCC.BloodUnitGuid AND BUS.LastUpdateDate >= MBUSCC.LastUpdateDate)

	JOIN dbo.BloodUnit ON dbo.BloodUnit.BloodUnitGUID = BUS.BloodUnitGUID

	JOIN dbo.UnitStatus ON dbo.UnitStatus.UnitStatusCode = BUSCC.UnitStatusCode

	JOIN dbo.BloodProduct ON dbo.BloodProduct.BloodProductGuid = dbo.BloodUnit.BloodProductGuid

	WHERE	BUS.MirrorDate BETWEEN @startdate  AND  @enddate
	AND	dbo.BloodUnit.DivisionCode = @divisioncode

UNION
	SELECT
		BUS.BloodUnitGuid,
		BUS.MirrorId,

		dbo.fnTimeZoneConversionDateTime(@divisioncode, 0, BUSCC.LastUpdateDate) AS MirrorDate,

		BUSCC.LastUpdateUser,
		BUS.UnitStatusComments,
		BUSCC.UnitStatusCode,
		BUS.BiohazardousWarningIndicator,
		BUS.LastUpdateFunctionId,
		dbo.UnitStatus.UnitStatusText,
		dbo.BloodUnit.EyeReadableUnitID,
		dbo.BloodProduct.ProductName,
		dbo.BloodProduct.ProductCode

	FROM VBECS_V1_PROD_MIRROR.dbo.V_BloodUnitStatusCodeCurrent BUSCC

	JOIN VBECS_V1_PROD_MIRROR.dbo.V_BloodUnitStatus BUS
				ON BUSCC.BloodUnitGuid = BUS.BloodUnitGuid
				AND BUSCC.LastUpdateDate >= BUS.LastUpdateDate
				AND BUS.LastUpdateDate = (SELECT MAX(LastUpdateDate) FROM VBECS_V1_PROD_MIRROR.dbo.V_BloodUnitStatus MBUS
							     WHERE BUSCC.BloodUnitGuid = MBUS.BloodUnitGuid AND BUSCC.LastUpdateDate >= MBUS.LastUpdateDate)
		
	JOIN dbo.BloodUnit ON dbo.BloodUnit.BloodUnitGUID = BUSCC.BloodUnitGUID

	JOIN dbo.UnitStatus ON dbo.UnitStatus.UnitStatusCode = BUSCC.UnitStatusCode

	JOIN dbo.BloodProduct ON dbo.BloodProduct.BloodProductGuid = dbo.BloodUnit.BloodProductGuid

	WHERE	BUSCC.MirrorDate BETWEEN @startdate  AND  @enddate
	AND	dbo.BloodUnit.DivisionCode = @divisioncode

	ORDER BY

		BUS.BloodUnitGuid,
		MirrorDate DESC

SET @ERROR = @@ERROR
	IF @ERROR !=0 GOTO ERR_HANDLER

SET NOCOUNT OFF

RETURN (@ERROR)

ERR_HANDLER:

	SET NOCOUNT OFF
	RETURN(@ERROR)

GO

if exists (select * from dbo.sysobjects where id = object_id(N'dbo.spGetBloodUnitStatusByGuid') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure dbo.spGetBloodUnitStatusByGuid
GO
/*******************************************************************************************************************************************************************************
**
**	Desc:	Gets Blood Unit Status By Guid
**
**	Author:	John Vrooland
**
**	Date: 	03/13/2003
**
*******************************************************************************************************************************************************************************
**	Modified:
**	Date		Name			Description
**	---------		----			-----------
**	8/15/03	Carrie Van Stedum	Removed the select of the BUS recordstatuscode
**	10/02/2003	Greg Lohse	Removed the select of BUS.DivisionCode (where'd it go?)
**	10/17/2003	Greg Lohse	Removed the UnitStatusText -- not needed
**	04/05/2004	C. Jensen	Added PresumedTransfusedIndicator
**	04/27/2004	M. Jablonski	Call fnTimeZoneConversionDateTime function on all dates; Added divisioncode
**	06/09/2004	C. Taylor	PresumedTranfusedIndicator typo
**	01/19/2005	D. Askew	Changed to DiscardDetailCode DiscardCannedCommentGuid, QuarantineDetailCode
**					to QuarantineCannedCommentGuid
**	07/15/2005 	D. Askew	** Reviewed for compliance with database standards and recommendations **
**					NO COUNT set ON/OFF; comments updated
**	08/19/2005	N.Paterson	Implemented differences between Review_Start and DEV before porting changes to DEV
**	04/11/2006	Lohse		Adding TestingLimitIndicator (needed for UC2/UnitStatusCode) (CR1730)
**	01/04/2010	M. Smith	Changed to get UnitStatusCode from the BloodUnitStatusCodeCurrent table. (CR 1174)
**	01/21/2010	K. Adu-Poku	** Reviewed for compliance with database standards and recommendations **
*******************************************************************************************************************************************************************************/
CREATE PROCEDURE dbo.spGetBloodUnitStatusByGuid
(
    	@bloodunitguid		UNIQUEIDENTIFIER,
	@divisioncode		CHAR(5)
)

AS

DECLARE @ERROR INT

SET NOCOUNT ON

	SELECT 
		BUS.BloodUnitStatusGuid, 
		BUS.BloodUnitGuid, 
		BUSCC.UnitStatusCode,
		dbo.fnTimeZoneConversionDateTime(@divisioncode, 0, BUS.UnitStatusDate) AS UnitStatusDate, 
		BUS.UnitStatusComments, 
		BUS.DiscardCannedCommentGuid, 
		BUS.BiohazardousWarningIndicator, 
		BUS.QuarantineIndicator, 
		BUS.QuarantineCannedCommentGuid, 
		dbo.fnTimeZoneConversionDateTime(@divisioncode, 0, BUS.LastUpdateDate) AS LastUpdateDate, 
		BUS.LastUpdateUser, 
		BUS.PresumedTransfusedIndicator,
		BUS.EmergencyIssueIndicator,
		BUS.[RowVersion],
		@divisioncode AS DivisionCode,
		BUS.TestingLimitIndicator

	FROM	dbo.BloodUnitStatus BUS
		JOIN dbo.BloodUnitStatusCodeCurrent BUSCC
			ON BUS.BloodUnitGuid = BUSCC.BloodUnitGuid
	WHERE
		BUS.BloodUnitGuid = @bloodunitguid

SET @ERROR = @@ERROR

SET NOCOUNT OFF

RETURN(@ERROR)
GO

if exists (select * from dbo.sysobjects where id = object_id(N'dbo.spGetBloodUnitWrkLst') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure dbo.spGetBloodUnitWrkLst
GO
/*******************************************************************************************************************************************************************************
**	Desc: 	Gets Blood Unit data for a given product code and or unit id for the worklist builder control
**
**	Author: 	Carrie Van Stedum
**
**	Date: 	8/29/2002
**
*******************************************************************************************************************************************************************************
**	Modified:
**	Date		Name			Description
**	----------	-----------------------	------------------------------------------------------------------------------------------------------------------------------------------------------------------------
**	10/03/02	LMeyer			Added UnitCost, SpecialTestingCost, & ReturnCreditAmount
**	10/4/2002	LMeyer			Took out UnitCost, SpecialTestingCost, & ReturnCreditAmount
**	10/9/2002	LMeyer			Added RowVersion
**	10/10/2002	LMeyer/MSmith		Added DivisionCode to WHERE condition
**	12/2/2002	C Taylor		Added PatientSSN and TestingStatusCode and ProductShortName
**	12/10/2002	C Taylor		Added AssignedPatientLastName, AssignedPatientFirstName, AssignedPatientMiddleInitial, AssignedPatientSSN and SpecimenExpirationDate
**	12/18/2002	LMeyer			Added TestingStatusID/Deleted TestingStatusCode
**	1/2/2003	C Taylor		Added OriginalVolume and MaximumStorageTime
**	1/9/2003	C Taylor		Added Comments
**	1/16/2003	C Jensen		Added IncomingShipmentGUID
**	1/28/2003	C Jensen		Added UnitContainerLotNumber
**	1/31/2003	C Jensen		Added UnitDivisionID
**	10/14/2003	Greg Lohse		Removing NULL parm defaults and the logic to support them, reformatting, etc.
**	12/23/03	C Taylor		Replaced PatientMiddleInitial with PatientMiddleName
**	01/13/2004	C. Taylor		Added DisplayVistaPatientId
**	04/27/2004	M. Jablonski		Call fnTimeZoneConversionDateTime function on all dates
**	09/14/2004	C. Taylor	Added ShipmentDate, to be used instead of UnitInDate
**	12/03/2004	C. Taylor		Added PresumedTransfusedIndicator
**	01/20/2005	C. Jensen		Changed DiscardDetailCode to DiscardCannedCommentGuid
**	06/17/2005	Npaterson	Changed to use new view to increase performance
**	07/14/2005	N.Paterson	** Reviewed for compliance with database standards and recommendations **
**					Removed Name/input/output from comment header, added SET NOCOUNT, formatted SQL, specified object owners
**	11/22/05	C.VanStedum	Added product code
**	01/22/2006	M Smith		** Reviewed for compliance with database standards and recommendations **
**	01/04/2010	M. Smith	Changed to get UnitStatusCode from the BloodUnitStatusCodeCurrent table. (CR 1174)
**	01/21/2010	K. Adu-Poku	** Reviewed for compliance with database standards and recommendations **
*******************************************************************************************************************************************************************************/

CREATE PROCEDURE dbo.spGetBloodUnitWrkLst
(
	@unitid			VARCHAR(13),
	@productguid		UNIQUEIDENTIFIER,
	@divisioncode		VARCHAR(5),
	@unitproductcode	VARCHAR(8) = NULL
)
AS

SET NOCOUNT ON
	if(@unitproductcode is NULL) OR LEN(@unitproductcode) = 5
		BEGIN

			SELECT

				BU.BloodUnitGUID,
				EyeReadableUnitID,
				DirectedPatientGuid,
				UnitProductCode,
				RhFactorCode,

				dbo.fnTimeZoneConversionDateTime(@divisioncode, 0, UnitExpirationDate) 	AS  UnitExpirationDate,

				DonationTypeID,
				UnitContainerLotNumber,
				UnitDivisionID,
				BloodProductGUID,

				dbo.fnTimeZoneConversionDateTime(@divisioncode, 0, UnitInDate) 		AS  UnitInDate,

				DivisionCode,
				BloodTypeCode,
				UnitFdaRegistrationNumber,
				LabelUnitID,
				LabelTypeCode,
				ProductTypeCode,
				ProductName,
				ProductShortName,
				BUS.BiohazardousWarningIndicator,
				DonationTypeText,
				ProductTypeName, 
				RhFactorText,
				FacilityName,
				PatientFirstName,
				PatientMiddleName,
				PatientLastName,
				MaximumStorageTime,
				VistaPatientID,
				PatientSSN,
				DisplayVistaPatientId,
				BUS.UnitStatusComments,
				BUS.DiscardCannedCommentGuid,
				BUSCC.UnitStatusCode,
				UnitStatusText,
				BUS.QuarantineIndicator,
				TestingStatusId,
				OriginalVolume, 
				BU.[RowVersion],
				BUS.[RowVersion] 								AS UnitStatusRowVersion,
				Comments,
				IncomingShipmentGUID,
				BUS.BloodUnitStatusGUID,

				dbo.fnTimeZoneConversionDateTime(@divisioncode, 0, ShipmentDate) 		AS ShipmentDate,

				BU.PresumedTransfusedIndicator

			FROM

				dbo.vw_BloodShipPatientAllCurrent BU
					JOIN dbo.BloodUnitStatus BUS 
						ON BUS.BloodUnitGUID = BU.BloodUnitGUID
					JOIN dbo.BloodUnitStatusCodeCurrent BUSCC
						ON BU.BloodUnitGuid = BUSCC.BloodUnitGuid

			WHERE

				bloodproductguid = @productguid

			AND	DivisionCode =@divisioncode

			AND	(EyeReadableUnitID = @unitid OR  LabelUnitID = @unitid)
		END
	ELSE
		BEGIN

		SELECT

				BU.BloodUnitGUID,
				EyeReadableUnitID,
				DirectedPatientGuid,
				UnitProductCode,
				RhFactorCode,

				dbo.fnTimeZoneConversionDateTime(@divisioncode, 0, UnitExpirationDate) 	AS  UnitExpirationDate,

				DonationTypeID,
				UnitContainerLotNumber,
				UnitDivisionID,
				BloodProductGUID,

				dbo.fnTimeZoneConversionDateTime(@divisioncode, 0, UnitInDate) 		AS  UnitInDate,

				DivisionCode,
				BloodTypeCode,
				UnitFdaRegistrationNumber,
				LabelUnitID,
				LabelTypeCode,
				ProductTypeCode,
				ProductName,
				ProductShortName,
				BUS.BiohazardousWarningIndicator,
				DonationTypeText,
				ProductTypeName, 
				RhFactorText,
				FacilityName,
				PatientFirstName,
				PatientMiddleName,
				PatientLastName,
				MaximumStorageTime,
				VistaPatientID,
				PatientSSN,
				DisplayVistaPatientId,
				BUS.UnitStatusComments,
				BUS.DiscardCannedCommentGuid,
				BUSCC.UnitStatusCode,
				UnitStatusText,
				BUS.QuarantineIndicator,
				TestingStatusId,
				OriginalVolume, 
				BU.[RowVersion],
				BUS.[RowVersion] 								AS UnitStatusRowVersion,
				Comments,
				IncomingShipmentGUID,
				BUS.BloodUnitStatusGUID,

				dbo.fnTimeZoneConversionDateTime(@divisioncode, 0, ShipmentDate) 		AS ShipmentDate,

				BU.PresumedTransfusedIndicator

			FROM
				dbo.vw_BloodShipPatientAllCurrent BU
					JOIN dbo.BloodUnitStatus BUS 
						ON BUS.BloodUnitGUID = BU.BloodUnitGUID
					JOIN dbo.BloodUnitStatusCodeCurrent BUSCC
						ON BU.BloodUnitGuid = BUSCC.BloodUnitGuid
			WHERE

				bloodproductguid = @productguid
				
			AND	UnitProductCode = SUBSTRING(@unitproductcode, 1, 5)

			AND 	UnitDivisionID = SUBSTRING(@unitproductcode, 7, 2)

			AND 	DonationTypeCode = SUBSTRING(@unitproductcode, 6,1)
			AND	DivisionCode =@divisioncode

			AND	(EyeReadableUnitID = @unitid OR  LabelUnitID = @unitid)
		END

SET NOCOUNT OFF
GO

if exists (select * from dbo.sysobjects where id = object_id(N'dbo.spGetCrossmatchedUnitsInDateRange') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure dbo.spGetCrossmatchedUnitsInDateRange
GO
/*******************************************************************************************************************************************************************************
**
**	Desc:	Gets all units crossmatched to patients in a given division within a date range
**
**	Author:	Cameron Taylor
**
**	Date: 	08/04/2004
**
*******************************************************************************************************************************************************************************
**	Modified:
**	Date		Name		Description
**	-------------	---------	-----------------
**	07/17/2005 	D. Askew	** Reviewed for compliance with database standards and recommendations **
**					NO COUNT set OFF; comments updated; changed formatting slightly for readability
**	07/19/05	C Taylor		Added call to fnCrossmatchResultOrderedUnitGuid to ensure latest crossmatch result is 
**					used (there may be repeat XMs)
**	08/19/2005	N.Paterson	Implemented differences between Review_Start and DEV before porting changes to DEV, 
**					major changes, most Indicated by -->
**	09/09/2005	D. Askew	Changed JOIN on Patient to select either the FinalMergeToPatient if the patient has one or more
**					merges (choosing the final merge record) or simply the patient guid if there are none
**	01/17/2006	C. Taylor	Added FullProductCode (UnitProductCode, DonationTypeCode, UnitDivisionId) to ProductShortName (DR 1729)
**	01/22/2006	M Smith		** Reviewed for compliance with database standards and recommendations **
**	06/12/2008	K. Dobranowski	Modifed JOIN and WHERE clauses to make sure that units that were crossmatched and then subsequently 
**					released are counted in the report (CR 2434)
**	06/16/2008	M. Smith	** Reviewed for compliance with database standards and recommendations **
**					Removed multiple "OR" and used "IN" on CrossmatchResultCode check
**	01/04/2010	M. Smith	Changed to get UnitStatusCode from the BloodUnitStatusCodeCurrent table. (CR 1174)
**	01/22/2010	K. Adu-Poku	** Reviewed for compliance with database standards and recommendations **
*******************************************************************************************************************************************************************************/
CREATE PROCEDURE dbo.spGetCrossmatchedUnitsInDateRange
(
	@startdate			DATETIME,
	@enddate			DATETIME,
	@divisioncode			CHAR(5),
	@multidivisional			BIT = false
)

AS

SET NOCOUNT ON

	--Convert the start and end date to UTC 
	SET @startdate = dbo.fnTimeZoneConversionDateTime(@divisioncode, 1, @startdate) 
	SET @enddate = dbo.fnTimeZoneConversionDateTime(@divisioncode, 1, @enddate) 
	
	SELECT DISTINCT
		PT.PatientGuid,
		P.PatientLastName,
		P.PatientFirstName,
		P.PatientMiddleName,
		P.DisplayVistaPatientId,
		BU.BloodUnitGuid,
		BU.EyeReadableUnitId,
		BU.UnitProductCode,
		CASE BU.LabelTypeCode
			WHEN 'I' THEN BP.ProductShortName+', '+BU.UnitProductCode + DT.DonationTypeCode COLLATE SQL_Latin1_General_CP1_CS_AS + BU.UnitDivisionId 
			ELSE BP.ProductShortName+', '+BU.UnitProductCode
		END AS ProductShortName,
		BUSCC.UnitStatusCode,
		US.UnitStatusText,
		BUS.PresumedTransfusedIndicator,
		OU.DivisionCode,
		D.DivisionName,
--3>
		OU.OrderedUnitGuid,
		dbo.fnTimeZoneConversionDateTime(@divisioncode, 0, OU.CrossmatchDate) AS CrossmatchDate,
		OU.CrossmatchResultCode,

		CR.CrossmatchResultText,
		PO.PatientOrderGuid,
		PO.OrderingProviderId,
		PO.OrderingProviderLastName,
		PO.OrderingProviderFirstName,
		PO.OrderingProviderMiddleInitial,
		PT.PatientTreatmentGuid,
		PT.TreatingSpecialtyCode,
		TS.TreatingSpecialtyName,
		TS.SortColumn
		
	FROM 
		dbo.OrderedUnit OU

		JOIN dbo.OrderedComponent OC ON OC.OrderedComponentGUID = OU.OrderedComponentGUID

		JOIN dbo.PatientOrder PO ON OC.PatientOrderGUID = PO.PatientOrderGUID

		JOIN dbo.PatientTreatment PT ON PO.PatientTreatmentGUID = PT.PatientTreatmentGUID

		JOIN dbo.Patient LinkPatient ON PT.PatientGuid = LinkPatient.PatientGuid

		JOIN dbo.Patient P ON P.PatientGuid = COALESCE(LinkPatient.FinalMergeToPatient, LinkPatient.PatientGuid)

		JOIN dbo.BloodUnit BU ON OU.BloodUnitGUID = BU.BloodUnitGUID

		JOIN dbo.BloodProduct BP ON BU.BloodProductGuid = BP.BloodProductGuid

		JOIN dbo.DonationType DT ON DT.DonationTypeId = BU.DonationTypeId
		
		JOIN dbo.BloodUnitStatus BUS ON BU.BloodUnitGuid = BUS.BloodUnitGuid

		JOIN dbo.BloodUnitStatusCodeCurrent BUSCC ON BU.BloodUnitGuid = BUSCC.BloodUnitGuid

		JOIN dbo.UnitStatus US ON BUSCC.UnitStatusCode = US.UnitStatusCode

		LEFT JOIN dbo.TreatingSpecialty TS ON PT.TreatingSpecialtyCode = TS.TreatingSpecialtyCode

		JOIN dbo.CrossmatchResult CR ON OU.CrossmatchResultCode = CR.CrossmatchResultCode
		JOIN dbo.VamcDivision D ON OU.DivisionCode = D.DivisionCode
	
	WHERE 
		BU.RecordStatusCode = 'A'
		AND OU.RecordStatusCode = 'A'

	AND ((OU.DivisionCode = @divisioncode) OR (@multidivisional = 1))

	 	AND OU.CrossmatchDate BETWEEN @startdate AND @enddate
	AND 	OU.CrossmatchResultCode IN ('C', 'E', 'G')
	ORDER BY 

		  OU.DivisionCode , P.PatientLastName, P.PatientFirstName, P.PatientMiddleName, P.DisplayVistaPatientId, OU.CrossmatchDate, BU.EyeReadableUnitId
	

SET NOCOUNT OFF
GO

if exists (select * from dbo.sysobjects where id = object_id(N'dbo.spGetEmergencyIssuedUnitsCountForOrderedTest') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure dbo.spGetEmergencyIssuedUnitsCountForOrderedTest
GO
/*******************************************************************************************************************************************************************************
**	Desc:	Gets the number of issued units for specimen belonging to ordered test
**
**	Author:	Krzysztof Dobranowski
**
**	Date: 	01/18/2005
**
*********************************************************************************************************************************************************************************
**	Modified:
**	Date		Name		Description
**	----------	---------------	------------------------------------------------------------------------------------------------------------------------------------------------------------------------
**	06/29/2005	N.Paterson	** Reviewed for compliance with database standards and recommendations **
**					Comment Header Adjusted, Aliased tables, Added NOCOUNT, Specified table owners
**					Applied join to replace subquery per request of Mike Smith:  JOIN dbo.OrderedTest OT ON OT.PatientOrderGuid = PO.PatientOrderGuid
**	01/04/2010	M. Smith	Changed to check UnitStatusCode from the BloodUnitStatusCodeCurrent table. (CR 1174)
**	01/22/2010	K. Adu-Poku	** Reviewed for compliance with database standards and recommendations **
********************************************************************************************************************************************************************************/

CREATE PROCEDURE dbo.spGetEmergencyIssuedUnitsCountForOrderedTest
(
	@orderedtestguid	 UNIQUEIDENTIFIER 
)
AS

DECLARE @ERROR INT

SET @ERROR = 0

SET NOCOUNT ON
	SELECT 
		OU.BloodUnitGuid 
	FROM 
		dbo.OrderedUnit OU

	JOIN dbo.BloodUnitStatusCodeCurrent BUSCC ON BUSCC.BloodUnitGuid = OU.BloodUnitGuid

	JOIN dbo.OrderedComponent OC ON OC.OrderedComponentGuid = OU.OrderedComponentGuid

	JOIN dbo.PatientOrder PO ON PO.PatientOrderGuid = OC.PatientOrderGuid

	 JOIN dbo.OrderedTest OT ON OT.PatientOrderGuid = PO.PatientOrderGuid

		WHERE 
			BUSCC.UnitStatusCode IN ('I', 'T')

		AND
			(OT.OrderedTestGuid = @orderedtestguid)


SET @ERROR = @@ERROR

SET NOCOUNT OFF


RETURN(@ERROR)
GO

if exists (select * from dbo.sysobjects where id = object_id(N'dbo.spGetIncomingShipmentsList') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure dbo.spGetIncomingShipmentsList
GO
/*******************************************************************************************************************************************************************************
**	Desc:	Gets the list of incoming shipments for the date range
**
**	Author:	Krzysztof Dobranowski
**
**	Date: 	08/10/2004
**
*******************************************************************************************************************************************************************************
**	Modified:
**	Date		Name		Description
**	------------	--------	-----------------
**	10/11/2004	Carrie Van Stedum	Changed for the db design change of adding bloodunitshipment table
**	07/20/2005	N.Paterson	** Reviewed for compliance with database standards and recommendations **
**					Removed Name/input/output from comment header, added SET NOCOUNT, formatted SQL
**	11/18/2005	Lohse		Adding Shipment.RecordStatusCode check -- M = modifed unit -- ignore
**	01/19/2006	C Taylor	Added FullProductCode (UnitProductCode, DonationTypeCode, UnitDivisionId) to ProductShortName (CR 1462)
**	01/22/2006	M Smith		** Reviewed for compliance with database standards and recommendations **
**	01/27/2006	K. Dobranowski	Added time conversion for ShipmentDate (CR 1537)
**	02/11/2006	M Smith		** Reviewed for compliance with database standards and recommendations **
**	01/04/2010	M. Smith	Changed to get UnitStatusCode from the BloodUnitStatusCodeCurrent table. (CR 1174)
**	01/22/2010	K. Adu-Poku	** Reviewed for compliance with database standards and recommendations **
*******************************************************************************************************************************************************************************/
CREATE PROCEDURE dbo.spGetIncomingShipmentsList
(
	@startdate	DATETIME,
	@enddate	DATETIME,
	@divisioncode	VARCHAR(5)
)
AS

DECLARE @ERROR INT

SET NOCOUNT ON

	--Since all the dates are saved in UTC, start and end data has to be adjusted first for correct comparison
	SET @startdate = dbo.fnTimeZoneConversionDateTime(@divisioncode, 1, @startdate)

SET @ERROR = @@ERROR
	IF @ERROR !=0 GOTO SPROC_EXIT

	SET @enddate = dbo.fnTimeZoneConversionDateTime(@divisioncode, 1, @enddate)

SET @ERROR = @@ERROR
	IF @ERROR !=0 GOTO SPROC_EXIT

	SELECT

		S.ShipmentGuid,
		S.InvoiceNumber,
		dbo.fnTimeZoneConversionDateTime(@divisioncode, 0, S.ShipmentDate) AS ShipmentDate,
		BSHIP.BloodUnitGuid,
		LS.FacilityName,
		BU.EyeReadableUnitId,
		DT.DonationTypeText,
		BUM.BloodTypeCode,
		RH.RhFactorText,
		BUF.UnitCost,
		BUF.SpecialTestingCost,
		US.UnitStatusText,
		CASE BU.LabelTypeCode
			WHEN 'I' THEN BP.ProductShortName+', '+BU.UnitProductCode + DT.DonationTypeCode COLLATE SQL_Latin1_General_CP1_CS_AS + BU.UnitDivisionId 
			ELSE BP.ProductShortName+', '+BU.UnitProductCode
		END AS ProductShortName
			
	FROM
		dbo.Shipment S

		JOIN dbo.BloodUnitShipment BSHIP ON BSHIP.IncomingShipmentGuid = S.ShipmentGuid
		
		JOIN dbo.BloodUnit BU ON BSHIP.BloodUnitGuid = BU.BloodUnitGuid
		
		JOIN dbo.DonationType DT ON DT.DonationTypeId = BU.DonationTypeId
		
		JOIN dbo.BloodUnitMedia BUM ON BUM.BloodUnitGuid = BU.BloodUnitGuid
		
		JOIN dbo.BloodUnitFinance BUF ON BUF.BloodUnitGuid = BU.BloodUnitGuid
		
		JOIN dbo.BloodUnitStatusCodeCurrent BUSCC ON BUSCC.BloodUnitGuid = BU.BloodUnitGuid
		
		JOIN dbo.UnitStatus US ON US.UnitStatusCode = BUSCC.UnitStatusCode
		
		JOIN dbo.LocalSupplier LS ON LS.LocalSupplierGuid = S.LocalSupplierGuid
		
		JOIN dbo.BloodProduct BP ON BU.BloodProductGuid = BP.BloodProductGuid
		
		JOIN dbo.RhFactor RH  ON RH.RhFactorCode = BUM.RhFactorCode

	WHERE
		S.DivisionCode = @divisioncode

	AND	S.ShipmentDate >= @startdate

	AND	S.ShipmentDate <= @enddate

	AND	S.ShipmentDirection = 1

	AND	BSHIP.RecordStatusCode = 'A'
	AND	S.RecordStatusCode = 'A'

	ORDER BY ShipmentDate

SET @ERROR = @@ERROR
	
SPROC_EXIT:

	SET NOCOUNT OFF
	RETURN(@ERROR)
GO

if exists (select * from dbo.sysobjects where id = object_id(N'dbo.spGetOrderedUnitByComponent') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure dbo.spGetOrderedUnitByComponent
GO
/****************************************************************************************
**	Desc:	Gets all Ordered Units associated with an Ordered Component
**
**	Author:	Carl Jensen
**
**	Date: 	8/4/2003
*************************************************************************************************************************************************************************
**	Modified:
**	Date		Name		Description
**  	---------	-----------     -----------------------------------------------------
**	09-04-03    	JHV             Removed ReleaseReasonId
**	10/13/2003	C. Jensen	Added DivisionCode
**	04/23/2004	M. Jablonski	Call fnTimeZoneConversionDateTime function on all dates
**	06/14/2004	C. Jensen	Added additional check to make sure ReleaseDate is NULL
**	07/02/2004	C. Jensen	Added CrossmatchRequiredIndicator
**	01/21/2005	C. Jensen	Adding issued and transfused units so retro crossmatches can be done.
**	07/15/2005	N.Paterson	** Reviewed for compliance with database standards and recommendations **
					Removed Name/input/output from comment header, added SET NOCOUNT OFF, formatted SQL
					NOTE: .UnitStatusCode is hardcoded in WHERE clause, consider changing to subquery so if values
					change in table, code in proc does not have to be updated
**	08/19/2005	N.Paterson	Implemented differences between Review_Start and DEV before porting changes to DEV
**	01/03/2006	K. Dobranowski	Added UnitStatusCode to the selection
**	01/23/2006	M Smith		** Reviewed for compliance with database standards and recommendations **
**	07/05/2006	Lohse		Adding BloodUnitStatusGuid - CR2043 - for locking
**	01/04/2010	M. Smith	Changed to get UnitStatusCode from the BloodUnitStatusCodeCurrent table. (CR 1174)
**	01/22/2010	K. Adu-Poku	** Reviewed for compliance with database standards and recommendations **
*************************************************************************************************************************************************************************/
CREATE PROCEDURE dbo.spGetOrderedUnitByComponent
(
	@orderedcomponentguid	UNIQUEIDENTIFIER,
	@divisioncode 			CHAR(5)
)
AS
	SET NOCOUNT ON
		
    SELECT 

	PO.PatientOrderGUID,
	PT.PatientGUID,
	PT.PatientTreatmentGuid,
	PO.OrderGroupNumber,
	PO.OrderingProviderLastName,
	PO.OrderingProviderFirstName,
	PO.OrderingProviderMiddleInitial,
	PO.OrderEnteredByLastName,
	PO.OrderEnteredByFirstName,
	PO.OrderComments,
	PO.OrderingHospitalLocation,
	PO.SurgeryName,
	PO.InformedConsentIndicator,
	PO.RequestReason,

	dbo.fnTimeZoneConversionDateTime(@divisioncode, 0, PO.OrderReceivedDateTime) 	AS OrderReceivedDateTime,

        	OU.BloodUnitGUID, 

	OU.CrossmatchRequiredIndicator,

        	dbo.fnTimeZoneConversionDateTime(@divisioncode, 0, OU.CrossmatchDate) 		AS CrossmatchDate, 

        	OU.CrossmatchResultCode, 
	OU.CrossmatchTechID,
        	OU.DivisionCode, 
        	OU.RecordStatusCode, 

        	dbo.fnTimeZoneConversionDateTime(@divisioncode, 0, OU.LastUpdateDate) 		AS LastUpdateDate , 

        	OU.LastUpdateUser, 
        	OU.OrderedTestGUID, 
        	OU.OrderedComponentGUID, 
        	OU.OrderedUnitGUID, 

        	dbo.fnTimeZoneConversionDateTime(@divisioncode, 0, OU.SelectedDate) 			AS SelectedDate, 

        	dbo.fnTimeZoneConversionDateTime(@divisioncode, 0, OU.ReleaseDate) 			AS ReleaseDate, 

	OU.SelectedTechID,

	dbo.fnTimeZoneConversionDateTime(@divisioncode, 0, OU.SelectedDate) 			AS SelectedDate,	

       	OU. [RowVersion],
	
	OC.TaskStatusCode,
	OC.VbecsOrderNumber,
	OC.PatientSpecimenGUID,
	OC.SpecimenRequiredIndicator,
	OC.SpecimenStatusCode,
	OC.OrderedComponentGUID,
	OC.ComponentClassID,
	OC.CprsOrderNumber,
	OC.PreOpIndicator,
	OC.RequiredUnitQuantity	,
	OC.OrderUrgencyCode,

	dbo.fnTimeZoneConversionDateTime(@divisioncode, 0, OC.RequiredDateTime) 		AS RequiredDateTime,

	OC.OrderedComponentComments,
	OC.OrderSpecialInstructions,
	OC.OrderStatusCode,
	OC.SpecimenRequiredIndicator,
	OC.LabOrderNumber,
	OC.DivisionCode,
	BUSCC.UnitStatusCode,
	BUS.BloodUnitStatusGuid
	
    FROM 

	dbo.OrderedUnit OU

    	JOIN dbo.OrderedComponent OC 	ON	 OC.OrderedComponentGUID = OU.OrderedComponentGUID

    	JOIN dbo.PatientOrder PO 		ON	 OC.PatientOrderGUID = PO.PatientOrderGUID

    	JOIN dbo.PatientTreatment PT 		ON 	PO.PatientTreatmentGUID = PT.PatientTreatmentGUID

	JOIN dbo.BloodUnitStatus BUS		ON 	OU.BloodUnitGUID = BUS.BloodUnitGUID

	JOIN dbo.BloodUnitStatusCodeCurrent BUSCC ON 	OU.BloodUnitGuid = BUSCC.BloodUnitGuid

    WHERE 

	OU.OrderedComponentGUID = @orderedcomponentguid

	AND RecordStatusCode = 'A'

	AND OC.DivisionCode = @divisioncode

	AND BUSCC.UnitStatusCode IN ('S','C','I','T')

	AND OU.ReleaseDate IS NULL

SET NOCOUNT OFF
GO

if exists (select * from dbo.sysobjects where id = object_id(N'dbo.spGetOrderedUnitsForPatientSpecimen') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure dbo.spGetOrderedUnitsForPatientSpecimen
GO
/*****************************************************************************************************************
**
**	Desc:	Gets all Ordered Units associated with a Patient Specimen
**
**	Author:	Cameron taylor
**
**	Date: 	04/09/2004
**
******************************************************************************************************************
**	Modified:
**	Date		Name		Description
** 	---------		-----------     	-----------------------------------------------------
**	04/23/2004	M. Jablonski	Call fnTimeZoneConversionDateTime function on all dates; Added divisioncode
**	09/14/2004	C. Taylor	Added ShipmentDate, to be used instead of UnitInDate
**	10/14/2004	C. Taylor	Extended search to include Issued and Transfused status
**	12/03/2004	C. Taylor	Added PresumedTransfusedIndicator
**	06/17/2005	Npaterson	Changed to use new view to increase performance
**	07/22/2005	C. Taylor	Removed all fields except for OrderedUnitGuid to increase performance, as this is only 
**							used to count ordered units
**	07/20/2005	N.Paterson	** Reviewed for compliance with database standards and recommendations **
**							Removed Name/input/output from comment header, added SET NOCOUNT, formatted SQL, 
**							specified object owners
**	08/21/2005	s. Antropov	** Reviewed for compliance with database standards and recommendations **
**							Performed secondary review during the code promotion, updated header comment, 
**							formatted SQL, merged changes
**	01/04/2010	M. Smith	Changed to check UnitStatusCode from the BloodUnitStatusCodeCurrent table. (CR 1174)
**	01/22/2010	K. Adu-Poku	** Reviewed for compliance with database standards and recommendations **
******************************************************************************************************************/

CREATE  PROCEDURE dbo.spGetOrderedUnitsForPatientSpecimen
(
	@patientspecimenguid	UNIQUEIDENTIFIER,
	@divisioncode			CHAR(5)
)
AS

SET NOCOUNT ON
		
SELECT 
	OU.OrderedUnitGUID
FROM 
	dbo.OrderedUnit OU
JOIN
	dbo.OrderedComponent OC ON OC.OrderedComponentGUID = OU.OrderedComponentGUID
JOIN
	dbo.BloodUnitStatusCodeCurrent BUSCC ON OU.BloodUnitGuid = BUSCC.BloodUnitGuid
WHERE 
	OC.PatientSpecimenGUID = @patientspecimenguid 
AND
	OU.RecordStatusCode = 'A'
AND
	BUSCC.UnitStatusCode IN ('C','S','I','T')
AND
	OU.ReleaseDate IS NULL

SET NOCOUNT OFF
GO

if exists (select * from dbo.sysobjects where id = object_id(N'dbo.spGetOrderedUnitsForRepeatXM') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure dbo.spGetOrderedUnitsForRepeatXM
GO
/*******************************************************************************************************************************************************************************
**
**	Desc:	Gets a list of Ordered Units for Repeat Crossmatch test. Returns only units that are Crossmatched
**		If the parent order was a Component Order with XM, @orderedcomponentGUID should be passed as an input parameter.
**		If the parent order was a Repeat Crossmatch order,  @orderedtestGUID should be passed as an input parameter.
**
**	Author:	Margaret Jablonski
**
**	Date: 	07/09/2003
**
*******************************************************************************************************************************************************************************
**	Modified:
**	Date		Name		Description
**	----------	-------------	-------------------------------------------------------------------------------------------------------
**	02/26/2004	M.Jablonski	Added row version to SELECT
**	04/14/2004	C.taylor	Added RhFactorText since it is used in frmOrderSpecimenReflex.PopulateRepeatCrossmatchUnitsList()
**	04/23/2004	M.Jablonski	Call fnTimeZoneConversionDateTime function on all dates; Added divisioncode
**	07/20/2005	C.Taylor	Added SelectedTechId
**	07/20/2005	N.Paterson	** Reviewed for compliance with database standards and recommendations **
**							Removed Name/input/output from comment header, added SET NOCOUNT, formatted SQL
**	08/21/2005	s. Antropov	** Reviewed for compliance with database standards and recommendations **
**							Performed secondary review during the code promotion, updated header comment, 
**							added object owners, formatted SQL, merged changes
**	01/10/2006	C. Taylor	Added UnitProductCode, DonationTypeCode, UnitDivisionId and LabelTypeCode (DR 1729)
**	01/23/2006	M Smith		** Reviewed for compliance with database standards and recommendations **
**	01/04/2010	M. Smith	Changed to get UnitStatusCode from the BloodUnitStatusCodeCurrent table. (CR 1174)
**	01/25/2010	K. Adu-Poku	** Reviewed for compliance with database standards and recommendations **
*******************************************************************************************************************************************************************************/

CREATE PROCEDURE dbo.spGetOrderedUnitsForRepeatXM
(
	@orderedtestguid		UNIQUEIDENTIFIER = NULL,
	@orderedcomponentguid	UNIQUEIDENTIFIER = NULL,
	@divisioncode			CHAR(5)
)
AS
	SET NOCOUNT ON

	SELECT
		dbo.OrderedUnit.OrderedUnitGUID, 
		dbo.OrderedUnit.OrderedComponentGUID, 
		dbo.OrderedUnit.OrderedTestGUID, 
		dbo.OrderedUnit.BloodUnitGUID, 
		dbo.OrderedUnit.CrossmatchResultCode,
		dbo.OrderedUnit.[RowVersion],
		dbo.OrderedUnit.CrossmatchRequiredIndicator,
		dbo.BloodUnit.LabelUnitId,
		dbo.BloodUnit.EyeReadableUnitId, 
		dbo.BloodProduct.ProductShortName, 
		dbo.BloodUnitMedia.BloodTypeCode, 
		dbo.BloodUnitMedia.RhFactorCode,
		dbo.RhFactor.RhFactorText, 
		BUSCC.UnitStatusCode,
		dbo.fnTimeZoneConversionDateTime(@divisioncode, 0, dbo.BloodUnitMedia.UnitExpirationDate) AS UnitExpirationDate,
		dbo.fnTimeZoneConversionDateTime(@divisioncode, 0, dbo.OrderedUnit.SelectedDate) AS SelectedDate,
		dbo.OrderedUnit.SelectedTechId,
		dbo.BloodUnit.UnitProductCode,
		dbo.BloodUnit.UnitDivisionId,
		dbo.BloodUnit.LabelTypeCode,
		dbo.DonationType.DonationTypeCode
	FROM         
		dbo.OrderedUnit 
			JOIN dbo.BloodUnit 
				ON dbo.OrderedUnit.BloodUnitGUID = dbo.BloodUnit.BloodUnitGUID 
			JOIN dbo.BloodProduct 
				ON dbo.BloodUnit.BloodProductGUID = dbo.BloodProduct.BloodProductGUID 
			JOIN dbo.BloodUnitMedia 
				ON dbo.BloodUnit.BloodUnitGUID = dbo.BloodUnitMedia.BloodUnitGuid 
			JOIN dbo.RhFactor 
				ON dbo.BloodUnitMedia.RhFactorCode = dbo.RhFactor.RhFactorCode 
			JOIN dbo.BloodUnitStatusCodeCurrent BUSCC 
				ON BUSCC.BloodUnitGuid = dbo.OrderedUnit.BloodUnitGuid 
			JOIN dbo.DonationType 
				ON dbo.DonationType.DonationTypeId = dbo.BloodUnit.DonationTypeId
	WHERE
		(   
				(@orderedtestGUID IS NOT NULL AND dbo.OrderedUnit.OrderedTestGUID = @orderedtestguid)
			OR  (@orderedcomponentGUID IS NOT NULL AND dbo.OrderedUnit.OrderedComponentGUID = @orderedcomponentguid)
		)
		AND dbo.OrderedUnit.CrossmatchRequiredIndicator = 1 
		AND dbo.OrderedUnit.RecordStatusCode = 'A'
		AND dbo.OrderedUnit.ReleaseDate IS NULL
	ORDER BY
		dbo.OrderedUnit.SelectedDate ASC

	SET NOCOUNT OFF
GO

if exists (select * from dbo.sysobjects where id = object_id(N'dbo.spGetPatientAboRHHistory') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure dbo.spGetPatientAboRHHistory
GO

SET QUOTED_IDENTIFIER OFF
GO

/*******************************************************************************************************************************************************************************
**	Desc: 	Returns 	BloodUnitGUID, BloodTypeCode, RhFactorCode, LastUpdateDate
**
**	Author: 	Carl Jensen
**
**	Date: 	6/23/2003
**
*******************************************************************************************************************************************************************************
**	Modified:
** 	Date		Name		Description
**	-------------------	-----------------------	------------------------------------------------------------------------------------------------------------------------------------------------------------------------
**	11/24/2003	C. Jensen	Added RecordStatusCode to WHERE statement and LastUpdateDate to SELECT.
**	12/9/2003	C. Jensen	Added BloodTestTypeIDs 118 and 121
**	04/06/2004	K. Dobranowski	Added TestTechID, EntryTechID and SpecimenAccessionNumber
**	04/22/2004	M. Jablonski	Call fnTimeZoneConversionDateTime function on all dates; Added divisioncode
**	05/05/2004	C. Taylor	Replaced SpecimenAccessionNumber with Specimenuid
**	06/02/2004	C. Jensen	Added comments to test IDs
**	06/07/2004	C. Taylor	Replaced PatientGuid clause with fnWherePatientGuid function, to include possible merged patients
**	12/10/2004	C. Jensen	Added fnIsComplete to the WHERE clause so only complete ABO/Rh tests are returned.  Completed tests
**					have both the ABO and Rh intrepretation done.
**	05/09/2004	K. Dobranowski	Added sorting by BloodTestTypeId so the Abo results come first before Rh for any given date
**	06/02/2005	C. Jensen	Added PatientSpecimenGuid to select statement
**	07/06/2005	NPaterson	** Reviewed for compliance with database standards and recommendations **
**					Removed name,input/output description from comment header, added nocount, aliased tables, specified object owner
**					Capitalized and spaced SQL
**	07/25/2005	N.Paterson	Modified And/Or clause for BloodTestTypeID to use IN clause instead per MSmith
**	08/12/2005	C. Jensen	Added a clause to make sure TestResultId is not NULL
**	09/09/2005	D. Askew	Removed fnWherePatientGuid via sub-query using new PatientMergeGroup
**	01/29/2010	M. Smith	Removed extra joins and unnecessary patient merge logic.  (CR 2720) 
**	02/01/2010	K. Adu-Poku	** Reviewed for compliance with database standards and recommendations **
*******************************************************************************************************************************************************************************/
CREATE PROCEDURE dbo.spGetPatientAboRHHistory
(
		@patientguid 	UNIQUEIDENTIFIER,
		@divisioncode	CHAR(5)
)	

AS

DECLARE @ERROR INT

SET @ERROR = 0

SET NOCOUNT ON

	SELECT DISTINCT	

			ST.SpecimenTestGuid,
			ST.PatientSpecimenGuid,
			ST.BloodTestTypeID, 
			dbo.fnTimeZoneConversionDateTime(@divisioncode, 0, ST.TestDate) AS  TestDate, 
			ST.DivisionCode, 
			ST.TestResultID,
			dbo.fnTimeZoneConversionDateTime(@divisioncode, 0,  ST.LastUpdateDate) AS LastUpdateDate, 
			ST.TestTechID, 
			ST.EntryTechID, 
			ST.ABORhChangeIndicator,
			PS.Specimenuid,
			ST.RecordStatusCode

	FROM        	dbo.SpecimenTest  ST 
				LEFT JOIN dbo.PatientSpecimen PS 
					ON PS.PatientSpecimenGUID = ST.PatientSpecimenGUID

	WHERE	PS.PatientGUID = @patientguid

			/*====  BloodTestTypeID Value/Description: ==========
			18	=	ABO Interpretation
			65	=	ABO Interpretation TAS
			118	=	-ABO Interpretation Repeat
			21	=	Rh Interpretation
			68	=	Rh Interpretation TAS
			121	=	Rh Interpretation Repeat
			=============================================*/
			AND (ST.BloodTestTypeID IN (18,65,118,21,68,121) )	
			AND ST.RecordStatusCode = 'A'
			AND dbo.fnIsABORhTestComplete(ST.OrderedTestGuid, ST.BloodTestTypeID) IS NOT NULL
			AND ST.TestResultId IS NOT NULL

			ORDER BY  ST.TestDate DESC, ST.BloodTestTypeID

SET @ERROR = @@ERROR

SET NOCOUNT OFF

RETURN (@ERROR)
GO
SET QUOTED_IDENTIFIER ON
GO

if exists (select * from dbo.sysobjects where id = object_id(N'dbo.spGetPatientComponentOrdersAll') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure dbo.spGetPatientComponentOrdersAll
GO
SET QUOTED_IDENTIFIER OFF
GO
/*******************************************************************************************************************************************************************************
**	Desc: 	Selects blood units for an invoice
**
**	Author: 	Carl Jensen
**
**	Date: 	5/29/2003
**
*******************************************************************************************************************************************************************************
**	Modified:
** 	Date		Name		Description
**	-------------------	-----------------------	------------------------------------------------------------------------------------------------------------------------------------------------------------------------
**	1/8/04		C Taylor		Added DisplayVistaPatientId & PatientMiddleName
**	03/02/2004	M.Jablonski	Added row version to SELECT
**	04/23/2004	M. Jablonski	Call fnTimeZoneConversionDateTime function on all dates
**	05/02/2004	C.Jensen	Added LabOrderNumber for new Specimen functionality
**	05/05/2004	C. Taylor	Replaced SpecimenAccessionNumber with Specimenuid
**	06/08/2004	C. Taylor	Replaced PatientGuid join with function fnGetPatientGuid to ensure latest patient details returned
**	06/23/2004	C. Jensen	Added LabTestId
**	12/13/2004	S. Antropov	Optimized the query by calling function only for patients requiring merge
**	12/28/2004	C. Jensen	Added JOIN to TreatingSpecialty
**	07/06/2005	NPaterson	** Reviewed for compliance with database standards and recommendations **
**					Removed name,input/output from comment header, added nocount, specified object owners, 
**					added space to SQL
**	09/09/2005	D. Askew	Changed JOIN on Patient to select either the FinalMergeToPatient if the patient has one or more
**					merges (choosing the final merge record) or simply the patient guid if there are none
**	12/15/2005	C. Taylor	Added additional sort elements (DR 1727)
**	01/04/2005	C. Jensen	Added RequiredDateTime to sort elements (DR 1727).
**	01/11/2006	C. Taylor	Removed ImmediateTransfusionIndicator
**	01/23/2006	M Smith		** Reviewed for compliance with database standards and recommendations **
**	01/29/2010	M. Smith	Added code to filter the data before it is returned to the screen (CR2720)
**	02/01/2010	K. Adu-Poku	** Reviewed for compliance with database standards and recommendations **
*******************************************************************************************************************************************************************************/

CREATE PROCEDURE dbo.spGetPatientComponentOrdersAll

		@divisioncode CHAR(5)

AS

DECLARE @ERROR INT

SET @ERROR = 0
		
SET NOCOUNT ON

	SELECT	PO.PatientOrderGUID,
			PO.OrderGroupNumber,
			OC.LabOrderNumber,
			PO.OrderingProviderLastName,
			PO.OrderingProviderFirstName,
			PO.OrderEnteredByLastName,
			PO.OrderEnteredByFirstName,
			PO.OrderComments,
			PO.OrderingHospitalLocation,
			PO.SurgeryName,
			PO.InformedConsentIndicator,
			PO.RequestReason,
			dbo.fnTimeZoneConversionDateTime(@divisioncode, 0, PO.OrderReceivedDateTime) AS OrderReceivedDateTime,
			P.PatientSSN,
			P.DisplayVistaPatientId,
			P.BloodTypeCode,
			P.RhFactorCode	,
			P.PatientLastName,
			P.PatientFirstName,
			P.PatientMiddleName,
			PT.PatientGUID,
			PT.PatientTreatingFacility,
			PT.PatientAdmittingDiagnosis,
			PT.PatientRoomBed,
			PT.PatientLocation,
			TS.TreatingSpecialtyName,
			P.PatientServiceBranch,
			P.VistaPatientID,
			OC.VbecsOrderNumber,
			OC.PatientSpecimenGUID,
			OC.SpecimenRequiredIndicator,
			OC.SpecimenStatusCode,
			OC.OrderedComponentGUID,
			OC.ComponentClassID,
			OC.CprsOrderNumber,
			OC.PreOpIndicator,
			OC.RequiredUnitQuantity	,
			OC.OrderUrgencyCode,
			dbo.fnTimeZoneConversionDateTime(@divisioncode, 0, OC.RequiredDateTime) AS RequiredDateTime,
			OC.OrderedComponentComments,
			OC.OrderSpecialInstructions,
			OC.OrderStatusCode,
			OC.DivisionCode,
			OC.LabOrderNumber,
			OC.LabTestId,
			CC.ComponentClassShortName,
			CC.ComponentClassName,
			OU.OrderUrgencyText,
			SS.SpecimenStatusCode,
			SS.SpecimenStatusText,
			OS.OrderStatusText,
			PS.Specimenuid,
			OC.[RowVersion],
			OU.SortColumn as UrgencySortColumn,
			CC.SortColumn as RequestSortColumn,
			OC.ImmediateTransfusionIndicator
	FROM 
		dbo.PatientOrder PO

		JOIN dbo.OrderedComponent OC 	ON PO.PatientOrderGUID = OC.PatientOrderGUID


		LEFT OUTER JOIN dbo.SpecimenStatus SS	ON OC.SpecimenStatusCode = SS.SpecimenStatusCode

		JOIN dbo.OrderUrgency OU 		ON OC.OrderUrgencyCode = OU.OrderUrgencyCode

		JOIN dbo.OrderStatus OS		ON OC.OrderStatusCode = OS.OrderStatusCode

		JOIN dbo.PatientTreatment PT 	ON PO.PatientTreatmentGUID = PT.PatientTreatmentGUID

		LEFT OUTER JOIN dbo.TreatingSpecialty TS ON PT.TreatingSpecialtyCode = TS.TreatingSpecialtyCode
	
		JOIN dbo.Patient LinkPatient ON PT.PatientGuid = LinkPatient.PatientGuid
		JOIN dbo.Patient P ON P.PatientGuid = COALESCE(LinkPatient.FinalMergeToPatient, LinkPatient.PatientGuid)

		JOIN ComponentClass CC 	ON OC.ComponentClassID = CC.ComponentClassID

		LEFT OUTER JOIN PatientSpecimen PS ON OC.PatientSpecimenGUID = PS.PatientSpecimenGUID
	
		WHERE OC.DivisionCode =  @DivisionCode
		AND PO.PatientOrderGuid IN (SELECT PatientOrderGuid 
						  FROM dbo.OrderedComponent
 						 WHERE OrderStatusCode = 'P')
	
		ORDER BY UrgencySortColumn,RequestSortColumn,RequiredDateTime

SET @ERROR = @@ERROR

SET NOCOUNT OFF

RETURN (@ERROR)
GO
SET QUOTED_IDENTIFIER ON
GO

if exists (select * from dbo.sysobjects where id = object_id(N'dbo.spGetPatientTestOrdersAll') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure dbo.spGetPatientTestOrdersAll
GO
/*******************************************************************************************************************************************************************************
**	Desc: 	Gets ordered tests
**
**	Author: 	Carl Jensen
**
**	Date: 	5/29/2003
**
*******************************************************************************************************************************************************************************
**	Modified:
** 	Date		Name		Description
**	-------------------	-----------------------	------------------------------------------------------------------------------------------------------------------------------------------------------------------------
**	8/13/2003	C. Jensen	Added DivisionCode
**	12/30/2003	C. Jensen	Fixed  JOINs to Patient and PatientTreatment
**	1/8/04		C Taylor	Added DisplayVistaPatientId and Patient MiddleName
**	04/22/2004	M. Jablonski	Call fnTimeZoneConversionDateTime function on all dates
**	05/02/2004	C.Jensen	Added LabOrderNumber for new Specimen functionality
**	05/05/2004	C. Taylor	Replaced SpecimenAccessionNumber with Specimenuid
**	06/15/2004	C. Taylor	Replaced PatientGuid join with function fnGetPatientGuid to ensure latest patient details returned
**	06/23/2004	C. Jensen	Added LabTestId
**	12/13/2004	S. Antropov	Optimized the query by calling function only for patients requiring merge
**	12/28/2004	C. Jensen	Added JOIN to TreatingSpecialty
**	07/06/2005	NPaterson	** Reviewed for compliance with database standards and recommendations **
**					Removed name, input/output from comment header, Added NOCOUNT, Specified table owners, 
**					spaced out SQL Enclosed rowversion in square brackets, removed unused code comments
**	09/09/2005	D. Askew	Changed JOIN on Patient to select either the FinalMergeToPatient if the patient has one or more
**					merges (choosing the final merge record) or simply the patient guid if there are none
**	12/15/2005	C. Taylor	Added additional sort elements (DR 1727)
**	01/04/2005	C. Jensen	Added RequredResultsDate (DR 1727).
**	01/18/2006	C. Taylor	Removed PreSpecimenUid & PreSpecimenGuid (DR1462)
**	01/23/2006	M Smith		** Reviewed for compliance with database standards and recommendations **
**	01/29/2010	M. Smith	Added code to filter the data before it is returned to the screen (CR2720)
**	02/01/2010	K. Adu-Poku	** Reviewed for compliance with database standards and recommendations **
*******************************************************************************************************************************************************************************/

CREATE PROCEDURE dbo.spGetPatientTestOrdersAll
		
	@divisioncode char(5)

AS

DECLARE @ERROR INT

SET @ERROR = 0

SET NOCOUNT ON

	SELECT   	PO.PatientOrderGUID,
			PT.PatientGUID,
			PO.OrderGroupNumber,
			PO.OrderingProviderLastName,
			PO.OrderingProviderFirstName,
			PO.OrderEnteredByLastName,
			PO.OrderEnteredByFirstName,
			PO.OrderComments,
			PO.OrderingHospitalLocation,
			PO.SurgeryName,
			PO.InformedConsentIndicator,
			PO.RequestReason,

			dbo.fnTimeZoneConversionDateTime(@divisioncode, 0, PO.OrderReceivedDateTime) AS OrderReceivedDateTime,

			P.DisplayVistaPatientId,
			P.PatientSSN,
			P.BloodTypeCode,
			P.RhFactorCode	,
			P.PatientLastName,
			P.PatientFirstName,
			P.PatientMiddleName,
			PT.PatientTreatingFacility,
			PT.PatientRoomBed,
			PT.PatientAdmittingDiagnosis,
			PT.PatientLocation,
			TS.TreatingSpecialtyName,
			P.PatientServiceBranch,
			P.VistaPatientID,
			OT.VbecsOrderNumber,
			OT.PatientSpecimenGUID,
			OT.OrderedTestGUID,
			OT.CprsOrderNumber,
			OT.OrderUrgencyCode,
			OT.OrderedTestComments,

			dbo.fnTimeZoneConversionDateTime(@divisioncode, 0, OT.RequiredResultsDate) AS RequiredResultsDate,

			OT.OrderStatusCode,
			OT.OrderableTestID,
			OT.TestInterpretationComments,
			OT.SpecimenRequiredIndicator,
			OT.DivisionCode,
			OT.LabOrderNumber,
			OT.LabTestId,
			OT.[RowVersion],
			PS.Specimenuid,
			OU.OrderUrgencyText,
			OS.OrderStatusText,

			OTE.OrderableTestName,
			OU.SortColumn as UrgencySortColumn,
			OTE.SortColumn as RequestSortColumn
	
	
	FROM dbo.PatientOrder PO
	
	JOIN dbo.OrderedTest OT 			ON PO.PatientOrderGUID = OT.PatientOrderGUID

	JOIN dbo.OrderUrgency OU 			ON OT.OrderUrgencyCode = OU.OrderUrgencyCode

	LEFT JOIN dbo.OrderStatus OS			ON OT.OrderStatusCode = OS.OrderStatusCode

	JOIN dbo.OrderableTest OTE			ON OT.OrderableTestID = OTE.OrderableTestID
	
	LEFT OUTER JOIN dbo.PatientSpecimen PS 	ON OT.PatientSpecimenGUID = PS.PatientSpecimenGUID

	JOIN dbo.PatientTreatment PT 			ON PO.PatientTreatmentGUID = PT.PatientTreatmentGUID

	LEFT OUTER JOIN dbo.TreatingSpecialty TS 	ON PT.TreatingSpecialtyCode = TS.TreatingSpecialtyCode
	
	JOIN dbo.Patient LinkPatient 			ON PT.PatientGuid = LinkPatient.PatientGuid
	JOIN dbo.Patient P 				ON P.PatientGuid = COALESCE(LinkPatient.FinalMergeToPatient, LinkPatient.PatientGuid)
	

		WHERE OT.DivisionCode = @DivisionCode
		  AND PO.PatientOrderGuid IN (SELECT PatientOrderGuid 
						  FROM OrderedTest
 						 WHERE OrderStatusCode = 'P')


		ORDER BY UrgencySortColumn,RequestSortColumn,RequiredResultsDate

SET @ERROR = @@ERROR

SET NOCOUNT OFF

RETURN (@ERROR)
GO

if exists (select * from dbo.sysobjects where id = object_id(N'dbo.spGetPreviousUnitStatus') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure dbo.spGetPreviousUnitStatus
GO
/*******************************************************************************************************************************************************************************
**	Desc: 	Return the previous status of a unit based on TT_27.01
**
**	Author: Cameron Taylor
**
**	Date: 	02/09/2004
**
*******************************************************************************************************************************************************************************
**	Modified:
**	Date		Name			Description
**	----------	---------------	------------------------------------------------------------------------------------------------------------------------------------------------------------------------
**	07/07/2005	NPaterson	** Reviewed for compliance with database standards and recommendations **
**					Removed name, input/output from comment header, Added NOCOUNT OFF, Specified table owners, spaced out SQL
**	01/04/2010	M. Smith	Changed to get the previous UnitStatusCode from the mirror BloodUnitStatusCodeCurrent table.  This 
**					also is ignoring final status for the blood unit.(CR 1174)
**	01/26/2010	K. Adu-Poku	** Reviewed for compliance with database standards and recommendations **
*******************************************************************************************************************************************************************************/
CREATE PROCEDURE dbo.spGetPreviousUnitStatus
(
	@bloodunitguid		UNIQUEIDENTIFIER
)

AS

DECLARE @ERROR INT

SET @ERROR = 0

SET NOCOUNT ON

	SELECT 	TOP 1
			BUSCC.UnitStatusCode,
			UnitStatusText

	FROM 	VBECS_V1_PROD_MIRROR.dbo.V_BloodUnitStatusCodeCurrent BUSCC
			JOIN dbo.UnitStatus US
				ON BUSCC.UnitStatusCode = US.UnitStatusCode

	WHERE	BloodUnitGuid = @bloodunitguid
	  AND 	BUSCC.UnitStatusCode NOT IN ('D', 'M', 'T', 'X')
	ORDER BY MirrorId DESC

SET @ERROR = @@ERROR

SET NOCOUNT OFF

RETURN(@ERROR)
GO

if exists (select * from dbo.sysobjects where id = object_id(N'dbo.spGetReportBloodUnitHistorySummary') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure dbo.spGetReportBloodUnitHistorySummary
GO
/*******************************************************************************************************************************************************************************
**	Desc: Returns status and testing results for a blood unit
**
**	Author:	David Askew
**
**	Date: 	08/17/2004
*******************************************************************************************************************************************************************************
**	Modified:
**	Date		Name		Description
**	-------------------	-----------------------	------------------------------------------------------------------------------------------------------------------------------------------------------------------------
**	01/26/05	D. Askew	Added QuarantineIndicator and PresumedTransfusedIndicator to select
**	03/15/05	Lohse		Adding BiohazardousWarningIndicator
**	05/31/2005	D. Askew	Added query to get current antigen info; removed modification info (split into separate procedures)
**	07/07/2005	NPaterson	** Reviewed for compliance with database standards and recommendations **
**					Removed name, input/output from comment header, Added NOCOUNT OFF, Specified table owners, 
**					spaced out SQL
**	09/11/2005	D. Askew	Added DiscardDate to Select, changed JOIN SQL to be more readable
**	10/27/2005	D. Askew	Added space to separate patient first and middle names; added '.' to end of middle initals
**	01/23/2006	M Smith		** Reviewed for compliance with database standards and recommendations **
**	01/24/2006	D. Askew	Added LastUpdateDate; changed formatting for readability
**	06/09/2008	K. Dobranowski Removed period ('.') from the end of the middle name (CR 2652)
**	06/25/2006	M. Smith	** Reviewed for compliance with database standards and recommendations **
**	01/04/2010	M. Smith	Changed to get UnitStatusCode from the BloodUnitStatusCodeCurrent table. (CR 1174)
**	01/26/2010	K. Adu-Poku	** Reviewed for compliance with database standards and recommendations **
*******************************************************************************************************************************************************************************/
CREATE PROCEDURE dbo.spGetReportBloodUnitHistorySummary
(
	@bloodunitguid	UNIQUEIDENTIFIER,
	@divisioncode	VARCHAR(5)
)
AS
	
DECLARE @ERROR INT

SET @ERROR = 0

SET NOCOUNT ON

	SELECT DISTINCT
		BU.EyeReadableUnitId,
		-- ********************************************************************************************************************************************************************************************************************************************************
		CASE BU.LabelTypeCode
			WHEN 'I' THEN 
				BU.UnitProductCode + DT.DonationTypeCode COLLATE SQL_Latin1_General_CP1_CS_AS + BU.UnitDivisionId 
			ELSE 
				BU.UnitProductCode
			END 																AS UnitProductCode,
		-- ********************************************************************************************************************************************************************************************************************************************************
		BP.ProductName,
		DT.DonationTypeText,
		dbo.fnTimeZoneConversionDateTime(@divisioncode, 0, BUM.UnitExpirationDate) 								AS UnitExpirationDate,
		-- ********************************************************************************************************************************************************************************************************************************************************
		P.PatientLastName + ', ' +  P.PatientFirstName + (
			CASE WHEN P.PatientMiddleName IS NULL THEN 
				'' 
			ELSE (' ' + P.PatientMiddleName)

			END) 																AS RestrictedFor,
		-- ********************************************************************************************************************************************************************************************************************************************************
		CASE WHEN US.UnitStatusCode = 'D' THEN
			dbo.fnTimeZoneConversionDateTime
			(
				@divisioncode, 0, BUSCC.LastUpdateDate
			)
		ELSE NULL END 															AS DiscardDate,
		-- ********************************************************************************************************************************************************************************************************************************************************
		US.UnitStatusText,
		ISNULL(BUS.QuarantineIndicator, 0) 													AS QuarantineIndicator,
		ISNULL(BUS.BiohazardousWarningIndicator, 0) 												AS BiohazardousWarningIndicator,
		ISNULL(BUS.PresumedTransfusedIndicator, 0) 												AS PresumedTransfusedIndicator,
		BT.BloodTypeCode + ' ' + RH.RhFactorText 												AS AboRh,
		BU.RecordStatusCode,
		dbo.fnTimeZoneConversionDateTime(@divisioncode, 0, BU.LastUpdateDate) 								AS LastUpdateDate

	FROM
		dbo.BloodUnit BU

		LEFT OUTER JOIN dbo.BloodUnitMedia BUM 
		
			ON BU.BloodUnitGuid = BUM.BloodUnitGuid
		
		LEFT OUTER JOIN dbo.BloodType BT 
		
			ON BUM.BloodTypeCode = BT.BloodTypeCode
		
		LEFT OUTER JOIN dbo.RhFactor RH 
		
			ON BUM.RhFactorCode = RH.RhFactorCode
		
		LEFT OUTER JOIN dbo.BloodProduct BP 
		
			ON BU.BloodProductGuid = BP.BloodProductGuid
		
		LEFT OUTER JOIN dbo.BloodUnitStatus BUS 

			ON BU.BloodUnitGuid = BUS.BloodUnitGuid

		LEFT JOIN dbo.BloodUnitStatusCodeCurrent BUSCC
			ON BU.BloodUnitGuid = BUSCC.BloodUnitGuid
		
		LEFT OUTER JOIN dbo.UnitStatus US 
		
			ON BUSCC.UnitStatusCode = US.UnitStatusCode
		
		LEFT OUTER JOIN dbo.DonationType DT 
		
			ON BU.DonationTypeId = DT.DonationTypeId
		
		LEFT OUTER JOIN dbo.Patient P 
		
			ON BUM.DirectedPatientGuid = P.PatientGuid

	WHERE 	
		BU.BloodUnitGuid = @bloodunitguid
		AND BU.DivisionCode = @divisioncode

	SET @ERROR = @@ERROR
	IF @ERROR != 0 GOTO ERR_HANDLER

	-- ********************************************************************************************************************************************************************************************************************************************************
	-- Get Current Antigens (From use cases 1, 41 and/or 70)
	--
	SELECT DISTINCT
		(
			CASE 	WHEN BUA.Positive = 1 THEN 
					'Pos'
				WHEN BUA.Positive = 0 THEN 
					'Neg'
				ELSE 
					'' 
				END
		) 							AS Positive,

		ANT.AntigenTypeName 					AS Antigen

	FROM
		dbo.BloodUnit BU

		JOIN dbo.BloodUnitAntigen BUA
			ON BU.BloodUnitGuid = BUA.BloodUnitGuid

		JOIN dbo.AntigenType ANT
			ON ANT.AntigenTypeId = BUA.AntigenTypeId

	WHERE 	
		BU.BloodUnitGuid = @bloodunitguid
		AND BU.DivisionCode = @divisioncode
		AND BUA.RecordStatusCode = 'A'

/*============================== U N I O N =========================================================*/

					UNION

	SELECT DISTINCT
		TR.TestResultText COLLATE SQL_Latin1_General_CP1_CS_AS AS Positive,
		ANT.AntigenTypeName AS Antigen

	FROM
		dbo.BloodUnit BU

		JOIN dbo.BloodUnitTest BUT
			ON BU.BloodUnitGuid = BUT.BloodUnitGuid
	
		JOIN dbo.AntigenTest ANTEST
			ON BUT.BloodTestTypeId = ANTEST.BloodTestTypeId
		
		JOIN dbo.AntigenType ANT
			ON ANTEST.AntigenTypeId = ANT.AntigenTypeId
		
		JOIN dbo.BloodTestType BTT
			ON BUT.BloodTestTypeId = BTT.BloodTestTypeId
		
		JOIN dbo.TestResult TR
			ON BUT.TestResultId = TR.TestResultId

	WHERE 	
		BU.BloodUnitGuid = @bloodunitguid
		AND BU.DivisionCode = @divisioncode
		AND BUT.RecordStatusCode = 'A'

	SET @ERROR = @@ERROR
	IF @ERROR != 0 GOTO ERR_HANDLER

SET NOCOUNT OFF

RETURN(@ERROR)

ERR_HANDLER:

	SET NOCOUNT OFF

	RETURN(@ERROR)
GO

if exists (select * from dbo.sysobjects where id = object_id(N'dbo.spGetShipmentsWithAvailableUnitsFromPastFiveDays') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure dbo.spGetShipmentsWithAvailableUnitsFromPastFiveDays
GO
/*******************************************************************************************************************************************************************************
**
**	Desc: 	Selects shipments that were received within the last 5 days.
**
**	Author: 	Carl Jensen
**
**	Date: 	11/14/2002
**
*******************************************************************************************************************************************************************************
**	Modified:
** 	Date		Name		Description
**	9/17/03	    C Taylor	Changed sort order to Shipment Date DESC
**	04/20/2004	M.Jablonski	Call fnTimeZoneConversionDateTime function on all dates
** 	10/11/2003	C.VanStedum	Added changes for the addition of the bloodunitshipmenttable
**	01/20/2005	Lohse		BloodUnitShipment was being joined on Incoming and OutgoingShipmentGuid.  
**					        Removed Outgoing ( BR27.09)
**	07/07/2005	NPaterson	** Reviewed for compliance with database standards and recommendations **
**					        Removed name, input/output from comment header, Added NOCOUNT, Specified table owners, spaced out SQL,
					        Placed brackets around input parameter
**	07/07/2005	D. Askew	Added condition to ensure invoices have at least one unit that is not in final status
**	08/21/2005	S. Antropov	** Reviewed for compliance with database standards and recommendations **
**							Performed secondary review during the code promotion - merged changes
**	11/20/2005	Lohse		Adding RecordStatusCode check against Shipment table to avoid Modification created "fake" invoices
**	01/23/2006	M Smith		** Reviewed for compliance with database standards and recommendations **
**	01/04/2010	M. Smith	Changed to check UnitStatusCode from the BloodUnitStatusCodeCurrent table. (CR 1174)
**	01/27/2010	K. Adu-Poku	** Reviewed for compliance with database standards and recommendations **
*******************************************************************************************************************************************************************************/
CREATE   PROCEDURE dbo.spGetShipmentsWithAvailableUnitsFromPastFiveDays
(
	@divisioncode	CHAR (5)
)

AS
    SET NOCOUNT ON

	DECLARE @validdate	DATETIME
    DECLARE @error INT

	SET @validdate = DATEADD(d, -5, GETUTCDATE())

	SELECT DISTINCT
		S.ShipmentGuid,
		InvoiceNumber,
		dbo.fnTimeZoneConversionDateTime(@divisioncode, 0, ShipmentDate) AS ShipmentDate,
		LS.FacilityName,
		S.LocalSupplierGuid,
		ShipmentDirection
	FROM
		dbo.Shipment S 
	JOIN dbo.LocalSupplier LS ON S.LocalSupplierGUID = LS.LocalSupplierGUID
	JOIN dbo.V_BloodUnit BU ON BU.IncomingShipmentGuid = S.ShipmentGuid

	WHERE
		BU.DivisionCode = @divisioncode
	AND UnitStatusCode NOT IN ('D','M','T','X')
	AND S.ShipmentDate > @validdate
	AND S.DivisionCode = @divisioncode
	AND S.RecordStatusCode = 'A'
	ORDER BY
		ShipmentDate DESC

    SET @error = @@ERROR

    SET NOCOUNT ON 

    RETURN (@error)

SET NOCOUNT OFF
GO

if exists (select * from dbo.sysobjects where id = object_id(N'dbo.spGetTransfusionHistoryForPatientSpecimen') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure dbo.spGetTransfusionHistoryForPatientSpecimen
GO
/*****************************************************************************************************************
**	Desc:	Gets all transfused and presumed transfused units associated with a Patient Specimen
**
**	Author:	Cameron taylor
**
**	Date: 	04/30/2004
**
******************************************************************************************************************
**	Modified:
**	Date		Name		Description
**	----------	---------------	------------------------------------------------------------------------------------------------------------------------------------------------------------------------
**	06/09/2004	C. Taylor	PresumedTranfusedIndicator typo
**	07/05/2005	NPaterson	** Reviewed for compliance with database standards and recommendations **
**	01/04/2010	M. Smith	Changed to check UnitStatusCode from the BloodUnitStatusCodeCurrent table. (CR 1174)
**	01/27/2010	K. Adu-Poku	** Reviewed for compliance with database standards and recommendations **
******************************************************************************************************************/
CREATE PROCEDURE dbo.spGetTransfusionHistoryForPatientSpecimen
(
		@patientspecimenguid	UNIQUEIDENTIFIER,
		@divisioncode			CHAR(5)
)

AS

DECLARE @ERROR INT

SET @ERROR = 0

SET NOCOUNT ON

	SELECT DISTINCT
		PT.BloodUnitGUID,
		PT.PatientGUID,
		BUS.PresumedTransfusedIndicator
	
	FROM dbo.PatientTransfusion PT

	JOIN dbo.BloodUnitStatus BUS 
			ON BUS.BloodUnitGUID = PT.BloodUnitGUID

	JOIN dbo.BloodUnitStatusCodeCurrent BUSCC
			ON PT.BloodUnitGuid = BUSCC.BloodUnitGuid

	JOIN dbo.OrderedUnit OU 
			ON OU.BloodUnitGuid = PT.BloodUnitGuid 

	JOIN dbo.OrderedComponent OC 
			ON OC.OrderedComponentGuid = OU.OrderedComponentGuid

	WHERE	OC.PatientSpecimenGuid = @patientspecimenguid
	AND	PT.DivisionCode = @divisioncode
	AND 	OU.RecordStatusCode = 'A' 
	AND 	OU.ReleaseDate IS NULL
	AND	PT.RecordStatusCode = 'A'
	AND	BUSCC.UnitStatusCode = 'T'

SET @ERROR = @@ERROR

SET NOCOUNT OFF

RETURN(@ERROR)
GO

if exists (select * from dbo.sysobjects where id = object_id(N'dbo.spGetTransfusionReport') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure dbo.spGetTransfusionReport
GO
/*******************************************************************************************************************************************************************************
**	Desc:	Gets the list of transfusion for a date range
**
**	Author:	Krzysztof Dobranowski
**
**	Date: 	08/30/2004
**
*******************************************************************************************************************************************************************************
**	Modified:
**	Date		Name		Description
**	----------	---------------	------------------------------------------------------------------------------------------------------------------------------------------------------------------------
**	05/26/05	Lohse		PooledUnitsCount is now a function
**	07/05/05	N. Paterson	** Reviewed for compliance with database standards and recommendations **
**					This code should be optimized to not use dynamic sql, except this would require a major code rewrite
**					in the app.  Removed name, input, output descriptions, added nocount, specified table owners, 
**					added error checking on date function, capitalized, spaced, SQL
**	07/21/05	J. Engstrom	Modified procedure to avoid Dynamic SQL.  Changed @whereclause parameter to @searchstring, added
**					@reporttype, @delimiter parameter.
**	01/17/06	C. Taylor	Added FullProductCode (UnitProductCode, DonationTypeCode, UnitDivisionId) to 
**					ProductShortName (DR 1729)
**	01/23/06	M Smith		** Reviewed for compliance with database standards and recommendations **
** 	03/04/06	D. Askew	Added fnTimeZoneConversionDateTime for IssueDateTime
**	07/20/07	D. Askew	Added dbo.Patient.PatientMiddleName to SELECT (CR 1947)
**	01/04/10	M. Smith	Changed to check UnitStatusCode from the BloodUnitStatusCodeCurrent table. (CR 1174)
**	01/27/2010	K. Adu-Poku	** Reviewed for compliance with database standards and recommendations **
*******************************************************************************************************************************************************************************/
CREATE PROCEDURE dbo.spGetTransfusionReport
(
	@startdate	DATETIME,
	@enddate	DATETIME,
	@divisioncode	VARCHAR(5),
	@searchstring	VARCHAR(2000),
	@reporttype 	INT,
	@delimiter	VARCHAR(1)
)
AS

DECLARE @ERROR INT
SET @ERROR = 0

SET NOCOUNT ON
	--Since all the dates are saved in UTC, start and end data has to be adjusted first for correct comparison
	SET @startdate = dbo.fnTimeZoneConversionDateTime(@divisioncode, 1, @startdate)

				SET @ERROR = @@ERROR
				IF @ERROR != 0 GOTO ERR_HANDLER

	SET @enddate = dbo.fnTimeZoneConversionDateTime(@divisioncode, 1, @enddate)

				SET @ERROR = @@ERROR
				IF @ERROR != 0 GOTO ERR_HANDLER

		SELECT
			dbo.Patient.PatientGuid,
			dbo.Patient.DisplayVistaPatientId,
			dbo.Patient.PatientLastName,
			dbo.Patient.PatientFirstName,
			dbo.Patient.PatientMiddleName,
			dbo.BloodUnit.EyeReadableUnitId,
			dbo.fnGetPooledUnitsCount(dbo.BloodUnit.BloodUnitGuid) AS PooledUnitsCount,
			CASE dbo.BloodUnit.LabelTypeCode
				WHEN 'I' THEN dbo.BloodProduct.ProductShortName+', '+dbo.BloodUnit.UnitProductCode + dbo.DonationType.DonationTypeCode COLLATE SQL_Latin1_General_CP1_CS_AS + dbo.BloodUnit.UnitDivisionId 
				ELSE dbo.BloodProduct.ProductShortName+', '+dbo.BloodUnit.UnitProductCode
			END AS ProductShortName, 
			dbo.fnTimeZoneConversionDateTime(@divisioncode, 0, IssuedUnit.IssueDateTime) 	AS IssueDateTime,
			dbo.IssuedUnit.PhysicianName,
			dbo.IssuedUnit.IssueToLocationName,
			dbo.TreatingSpecialty.TreatingSpecialtyName,
			dbo.BloodUnitStatus.PresumedTransfusedIndicator,
			dbo.PatientTransfusionComment.PatientTransfusionCommentText,
			dbo.PatientTransfusion.PatientTransfusionGuid,
			dbo.ComponentClass.ComponentClassShortName,
			dbo.ComponentClass.ComponentClassName
	
		FROM
			dbo.PatientTransfusion
	
	JOIN dbo.Patient ON dbo.Patient.PatientGuid = dbo.PatientTransfusion.PatientGuid
	JOIN dbo.BloodUnit ON dbo.BloodUnit.BloodUnitGuid = dbo.PatientTransfusion.BloodUnitGuid
	JOIN dbo.BloodProduct ON dbo.BloodProduct.BloodProductGuid = dbo.BloodUnit.BloodProductGuid
	JOIN dbo.DonationType ON dbo.DonationType.DonationTypeId = dbo.BloodUnit.DonationTypeId
	LEFT JOIN dbo.IssuedUnit ON dbo.IssuedUnit.BloodUnitGuid = dbo.PatientTransfusion.BloodUnitGuid AND	dbo.IssuedUnit.ReturnDateTime IS NULL
	LEFT JOIN dbo.OrderedUnit ON dbo.OrderedUnit.BloodUnitGuid = dbo.PatientTransfusion.BloodUnitGuid AND dbo.OrderedUnit.ReleaseDate IS NULL AND dbo.OrderedUnit.RecordStatusCode = 'A' AND OrderedUnit.OrderedComponentGuid IS NOT NULL
	LEFT JOIN dbo.OrderedComponent ON dbo.OrderedComponent.OrderedComponentGuid = dbo.OrderedUnit.OrderedComponentGuid
	LEFT JOIN dbo.PatientOrder ON dbo.PatientOrder.PatientOrderGuid = dbo.OrderedComponent.PatientOrderGuid
	LEFT JOIN dbo.PatientTreatment ON dbo.PatientTreatment.PatientTreatmentGuid = dbo.PatientOrder.PatientTreatmentGuid
	LEFT JOIN dbo.TreatingSpecialty ON dbo.TreatingSpecialty.TreatingSpecialtyCode = dbo.PatientTreatment.TreatingSpecialtyCode
	JOIN dbo.BloodUnitStatus ON dbo.BloodUnitStatus.BloodUnitGuid = dbo.PatientTransfusion.BloodUnitGuid
	JOIN dbo.BloodUnitStatusCodeCurrent BUSCC ON dbo.PatientTransfusion.BloodUnitGuid = BUSCC.BloodUnitGuid
	LEFT JOIN dbo.PatientTransfusionComment ON dbo.PatientTransfusionComment.PatientTransfusionGuid = dbo.PatientTransfusion.PatientTransfusionGuid
	JOIN dbo.ProductType ON dbo.ProductType.ProductTypeCode = dbo.BloodProduct.ProductTypeCode
	JOIN dbo.ComponentClass ON dbo.ComponentClass.ComponentClassId = dbo.ProductType.ComponentClassid
	
		WHERE ( @searchstring IS NOT NULL AND @searchstring LIKE '%' + @delimiter + CASE WHEN @reporttype = 1 THEN PhysicianName WHEN @reporttype = 2 THEN IssueToLocationName WHEN @reporttype = 3 THEN TreatingSpecialtyName END + @delimiter + '%' AND CASE WHEN @reporttype = 1 THEN PhysicianName WHEN @reporttype = 2 THEN IssueToLocationName WHEN @reporttype = 3 THEN TreatingSpecialtyName END <> '' )
		AND dbo.PatientTransfusion.DivisionCode = @divisioncode
		AND	dbo.PatientTransfusion.TransfusionStartDateTime >= CONVERT(VARCHAR(50), @startdate)
		AND	dbo.PatientTransfusion.TransfusionStartDateTime <= CONVERT(VARCHAR(50), @enddate)
		AND	BUSCC.UnitStatusCode = 'T'
		AND	dbo.PatientTransfusionComment.PatientTransfusionReactionGuid IS NULL
		AND dbo.PatientTransfusion.RecordStatusCode = 'A'
	
		ORDER BY dbo.ComponentClass.SortColumn, dbo.PatientTransfusion.TransfusionStartDateTime DESC, dbo.Patient.PatientLastName, dbo.Patient.PatientFirstName, dbo.PatientTransfusion.PatientTransfusionGuid

				SET @ERROR = @@ERROR
				IF @ERROR != 0 GOTO ERR_HANDLER

SET NOCOUNT OFF
RETURN(@ERROR)


ERR_HANDLER:
	SET NOCOUNT OFF
	RETURN @ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'dbo.spVistaGetXmlAvailableUnits') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure dbo.spVistaGetXmlAvailableUnits
GO
/*******************************************************************************************************************************************************************************
**
**	Desc: 	Retrieves XML to submit to VistA containing available units information
**
**	Author:	Brian Tomlin / Stas Antropov
**
**	Date: 	01/25/2005
**
*******************************************************************************************************************************************************************************
**	Modified:
**	Date		Name		Description
**	--------	--------------	------------------------------------------------------------------------------------------------------------------------------------------------------------------------
**	07/19/05	C. Taylor	Added call to fnOrderedUnitCrossmatchResultCode to ensure latest crossmatch result is used 
**					(there may be repeat XMs)
**	06/29/05	N. Paterson	** Reviewed for compliance with database standards and recommendations **
**					Header added, Added NOCOUNT, Specified table owners, Removed comments, UPPERCASED SQL
**	08/21/05	S. Antropov	** Reviewed for compliance with database standards and recommendations **
**					Performed secondary review during the code promotion - merged changes
**	08/24/05	C. Taylor	Fixed typo introduced during compliance: Bdbo.loodUnit and Bdbo.loodProduct
**	03/29/07	D. Askew	Made changes for DR 2594, see Assigned, crossmatched, autologous, and directed units: changed 
**					[Unit!4!location] to use dbo.fnCurrentUnitLocation (new function); removed JOIN to dbo.IssuedUnit
**	07/13/07	Lohse		Adding datetime conversion for CR2253.
**	03/06/08	Stedum		Added the return of the label unit id for CR 2399.
**	03/11/08	K Adu-Poku	** Reviewed for compliance with database standards and recommendations **
**	05/13/08	M. Smith	Changed @VistaPatientID to BIGINT datatype (CR 2431)
**	06/10/08	Stedum		Implemented proposed solution for CR 2237, 2130, removed  issued from the where clause 
**					of the unit status code, also removed the check for donation type within the same where clause
**	06/12/08	K. Adu-Poku	** Reviewed for compliance with database standards and recommendations **
**	01/04/10	M. Smith	Changed to check UnitStatusCode from the BloodUnitStatusCodeCurrent table. (CR 1174)
**	01/25/2010	K. Adu-Poku	** Reviewed for compliance with database standards and recommendations **
*******************************************************************************************************************************************************************************/
CREATE PROCEDURE  dbo.spVistaGetXmlAvailableUnits
(
	@VistAPatientId		BIGINT
)

AS
SET NOCOUNT ON

DECLARE @PatientFoundFlag AS BIT;
	
	SELECT @PatientFoundFlag = ISNULL((	SELECT TOP 1 1
						FROM 	dbo.Patient
						WHERE	VistaPatientId = @VistaPatientId), 0 );

--<BloodBank>
SELECT	1					AS Tag,
		NULL					AS Parent,
		1					AS [Bloodbank!1!GroupOrder!hide],
		NULL 					AS [Bloodbank!1],
		NULL					AS [Patient!2!dfn],
		NULL					AS [Patient!2!firstName],
		NULL					AS [Patient!2!lastName],
		NULL					AS [Patient!2!dob],
		NULL					AS [Patient!2!ssn],
		NULL					AS [Patient!2!abo],
		NULL					AS [Patient!2!rh],
		NULL					AS [Units!3],
		NULL					AS [Unit!4!status],
		NULL					AS [Unit!4!id],
		NULL					AS [Unit!4!labelid],
		NULL					AS [Unit!4!product],
		NULL					AS [Unit!4!productCode],
		NULL					AS [Unit!4!abo],
		NULL					AS [Unit!4!rh],
		NULL					AS [Unit!4!volume],
		NULL					AS [Unit!4!dateAssigned],
		NULL					AS [Unit!4!divisionCode],
		NULL					AS [Unit!4!location],
		NULL					AS [Unit!4!expDate]

UNION ALL

-- <Patient dfn="" firstName="" lastName="" ssn="" abo="" rh="">
SELECT	2					AS Tag,
		1					AS Parent,
		2					AS [Bloodbank!1!GroupOrder!hide],
		NULL 					AS [Bloodbank!1],
		P.VistaPatientID			AS [Patient!2!dfn],
		P.PatientFirstName			AS [Patient!2!firstName],
		P.PatientLastName			AS [Patient!2!lastName],
		dbo.fnPatientDobConversionToFileManDateTime(P.PatientGuid)	AS [Patient!2!dob],
		P.PatientSSN				AS [Patient!2!ssn],
		dbo.fnGetABO( P.PatientGUID )	AS [Patient!2!abo],
		dbo.fnGetRh( P.PatientGUID )		AS [Patient!2!rh],
		NULL					AS [Units!3],
		NULL					AS [Unit!4!status],
		NULL					AS [Unit!4!id],
		NULL					AS [Unit!4!labelid],
		NULL					AS [Unit!4!product],
		NULL					AS [Unit!4!productCode],
		NULL					AS [Unit!4!abo],
		NULL					AS [Unit!4!rh],
		NULL					AS [Unit!4!volume],
		NULL					AS [Unit!4!dateAssigned],
		NULL					AS [Unit!4!divisionCode],
		NULL					AS [Unit!4!location],
		NULL					AS [Unit!4!expDate]

FROM		
		dbo.Patient P
WHERE		

		P.VistaPatientID = @VistaPatientID

UNION ALL

-- <Units>
SELECT	3					AS Tag,
		2					AS Parent,
		2					AS [Bloodbank!1!GroupOrder!hide],
		NULL 					AS [Bloodbank!1],
		NULL					AS [Patient!2!dfn],
		NULL					AS [Patient!2!firstName],
		NULL					AS [Patient!2!lastName],
		NULL					AS [Patient!2!dob],
		NULL					AS [Patient!2!ssn],
		NULL					AS [Patient!2!abo],
		NULL					AS [Patient!2!rh],
		NULL					AS [Units!3],
		NULL					AS [Unit!4!status],
		NULL					AS [Unit!4!id],
		NULL					AS [Unit!4!labelid],
		NULL					AS [Unit!4!product],
		NULL					AS [Unit!4!productCode],
		NULL					AS [Unit!4!abo],
		NULL					AS [Unit!4!rh],
		NULL					AS [Unit!4!volume],
		NULL					AS [Unit!4!dateAssigned],
		NULL					AS [Unit!4!divisionCode],
		NULL					AS [Unit!4!location],
		NULL					AS [Unit!4!expDate]

WHERE		
		@PatientFoundFlag = 1

UNION ALL

-- Assigned, crossmatched, autologous, and directed units
-- <Unit status="" id="" product="" productCode="" abo="" rh="" divisionCode="" location="" expDate="" />
SELECT DISTINCT	
		4										AS Tag,
		3										AS Parent,
		2										AS [Bloodbank!1!GroupOrder!hide],
		NULL 										AS [Bloodbank!1],
		NULL										AS [Patient!2!dfn],
		NULL										AS [Patient!2!firstName],
		NULL										AS [Patient!2!lastName],
		NULL										AS [Patient!2!dob],
		NULL										AS [Patient!2!ssn],
		NULL										AS [Patient!2!abo],
		NULL										AS [Patient!2!rh],
		NULL										AS [Units!3],
		-- ******************************************************************************************************************************************************************************************
		CASE
			WHEN	dbo.DonationType.RestrictionTypeCode IN ('A','D') THEN 
				dbo.DonationType.RestrictionTypeCode
			ELSE 	BUSCC.UnitStatusCode
		END 										AS [Unit!4!status],
		-- ******************************************************************************************************************************************************************************************
		dbo.BloodUnit.EyeReadableUnitId						AS [Unit!4!id],
		dbo.BloodUnit.LabelUnitId							AS [Unit!4!labelid],
		dbo.ProductType.ProductTypeName						AS [Unit!4!product],
		dbo.BloodProduct.ProductCode							AS [Unit!4!productCode],
		dbo.BloodUnitMedia.BloodTypeCode						AS [Unit!4!abo],
		dbo.BloodUnitMedia.RhFactorCode						AS [Unit!4!rh],
		dbo.BloodUnit.OriginalVolume							AS [Unit!4!volume],
		dbo.fnDateTimeConversionToFileManDateTime(dbo.fnTimeZoneConversionDateTime( OrderedUnit.DivisionCode, 0, OrderedUnit.SelectedDate ))		AS [Unit!4!dateAssigned],
		dbo.VamcDivision.DivisionCode							AS [Unit!4!divisionCode],
		dbo.fnCurrentUnitLocation(dbo.BloodUnit.BloodUnitGuid) 				AS [Unit!4!location],
		dbo.fnDateTimeConversionToFileManDateTime(dbo.fnTimeZoneConversionDateTime( OrderedUnit.DivisionCode, 0, BloodUnitMedia.UnitExpirationDate ))	AS [Unit!4!expDate]

FROM		dbo.BloodUnitStatusCodeCurrent BUSCC
	INNER JOIN 	dbo.BloodUnit
		ON 	BUSCC.BloodUnitGuid = dbo.BloodUnit.BloodUnitGuid
	LEFT OUTER JOIN	dbo.PatientTransfusion
		ON	dbo.BloodUnit.BloodUnitGuid = dbo.PatientTransfusion.BloodUnitGuid
	INNER JOIN	dbo.DonationType
		ON	dbo.BloodUnit.DonationTypeId = dbo.DonationType.DonationTypeId
	INNER JOIN 	dbo.OrderedUnit
		ON 	dbo.BloodUnit.BloodUnitGuid = dbo.OrderedUnit.BloodUnitGuid
	INNER JOIN 	dbo.OrderedComponent
		ON 	dbo.OrderedUnit.OrderedComponentGuid = dbo.OrderedComponent.OrderedComponentGuid
	INNER JOIN 	dbo.PatientOrder
		ON 	dbo.OrderedComponent.PatientOrderGuid = dbo.PatientOrder.PatientOrderGuid
	INNER JOIN 	dbo.PatientTreatment
		ON 	dbo.PatientOrder.PatientTreatmentGuid = dbo.PatientTreatment.PatientTreatmentGuid
	INNER JOIN 	dbo.Patient
		ON 	dbo.PatientTreatment.PatientGuid = dbo.Patient.PatientGuid
	INNER JOIN 	dbo.BloodProduct
		ON 	dbo.BloodUnit.BloodProductGuid =dbo.BloodProduct.BloodProductGuid
	INNER JOIN 	dbo.ProductType
		ON 	dbo.BloodProduct.ProductTypeCode = dbo.ProductType.ProductTypeCode
	INNER JOIN 	dbo.VamcDivision
		ON 	dbo.BloodUnit.DivisionCode = dbo.VamcDivision.DivisionCode
	INNER JOIN 	dbo.BloodUnitMedia
		ON 	dbo.BloodUnit.BloodUnitGuid = dbo.BloodUnitMedia.BloodUnitGuid

	WHERE		

		dbo.Patient.VistaPatientID = @VistaPatientId

		AND	BUSCC.UnitStatusCode IN ( 'S', 'C' , 'I')

		AND	dbo.BloodUnitMedia.UnitExpirationDate > GETUTCDATE()

		AND	dbo.PatientTransfusion.TransfusionStartDateTime IS NULL

		AND	dbo.OrderedUnit.ReleaseDate IS NULL

		AND	dbo.OrderedUnit.SelectedDate IS NOT NULL

		AND	((dbo.fnOrderedUnitCrossmatchResultCode(OrderedUnit.OrderedUnitGuid) IN ('C', 'E', 'G')) OR (OrderedUnit.CrossmatchResultCode IS NULL))
		
		AND	@PatientFoundFlag = 1


FOR XML EXPLICIT

SET NOCOUNT OFF
GO

if exists (select * from dbo.sysobjects where id = object_id(N'dbo.spVistaGetXmlBloodBankData') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure dbo.spVistaGetXmlBloodBankData
GO
/*******************************************************************************************************************************************************************************
**	Desc: 	Retrieves blood bank data XML to return to VistA
**
**	Author:	Brian Tomlin / Stas Antropov
**
**	Date: 	01/25/2005
**
*******************************************************************************************************************************************************************************
**	Modified:
**	Date		Name		Description
**	-------------		---------		-----------------
**	07/19/05	C. Taylor	Added call to fnOrderedUnitCrossmatchResultCode to ensure latest crossmatch result is used 
**					(there may be repeat XMs)
**	06/29/05	N. Paterson	** Reviewed for compliance with database standards and recommendations **
**					Header added, Added NOCOUNT, Specified table owners, Removed comments, UPPERCASED SQL
**	08/21/05	S. Antropov	** Reviewed for compliance with database standards and recommendations **
**					Performed secondary review during the code promotion - merged changes
**	08/24/05	C. Taylor	Fixed typo introduced during compliance: INNER JOIN 
**					dbo.PatientTransfusionRequirement.PatientTransReq
**	09/09/05	D. Askew	Changed JOIN on Patient to select either the FinalMergeToPatient if the patient has one or more
**					merges (choosing the final merge record) or simply the patient guid if there are none
**	10/27/05	C. Jensen	Added code to not get ABO/Rh if from Db conversion.
**	01/23/06	M. Smith	** Reviewed for compliance with database standards and recommendations **
**	03/29/07	D. Askew	Made changes for DR 2595, see Assigned and crossmatched units: changed [Unit!10!expDate] to use 
**					BloodUnitMedia.UnitExpirationDate rather than PatientSpecimen.SpecimenExpirationDate; changed
**					INNER JOIN on dbo.PatientSpecimen to LEFT JOIN; added AND condition for 
**					dbo.PatientSpecimen.SpecimenExpirationDate, which will be NULL for certain blood product types
**	07/13/07	Lohse		Adding datetime conversion for CR2253.
**	05/13/08	M. Smith	Changed @VistaPatientID to BIGINT datatype (CR 2431)
**	06/04/08	K. Adu-Poku	** Reviewed for compliance with database standards and recommendations **
**	01/04/10	M. Smith	Changed to get and check UnitStatusCode from the BloodUnitStatusCodeCurrent table. (CR 1174)
**	01/25/10	K. Adu-Poku	** Reviewed for compliance with database standards and recommendations **
*******************************************************************************************************************************************************************************/
CREATE PROCEDURE dbo.spVistaGetXmlBloodBankData
(
	@VistAPatientId 	BIGINT,
	@DivisionCode 		CHAR(5)
)
AS

SET NOCOUNT ON

DECLARE @PatientFoundFlag AS BIT;
DECLARE @PatientGuid AS UNIQUEIDENTIFIER;
DECLARE @ABO AS VarChar(2);
DECLARE @Rh AS VarChar(2);
	
	SELECT @PatientFoundFlag = ISNULL((	SELECT TOP 1 1
						FROM 	dbo.Patient
						WHERE	VistaPatientID = @VistaPatientID), 0 );

	SELECT @PatientGuid = (SELECT TOP 1 PatientGuid FROM dbo.Patient P WHERE P.VistaPatientID = @VistaPatientID);
	SELECT @ABO = (SELECT ABO FROM dbo.fnGetABORhTable(@PatientGuid) WHERE TestDivision IS NOT NULL);
	SELECT @Rh = (SELECT Rh FROM dbo.fnGetABORhTable(@PatientGuid) WHERE TestDivision IS NOT NULL);
		

-- <BloodBank>
SELECT	1					AS Tag,
		NULL					AS Parent,
		1					 AS [Bloodbank!1!GroupOrder!hide],
		NULL					 AS [Component!13!GroupOrder!hide],
		NULL 					 AS [Bloodbank!1],
		NULL					 AS [Patient!2!dfn],
		NULL					 AS [Patient!2!firstName],
		NULL					 AS [Patient!2!lastName],
		NULL					 AS [Patient!2!ssn],
		NULL					 AS [Patient!2!abo],
		NULL					 AS [Patient!2!rh],
		NULL					 AS [TransfusionReactions!3],
		NULL					 AS [TransfusionReaction!4!type],
		NULL					 AS [TransfusionReaction!4!date],
		NULL					 AS [TransfusionRequirements!5],
		NULL					 AS [TransfusionRequirement!6!modifier],
		NULL					 AS [Antibodies!7],
		NULL					 AS [Antibody!8!name],
		NULL					 AS [Units!9],
		NULL					 AS [Unit!10!status],
		NULL					 AS [Unit!10!id],
		NULL					 AS [Unit!10!product],
		NULL					 AS [Unit!10!location],
		NULL					 AS [Unit!10!expDate],
		NULL					 AS [Specimen!11!expDate],
		NULL					 AS [Specimen!11!uid],
		NULL					 AS [Components!12],
		NULL					 AS [Component!13!name],
		NULL					 AS [Component!13!id],
		NULL					 AS [Component!13!specimen],
		NULL					 AS [LabTests!14],
		NULL					 AS [LabTest!15!id],
		NULL					 AS [LabTest!15!name],
		NULL					 AS [MsbosList!16],
		NULL					 AS [Msbos!17!name],
		NULL					 AS [Msbos!17!threshold],
		NULL					 AS [Surgeries!18],
		NULL					 AS [Surgery!19!name]

UNION ALL

-- <Patient dfn="" firstName="" lastName="" ssn="" abo="" rh="">
SELECT	2					AS Tag,
		1					AS Parent,
		2					 AS [Bloodbank!1!GroupOrder!hide],
		NULL					 AS [Component!13!GroupOrder!hide],
		NULL 					 AS [Bloodbank!1],
		P.VistaPatientID			 	AS [Patient!2!dfn],
		P.PatientFirstName			 AS [Patient!2!firstName],
		P.PatientLastName			 AS [Patient!2!lastName],
		P.PatientSSN				 AS [Patient!2!ssn],
		@ABO 					AS [Patient!2!abo],
		@Rh 					AS [Patient!2!rh],
		NULL					 AS [TransfusionReactions!3],
		NULL					 AS [TransfusionReaction!4!type],
		NULL					 AS [TransfusionReaction!4!date],
		NULL					 AS [TransfusionRequirements!5],
		NULL					 AS [TransfusionRequirement!6!modifier],
		NULL					 AS [Antibodies!7],
		NULL					 AS [Antibody!8!name],
		NULL					 AS [Units!9],
		NULL					 AS [Unit!10!status],
		NULL					 AS [Unit!10!id],
		NULL					 AS [Unit!10!product],
		NULL					 AS [Unit!10!location],
		NULL					 AS [Unit!10!expDate],
		NULL					 AS [Specimen!11!expDate],
		NULL					 AS [Specimen!11!uid],
		NULL					 AS [Components!12],
		NULL					 AS [Component!13!name],
		NULL					 AS [Component!13!id],
		NULL					 AS [Component!13!specimen],
		NULL					 AS [LabTests!14],
		NULL					 AS [LabTest!15!id],
		NULL					 AS [LabTest!15!name],
		NULL					 AS [MsbosList!16],
		NULL					 AS [Msbos!17!name],
		NULL					 AS [Msbos!17!threshold],
		NULL					 AS [Surgeries!18],
		NULL					 AS [Surgery!19!name]
FROM		dbo.Patient P
WHERE		P.VistaPatientID = @VistaPatientID

UNION ALL

-- <TransfusionReactions>
SELECT	3					AS Tag,
		2					AS Parent,
		2					 AS [Bloodbank!1!GroupOrder!hide],
		NULL					 AS [Component!13!GroupOrder!hide],
		NULL 					 AS [Bloodbank!1],
		NULL					 AS [Patient!2!dfn],
		NULL					 AS [Patient!2!firstName],
		NULL					 AS [Patient!2!lastName],
		NULL					 AS [Patient!2!ssn],
		NULL					 AS [Patient!2!abo],
		NULL					 AS [Patient!2!rh],
		NULL					 AS [TransfusionReactions!3],
		NULL					 AS [TransfusionReaction!4!type],
		NULL					 AS [TransfusionReaction!4!date],
		NULL					 AS [TransfusionRequirements!5],
		NULL					 AS [TransfusionRequirement!6!modifier],
		NULL					 AS [Antibodies!7],
		NULL					 AS [Antibody!8!name],
		NULL					 AS [Units!9],
		NULL					 AS [Unit!10!status],
		NULL					 AS [Unit!10!id],
		NULL					 AS [Unit!10!product],
		NULL					 AS [Unit!10!location],
		NULL					 AS [Unit!10!expDate],
		NULL					 AS [Specimen!11!expDate],
		NULL					 AS [Specimen!11!uid],
		NULL					 AS [Components!12],
		NULL					 AS [Component!13!name],
		NULL					 AS [Component!13!id],
		NULL					 AS [Component!13!specimen],
		NULL					 AS [LabTests!14],
		NULL					 AS [LabTest!15!id],
		NULL					 AS [LabTest!15!name],
		NULL					 AS [MsbosList!16],
		NULL					 AS [Msbos!17!name],
		NULL					 AS [Msbos!17!threshold],
		NULL					 AS [Surgeries!18],
		NULL					 AS [Surgery!19!name]
WHERE		@PatientFoundFlag = 1

UNION ALL

-- <TransfusionReaction type="" date="">
SELECT DISTINCT	
		4					AS Tag,
		3					AS Parent,
		2					 AS [Bloodbank!1!GroupOrder!hide],
		NULL					 AS [Component!13!GroupOrder!hide],
		NULL 					 AS [Bloodbank!1],
		NULL					 AS [Patient!2!dfn],
		NULL					 AS [Patient!2!firstName],
		NULL					 AS [Patient!2!lastName],
		NULL					 AS [Patient!2!ssn],
		NULL					 AS [Patient!2!abo],
		NULL					 AS [Patient!2!rh],
		NULL					 AS [TransfusionReactions!3],
		TRT.TransfusionReactionTypeText	 AS [TransfusionReaction!4!type],
		dbo.fnDateTimeConversionToHL7DateTime(dbo.fnTimeZoneConversionDateTime( @DivisionCode, 0, PTR.NotedDateTime ))		 AS [TransfusionReaction!4!date],
		NULL					 AS [TransfusionRequirements!5],
		NULL					 AS [TransfusionRequirement!6!modifier],
		NULL					 AS [Antibodiess!7],
		NULL					 AS [Antibody!8!name],
		NULL					 AS [Units!9],
		NULL					 AS [Unit!10!status],
		NULL					 AS [Unit!10!id],
		NULL					 AS [Unit!10!product],
		NULL					 AS [Unit!10!location],
		NULL					 AS [Unit!10!expDate],
		NULL					 AS [Specimen!11!expDate],
		NULL					 AS [Specimen!11!uid],
		NULL					 AS [Components!12],
		NULL					 AS [Component!13!name],
		NULL					 AS [Component!13!id],
		NULL					 AS [Component!13!specimen],
		NULL					 AS [LabTests!14],
		NULL					 AS [LabTest!15!id],
		NULL					 AS [LabTest!15!name],
		NULL					 AS [MsbosList!16],
		NULL					 AS [Msbos!17!name],
		NULL					 AS [Msbos!17!threshold],
		NULL					 AS [Surgeries!18],
		NULL					 AS [Surgery!19!name]

FROM		dbo.PatientTransfusionReaction PTR

JOIN 		
	dbo.Patient LinkPatient ON PTR.PatientGuid = LinkPatient.PatientGuid
JOIN 	
	dbo.Patient P ON P.PatientGuid = COALESCE(LinkPatient.FinalMergeToPatient, LinkPatient.PatientGuid)

LEFT JOIN
	dbo.TransfusionReactionType TRT ON TRT.TransfusionReactionTypeCode = PTR.TransfusionReactionTypeCode

			WHERE		P.VistaPatientID = @VistaPatientID
			
				AND	PTR.RecordStatusCode NOT IN ('X','I','E')
			
				AND	@PatientFoundFlag = 1
		
UNION ALL 

-- <TransfusionRequirements>
SELECT	5					AS Tag,
		2					AS Parent,
		2					 AS [Bloodbank!1!GroupOrder!hide],
		NULL					 AS [Component!13!GroupOrder!hide],
		NULL 					 AS [Bloodbank!1],
		NULL					 AS [Patient!2!dfn],
		NULL					 AS [Patient!2!firstName],
		NULL					 AS [Patient!2!lastName],
		NULL					 AS [Patient!2!ssn],
		NULL					 AS [Patient!2!abo],
		NULL					 AS [Patient!2!rh],
		NULL					 AS [TransfusionReactions!3],
		NULL					 AS [TransfusionReaction!4!type],
		NULL					 AS [TransfusionReaction!4!date],
		NULL					 AS [TransfusionRequirements!5],
		NULL					 AS [TransfusionRequirement!6!modifier],
		NULL					 AS [Antibodies!7],
		NULL					 AS [Antibody!8!name],
		NULL					 AS [Units!9],
		NULL					 AS [Unit!10!status],
		NULL					 AS [Unit!10!id],
		NULL					 AS [Unit!10!product],
		NULL					 AS [Unit!10!location],
		NULL					 AS [Unit!10!expDate],
		NULL					 AS [Specimen!11!expDate],
		NULL					 AS [Specimen!11!uid],
		NULL					 AS [Components!12],
		NULL					 AS [Component!13!name],
		NULL					 AS [Component!13!id],
		NULL					 AS [Component!13!specimen],
		NULL					 AS [LabTests!14],
		NULL					 AS [LabTest!15!id],
		NULL					 AS [LabTest!15!name],
		NULL					 AS [MsbosList!16],
		NULL					 AS [Msbos!17!name],
		NULL					 AS [Msbos!17!threshold],
		NULL					 AS [Surgeries!18],
		NULL					 AS [Surgery!19!name]
WHERE		@PatientFoundFlag = 1

UNION ALL

-- <TransfusionRequirement modifier="" >
SELECT	6					AS Tag,
		5					AS Parent,
		2					 AS [Bloodbank!1!GroupOrder!hide],
		NULL					 AS [Component!13!GroupOrder!hide],
		NULL 					 AS [Bloodbank!1],
		NULL					 AS [Patient!2!dfn],
		NULL					 AS [Patient!2!firstName],
		NULL					 AS [Patient!2!lastName],
		NULL					 AS [Patient!2!ssn],
		NULL					 AS [Patient!2!abo],
		NULL					 AS [Patient!2!rh],
		NULL					 AS [TransfusionReactions!3],
		NULL					 AS [TransfusionReaction!4!type],
		NULL					 AS [TransfusionReaction!4!date],
		NULL					 AS [TransfusionRequirements!5],
		dbo.PatientTransfusionRequirement.TransfusionRequirementText	 AS [TransfusionRequirement!6!modifier],
		NULL					 AS [Antibodies!7],
		NULL					 AS [Antibody!8!name],
		NULL					 AS [Units!9],
		NULL					 AS [Unit!10!status],
		NULL					 AS [Unit!10!id],
		NULL					 AS [Unit!10!product],
		NULL					 AS [Unit!10!location],
		NULL					 AS [Unit!10!expDate],
		NULL					 AS [Specimen!11!expDate],
		NULL					 AS [Specimen!11!uid],
		NULL					 AS [Components!12],
		NULL					 AS [Component!13!name],
		NULL					 AS [Component!13!id],
		NULL					 AS [Component!13!specimen],
		NULL					 AS [LabTests!14],
		NULL					 AS [LabTest!15!id],
		NULL					 AS [LabTest!15!name],
		NULL					 AS [MsbosList!16],
		NULL					 AS [Msbos!17!name],
		NULL					 AS [Msbos!17!threshold],
		NULL					 AS [Surgeries!18],
		NULL					 AS [Surgery!19!name]
FROM		dbo.Patient

INNER JOIN	dbo.PatientTransfusionRequirement

	ON	dbo.Patient.PatientGuid = dbo.PatientTransfusionRequirement.PatientGuid

		WHERE		dbo.Patient.VistaPatientID = @VistaPatientID

			AND	dbo.PatientTransfusionRequirement.PatientGUID = dbo.Patient.PatientGUID

				AND	dbo.PatientTransfusionRequirement.RecordStatusCode IN ('A', 'C', 'H' )

              			  -- The following line Addresses CR 840
					AND	dbo.PatientTransfusionRequirement.TransfusionRequirementCategoryCode IN ('AN', 'CR')

						AND	@PatientFoundFlag = 1

UNION ALL

-- <Antibodies>
SELECT	7					AS Tag,
		2					AS Parent,
		2					 AS [Bloodbank!1!GroupOrder!hide],
		NULL					 AS [Component!13!GroupOrder!hide],
		NULL 					 AS [Bloodbank!1],
		NULL					 AS [Patient!2!dfn],
		NULL					 AS [Patient!2!firstName],
		NULL					 AS [Patient!2!lastName],
		NULL					 AS [Patient!2!ssn],
		NULL					 AS [Patient!2!abo],
		NULL					 AS [Patient!2!rh],
		NULL					 AS [TransfusionReactions!3],
		NULL					 AS [TransfusionReaction!4!type],
		NULL					 AS [TransfusionReaction!4!date],
		NULL					 AS [TransfusionRequirements!5],
		NULL					 AS [TransfusionRequirement!6!modifier],
		NULL					 AS [Antibodies!7],
		NULL					 AS [Antibody!8!name],
		NULL					 AS [Units!9],
		NULL					 AS [Unit!10!status],
		NULL					 AS [Unit!10!id],
		NULL					 AS [Unit!10!product],
		NULL					 AS [Unit!10!location],
		NULL					 AS [Unit!10!expDate],
		NULL					 AS [Specimen!11!expDate],
		NULL					 AS [Specimen!11!uid],
		NULL					 AS [Components!12],
		NULL					 AS [Component!13!name],
		NULL					 AS [Component!13!id],
		NULL					 AS [Component!13!specimen],
		NULL					 AS [LabTests!14],
		NULL					 AS [LabTest!15!id],
		NULL					 AS [LabTest!15!name],
		NULL					 AS [MsbosList!16],
		NULL					 AS [Msbos!17!name],
		NULL					 AS [Msbos!17!threshold],
		NULL					 AS [Surgeries!18],
		NULL					 AS [Surgery!19!name]
WHERE		@PatientFoundFlag = 1

UNION ALL

-- <Antibody name="">
SELECT DISTINCT	
		8					AS Tag,
		7					AS Parent,
		2					 AS [Bloodbank!1!GroupOrder!hide],
		NULL					 AS [Component!13!GroupOrder!hide],
		NULL 					 AS [Bloodbank!1],
		NULL					 AS [Patient!2!dfn],
		NULL					 AS [Patient!2!firstName],
		NULL					 AS [Patient!2!lastName],
		NULL					 AS [Patient!2!ssn],
		NULL					 AS [Patient!2!abo],
		NULL					 AS [Patient!2!rh],
		NULL					 AS [TransfusionReactions!3],
		NULL					 AS [TransfusionReaction!4!type],
		NULL					 AS [TransfusionReaction!4!date],
		NULL					 AS [TransfusionRequirements!5],
		NULL					 AS [TransfusionRequirement!6!modifier],
		NULL					 AS [Antibodies!7],
		dbo.AntibodyType.AntibodyTypeName		 AS [Antibody!8!name],
		NULL					 AS [Units!9],
		NULL					 AS [Unit!10!status],
		NULL					 AS [Unit!10!id],
		NULL					 AS [Unit!10!product],
		NULL					 AS [Unit!10!location],
		NULL					 AS [Unit!10!expDate],
		NULL					 AS [Specimen!11!expDate],
		NULL					 AS [Specimen!11!uid],
		NULL					 AS [Components!12],
		NULL					 AS [Component!13!name],
		NULL					 AS [Component!13!id],
		NULL					 AS [Component!13!specimen],
		NULL					 AS [LabTests!14],
		NULL					 AS [LabTest!15!id],
		NULL					 AS [LabTest!15!name],
		NULL					 AS [MsbosList!16],
		NULL					 AS [Msbos!17!name],
		NULL					 AS [Msbos!17!threshold],
		NULL					 AS [Surgeries!18],
		NULL					 AS [Surgery!19!name]

FROM		dbo.Patient

	INNER JOIN	dbo.PatientTransfusionRequirement
	
		ON	dbo.PatientTransfusionRequirement.PatientGUID = dbo.Patient.PatientGUID		
	
			INNER JOIN 	dbo.AntibodyType
	
				ON 	dbo.AntibodyType.AntibodyTypeID =dbo. PatientTransfusionRequirement.AntibodyTypeID
	
					WHERE		dbo.Patient.VistaPatientID = @VistaPatientID
	
						AND	@PatientFoundFlag = 1
					
							AND	dbo.AntibodyType.AntibodyTypeId != 1
					
								AND	dbo.AntibodyType.AntibodyTypeId != 4
					
									AND	dbo.PatientTransfusionRequirement.RecordStatusCode IN ('A', 'C', 'H' )


UNION ALL

-- <Units>
SELECT	9					AS Tag,
		2					AS Parent,
		2					 AS [Bloodbank!1!GroupOrder!hide],
		NULL					 AS [Component!13!GroupOrder!hide],
		NULL 					 AS [Bloodbank!1],
		NULL					 AS [Patient!2!dfn],
		NULL					 AS [Patient!2!firstName],
		NULL					 AS [Patient!2!lastName],
		NULL					 AS [Patient!2!ssn],
		NULL					 AS [Patient!2!abo],
		NULL					 AS [Patient!2!rh],
		NULL					 AS [TransfusionReactions!3],
		NULL					 AS [TransfusionReaction!4!type],
		NULL					 AS [TransfusionReaction!4!date],
		NULL					 AS [TransfusionRequirements!5],
		NULL					 AS [TransfusionRequirement!6!modifier],
		NULL					 AS [Antibodies!7],
		NULL					 AS [Antibody!8!name],
		NULL					 AS [Units!9],
		NULL					 AS [Unit!10!status],
		NULL					 AS [Unit!10!id],
		NULL					 AS [Unit!10!product],
		NULL					 AS [Unit!10!location],
		NULL					 AS [Unit!10!expDate],
		NULL					 AS [Specimen!11!expDate],
		NULL					 AS [Specimen!11!uid],
		NULL					 AS [Components!12],
		NULL					 AS [Component!13!name],
		NULL					 AS [Component!13!id],
		NULL					 AS [Component!13!specimen],
		NULL					 AS [LabTests!14],
		NULL					 AS [LabTest!15!id],
		NULL					 AS [LabTest!15!name],
		NULL					 AS [MsbosList!16],
		NULL					 AS [Msbos!17!name],
		NULL					 AS [Msbos!17!threshold],
		NULL					 AS [Surgeries!18],
		NULL					 AS [Surgery!19!name]
WHERE		@PatientFoundFlag = 1

UNION ALL

-- Assigned and crossmatched units
-- <Unit status="" id="" product="" location="" expDate="" />
SELECT DISTINCT	
		10											AS Tag,
		9											AS Parent,
		2					 						AS [Bloodbank!1!GroupOrder!hide],
		NULL					 						AS [Component!13!GroupOrder!hide],
		NULL 					 						AS [Bloodbank!1],
		NULL					 						AS [Patient!2!dfn],
		NULL					 						AS [Patient!2!firstName],
		NULL					 						AS [Patient!2!lastName],
		NULL					 						AS [Patient!2!ssn],
		NULL					 						AS [Patient!2!abo],
		NULL					 						AS [Patient!2!rh],
		NULL					 						AS [TransfusionReactions!3],
		NULL					 						AS [TransfusionReaction!4!type],
		NULL					 						AS [TransfusionReaction!4!date],
		NULL					 						AS [TransfusionRequirements!5],
		NULL					 						AS [TransfusionRequirement!6!modifier],
		NULL					 						AS [Antibodies!7],
		NULL					 						AS [Antibody!8!name],
		NULL					 						AS [Units!9],
		BUSCC.UnitStatusCode		 						AS [Unit!10!status],
		dbo.BloodUnit.EyeReadableUnitId		 					AS [Unit!10!id],
		dbo.ProductType.ProductTypePrintName	 						AS [Unit!10!product],
		dbo.VamcDivision.DivisionName		 						AS [Unit!10!location],
		dbo.fnDateTimeConversionToHL7DateTime(dbo.fnTimeZoneConversionDateTime( @divisioncode, 0, BloodUnitMedia.UnitExpirationDate ))		AS [Unit!10!expDate],				
		NULL						 					AS [Specimen!11!expDate],
		NULL					 						AS [Specimen!11!uid],
		NULL						 					AS [Components!12],
		NULL					 						AS [Component!13!name],
		NULL					 						AS [Component!13!id],
		NULL					 						AS [Component!13!specimen],
		NULL					 						AS [LabTests!14],
		NULL					 						AS [LabTest!15!id],
		NULL					 						AS [LabTest!15!name],
		NULL					 						AS [MsbosList!16],
		NULL					 						AS [Msbos!17!name],
		NULL					 						AS [Msbos!17!threshold],
		NULL					 						AS [Surgeries!18],
		NULL					 						AS [Surgery!19!name]

FROM		dbo.BloodUnitStatusCodeCurrent BUSCC

	INNER JOIN 	dbo.BloodUnit
		ON 	BUSCC.BloodUnitGUID = dbo.BloodUnit.BloodUnitGUID
	
	LEFT  JOIN	dbo.PatientTransfusion
		ON	dbo.BloodUnit.BloodUnitGuid = dbo.PatientTransfusion.BloodUnitGuid
	
	INNER JOIN 	dbo.OrderedUnit
		ON 	dbo.BloodUnit.BloodUnitGUID = dbo.OrderedUnit.BloodUnitGUID
	
	INNER JOIN 	dbo.OrderedComponent
		ON	dbo.OrderedUnit.OrderedComponentGUID = dbo.OrderedComponent.OrderedComponentGUID
	
	LEFT JOIN	dbo.PatientSpecimen
		ON	dbo.OrderedComponent.PatientSpecimenGuid = dbo.PatientSpecimen.PatientSpecimenGuid

	INNER JOIN 	dbo.PatientOrder
		ON 	dbo.OrderedComponent.PatientOrderGUID = dbo.PatientOrder.PatientOrderGUID
	
	INNER JOIN 	dbo.PatientTreatment
		ON 	dbo.PatientOrder.PatientTreatmentGUID = dbo.PatientTreatment.PatientTreatmentGUID
	
	INNER JOIN 	dbo.Patient
		ON	dbo.PatientTreatment.PatientGUID = dbo.Patient.PatientGUID
	
	INNER JOIN 	dbo.BloodProduct
		ON 	dbo.BloodUnit.BloodProductGUID = dbo.BloodProduct.BloodProductGUID
	
	INNER JOIN 	dbo.ProductType
		ON 	dbo.BloodProduct.ProductTypeCode = dbo.ProductType.ProductTypeCode
	
	INNER JOIN 	dbo.VamcDivision
		ON 	dbo.BloodUnit.DivisionCode = dbo.VamcDivision.DivisionCode
	
	INNER JOIN 	dbo.BloodUnitMedia
		ON 	dbo.BloodUnit.BloodUnitGUID = dbo.BloodUnitMedia.BloodUnitGUID
	
	WHERE		

		dbo.Patient.VistaPatientID = @VistaPatientID
	
		AND	BUSCC.UnitStatusCode IN ( 'S', 'C' )
	
		AND	@PatientFoundFlag = 1
	
		AND	dbo.PatientTransfusion.TransfusionStartDateTime IS NULL
	
		AND	
		(	
			dbo.PatientSpecimen.SpecimenExpirationDate IS NULL 
			OR dbo.PatientSpecimen.SpecimenExpirationDate IS NOT NULL AND dbo.PatientSpecimen.SpecimenExpirationDate > GETUTCDATE()
		)

		AND	dbo.OrderedUnit.ReleaseDate IS NULL
		AND	dbo.OrderedUnit.SelectedDate IS NOT NULL
	
		AND	((dbo.fnOrderedUnitCrossmatchResultCode(OrderedUnit.OrderedUnitGuid) IN ('C', 'E', 'G')) OR (OrderedUnit.CrossmatchResultCode IS NULL))

UNION ALL

-- Autologous units
-- <Unit status="" id="" product="" location="" expDate="" />
SELECT DISTINCT	
		10					AS Tag,
		9					AS Parent,
		2					 AS [Bloodbank!1!GroupOrder!hide],
		NULL					 AS [Component!13!GroupOrder!hide],
		NULL 					 AS [Bloodbank!1],
		NULL					 AS [Patient!2!dfn],
		NULL					 AS [Patient!2!firstName],
		NULL					 AS [Patient!2!lastName],
		NULL					 AS [Patient!2!ssn],
		NULL					 AS [Patient!2!abo],
		NULL					 AS [Patient!2!rh],
		NULL					 AS [TransfusionReactions!3],
		NULL					 AS [TransfusionReaction!4!type],
		NULL					 AS [TransfusionReaction!4!date],
		NULL					 AS [TransfusionRequirements!5],
		NULL					 AS [TransfusionRequirement!6!modifier],
		NULL					 AS [Antibodies!7],
		NULL					 AS [Antibody!8!name],
		NULL					 AS [Units!9],
		dbo.DonationType.RestrictionTypeCode	 AS [Unit!10!status],
		dbo.BloodUnit.EyeReadableUnitId		 AS [Unit!10!id],
		dbo.ProductType.ProductTypePrintName	 AS [Unit!10!product],
		dbo.VamcDivision.DivisionName		 AS [Unit!10!location],
		dbo.fnDateTimeConversionToHL7DateTime(dbo.fnTimeZoneConversionDateTime( @divisioncode, 0, BloodUnitMedia.UnitExpirationDate ))	 AS [Unit!10!expDate],
		NULL					 AS [Specimen!11!expDate],
		NULL					 AS [Specimen!11!uid],
		NULL					 AS [Components!12],
		NULL					 AS [Component!13!name],
		NULL					 AS [Component!13!id],
		NULL					 AS [Component!13!specimen],
		NULL					 AS [LabTests!14],
		NULL					 AS [LabTest!15!id],
		NULL					 AS [LabTest!15!name],
		NULL					 AS [MsbosList!16],
		NULL					 AS [Msbos!17!name],
		NULL					 AS [Msbos!17!threshold],
		NULL					 AS [Surgeries!18],
		NULL					 AS [Surgery!19!name]
FROM		dbo.DonationType

	INNER JOIN	dbo.BloodUnit
		ON	dbo.DonationType.DonationTypeId = dbo.BloodUnit.DonationTypeId
	
	INNER JOIN 	dbo.BloodUnitMedia
		ON 	dbo.BloodUnit.BloodUnitGUID = dbo.BloodUnitMedia.BloodUnitGUID
	
	LEFT OUTER JOIN	dbo.PatientTransfusion
		ON	dbo.BloodUnit.BloodUnitGuid = dbo.PatientTransfusion.BloodUnitGuid
	
	INNER JOIN 	dbo.OrderedUnit
		ON 	dbo.BloodUnit.BloodUnitGUID = dbo.OrderedUnit.BloodUnitGUID
	
	INNER JOIN 	dbo.Patient
		ON 	dbo.BloodUnitMedia.DirectedPatientGUID = dbo.Patient.PatientGUID
	
	INNER JOIN 	dbo.BloodProduct
		ON 	dbo.BloodUnit.BloodProductGUID = dbo.BloodProduct.BloodProductGUID
	
	INNER JOIN 	dbo.ProductType
		ON 	dbo.BloodProduct.ProductTypeCode = dbo.ProductType.ProductTypeCode
	
	INNER JOIN 	dbo.VamcDivision
		ON 	dbo.BloodUnit.DivisionCode = dbo.VamcDivision.DivisionCode
	
	WHERE		dbo.Patient.VistaPatientID = @VistaPatientID
	
		AND 	dbo.DonationType.RestrictionTypeCode IN ('A', 'D')
	
		AND	@PatientFoundFlag = 1
	
		AND	dbo.BloodUnitMedia.UnitExpirationDate > GETUTCDATE()
	
		AND	PatientTransfusion.TransfusionStartDateTime IS NULL
	
		AND	dbo.OrderedUnit.ReleaseDate IS NULL
	
		AND	dbo.OrderedUnit.SelectedDate IS NOT NULL
	
		AND	((dbo.OrderedUnit.CrossmatchResultCode IN ('C', 'G')) OR (dbo.OrderedUnit.CrossmatchResultCode IS NULL))

UNION ALL

-- <Specimen expDate="" uid="" />
SELECT DISTINCT	
		11					AS Tag,
		2					AS Parent,
		2					 AS [Bloodbank!1!GroupOrder!hide],
		NULL					 AS [Component!13!GroupOrder!hide],
		NULL 					 AS [Bloodbank!1],
		NULL					 AS [Patient!2!dfn],
		NULL					 AS [Patient!2!firstName],
		NULL					 AS [Patient!2!lastName],
		NULL					 AS [Patient!2!ssn],
		NULL					 AS [Patient!2!abo],
		NULL					 AS [Patient!2!rh],
		NULL					 AS [TransfusionReactions!3],
		NULL					 AS [TransfusionReaction!4!type],
		NULL					 AS [TransfusionReaction!4!date],
		NULL					 AS [TransfusionRequirements!5],
		NULL					 AS [TransfusionRequirement!6!modifier],
		NULL					 AS [Antibodies!7],
		NULL					 AS [Antibody!8!name],
		NULL					 AS [Units!9],
		NULL					 AS [Unit!10!status],
		NULL					 AS [Unit!10!id],
		NULL					 AS [Unit!10!product],
		NULL					 AS [Unit!10!location],
		NULL					 AS [Unit!10!expDate],
		dbo.fnDateTimeConversionToHL7DateTime(dbo.fnTimeZoneConversionDateTime( @divisioncode, 0, PatientSpecimen.SpecimenExpirationDate ))	 AS [Specimen!11!expDate],
		dbo.PatientSpecimen.SpecimenUID		 AS [Specimen!11!uid],
		NULL					 AS [Components!12],
		NULL					 AS [Component!13!name],
		NULL					 AS [Component!13!id],
		NULL					 AS [Component!13!specimen],
		NULL					 AS [LabTests!14],
		NULL					 AS [LabTest!15!id],
		NULL					 AS [LabTest!15!name],
		NULL					 AS [MsbosList!16],
		NULL					 AS [Msbos!17!name],
		NULL					 AS [Msbos!17!threshold],
		NULL					 AS [Surgeries!18],
		NULL					 AS [Surgery!19!name]
FROM		dbo.PatientSpecimen

	INNER JOIN 	dbo.OrderedTest
		ON 	dbo.PatientSpecimen.PatientSpecimenGUID = dbo.OrderedTest.PatientSpecimenGUID
	
	INNER JOIN 	dbo.OrderableTest
		ON	dbo.OrderedTest.OrderableTestID = dbo.OrderableTest.OrderableTestID
	
	INNER JOIN 	dbo.Patient
		ON 	dbo.PatientSpecimen.PatientGUID =dbo. Patient.PatientGUID	
	
	WHERE	dbo.Patient.VistaPatientID = @VistaPatientID
	
		AND	dbo.PatientSpecimen.UnacceptableSpecimenIndicator <> 1
	
		AND	dbo.OrderableTest.CprsOrderableItemID = '1'
	
		AND	dbo.PatientSpecimen.SpecimenExpirationDate > GETUTCDATE()
	
		AND	@PatientFoundFlag = 1
	
	/****** Brian Tomlin:  Added Division check on PatientSpecimen 07-12-2004 *******/
		AND	dbo.PatientSpecimen.DivisionCode = @DivisionCode
	

UNION ALL

-- <Components>
SELECT		
		12					AS Tag,
		1					AS Parent,
		3					 AS [Bloodbank!1!GroupOrder!hide],
		NULL					 AS [Component!13!GroupOrder!hide],
		NULL 					 AS [Bloodbank!1],
		NULL					 AS [Patient!2!dfn],
		NULL					 AS [Patient!2!firstName],
		NULL					 AS [Patient!2!lastName],
		NULL					 AS [Patient!2!ssn],
		NULL					 AS [Patient!2!abo],
		NULL					 AS [Patient!2!rh],
		NULL					 AS [TransfusionReactions!3],
		NULL					 AS [TransfusionReaction!4!type],
		NULL					 AS [TransfusionReaction!4!date],
		NULL					 AS [TransfusionRequirements!5],
		NULL					 AS [TransfusionRequirement!6!modifier],
		NULL					 AS [Antibodies!7],
		NULL					 AS [Antibody!8!name],
		NULL					 AS [Units!9],
		NULL					 AS [Unit!10!status],
		NULL					 AS [Unit!10!id],
		NULL					 AS [Unit!10!product],
		NULL					 AS [Unit!10!location],
		NULL					 AS [Unit!10!expDate],
		NULL					 AS [Specimen!11!expDate],
		NULL					 AS [Specimen!11!uid],
		NULL					 AS [Components!12],
		NULL					 AS [Component!13!name],
		NULL					 AS [Component!13!id],
		NULL					 AS [Component!13!specimen],
		NULL					 AS [LabTests!14],
		NULL					 AS [LabTest!15!id],
		NULL					 AS [LabTest!15!name],
		NULL					 AS [MsbosList!16],
		NULL					 AS [Msbos!17!name],
		NULL					 AS [Msbos!17!threshold],
		NULL					 AS [Surgeries!18],
		NULL					 AS [Surgery!19!name]

UNION ALL

-- <Component name="" id="" specimen="">
SELECT DISTINCT	
		13					AS Tag,
		12					AS Parent,
		3					 AS [Bloodbank!1!GroupOrder!hide],
		NULL					 AS [Component!13!GroupOrder!hide],
		NULL 					 AS [Bloodbank!1],
		NULL					 AS [Patient!2!dfn],
		NULL					 AS [Patient!2!firstName],
		NULL					 AS [Patient!2!lastName],
		NULL					 AS [Patient!2!ssn],
		NULL					 AS [Patient!2!abo],
		NULL					 AS [Patient!2!rh],
		NULL					 AS [TransfusionReactions!3],
		NULL					 AS [TransfusionReaction!4!type],
		NULL					 AS [TransfusionReaction!4!date],
		NULL					 AS [TransfusionRequirements!5],
		NULL					 AS [TransfusionRequirement!6!modifier],
		NULL					 AS [Antibodies!7],
		NULL					 AS [Antibody!8!name],
		NULL					 AS [Units!9],
		NULL					 AS [Unit!10!status],
		NULL					 AS [Unit!10!id],
		NULL					 AS [Unit!10!product],
		NULL					 AS [Unit!10!location],
		NULL					 AS [Unit!10!expDate],
		NULL					 AS [Specimen!11!expDate],
		NULL					 AS [Specimen!11!uid],
		NULL					 AS [Components!12],
		CompCls.ComponentClassShortName		 AS [Component!13!name],
		rtrim( CompCls.CprsOrderableItemID )	 AS [Component!13!id],
		CompClsParam.SpecimenRequiredIndicator	 AS [Component!13!specimen],
		NULL					 AS [LabTests!14],
		NULL					 AS [LabTest!15!id],
		NULL					 AS [LabTest!15!name],
		NULL					 AS [MsbosList!16],
		NULL					 AS [Msbos!17!name],
		NULL					 AS [Msbos!17!threshold],
		NULL					 AS [Surgeries!18],
		NULL					 AS [Surgery!19!name]
FROM		dbo.ComponentClass CompCls
	
	INNER JOIN 	dbo.ComponentClassParameter CompClsParam
		ON 	CompCls.ComponentClassID = CompClsParam.ComponentClassID
	
	WHERE 		CompCls.CprsOrderableItemID IS NOT NULL

		AND	CompClsParam.DivisionCode = @DivisionCode

UNION ALL

-- <LabTests>
SELECT		
		14					AS Tag,
		13					AS Parent,
		3					 AS [Bloodbank!1!GroupOrder!hide],
		1					 AS [Component!13!GroupOrder!hide],
		NULL 					 AS [Bloodbank!1],
		NULL					 AS [Patient!2!dfn],
		NULL					 AS [Patient!2!firstName],
		NULL					 AS [Patient!2!lastName],
		NULL					 AS [Patient!2!ssn],
		NULL					 AS [Patient!2!abo],
		NULL					 AS [Patient!2!rh],
		NULL					 AS [TransfusionReactions!3],
		NULL					 AS [TransfusionReaction!4!type],
		NULL					 AS [TransfusionReaction!4!date],
		NULL					 AS [TransfusionRequirements!5],
		NULL					 AS [TransfusionRequirement!6!modifier],
		NULL					 AS [Antibodies!7],
		NULL					 AS [Antibody!8!name],
		NULL					 AS [Units!9],
		NULL					 AS [Unit!10!status],
		NULL					 AS [Unit!10!id],
		NULL					 AS [Unit!10!product],
		NULL					 AS [Unit!10!location],
		NULL					 AS [Unit!10!expDate],
		NULL					 AS [Specimen!11!expDate],
		NULL					 AS [Specimen!11!uid],
		NULL					 AS [Components!12],
		NULL					 AS [Component!13!name],
		rtrim( CompCls.CprsOrderableItemID )	 AS [Component!13!id],
		NULL					 AS [Component!13!specimen],
		NULL					 AS [LabTests!14],
		NULL					 AS [LabTest!15!id],
		NULL					 AS [LabTest!15!name],
		NULL					 AS [MsbosList!16],
		NULL					 AS [Msbos!17!name],
		NULL					 AS [Msbos!17!threshold],
		NULL					 AS [Surgeries!18],
		NULL					 AS [Surgery!19!name]
FROM		dbo.ComponentClass CompCls
	
	INNER JOIN 	dbo.ComponentClassParameter CompClsParam
		ON 	CompCls.ComponentClassID = CompClsParam.ComponentClassID
	
	WHERE 		CompCls.CprsOrderableItemID IS NOT NULL
	
		AND	CompClsParam.DivisionCode = @DivisionCode

UNION ALL

-- <LabTest id="" name="">
SELECT DISTINCT	
		15					AS Tag,
		14					AS Parent,
		3					 AS [Bloodbank!1!GroupOrder!hide],
		1					 AS [Component!13!GroupOrder!hide],
		NULL 					 AS [Bloodbank!1],
		NULL					 AS [Patient!2!dfn],
		NULL					 AS [Patient!2!firstName],
		NULL					 AS [Patient!2!lastName],
		NULL					 AS [Patient!2!ssn],
		NULL					 AS [Patient!2!abo],
		NULL					 AS [Patient!2!rh],
		NULL					 AS [TransfusionReactions!3],
		NULL					 AS [TransfusionReaction!4!type],
		NULL					 AS [TransfusionReaction!4!date],
		NULL					 AS [TransfusionRequirements!5],
		NULL					 AS [TransfusionRequirement!6!modifier],
		NULL					 AS [Antibodies!7],
		NULL					 AS [Antibody!8!name],
		NULL					 AS [Units!9],
		NULL					 AS [Unit!10!status],
		NULL					 AS [Unit!10!id],
		NULL					 AS [Unit!10!product],
		NULL					 AS [Unit!10!location],
		NULL					 AS [Unit!10!expDate],
		NULL					 AS [Specimen!11!expDate],
		NULL					 AS [Specimen!11!uid],
		NULL					 AS [Components!12],
		NULL					 AS [Component!13!name],
		rtrim( CompCls.CprsOrderableItemID )	 AS [Component!13!id],
		NULL					 AS [Component!13!specimen],
		NULL					 AS [LabTests!14],
		rtrim( SpecTestThrd.LabTestID ) 	 AS [LabTest!15!id],
		SpecTestThrd.VistALaboratoryTestName 	 AS [LabTest!15!name],
		NULL					 AS [MsbosList!16],
		NULL					 AS [Msbos!17!name],
		NULL					 AS [Msbos!17!threshold],
		NULL					 AS [Surgeries!18],
		NULL					 AS [Surgery!19!name]
FROM		dbo.ComponentClass CompCls

	INNER JOIN	dbo.SpecimenTestThreshold SpecTestThrd
		ON 	SpecTestThrd.ComponentClassID = CompCls.ComponentClassID		
	
	WHERE		CompCls.CprsOrderableItemID IS NOT NULL
		AND 	SpecTestThrd.DivisionCode = @DivisionCode

UNION ALL

-- <MsbosList>
SELECT		
		16					AS Tag,
		13					AS Parent,
		3					 AS [Bloodbank!1!GroupOrder],
		2					 AS [Component!13!GroupOrder!hide],
		NULL 					 AS [Bloodbank!1],
		NULL					 AS [Patient!2!dfn],
		NULL					 AS [Patient!2!firstName],
		NULL					 AS [Patient!2!lastName],
		NULL					 AS [Patient!2!ssn],
		NULL					 AS [Patient!2!abo],
		NULL					 AS [Patient!2!rh],
		NULL					 AS [TransfusionReactions!3],
		NULL					 AS [TransfusionReaction!4!type],
		NULL					 AS [TransfusionReaction!4!date],
		NULL					 AS [TransfusionRequirements!5],
		NULL					 AS [TransfusionRequirement!6!modifier],
		NULL					 AS [Antibodies!7],
		NULL					 AS [Antibody!8!name],
		NULL					 AS [Units!9],
		NULL					 AS [Unit!10!status],
		NULL					 AS [Unit!10!id],
		NULL					 AS [Unit!10!product],
		NULL					 AS [Unit!10!location],
		NULL					 AS [Unit!10!expDate],
		NULL					 AS [Specimen!11!expDate],
		NULL					 AS [Specimen!11!uid],
		NULL					 AS [Components!12],
		NULL					 AS [Component!13!name],
		rtrim( CompCls.CprsOrderableItemID )	 AS [Component!13!id],
		NULL					 AS [Component!13!specimen],
		NULL					 AS [LabTests!14],
		NULL					 AS [LabTest!15!id],
		NULL					 AS [LabTest!15!name],
		NULL					 AS [MsbosList!16],
		NULL					 AS [Msbos!17!name],
		NULL					 AS [Msbos!17!threshold],
		NULL					 AS [Surgeries!18],
		NULL					 AS [Surgery!19!name]
FROM		dbo.ComponentClass CompCls
	
	INNER JOIN 	dbo.ComponentClassParameter CompClsParam
		ON 	CompCls.ComponentClassID = CompClsParam.ComponentClassID
	
	WHERE 		CompCls.CprsOrderableItemID IS NOT NULL
		AND	CompClsParam.DivisionCode = @DivisionCode

UNION ALL

-- <Msbos name="" threshold="" />
SELECT DISTINCT	
		17					AS Tag,
		16					AS Parent,
		3					 AS [Bloodbank!1!GroupOrder!hide],
		2					 AS [Component!13!GroupOrder!hide],
		NULL 					 AS [Bloodbank!1],
		NULL					 AS [Patient!2!dfn],
		NULL					 AS [Patient!2!firstName],
		NULL					 AS [Patient!2!lastName],
		NULL					 AS [Patient!2!ssn],
		NULL					 AS [Patient!2!abo],
		NULL					 AS [Patient!2!rh],
		NULL					 AS [TransfusionReactions!3],
		NULL					 AS [TransfusionReaction!4!type],
		NULL					 AS [TransfusionReaction!4!date],
		NULL					 AS [TransfusionRequirements!5],
		NULL					 AS [TransfusionRequirement!6!modifier],
		NULL					 AS [Antibodies!7],
		NULL					 AS [Antibody!8!name],
		NULL					 AS [Units!9],
		NULL					 AS [Unit!10!status],
		NULL					 AS [Unit!10!id],
		NULL					 AS [Unit!10!product],
		NULL					 AS [Unit!10!location],
		NULL					 AS [Unit!10!expDate],
		NULL					 AS [Specimen!11!expDate],
		NULL					 AS [Specimen!11!uid],
		NULL					 AS [Components!12],
		NULL					 AS [Component!13!name],
		rtrim( CompCls.CprsOrderableItemID )	 AS [Component!13!id],
		NULL					 AS [Component!13!specimen],
		NULL					 AS [LabTests!14],
		NULL					 AS [LabTest!15!id],
		NULL					 AS [LabTest!15!name],
		NULL					 AS [MsbosList!16],
		Msbos.SurgeryName			 AS [Msbos!17!name],
		MsbosComponentClass.MaximumSetupUnitQuantity  AS [Msbos!17!threshold],
		NULL					 AS [Surgeries!18],
		NULL					 AS [Surgery!19!name]
FROM		dbo.ComponentClass CompCls

	INNER JOIN	dbo.MsbosComponentClass
		ON	CompCls.ComponentClassID = MsbosComponentClass.ComponentClassID		
	
	INNER JOIN	dbo.Msbos
		ON	Msbos.MsbosGUID = MsbosComponentClass.MsbosGUID
		
		WHERE		Msbos.DivisionCode = @DivisionCode
			AND	CompCls.CprsOrderableItemID IS NOT NULL

UNION ALL

-- <Surgeries>
SELECT		
		18					AS Tag,
		1					AS Parent,
		4					 AS [Bloodbank!1!GroupOrder!hide],
		NULL					 AS [Component!13!GroupOrder!hide],
		NULL 					 AS [Bloodbank!1],
		NULL					 AS [Patient!2!dfn],
		NULL					 AS [Patient!2!firstName],
		NULL					 AS [Patient!2!lastName],
		NULL					 AS [Patient!2!ssn],
		NULL					 AS [Patient!2!abo],
		NULL					 AS [Patient!2!rh],
		NULL					 AS [TransfusionReactions!3],
		NULL					 AS [TransfusionReaction!4!type],
		NULL					 AS [TransfusionReaction!4!date],
		NULL					 AS [TransfusionRequirements!5],
		NULL					 AS [TransfusionRequirement!6!modifier],
		NULL					 AS [Antibodies!7],
		NULL					 AS [Antibody!8!name],
		NULL					 AS [Units!9],
		NULL					 AS [Unit!10!status],
		NULL					 AS [Unit!10!id],
		NULL					 AS [Unit!10!product],
		NULL					 AS [Unit!10!location],
		NULL					 AS [Unit!10!expDate],
		NULL					 AS [Specimen!11!expDate],
		NULL					 AS [Specimen!11!uid],
		NULL					 AS [Components!12],
		NULL					 AS [Component!13!name],
		NULL					 AS [Component!13!id],
		NULL					 AS [Component!13!specimen],
		NULL					 AS [LabTests!14],
		NULL					 AS [LabTest!15!id],
		NULL					 AS [LabTest!15!name],
		NULL					 AS [MsbosList!16],
		NULL					 AS [Msbos!17!name],
		NULL					 AS [Msbos!17!threshold],
		NULL					 AS [Surgeries!18],
		NULL					 AS [Surgery!19!name]

UNION ALL

-- <Surgery name="">
SELECT DISTINCT	
		19					AS Tag,
		18					AS Parent,
		4					 AS [Bloodbank!1!GroupOrder!hide],
		NULL					 AS [Component!13!GroupOrder!hide],
		NULL 					 AS [Bloodbank!1],
		NULL					 AS [Patient!2!dfn],
		NULL					 AS [Patient!2!firstName],
		NULL					 AS [Patient!2!lastName],
		NULL					 AS [Patient!2!ssn],
		NULL					 AS [Patient!2!abo],
		NULL					 AS [Patient!2!rh],
		NULL					 AS [TransfusionReactions!3],
		NULL					 AS [TransfusionReaction!4!type],
		NULL					 AS [TransfusionReaction!4!date],
		NULL					 AS [TransfusionRequirements!5],
		NULL					 AS [TransfusionRequirement!6!modifier],
		NULL					 AS [Antibodies!7],
		NULL					 AS [Antibody!8!name],
		NULL					 AS [Units!9],
		NULL					 AS [Unit!10!status],
		NULL					 AS [Unit!10!id],
		NULL					 AS [Unit!10!product],
		NULL					 AS [Unit!10!location],
		NULL					 AS [Unit!10!expDate],
		NULL					 AS [Specimen!11!expDate],
		NULL					 AS [Specimen!11!uid],
		NULL					 AS [Components!12],
		NULL					 AS [Component!13!name],
		NULL					 AS [Component!13!id],
		NULL					 AS [Component!13!specimen],
		NULL					 AS [LabTests!14],
		NULL					 AS [LabTest!15!id],
		NULL					 AS [LabTest!15!name],
		NULL					 AS [MsbosList!16],
		NULL					 AS [Msbos!17!name],
		NULL					 AS [Msbos!17!threshold],
		NULL					 AS [Surgeries!18],
		dbo.Msbos.SurgeryName			 AS [Surgery!19!name]
FROM		dbo.Msbos

ORDER BY	[Bloodbank!1!GroupOrder!hide], 
		[Component!13!id], 
		[Component!13!GroupOrder!hide], 
		[LabTest!15!id], 
		[Msbos!17!name], 
		tag
FOR XML EXPLICIT

SET NOCOUNT OFF
GO

if exists (select * from dbo.sysobjects where id = object_id(N'dbo.spVistaGetXmlPatientData') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure dbo.spVistaGetXmlPatientData
GO
/*******************************************************************************************************************************************************************************
**	Desc: 	
**
**	Author:	Brian Tomlin / Stas Antropov
**	Date: 	01-25-2005
*******************************************************************************************************************************************************************************
**	Modified:
**	Date		Name		Description
**	----------	--------------	------------------------------------------------------------------------------------------------------------------------------------------------------------------------
**	06/29/2005	NPaterson	** Reviewed for compliance with database standards and recommendations **
**					Header added, Added NOCOUNT, Specified table owners, Removed comments, UPPERCASED SQL
**	05/13/2008	M. Smith	Changed @VistaPatientID to BIGINT datatype (CR 2431)
**	06/04/2008	K. Adu-Poku	** Reviewed for compliance with database standards and recommendations **
**	06/16/2008	M. Smith	Changed "SELECT" to "SET" for @PatientFoundFlag, changed JOIN to be ANSI 92 compliant, and
**					moved @PatientFoundFlag up for performance 
**	01/04/10	M. Smith	Changed to get and check UnitStatusCode from the BloodUnitStatusCodeCurrent table. (CR 1174)
**	01/25/2010	K. Adu-Poku	** Reviewed for compliance with database standards and recommendations **
*******************************************************************************************************************************************************************************/
CREATE PROCEDURE dbo.spVistaGetXmlPatientData
(
	@VistAPatientId		BIGINT
)

AS

SET NOCOUNT ON

DECLARE @PatientFoundFlag AS BIT
	
	SET @PatientFoundFlag = ISNULL((	SELECT 	TOP 1 1
						FROM 	dbo.Patient
						WHERE	VistaPatientId = @VistaPatientId), 0 )

--<BloodBank>
SELECT	1					AS Tag,
		NULL					AS Parent,
		1					 AS [Bloodbank!1!GroupOrder!hide],
		NULL					 AS [Component!11!GroupOrder!hide],
		NULL 					 AS [Bloodbank!1],
		NULL					 AS [Patient!2!dfn],
		NULL					 AS [Patient!2!firstName],
		NULL					 AS [Patient!2!lastName],
		NULL					 AS [Patient!2!ssn],
		NULL					 AS [Patient!2!abo],
		NULL					 AS [Patient!2!rh],
		NULL					 AS [TransfusionReactions!3],
		NULL					 AS [TransfusionReaction!4!type],
		NULL					 AS [TransfusionReaction!4!date],
		NULL					 AS [Antibodies!5],
		NULL					 AS [Antibody!6!name],
		NULL					 AS [Units!7],
		NULL					 AS [Unit!8!status],
		NULL					 AS [Unit!8!id],
		NULL					 AS [Unit!8!product],
		NULL					 AS [Unit!8!location],
		NULL					 AS [Unit!8!expDate]

UNION ALL

-- <Patient dfn="" firstName="" lastName="" ssn="" abo="" rh="">
SELECT	2					AS Tag,
		1					AS Parent,
		2					 AS [Bloodbank!1!GroupOrder!hide],
		NULL					 AS [Component!11!GroupOrder!hide],
		NULL 					 AS [Bloodbank!1],
		P.VistaPatientID			 AS [Patient!2!dfn],
		P.PatientFirstName			 AS [Patient!2!firstName],
		P.PatientLastName			 AS [Patient!2!lastName],
		P.PatientSSN				 AS [Patient!2!ssn],
		dbo.fnGetABO( P.PatientGUID )	 AS [Patient!2!abo],
		dbo.fnGetRh( P.PatientGUID )		 AS [Patient!2!rh],
		NULL					 AS [TransfusionReactions!3],
		NULL					 AS [TransfusionReaction!4!type],
		NULL					 AS [TransfusionReaction!4!date],
		NULL					 AS [Antibodies!5],
		NULL					 AS [Antibody!6!name],
		NULL					 AS [Units!7],
		NULL					 AS [Unit!8!status],
		NULL					 AS [Unit!8!id],
		NULL					 AS [Unit!8!product],
		NULL					 AS [Unit!8!location],
		NULL					 AS [Unit!8!expDate]
FROM		dbo.Patient P
WHERE		P.VistaPatientID = @VistaPatientID

UNION ALL

-- <TransfusionReactions>
SELECT	3					AS Tag,
		2					AS Parent,
		2					 AS [Bloodbank!1!GroupOrder!hide],
		NULL					 AS [Component!11!GroupOrder!hide],
		NULL 					 AS [Bloodbank!1],
		NULL					 AS [Patient!2!dfn],
		NULL					 AS [Patient!2!firstName],
		NULL					 AS [Patient!2!lastName],
		NULL					 AS [Patient!2!ssn],
		NULL					 AS [Patient!2!abo],
		NULL					 AS [Patient!2!rh],
		NULL					 AS [TransfusionReactions!3],
		NULL					 AS [TransfusionReaction!4!type],
		NULL					 AS [TransfusionReaction!4!date],
		NULL					 AS [Antibodies!5],
		NULL					 AS [Antibody!6!name],
		NULL					 AS [Units!7],
		NULL					 AS [Unit!8!status],
		NULL					 AS [Unit!8!id],
		NULL					 AS [Unit!8!product],
		NULL					 AS [Unit!8!location],
		NULL					 AS [Unit!8!expDate]
WHERE		@PatientFoundFlag = 1

UNION ALL

-- <TransfusionReaction type="" date="">
SELECT DISTINCT	
		4					AS Tag,
		3					AS Parent,
		2					 AS [Bloodbank!1!GroupOrder!hide],
		NULL					 AS [Component!11!GroupOrder!hide],
		NULL 					 AS [Bloodbank!1],
		NULL					 AS [Patient!2!dfn],
		NULL					 AS [Patient!2!firstName],
		NULL					 AS [Patient!2!lastName],
		NULL					 AS [Patient!2!ssn],
		NULL					 AS [Patient!2!abo],
		NULL					 AS [Patient!2!rh],
		NULL					 AS [TransfusionReactions!3],
		TransReactType.TransfusionReactionTypeText	 AS [TransfusionReaction!4!type],
		PatTransReact.NotedDateTime		 AS [TransfusionReaction!4!date],
		NULL					 AS [Antibodiess!5],
		NULL					 AS [Antibody!6!name],
		NULL					 AS [Units!7],
		NULL					 AS [Unit!8!status],
		NULL					 AS [Unit!8!id],
		NULL					 AS [Unit!8!product],
		NULL					 AS [Unit!8!location],
		NULL					 AS [Unit!8!expDate]

FROM		dbo.Patient P
	JOIN	dbo.PatientTransfusion PT
		ON P.PatientGuid = PT.PatientGuid
	JOIN	dbo.TransfusionReaction TR
		ON PT.PatientTransfusionGuid = TR.PatientTransfusionGuid
	JOIN	dbo.PatientTransfusionReaction PatTransReact
		ON TR.PatientTransfusionReactionGuid = PatTransReact.PatientTransfusionReactionGuid
	JOIN	dbo.TransfusionReactionType TransReactType 	
		ON PatTransReact.TransfusionReactionTypeCode = TransReactType.TransfusionReactionTypeCode
	
		WHERE	P.VistaPatientID = @VistaPatientID
			AND	@PatientFoundFlag = 1
			
UNION ALL 

-- <Antibodies>
SELECT	5					AS Tag,
		2					AS Parent,
		2					 AS [Bloodbank!1!GroupOrder!hide],
		NULL					 AS [Component!11!GroupOrder!hide],
		NULL 					 AS [Bloodbank!1],
		NULL					 AS [Patient!2!dfn],
		NULL					 AS [Patient!2!firstName],
		NULL					 AS [Patient!2!lastName],
		NULL					 AS [Patient!2!ssn],
		NULL					 AS [Patient!2!abo],
		NULL					 AS [Patient!2!rh],
		NULL					 AS [TransfusionReactions!3],
		NULL					 AS [TransfusionReaction!4!type],
		NULL					 AS [TransfusionReaction!4!date],
		NULL					 AS [Antibodies!5],
		NULL					 AS [Antibody!6!name],
		NULL					 AS [Units!7],
		NULL					 AS [Unit!8!status],
		NULL					 AS [Unit!8!id],
		NULL					 AS [Unit!8!product],
		NULL					 AS [Unit!8!location],
		NULL					 AS [Unit!8!expDate]
WHERE		@PatientFoundFlag = 1

UNION ALL

-- <Antibody name="">
SELECT DISTINCT	6					AS Tag,
		5					AS Parent,
		2					 AS [Bloodbank!1!GroupOrder!hide],
		NULL					 AS [Component!11!GroupOrder!hide],
		NULL 					 AS [Bloodbank!1],
		NULL					 AS [Patient!2!dfn],
		NULL					 AS [Patient!2!firstName],
		NULL					 AS [Patient!2!lastName],
		NULL					 AS [Patient!2!ssn],
		NULL					 AS [Patient!2!abo],
		NULL					 AS [Patient!2!rh],
		NULL					 AS [TransfusionReactions!3],
		NULL					 AS [TransfusionReaction!4!type],
		NULL					 AS [TransfusionReaction!4!date],
		NULL					 AS [Antibodies!5],
		dbo.AntibodyType.AntibodyTypeName		 AS [Antibody!6!name],
		NULL					 AS [Units!7],
		NULL					 AS [Unit!8!status],
		NULL					 AS [Unit!8!id],
		NULL					 AS [Unit!8!product],
		NULL					 AS [Unit!8!location],
		NULL					 AS [Unit!8!expDate]
	
FROM		dbo.Patient

	INNER JOIN	dbo.PatientTransfusionRequirement
		ON	dbo.PatientTransfusionRequirement.PatientGUID = dbo.Patient.PatientGUID	
		
	INNER JOIN 	dbo.AntibodyType
		ON 	dbo.AntibodyType.AntibodyTypeID = dbo.PatientTransfusionRequirement.AntibodyTypeID
	
		WHERE		dbo.Patient.VistaPatientID = @VistaPatientID
			AND	@PatientFoundFlag = 1

UNION ALL

-- <Units>
SELECT	7					AS Tag,
		2					AS Parent,
		2					 AS [Bloodbank!1!GroupOrder!hide],
		NULL					 AS [Component!11!GroupOrder!hide],
		NULL 					 AS [Bloodbank!1],
		NULL					 AS [Patient!2!dfn],
		NULL					 AS [Patient!2!firstName],
		NULL					 AS [Patient!2!lastName],
		NULL					 AS [Patient!2!ssn],
		NULL					 AS [Patient!2!abo],
		NULL					 AS [Patient!2!rh],
		NULL					 AS [TransfusionReactions!3],
		NULL					 AS [TransfusionReaction!4!type],
		NULL					 AS [TransfusionReaction!4!date],
		NULL					 AS [Antibodies!5],
		NULL					 AS [Antibody!6!name],
		NULL					 AS [Units!7],
		NULL					 AS [Unit!8!status],
		NULL					 AS [Unit!8!id],
		NULL					 AS [Unit!8!product],
		NULL					 AS [Unit!8!location],
		NULL					 AS [Unit!8!expDate]
WHERE		@PatientFoundFlag = 1

UNION ALL

-- Assigned and crossmatched units
-- <Unit status="" id="" product="" location="" expDate="" />
SELECT DISTINCT	
		8					AS Tag,
		7					AS Parent,
		2					 AS [Bloodbank!1!GroupOrder!hide],
		NULL					 AS [Component!11!GroupOrder!hide],
		NULL 					 AS [Bloodbank!1],
		NULL					 AS [Patient!2!dfn],
		NULL					 AS [Patient!2!firstName],
		NULL					 AS [Patient!2!lastName],
		NULL					 AS [Patient!2!ssn],
		NULL					 AS [Patient!2!abo],
		NULL					 AS [Patient!2!rh],
		NULL					 AS [TransfusionReactions!3],
		NULL					 AS [TransfusionReaction!4!type],
		NULL					 AS [TransfusionReaction!4!date],
		NULL					 AS [Antibodies!5],
		NULL					 AS [Antibody!6!name],
		NULL					 AS [Units!7],
		BUSCC.UnitStatusCode			 AS [Unit!8!status],
		dbo.BloodUnit.EyeReadableUnitId		 AS [Unit!8!id],
		dbo.ProductType.ProductTypePrintName	 AS [Unit!8!product],
		dbo.VamcDivision.DivisionName		 AS [Unit!8!location],
		dbo.BloodUnitMedia.UnitExpirationDate	 AS [Unit!8!expDate]

FROM		dbo.BloodUnitStatusCodeCurrent BUSCC

	INNER JOIN 	dbo.BloodUnit
		on 	BUSCC.BloodUnitGUID = dbo.BloodUnit.BloodUnitGUID

	INNER JOIN 	dbo.OrderedUnit
		on 	dbo.BloodUnit.BloodUnitGUID = dbo.OrderedUnit.BloodUnitGUID

	INNER JOIN 	dbo.OrderedComponent
		on 	dbo.OrderedUnit.OrderedComponentGUID = dbo.OrderedComponent.OrderedComponentGUID

	INNER JOIN 	dbo.PatientOrder
		on 	dbo.OrderedComponent.PatientOrderGUID = dbo.PatientOrder.PatientOrderGUID

	INNER JOIN 	dbo.PatientTreatment
		on 	dbo.PatientOrder.PatientTreatmentGUID = dbo.PatientTreatment.PatientTreatmentGUID

	INNER JOIN 	dbo.Patient
		on 	dbo.PatientTreatment.PatientGUID = dbo.Patient.PatientGUID

	INNER JOIN 	dbo.BloodProduct
		on 	dbo.BloodUnit.BloodProductGUID = dbo.BloodProduct.BloodProductGUID

	INNER JOIN 	dbo.ProductType
		on 	BloodProduct.ProductTypeCode = ProductType.ProductTypeCode

	INNER JOIN 	dbo.VamcDivision
		on 	dbo.BloodUnit.DivisionCode = dbo.VamcDivision.DivisionCode

	INNER JOIN 	dbo.BloodUnitMedia
		on 	dbo.BloodUnit.BloodUnitGUID = dbo.BloodUnitMedia.BloodUnitGUID

	WHERE		dbo.Patient.VistaPatientID = @VistaPatientID
		AND	@PatientFoundFlag = 1
		AND	BUSCC.UnitStatusCode IN ( 'S', 'C' )
		AND	dbo.BloodUnitMedia.UnitExpirationDate > GETUTCDATE()

UNION ALL

-- Autologous units
-- <Unit status="" id="" product="" location="" expDate="" />
SELECT DISTINCT	
		8					AS Tag,
		7					AS Parent,
		2					 AS [Bloodbank!1!GroupOrder!hide],
		NULL					 AS [Component!11!GroupOrder!hide],
		NULL 					 AS [Bloodbank!1],
		NULL					 AS [Patient!2!dfn],
		NULL					 AS [Patient!2!firstName],
		NULL					 AS [Patient!2!lastName],
		NULL					 AS [Patient!2!ssn],
		NULL					 AS [Patient!2!abo],
		NULL					 AS [Patient!2!rh],
		NULL					 AS [TransfusionReactions!3],
		NULL					 AS [TransfusionReaction!4!type],
		NULL					 AS [TransfusionReaction!4!date],
		NULL					 AS [Antibodies!5],
		NULL					 AS [Antibody!6!name],
		NULL					 AS [Units!7],
		dbo.DonationType.RestrictionTypeCode	 AS [Unit!8!status],
		dbo.BloodUnit.UnitProductCode		 AS [Unit!8!id],
		dbo.ProductType.ProductTypePrintName	 AS [Unit!8!product],
		dbo.VamcDivision.DivisionName		 AS [Unit!8!location],
		dbo.BloodUnitMedia.UnitExpirationDate	 AS [Unit!8!expDate]

FROM		dbo.DonationType

	INNER JOIN	dbo.BloodUnit
		ON	dbo.DonationType.DonationTypeId = dbo.BloodUnit.DonationTypeId

	INNER JOIN 	dbo.BloodUnitMedia
		ON 	dbo.BloodUnit.BloodUnitGUID = dbo.BloodUnitMedia.BloodUnitGUID

	INNER JOIN 	dbo.Patient
		ON 	dbo.BloodUnitMedia.DirectedPatientGUID = dbo.Patient.PatientGUID

	INNER JOIN 	dbo.BloodProduct
		ON 	dbo.BloodUnit.BloodProductGUID = dbo.BloodProduct.BloodProductGUID

	INNER JOIN 	dbo.ProductType
		ON 	dbo.BloodProduct.ProductTypeCode = dbo.ProductType.ProductTypeCode

	INNER JOIN 	dbo.VamcDivision
		ON 	dbo.BloodUnit.DivisionCode = dbo.VamcDivision.DivisionCode

		WHERE		dbo.Patient.VistaPatientID = @VistaPatientID
			AND	@PatientFoundFlag = 1
			AND 	dbo.DonationType.RestrictionTypeCode IN ('A', 'D')
			AND	dbo.BloodUnitMedia.UnitExpirationDate > GETUTCDATE()


FOR XML EXPLICIT

SET NOCOUNT OFF
GO

if exists (select * from dbo.sysobjects where id = object_id(N'dbo.spVistaGetXmlPatientReportData') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure dbo.spVistaGetXmlPatientReportData
GO
/*******************************************************************************************************************************************************************************
**	Desc: 	
**
**	Author:	Brian Tomlin / Stas Antropov
**	Date: 	01-25-2005
*******************************************************************************************************************************************************************************
**	Modified:
**	Date		Name		Description
**	----------	---------------	------------------------------------------------------------------------------------------------------------------------------------------------------------------------
**	06/29/2005	NPaterson	** Reviewed for compliance with database standards and recommendations **
**							Header added, Added NOCOUNT, Specified table owners, Removed comments, UPPERCASED SQL
**							Removed Comments
**	07/19/2005	C. Taylor	Added call to fnOrderedUnitCrossmatchResultCode to ensure latest crossmatch result is used (there may be repeat XMs)
**	08/21/2005	S. Antropov	** Reviewed for compliance with database standards and recommendations **
**							Performed secondary review during the code promotion - merged changes
**	07/13/07	Lohse		Adding datetime conversion for CR2253.
**	03/20/08	M. Smith	Modified SpecimenTest!4!comment to do checking for corrected records and records entered in error, added
**					cannedComment, and changed where condition for specimen test to include recordstatus = 'E' (Entered in Error).  (CR2403, CR2404)
**	03/25/08	K Adu-Poku	** Reviewed for compliance with database standards and recommendations **
**	05/13/08	M. Smith	Changed @VistaPatientID to BIGINT datatype (CR 2431)
**	06/04/08	K. Adu-Poku	** Reviewed for compliance with database standards and recommendations **
**	06/16/08	M. Smith	Changed "SELECT" to "SET" for @PatientFoundFlag and moved @PatientFoundFlag up for performance 
**	01/04/10	M. Smith	Changed to get and check UnitStatusCode from the BloodUnitStatusCodeCurrent table. (CR 1174)
**	01/25/2010	K. Adu-Poku	** Reviewed for compliance with database standards and recommendations **
*******************************************************************************************************************************************************************************/
CREATE   PROCEDURE dbo.spVistaGetXmlPatientReportData
(
	@VistAPatientId		BIGINT
)

AS

SET NOCOUNT ON

DECLARE @PatientFoundFlag AS BIT
	
	SET @PatientFoundFlag = ISNULL((	SELECT 	TOP 1 1
						FROM 	Patient
						WHERE	VistaPatientId = @VistaPatientId), 0 )

--<BloodBank>
SELECT	1					AS Tag,
		NULL					AS Parent,
		1					AS [Bloodbank!1!GroupOrder!hide],
		NULL 					AS [Bloodbank!1],
		NULL					AS [Patient!2!dfn],
		NULL					AS [Patient!2!firstName],
		NULL					AS [Patient!2!lastName],
		NULL					AS [Patient!2!dob],
		NULL					AS [Patient!2!ssn],
		NULL					AS [Patient!2!abo],
		NULL					AS [Patient!2!rh],
		NULL					AS [SpecimenTests!3],
		NULL					AS [SpecimenTest!4!printTestName],
		NULL					AS [SpecimenTest!4!orderableTestName],
		NULL					AS [SpecimenTest!4!result],
		NULL					AS [SpecimenTest!4!testDate],
		NULL					AS [SpecimenTest!4!cprsOrderId],
		NULL					AS [SpecimenTest!4!divisionCode],
		NULL					AS [SpecimenTest!4!enteringTechId],
		NULL					AS [SpecimenTest!4!requestorId],
		NULL					AS [SpecimenTest!4!comment],
		NULL					AS [SpecimenTest!4!cannedComment],
		NULL					AS [ComponentRequests!5],
		NULL					AS [ComponentRequest!6!dateRequested],
		NULL					AS [ComponentRequest!6!dateWanted],
		NULL					AS [ComponentRequest!6!unitsRequested],
		NULL					AS [ComponentRequest!6!cprsOrderId],
		NULL					AS [ComponentRequest!6!componentClassName],
		NULL					AS [ComponentRequest!6!componentClassShortName],
		NULL					AS [ComponentRequest!6!requestorId],
		NULL					AS [ComponentRequest!6!enteredById],
		NULL					AS [Units!7],
		NULL					AS [Unit!8!status],
		NULL					AS [Unit!8!id],
		NULL					AS [Unit!8!product],
		NULL					AS [Unit!8!abo],
		NULL					AS [Unit!8!rh],
		NULL					AS [Unit!8!divisionCode],
		NULL					AS [Unit!8!location],
		NULL					AS [Unit!8!expDate]

UNION ALL

-- <Patient dfn="" firstName="" lastName="" dob="" ssn="" abo="" rh="">
SELECT	2					AS Tag,
		1					AS Parent,
		2					AS [Bloodbank!1!GroupOrder!hide],
		NULL 					AS [Bloodbank!1],
		P.VistaPatientID			AS [Patient!2!dfn],
		P.PatientFirstName			AS [Patient!2!firstName],
		P.PatientLastName			AS [Patient!2!lastName],
		dbo.fnPatientDobConversionToFileManDateTime(P.PatientGuid)	AS [Patient!2!dob],
		P.PatientSSN				AS [Patient!2!ssn],
		dbo.fnGetABO( P.PatientGUID )		AS [Patient!2!abo],
		dbo.fnGetRh( P.PatientGUID )		AS [Patient!2!rh],
		NULL					AS [SpecimenTests!3],
		NULL					AS [SpecimenTest!4!printTestName],
		NULL					AS [SpecimenTest!4!orderableTestName],
		NULL					AS [SpecimenTest!4!result],
		NULL					AS [SpecimenTest!4!testDate],
		NULL					AS [SpecimenTest!4!cprsOrderId],
		NULL					AS [SpecimenTest!4!divisionCode],
		NULL					AS [SpecimenTest!4!enteringTechId],
		NULL					AS [SpecimenTest!4!requestorId],
		NULL					AS [SpecimenTest!4!comment],
		NULL					AS [SpecimenTest!4!cannedComment],
		NULL					AS [ComponentRequests!5],
		NULL					AS [ComponentRequest!6!dateRequested],
		NULL					AS [ComponentRequest!6!dateWanted],
		NULL					AS [ComponentRequest!6!unitsRequested],
		NULL					AS [ComponentRequest!6!cprsOrderId],
		NULL					AS [ComponentRequest!6!componentClassName],
		NULL					AS [ComponentRequest!6!componentClassShortName],
		NULL					AS [ComponentRequest!6!requestorId],
		NULL					AS [ComponentRequest!6!enteredById],
		NULL					AS [Units!7],
		NULL					AS [Unit!8!status],
		NULL					AS [Unit!8!id],
		NULL					AS [Unit!8!product],
		NULL					AS [Unit!8!abo],
		NULL					AS [Unit!8!rh],
		NULL					AS [Unit!8!divisionCode],
		NULL					AS [Unit!8!location],
		NULL					AS [Unit!8!expDate]
FROM		dbo.Patient P
WHERE		P.VistaPatientID = @VistaPatientID

UNION ALL

-- <SpecimenTests>
SELECT	3					AS Tag,
		2					AS Parent,
		2					AS [Bloodbank!1!GroupOrder!hide],
		NULL 					AS [Bloodbank!1],
		NULL					AS [Patient!2!dfn],
		NULL					AS [Patient!2!firstName],
		NULL					AS [Patient!2!lastName],
		NULL					AS [Patient!2!dob],
		NULL					AS [Patient!2!ssn],
		NULL					AS [Patient!2!abo],
		NULL					AS [Patient!2!rh],
		NULL					AS [SpecimenTests!3],
		NULL					AS [SpecimenTest!4!printTestName],
		NULL					AS [SpecimenTest!4!orderableTestName],
		NULL					AS [SpecimenTest!4!result],
		NULL					AS [SpecimenTest!4!testDate],
		NULL					AS [SpecimenTest!4!cprsOrderId],
		NULL					AS [SpecimenTest!4!divisionCode],
		NULL					AS [SpecimenTest!4!enteringTechId],
		NULL					AS [SpecimenTest!4!requestorId],
		NULL					AS [SpecimenTest!4!comment],
		NULL					AS [SpecimenTest!4!cannedComment],
		NULL					AS [ComponentRequests!5],
		NULL					AS [ComponentRequest!6!dateRequested],
		NULL					AS [ComponentRequest!6!dateWanted],
		NULL					AS [ComponentRequest!6!unitsRequested],
		NULL					AS [ComponentRequest!6!cprsOrderId],
		NULL					AS [ComponentRequest!6!componentClassName],
		NULL					AS [ComponentRequest!6!componentClassShortName],
		NULL					AS [ComponentRequest!6!requestorId],
		NULL					AS [ComponentRequest!6!enteredById],
		NULL					AS [Units!7],
		NULL					AS [Unit!8!status],
		NULL					AS [Unit!8!id],
		NULL					AS [Unit!8!product],
		NULL					AS [Unit!8!abo],
		NULL					AS [Unit!8!rh],
		NULL					AS [Unit!8!divisionCode],
		NULL					AS [Unit!8!location],
		NULL					AS [Unit!8!expDate]
WHERE		@PatientFoundFlag = 1

UNION ALL

-- Specimen test results
-- <SpecimenTest printTestName="" orderableTestName="" result="" testDate="" cprsOrderId="" 
--	divisionCode="" enteringTechId="" requestorId="">
SELECT DISTINCT	
		4					AS Tag,
		3					AS Parent,
		2					AS [Bloodbank!1!GroupOrder!hide],
		NULL 					AS [Bloodbank!1],
		NULL					AS [Patient!2!dfn],
		NULL					AS [Patient!2!firstName],
		NULL					AS [Patient!2!lastName],
		NULL					AS [Patient!2!dob],
		NULL					AS [Patient!2!ssn],
		NULL					AS [Patient!2!abo],
		NULL					AS [Patient!2!rh],
		NULL					AS [SpecimenTests!3],
		dbo.BloodTestType.BloodTestName		AS [SpecimenTest!4!printTestName],
		dbo.OrderableTest.OrderableTestName		AS [SpecimenTest!4!orderableTestName],
		dbo.TestResult.TestResultText		AS [SpecimenTest!4!result],
		dbo.fnDateTimeConversionToFileManDateTime(dbo.fnTimeZoneConversionDateTime( SpecimenTest.DivisionCode, 0, SpecimenTest.TestDate))	AS [SpecimenTest!4!testDate],
		dbo.PatientOrder.OrderGroupNumber		AS [SpecimenTest!4!cprsOrderId],
		dbo.SpecimenTest.DivisionCode		AS [SpecimenTest!4!divisionCode],
		dbo.VbecsUser.UserDUZ			AS [SpecimenTest!4!enteringTechId],
		dbo.PatientOrder.OrderingProviderId		AS [SpecimenTest!4!requestorId],
		CASE WHEN dbo.SpecimenTest.RecordStatusCode = 'E'
			THEN '** Entered in Error **     ' + ISNULL(dbo.SpecimenTest.TestComments, '')  + '     ' +
					CAST(dbo.fnTimeZoneConversionDateTime( dbo.SpecimenTest.DivisionCode, 0, dbo.SpecimenTest.TestDate) AS VARCHAR(20)) + '     ' + dbo.VbecsUser.UserName
		    WHEN CorrectedResultIndicator = 1
			THEN '** Corrected Result **     ' + ISNULL(dbo.SpecimenTest.TestComments, '')  + '     ' +
					CAST(dbo.fnTimeZoneConversionDateTime( dbo.SpecimenTest.DivisionCode, 0, dbo.SpecimenTest.TestDate) AS VARCHAR(20)) + '     ' + dbo.VbecsUser.UserName
			ELSE ISNULL(dbo.SpecimenTest.TestComments, '')
		END 					AS [SpecimenTest!4!comment],
		InformationMessageText			AS [SpecimenTest!4!cannedComment],
		NULL					AS [ComponentRequests!5],
		NULL					AS [ComponentRequest!6!dateRequested],
		NULL					AS [ComponentRequest!6!dateWanted],
		NULL					AS [ComponentRequest!6!unitsRequested],
		NULL					AS [ComponentRequest!6!cprsOrderId],
		NULL					AS [ComponentRequest!6!componentClassName],
		NULL					AS [ComponentRequest!6!componentClassShortName],
		NULL					AS [ComponentRequest!6!requestorId],
		NULL					AS [ComponentRequest!6!enteredById],
		NULL					AS [Units!7],
		NULL					AS [Unit!8!status],
		NULL					AS [Unit!8!id],
		NULL					AS [Unit!8!product],
		NULL					AS [Unit!8!abo],
		NULL					AS [Unit!8!rh],
		NULL					AS [Unit!8!divisionCode],
		NULL					AS [Unit!8!location],
		NULL					AS [Unit!8!expDate]

FROM		dbo.BloodTestType

	INNER JOIN	dbo.SpecimenTest
		ON	dbo.BloodTestType.BloodTestTypeId = dbo.SpecimenTest.BloodTestTypeId
	
	INNER JOIN	dbo.VbecsUser
		ON	dbo.SpecimenTest.EntryTechId = dbo.VbecsUser.VbecsUserId
	
	INNER JOIN	dbo.TestResult
		ON	dbo.SpecimenTest.TestResultId = dbo.TestResult.TestResultId
	
	INNER JOIN	dbo.OrderedTest
		ON	dbo.SpecimenTest.OrderedTestGuid = dbo.OrderedTest.OrderedTestGuid
	
	INNER JOIN	dbo.PatientOrder
		ON	dbo.OrderedTest.PatientOrderGuid = dbo.PatientOrder.PatientOrderGuid
	
	INNER JOIN	dbo.PatientTreatment
		ON	dbo.PatientOrder.PatientTreatmentGuid = dbo.PatientTreatment.PatientTreatmentGuid
	
	INNER JOIN	dbo.Patient
		ON	dbo.PatientTreatment.PatientGuid = dbo.Patient.PatientGuid
	
	INNER JOIN	dbo.OrderableTest
		ON	dbo.BloodTestType.OrderableTestId = dbo.OrderableTest.OrderableTestId
	CROSS JOIN 	dbo.InformationMessage
	
	
		WHERE		dbo.Patient.VistaPatientID = @VistaPatientID

			AND	@PatientFoundFlag = 1

			AND	dbo.OrderedTest.OrderStatusCode = 'C'

			AND	dbo.SpecimenTest.RecordStatusCode IN ('A', 'E')

			AND	dbo.InformationMessage.InformationMessageId = 5407

			AND	dbo.BloodTestType.BloodTestTypeId IN ( 18, 21, 52, 53, 54, 55, 56, 57, 58, 59, 61, 65, 68, 92, 93, 94,
								95, 105, 106, 107, 108, 109, 110 )
				
UNION ALL 

-- Antibody test results
-- <SpecimenTest printTestName="" orderableTestName="" result="" testDate="" cprsOrderId="" 
--	divisionCode="" enteringTechId="" requestorId="">
SELECT DISTINCT	
		4					AS Tag,
		3					AS Parent,
		2					AS [Bloodbank!1!GroupOrder!hide],
		NULL 					AS [Bloodbank!1],
		NULL					AS [Patient!2!dfn],
		NULL					AS [Patient!2!firstName],
		NULL					AS [Patient!2!lastName],
		NULL					AS [Patient!2!dob],
		NULL					AS [Patient!2!ssn],
		NULL					AS [Patient!2!abo],
		NULL					AS [Patient!2!rh],
		NULL					AS [SpecimenTests!3],
		dbo.BloodTestType.BloodTestName		AS [SpecimenTest!4!printTestName],
		dbo.OrderableTest.OrderableTestName		AS [SpecimenTest!4!orderableTestName],
		dbo.AntibodyType.AntibodyTypeName collate SQL_Latin1_General_CP1_CI_AS		AS [SpecimenTest!4!result],
		dbo.fnDateTimeConversionToFileManDateTime(dbo.fnTimeZoneConversionDateTime( SpecimenTest.DivisionCode, 0, SpecimenTest.TestDate ))	AS [SpecimenTest!4!testDate],
		dbo.PatientOrder.OrderGroupNumber		AS [SpecimenTest!4!cprsOrderId],
		dbo.SpecimenTest.DivisionCode		AS [SpecimenTest!4!divisionCode],
		dbo.VbecsUser.UserDUZ			AS [SpecimenTest!4!enteringTechId],
		dbo.PatientOrder.OrderingProviderId		AS [SpecimenTest!4!requestorId],
		CASE WHEN dbo.SpecimenTest.RecordStatusCode = 'E'
			THEN '** Entered in Error **     ' + ISNULL(dbo.SpecimenTest.TestComments, '')  + '     ' +
					CAST(dbo.fnTimeZoneConversionDateTime( dbo.SpecimenTest.DivisionCode, 0, dbo.SpecimenTest.TestDate) AS VARCHAR(20)) + '     ' + dbo.VbecsUser.UserName
		    WHEN CorrectedResultIndicator = 1
			THEN '** Corrected Result **     ' + ISNULL(dbo.SpecimenTest.TestComments, '')  + '     ' +
					CAST(dbo.fnTimeZoneConversionDateTime( dbo.SpecimenTest.DivisionCode, 0, dbo.SpecimenTest.TestDate) AS VARCHAR(20)) + '     ' + dbo.VbecsUser.UserName
			ELSE ISNULL(dbo.SpecimenTest.TestComments, '')
		END 					AS [SpecimenTest!4!comment],
		InformationMessageText			AS [SpecimenTest!4!cannedComment],
		NULL					AS [ComponentRequests!5],
		NULL					AS [ComponentRequest!6!dateRequested],
		NULL					AS [ComponentRequest!6!dateWanted],
		NULL					AS [ComponentRequest!6!unitsRequested],
		NULL					AS [ComponentRequest!6!cprsOrderId],
		NULL					AS [ComponentRequest!6!componentClassName],
		NULL					AS [ComponentRequest!6!componentClassShortName],
		NULL					AS [ComponentRequest!6!requestorId],
		NULL					AS [ComponentRequest!6!enteredById],
		NULL					AS [Units!7],
		NULL					AS [Unit!8!status],
		NULL					AS [Unit!8!id],
		NULL					AS [Unit!8!product],
		NULL					AS [Unit!8!abo],
		NULL					AS [Unit!8!rh],
		NULL					AS [Unit!8!divisionCode],
		NULL					AS [Unit!8!location],
		NULL					AS [Unit!8!expDate]
FROM		dbo.BloodTestType

	INNER JOIN	dbo.SpecimenTest
		ON	dbo.BloodTestType.BloodTestTypeId = dbo.SpecimenTest.BloodTestTypeId
	
	INNER JOIN	dbo.VbecsUser
		ON	dbo.SpecimenTest.EntryTechId = dbo.VbecsUser.VbecsUserId
	
	INNER JOIN	dbo.AntibodyType
		ON	dbo.SpecimenTest.AntibodyTypeId = dbo.AntibodyType.AntibodyTypeId
	
	INNER JOIN	dbo.OrderedTest
		ON	dbo.SpecimenTest.OrderedTestGuid = dbo.OrderedTest.OrderedTestGuid
	
	INNER JOIN	dbo.PatientOrder
		ON	dbo.OrderedTest.PatientOrderGuid = dbo.PatientOrder.PatientOrderGuid
	
	INNER JOIN	dbo.PatientTreatment
		ON	dbo.PatientOrder.PatientTreatmentGuid = dbo.PatientTreatment.PatientTreatmentGuid
	
	INNER JOIN	dbo.Patient
		ON	dbo.PatientTreatment.PatientGuid = dbo.Patient.PatientGuid
	
	INNER JOIN	dbo.OrderableTest
		ON	dbo.BloodTestType.OrderableTestId = dbo.OrderableTest.OrderableTestId
	CROSS JOIN 	dbo.InformationMessage
	
		WHERE		dbo.Patient.VistaPatientID = @VistaPatientID

			AND	@PatientFoundFlag = 1		
			AND	dbo.OrderedTest.OrderStatusCode = 'C'

			AND	dbo.SpecimenTest.RecordStatusCode IN ('A', 'E')

			AND	dbo.InformationMessage.InformationMessageId = 2302

			AND	dbo.BloodTestType.BloodTestTypeId IN ( 52, 92, 107 )
	
UNION ALL

-- <ComponentRequests>
SELECT 		
		5					AS Tag,
		2					AS Parent,
		2					AS [Bloodbank!1!GroupOrder!hide],
		NULL 					AS [Bloodbank!1],
		NULL					AS [Patient!2!dfn],
		NULL					AS [Patient!2!firstName],
		NULL					AS [Patient!2!lastName],
		NULL					AS [Patient!2!dob],
		NULL					AS [Patient!2!ssn],
		NULL					AS [Patient!2!abo],
		NULL					AS [Patient!2!rh],
		NULL					AS [SpecimenTests!3],
		NULL					AS [SpecimenTest!4!printTestName],
		NULL					AS [SpecimenTest!4!orderableTestName],
		NULL					AS [SpecimenTest!4!result],
		NULL					AS [SpecimenTest!4!testDate],
		NULL					AS [SpecimenTest!4!cprsOrderId],
		NULL					AS [SpecimenTest!4!divisionCode],
		NULL					AS [SpecimenTest!4!enteringTechId],
		NULL					AS [SpecimenTest!4!requestorId],
		NULL					AS [SpecimenTest!4!comment],
		NULL					AS [SpecimenTest!4!cannedComment],
		NULL					AS [ComponentRequests!5],
		NULL					AS [ComponentRequest!6!dateRequested],
		NULL					AS [ComponentRequest!6!dateWanted],
		NULL					AS [ComponentRequest!6!unitsRequested],
		NULL					AS [ComponentRequest!6!cprsOrderId],
		NULL					AS [ComponentRequest!6!componentClassName],
		NULL					AS [ComponentRequest!6!componentClassShortName],
		NULL					AS [ComponentRequest!6!requestorId],
		NULL					AS [ComponentRequest!6!enteredById],
		NULL					AS [Units!7],
		NULL					AS [Unit!8!status],
		NULL					AS [Unit!8!id],
		NULL					AS [Unit!8!product],
		NULL					AS [Unit!8!abo],
		NULL					AS [Unit!8!rh],
		NULL					AS [Unit!8!divisionCode],
		NULL					AS [Unit!8!location],
		NULL					AS [Unit!8!expDate]
WHERE		@PatientFoundFlag = 1

UNION ALL

-- <ComponentRequest dateRequested="" dateWanted="" unitsRequested="" cprsOrderId="" componentClassName=""
--	componentClassShortName="" requestorId="" enteredById=">
SELECT DISTINCT	
		6					AS Tag,
		5					AS Parent,
		2					AS [Bloodbank!1!GroupOrder!hide],
		NULL 					AS [Bloodbank!1],
		NULL					AS [Patient!2!dfn],
		NULL					AS [Patient!2!firstName],
		NULL					AS [Patient!2!lastName],
		NULL					AS [Patient!2!dob],
		NULL					AS [Patient!2!ssn],
		NULL					AS [Patient!2!abo],
		NULL					AS [Patient!2!rh],
		NULL					AS [SpecimenTests!3],
		NULL					AS [SpecimenTest!4!printTestName],
		NULL					AS [SpecimenTest!4!orderableTestName],
		NULL					AS [SpecimenTest!4!result],
		NULL					AS [SpecimenTest!4!testDate],
		NULL					AS [SpecimenTest!4!cprsOrderId],
		NULL					AS [SpecimenTest!4!divisionCode],
		NULL					AS [SpecimenTest!4!enteringTechId],
		NULL					AS [SpecimenTest!4!requestorId],
		NULL					AS [SpecimenTest!4!comment],
		NULL					AS [SpecimenTest!4!cannedComment],
		NULL					AS [ComponentRequests!5],
		dbo.fnDateTimeConversionToFileManDateTime(dbo.fnTimeZoneConversionDateTime( PatientOrder.DivisionCode, 0, PatientOrder.OrderPlacedDatetime ))	AS [ComponentRequest!6!dateRequested],
		dbo.fnDateTimeConversionToFileManDateTime(dbo.fnTimeZoneConversionDateTime( OrderedComponent.DivisionCode, 0, OrderedComponent.RequiredDatetime ))	AS [ComponentRequest!6!dateWanted],
		dbo.OrderedComponent.RequiredUnitQuantity	AS [ComponentRequest!6!unitsRequested],
		dbo.PatientOrder.OrderGroupNumber		AS [ComponentRequest!6!cprsOrderId],
		dbo.ComponentClass.ComponentClassName	AS [ComponentRequest!6!componentClassName],
		dbo.ComponentClass.ComponentClassShortName	AS [ComponentRequest!6!componentClassShortName],
		dbo.PatientOrder.OrderingProviderId		AS [ComponentRequest!6!requestorId],
		dbo.PatientOrder.OrderEnteredById		AS [ComponentRequest!6!enteredById],
		NULL					AS [Units!7],
		NULL					AS [Unit!8!status],
		NULL					AS [Unit!8!id],
		NULL					AS [Unit!8!product],
		NULL					AS [Unit!8!abo],
		NULL					AS [Unit!8!rh],
		NULL					AS [Unit!8!divisionCode],
		NULL					AS [Unit!8!location],
		NULL					AS [Unit!8!expDate]
FROM		dbo.PatientOrder

	INNER JOIN	dbo.PatientTreatment
		ON	dbo.PatientOrder.PatientTreatmentGuid = dbo.PatientTreatment.PatientTreatmentGuid

	INNER JOIN	dbo.Patient
		ON	dbo.PatientTreatment.PatientGuid = dbo.Patient.PatientGuid

	INNER JOIN	dbo.OrderedComponent
		ON	dbo.PatientOrder.PatientOrderGuid = dbo.OrderedComponent.PatientOrderGuid

	INNER JOIN	dbo.ComponentClass
		ON	dbo.OrderedComponent.ComponentClassId = dbo.ComponentClass.ComponentClassId

		WHERE		dbo.Patient.VistaPatientID = @VistaPatientID
			AND	@PatientFoundFlag = 1

UNION ALL

-- <Units>
SELECT 		
		7					AS Tag,
		2					AS Parent,
		2					AS [Bloodbank!1!GroupOrder!hide],
		NULL 					AS [Bloodbank!1],
		NULL					AS [Patient!2!dfn],
		NULL					AS [Patient!2!firstName],
		NULL					AS [Patien!2!lastName],
		NULL					AS [Patient!2!dob],
		NULL					AS [Patient!2!ssn],
		NULL					AS [Patient!2!abo],
		NULL					AS [Patient!2!rh],
		NULL					AS [SpecimenTests!3],
		NULL					AS [SpecimenTest!4!printTestName],
		NULL					AS [SpecimenTest!4!orderableTestName],
		NULL					AS [SpecimenTest!4!result],
		NULL					AS [SpecimenTest!4!testDate],
		NULL					AS [SpecimenTest!4!cprsOrderId],
		NULL					AS [SpecimenTest!4!divisionCode],
		NULL					AS [SpecimenTest!4!enteringTechId],
		NULL					AS [SpecimenTest!4!requestorId],
		NULL					AS [SpecimenTest!4!comment],
		NULL					AS [SpecimenTest!4!cannedComment],
		NULL					AS [ComponentRequests!5],
		NULL					AS [ComponentRequest!6!dateRequested],
		NULL					AS [ComponentRequest!6!dateWanted],
		NULL					AS [ComponentRequest!6!unitsRequested],
		NULL					AS [ComponentRequest!6!cprsOrderId],
		NULL					AS [ComponentRequest!6!componentClassName],
		NULL					AS [ComponentRequest!6!componentClassShortName],
		NULL					AS [ComponentRequest!6!requestorId],
		NULL					AS [ComponentRequest!6!enteredById],
		NULL					AS [Units!7],
		NULL					AS [Unit!8!status],
		NULL					AS [Unit!8!id],
		NULL					AS [Unit!8!product],
		NULL					AS [Unit!8!abo],
		NULL					AS [Unit!8!rh],
		NULL					AS [Unit!8!divisionCode],
		NULL					AS [Unit!8!location],
		NULL					AS [Unit!8!expDate]
WHERE		@PatientFoundFlag = 1

UNION ALL

-- Assigned and crossmatched units
-- <Unit status="" id="" product="" abo="" rh="" divisionCode="" location="" expDate="" />
SELECT DISTINCT	
		8					AS Tag,
		7					AS Parent,
		2					AS [Bloodbank!1!GroupOrder!hide],
		NULL 					AS [Bloodbank!1],
		NULL					AS [Patient!2!dfn],
		NULL					AS [Patient!2!firstName],
		NULL					AS [Patient!2!lastName],
		NULL					AS [Patient!2!dob],
		NULL					AS [Patient!2!ssn],
		NULL					AS [Patient!2!abo],
		NULL					AS [Patient!2!rh],
		NULL					AS [SpecimenTests!3],
		NULL					AS [SpecimenTest!4!printTestName],
		NULL					AS [SpecimenTest!4!orderableTestName],
		NULL					AS [SpecimenTest!4!result],
		NULL					AS [SpecimenTest!4!testDate],
		NULL					AS [SpecimenTest!4!cprsOrderId],
		NULL					AS [SpecimenTest!4!divisionCode],
		NULL					AS [SpecimenTest!4!enteringTechId],
		NULL					AS [SpecimenTest!4!requestorId],
		NULL					AS [SpecimenTest!4!comment],
		NULL					AS [SpecimenTest!4!cannedComment],
		NULL					AS [ComponentRequests!5],
		NULL					AS [ComponentRequest!6!dateRequested],
		NULL					AS [ComponentRequest!6!dateWanted],
		NULL					AS [ComponentRequest!6!unitsRequested],
		NULL					AS [ComponentRequest!6!cprsOrderId],
		NULL					AS [ComponentRequest!6!componentClassName],
		NULL					AS [ComponentRequest!6!componentClassShortName],
		NULL					AS [ComponentRequest!6!requestorId],
		NULL					AS [ComponentRequest!6!enteredById],
		NULL					AS [Units!7],
		BUSCC.UnitStatusCode			AS [Unit!8!status],
		dbo.BloodUnit.EyeReadableUnitId		AS [Unit!8!id],
		dbo.ProductType.ProductTypePrintName	AS [Unit!8!product],
		dbo.BloodUnitMedia.BloodTypeCode		AS [Unit!8!abo],
		dbo.BloodUnitMedia.RhFactorCode		AS [Unit!8!rh],
		dbo.BloodUnit.DivisionCode			AS [Unit!8!divisionCode],
		dbo.IssuedUnit.LocationIen			AS [Unit!8!location],
		dbo.fnDateTimeConversionToFileManDateTime(dbo.fnTimeZoneConversionDateTime( BloodUnit.DivisionCode, 0, BloodUnitMedia.UnitExpirationDate ))	AS [Unit!8!expDate]

FROM		dbo.BloodUnitStatusCodeCurrent BUSCC

	INNER JOIN 	dbo.BloodUnit
		ON 	BUSCC.BloodUnitGUID = dbo.BloodUnit.BloodUnitGUID

	LEFT OUTER JOIN	dbo.IssuedUnit
		ON	dbo.BloodUnit.BloodUnitGuid = dbo.IssuedUnit.BloodUnitGuid

	INNER JOIN 	dbo.OrderedUnit
		ON 	dbo.BloodUnit.BloodUnitGUID = dbo.OrderedUnit.BloodUnitGUID

	INNER JOIN 	dbo.OrderedComponent
		ON 	dbo.OrderedUnit.OrderedComponentGUID = dbo.OrderedComponent.OrderedComponentGUID

	INNER JOIN 	dbo.PatientOrder
		ON	dbo.OrderedComponent.PatientOrderGUID = dbo.PatientOrder.PatientOrderGUID

	INNER JOIN 	dbo.PatientTreatment
		ON 	dbo.PatientOrder.PatientTreatmentGUID = dbo.PatientTreatment.PatientTreatmentGUID

	INNER JOIN 	dbo.Patient
		ON 	dbo.PatientTreatment.PatientGUID = dbo.Patient.PatientGUID

	INNER JOIN 	dbo.BloodProduct
		ON 	dbo.BloodUnit.BloodProductGUID = dbo.BloodProduct.BloodProductGUID

	INNER JOIN 	dbo.ProductType
		ON 	dbo.BloodProduct.ProductTypeCode = dbo.ProductType.ProductTypeCode

	INNER JOIN 	dbo.VamcDivision
		ON 	dbo.BloodUnit.DivisionCode = dbo.VamcDivision.DivisionCode

	INNER JOIN 	dbo.BloodUnitMedia
		ON 	dbo.BloodUnit.BloodUnitGUID = dbo.BloodUnitMedia.BloodUnitGUID


		WHERE		dbo.Patient.VistaPatientID = @VistaPatientID

			AND	@PatientFoundFlag = 1
			AND	BUSCC.UnitStatusCode IN ( 'S', 'C' )

			AND	dbo.BloodUnitMedia.UnitExpirationDate > GETUTCDATE()

			AND	dbo.OrderedUnit.ReleaseDate IS NULL

			AND	((dbo.fnOrderedUnitCrossmatchResultCode(OrderedUnit.OrderedUnitGuid) IN ('C', 'E', 'G')) OR (OrderedUnit.CrossmatchResultCode IS NULL))

ORDER BY	[Bloodbank!1!GroupOrder!hide],
		tag
		

FOR XML EXPLICIT

SET NOCOUNT OFF
GO

if exists (select * from dbo.sysobjects where id = object_id(N'dbo.spVistaGetXmlSpecimenTestForPatient') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure dbo.spVistaGetXmlSpecimenTestForPatient
GO
/*******************************************************************************************************************************************************************************
**	Desc: 	
**
**	Author:	Brian Tomlin / Stas Antropov
**	Date: 	01-25-2005
*******************************************************************************************************************************************************************************
**	Modified:
**	Date		Name		Description
**	----------	---------------	------------------------------------------------------------------------------------------------------------------------------------------------------------------------
**	06/29/2005	NPaterson	** Reviewed for compliance with database standards and recommendations **
**					Header added, Added NOCOUNT, Specified table owners, Removed comments, UPPERCASED SQL
**	05/13/2008	M. Smith	Changed @VistaPatientID to BIGINT datatype (CR 2431)
**	06/04/2008	K. Adu-Poku	** Reviewed for compliance with database standards and recommendations **
**	06/16/2008	M. Smith	Changed "SELECT" to "SET" for @PatientFoundFlag, changed JOIN to be ANSI 92 compliant, and
**					moved @PatientFoundFlag up for performance
**	01/04/2010	M. Smith	Changed to get and check UnitStatusCode from the BloodUnitStatusCodeCurrent table. (CR 1174)
**	01/25/2010	K. Adu-Poku	** Reviewed for compliance with database standards and recommendations **
*******************************************************************************************************************************************************************************/
CREATE PROCEDURE dbo.spVistaGetXmlSpecimenTestForPatient
(
	@VistAPatientId		BIGINT
)

AS

SET NOCOUNT ON

DECLARE @PatientFoundFlag AS BIT
	
	SET @PatientFoundFlag = ISNULL((	SELECT 	TOP 1 1
						FROM 	dbo.Patient
						WHERE	VistaPatientId = @VistaPatientId), 0 )

--<BloodBank>
SELECT	1					AS Tag,
		NULL					AS Parent,
		1					AS [Bloodbank!1!GroupOrder!hide],
		NULL					AS [Component!11!GroupOrder!hide],
		NULL 					AS [Bloodbank!1],
		NULL					AS [Patient!2!dfn],
		NULL					AS [Patient!2!firstName],
		NULL					AS [Patient!2!lastName],
		NULL					AS [Patient!2!ssn],
		NULL					AS [Patient!2!abo],
		NULL					AS [Patient!2!rh],
		NULL					AS [TransfusionReactions!3],
		NULL					AS [TransfusionReaction!4!type],
		NULL					AS [TransfusionReaction!4!date],
		NULL					AS [Antibodies!5],
		NULL					AS [Antibody!6!name],
		NULL					AS [Units!7],
		NULL					AS [Unit!8!status],
		NULL					AS [Unit!8!id],
		NULL					AS [Unit!8!product],
		NULL					AS [Unit!8!location],
		NULL					AS [Unit!8!expDate]

UNION ALL

-- <Patient dfn="" firstName="" lastName="" ssn="" abo="" rh="">
SELECT	2					AS Tag,
		1					AS Parent,
		2					AS [Bloodbank!1!GroupOrder!hide],
		NULL					AS [Component!11!GroupOrder!hide],
		NULL 					AS [Bloodbank!1],
		P.VistaPatientID			AS [Patient!2!dfn],
		P.PatientFirstName			AS [Patient!2!firstName],
		P.PatientLastName			AS [Patient!2!lastName],
		P.PatientSSN				AS [Patient!2!ssn],
		dbo.fnGetABO( P.PatientGUID )	AS [Patient!2!abo],
		dbo.fnGetRh( P.PatientGUID )		AS [Patient!2!rh],
		NULL					AS [TransfusionReactions!3],
		NULL					AS [TransfusionReaction!4!type],
		NULL					AS [TransfusionReaction!4!date],
		NULL					AS [Antibodies!5],
		NULL					AS [Antibody!6!name],
		NULL					AS [Units!7],
		NULL					AS [Unit!8!status],
		NULL					AS [Unit!8!id],
		NULL					AS [Unit!8!product],
		NULL					AS [Unit!8!location],
		NULL					AS [Unit!8!expDate]
FROM		dbo.Patient P
WHERE		P.VistaPatientID = @VistaPatientID

UNION ALL

-- <TransfusionReactions>
SELECT	3					AS Tag,
		2					AS Parent,
		2					AS [Bloodbank!1!GroupOrder!hide],
		NULL					AS [Component!11!GroupOrder!hide],
		NULL 					AS [Bloodbank!1],
		NULL					AS [Patient!2!dfn],
		NULL					AS [Patient!2!firstName],
		NULL					AS [Patient!2!lastName],
		NULL					AS [Patient!2!ssn],
		NULL					AS [Patient!2!abo],
		NULL					AS [Patient!2!rh],
		NULL					AS [TransfusionReactions!3],
		NULL					AS [TransfusionReaction!4!type],
		NULL					AS [TransfusionReaction!4!date],
		NULL					AS [Antibodies!5],
		NULL					AS [Antibody!6!name],
		NULL					AS [Units!7],
		NULL					AS [Unit!8!status],
		NULL					AS [Unit!8!id],
		NULL					AS [Unit!8!product],
		NULL					AS [Unit!8!location],
		NULL					AS [Unit!8!expDate]
WHERE		@PatientFoundFlag = 1

UNION ALL

-- <TransfusionReaction type="" date="">
SELECT DISTINCT	
		4					AS Tag,
		3					AS Parent,
		2					AS [Bloodbank!1!GroupOrder!hide],
		NULL					AS [Component!11!GroupOrder!hide],
		NULL 					AS [Bloodbank!1],
		NULL					AS [Patient!2!dfn],
		NULL					AS [Patient!2!firstName],
		NULL					AS [Patient!2!lastName],
		NULL					AS [Patient!2!ssn],
		NULL					AS [Patient!2!abo],
		NULL					AS [Patient!2!rh],
		NULL					AS [TransfusionReactions!3],
		TransReactType.TransfusionReactionTypeText	AS [TransfusionReaction!4!type],
		PatTransReact.NotedDateTime		AS [TransfusionReaction!4!date],
		NULL					AS [Antibodiess!5],
		NULL					AS [Antibody!6!name],
		NULL					AS [Units!7],
		NULL					AS [Unit!8!status],
		NULL					AS [Unit!8!id],
		NULL					AS [Unit!8!product],
		NULL					AS [Unit!8!location],
		NULL					AS [Unit!8!expDate]

FROM		dbo.Patient P
	JOIN 	dbo.PatientTransfusion PT
		ON	P.PatientGuid = PT.PatientGuid

	JOIN	dbo.TransfusionReaction TR
		ON 	PT.PatientTransfusionGUID = TR.PatientTransfusionGUID

	JOIN 	dbo.PatientTransfusionReaction PatTransReact
		ON	TR.PatientTransfusionReactionGuid = PatTransReact.PatientTransfusionReactionGuid
	
	JOIN	dbo.TransfusionReactionType  TransReactType
		ON	PatTransReact.TransfusionReactionTypeCode = TransReactType.TransfusionReactionTypeCode
	
	
		WHERE		P.VistaPatientID = @VistaPatientID
			AND	@PatientFoundFlag = 1
		
UNION ALL 

-- <Antibodies>
SELECT	5					AS Tag,
		2					AS Parent,
		2					AS [Bloodbank!1!GroupOrder!hide],
		NULL					AS [Component!11!GroupOrder!hide],
		NULL 					AS [Bloodbank!1],
		NULL					AS [Patient!2!dfn],
		NULL					AS [Patient!2!firstName],
		NULL					AS [Patient!2!lastName],
		NULL					AS [Patient!2!ssn],
		NULL					AS [Patient!2!abo],
		NULL					AS [Patient!2!rh],
		NULL					AS [TransfusionReactions!3],
		NULL					AS [TransfusionReaction!4!type],
		NULL					AS [TransfusionReaction!4!date],
		NULL					AS [Antibodies!5],
		NULL					AS [Antibody!6!name],
		NULL					AS [Units!7],
		NULL					AS [Unit!8!status],
		NULL					AS [Unit!8!id],
		NULL					AS [Unit!8!product],
		NULL					AS [Unit!8!location],
		NULL					AS [Unit!8!expDate]
WHERE		@PatientFoundFlag = 1

UNION ALL

-- <Antibody name="">
SELECT DISTINCT	
		6					AS Tag,
		5					AS Parent,
		2					AS [Bloodbank!1!GroupOrder!hide],
		NULL					AS [Component!11!GroupOrder!hide],
		NULL 					AS [Bloodbank!1],
		NULL					AS [Patient!2!dfn],
		NULL					AS [Patient!2!firstName],
		NULL					AS [Patient!2!lastName],
		NULL					AS [Patient!2!ssn],
		NULL					AS [Patient!2!abo],
		NULL					AS [Patient!2!rh],
		NULL					AS [TransfusionReactions!3],
		NULL					AS [TransfusionReaction!4!type],
		NULL					AS [TransfusionReaction!4!date],
		NULL					AS [Antibodies!5],
		dbo.AntibodyType.AntibodyTypeName		AS [Antibody!6!name],
		NULL					AS [Units!7],
		NULL					AS [Unit!8!status],
		NULL					AS [Unit!8!id],
		NULL					AS [Unit!8!product],
		NULL					AS [Unit!8!location],
		NULL					AS [Unit!8!expDate]
	
FROM		dbo.Patient

	INNER JOIN	dbo.PatientTransfusionRequirement
		ON	dbo.PatientTransfusionRequirement.PatientGUID = dbo.Patient.PatientGUID	
		
	INNER JOIN 	dbo.AntibodyType
		ON 	dbo.AntibodyType.AntibodyTypeID = dbo.PatientTransfusionRequirement.AntibodyTypeID
	
		WHERE		dbo.Patient.VistaPatientID = @VistaPatientID

			AND	@PatientFoundFlag = 1

UNION ALL

-- <Units>
SELECT	7					AS Tag,
		2					AS Parent,
		2					AS [Bloodbank!1!GroupOrder!hide],
		NULL					AS [Component!11!GroupOrder!hide],
		NULL 					AS [Bloodbank!1],
		NULL					AS [Patient!2!dfn],
		NULL					AS [Patient!2!firstName],
		NULL					AS [Patient!2!lastName],
		NULL					AS [Patient!2!ssn],
		NULL					AS [Patient!2!abo],
		NULL					AS [Patient!2!rh],
		NULL					AS [TransfusionReactions!3],
		NULL					AS [TransfusionReaction!4!type],
		NULL					AS [TransfusionReaction!4!date],
		NULL					AS [Antibodies!5],
		NULL					AS [Antibody!6!name],
		NULL					AS [Units!7],
		NULL					AS [Unit!8!status],
		NULL					AS [Unit!8!id],
		NULL					AS [Unit!8!product],
		NULL					AS [Unit!8!location],
		NULL					AS [Unit!8!expDate]
WHERE		@PatientFoundFlag = 1

UNION ALL

-- Assigned and crossmatched units
-- <Unit status="" id="" product="" location="" expDate="" />
SELECT DISTINCT	
		8					AS Tag,
		7					AS Parent,
		2					AS [Bloodbank!1!GroupOrder!hide],
		NULL					AS [Component!11!GroupOrder!hide],
		NULL 					AS [Bloodbank!1],
		NULL					AS [Patient!2!dfn],
		NULL					AS [Patient!2!firstName],
		NULL					AS [Patient!2!lastName],
		NULL					AS [Patient!2!ssn],
		NULL					AS [Patient!2!abo],
		NULL					AS [Patient!2!rh],
		NULL					AS [TransfusionReactions!3],
		NULL					AS [TransfusionReaction!4!type],
		NULL					AS [TransfusionReaction!4!date],
		NULL					AS [Antibodies!5],
		NULL					AS [Antibody!6!name],
		NULL					AS [Units!7],
		BUSCC.UnitStatusCode			AS [Unit!8!status],
		dbo.BloodUnit.EyeReadableUnitId		AS [Unit!8!id],
		dbo.ProductType.ProductTypePrintName	AS [Unit!8!product],
		dbo.VamcDivision.DivisionName		AS [Unit!8!location],
		dbo.BloodUnitMedia.UnitExpirationDate	AS [Unit!8!expDate]

FROM		dbo.BloodUnitStatusCodeCurrent BUSCC

	INNER JOIN 	dbo.BloodUnit
		ON 	BUSCC.BloodUnitGUID = dbo.BloodUnit.BloodUnitGUID

	INNER JOIN 	dbo.OrderedUnit
		ON	dbo.BloodUnit.BloodUnitGUID = dbo.OrderedUnit.BloodUnitGUID

	INNER JOIN 	dbo.OrderedComponent
		ON	dbo.OrderedUnit.OrderedComponentGUID = dbo.OrderedComponent.OrderedComponentGUID

	INNER JOIN 	dbo.PatientOrder
		ON 	dbo.OrderedComponent.PatientOrderGUID = dbo.PatientOrder.PatientOrderGUID

	INNER JOIN 	dbo.PatientTreatment
		ON	dbo.PatientOrder.PatientTreatmentGUID = dbo.PatientTreatment.PatientTreatmentGUID

	INNER JOIN 	dbo.Patient
		ON 	dbo.PatientTreatment.PatientGUID = dbo.Patient.PatientGUID

	INNER JOIN 	dbo.BloodProduct
		ON 	dbo.BloodUnit.BloodProductGUID = dbo.BloodProduct.BloodProductGUID

	INNER JOIN 	dbo.ProductType
		ON	dbo.BloodProduct.ProductTypeCode = dbo.ProductType.ProductTypeCode

	INNER JOIN 	dbo.VamcDivision
		ON	dbo.BloodUnit.DivisionCode = dbo.VamcDivision.DivisionCode

	INNER JOIN 	dbo.BloodUnitMedia
		ON 	dbo.BloodUnit.BloodUnitGUID = dbo.BloodUnitMedia.BloodUnitGUID

		WHERE		dbo.Patient.VistaPatientID = @VistaPatientID
			AND	@PatientFoundFlag = 1
			AND	BUSCC.UnitStatusCode IN ( 'S', 'C' )
			AND	dbo.BloodUnitMedia.UnitExpirationDate > GETUTCDATE()

UNION ALL

-- Autologous units
-- <Unit status="" id="" product="" location="" expDate="" />
SELECT DISTINCT	
		8					AS Tag,
		7					AS Parent,
		2					AS [Bloodbank!1!GroupOrder!hide],
		NULL					AS [Component!11!GroupOrder!hide],
		NULL 					AS [Bloodbank!1],
		NULL					AS [Patient!2!dfn],
		NULL					AS [Patient!2!firstName],
		NULL					AS [Patient!2!lastName],
		NULL					AS [Patient!2!ssn],
		NULL					AS [Patient!2!abo],
		NULL					AS [Patient!2!rh],
		NULL					AS [TransfusionReactions!3],
		NULL					AS [TransfusionReaction!4!type],
		NULL					AS [TransfusionReaction!4!date],
		NULL					AS [Antibodies!5],
		NULL					AS [Antibody!6!name],
		NULL					AS [Units!7],
		dbo.DonationType.RestrictionTypeCode	AS [Unit!8!status],
		dbo.BloodUnit.UnitProductCode		AS [Unit!8!id],
		dbo.ProductType.ProductTypePrintName	AS [Unit!8!product],
		dbo.VamcDivision.DivisionName		AS [Unit!8!location],
		dbo.BloodUnitMedia.UnitExpirationDate	AS [Unit!8!expDate]

FROM		dbo.DonationType

	INNER JOIN	dbo.BloodUnit
		ON	dbo.DonationType.DonationTypeId = dbo.BloodUnit.DonationTypeId
	
	INNER JOIN 	dbo.BloodUnitMedia
		ON 	dbo.BloodUnit.BloodUnitGUID = dbo.BloodUnitMedia.BloodUnitGUID
	
	INNER JOIN 	dbo.Patient
		ON 	dbo.BloodUnitMedia.DirectedPatientGUID = dbo.Patient.PatientGUID
	
	INNER JOIN 	dbo.BloodProduct
		ON 	dbo.BloodUnit.BloodProductGUID = dbo.BloodProduct.BloodProductGUID
	
	INNER JOIN 	dbo.ProductType
		ON 	dbo.BloodProduct.ProductTypeCode = dbo.ProductType.ProductTypeCode
	
	INNER JOIN 	dbo.VamcDivision
		ON 	dbo.BloodUnit.DivisionCode = dbo.VamcDivision.DivisionCode
	
		WHERE		dbo.Patient.VistaPatientID = @VistaPatientID

			AND	@PatientFoundFlag = 1

			AND 	dbo.DonationType.RestrictionTypeCode IN ('A', 'D')

			AND	dbo.BloodUnitMedia.UnitExpirationDate > GETUTCDATE()


FOR XML EXPLICIT

SET NOCOUNT OFF
GO

if exists (select * from dbo.sysobjects where id = object_id(N'dbo.spVistaGetXmlWorkloadData') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure dbo.spVistaGetXmlWorkloadData
GO
SET QUOTED_IDENTIFIER OFF
GO

/*******************************************************************************************************************************************************************************
**	Desc: 	
**
**	Author:	Brian Tomlin / Stas Antropov
**	Date: 	01-25-2005
*******************************************************************************************************************************************************************************
**	Modified:
**	Date		Name		Description
**	-------------------	-----------------------	------------------------------------------------------------------------------------------------------------------------------------------------------------------------
**	06/29/2005	NPaterson	** Reviewed for compliance with database standards and recommendations **
**					Header added, Added NOCOUNT, Specified table owners, Removed comments, UPPERCASED SQL
**	09/27/2005	NPaterson				Line 32 Update statement added by Brian Tomlin, was removed in review by accident
**	07/13/07	Lohse		Adding datetime conversion for CR2253.
**	11/4/09		Van Stedum	Changed logic to parse out the method and code in XML, changed the default value of  
**					Workload!3!method from NULL to a valid value (CR 2737).
**	01/21/10	K. Adu-Poku	** Reviewed for compliance with database standards and recommendations **
*******************************************************************************************************************************************************************************/
CREATE	procedure dbo.spVistaGetXmlWorkloadData
(
	@WorkloadEventStatusCode	CHAR
)
AS

SET NOCOUNT ON

DECLARE @WorkloadEventGuid AS UNIQUEIDENTIFIER;

DECLARE @WorkloadFoundFlag AS BIT;

	SELECT 	@WorkloadEventGuid =	(
					SELECT TOP 1 	WorkloadEventGuid
					FROM	dbo.WorkloadEvent
					WHERE		WorkloadEventStatusCode = @WorkloadEventStatusCode
					)
	UPDATE 	dbo.WorkloadEvent

		SET WorkloadEventStatusCode = 'I'

			WHERE	WorkloadEventGuid = @WorkloadEventGuid

-- <WorkloadTransactions>
SELECT 	1					AS Tag,
		NULL					AS Parent,
		1					AS [WorkloadTransactions!1!GroupOrder!hide],
		NULL					AS [WorkloadTransactions!1],
		NULL					AS [Transaction!2!id],
		NULL					AS [Transaction!2!type],
		NULL					AS [Transaction!2!division],
		NULL					AS [Transaction!2!accessionArea],
		NULL					AS [Transaction!2!dateTime],
		NULL					AS [Transaction!2!status],
		NULL					AS [Workload!3!code],
		NULL					AS [Workload!3!method],
		NULL					AS [Workload!3!multiplyFactor],
		NULL					AS [Patient!4!dfn],
		NULL					AS [VbecsUser!5!duz],
		NULL					AS [Lab!6!accessionNumber],
		NULL					AS [Lab!6!testPerformed],
		NULL					AS [Unit!7!id]

UNION ALL

-- <Transaction id="" type="" division="" accessionArea="" dateTime="" status="">
SELECT TOP 1	2					AS Tag,
		1					AS Parent,
		2					AS [WorkloadTransactions!1!GroupOrder!hide],
		NULL					AS [WorkloadTransactions!1],
		W.WorkloadEventGuid			AS [Transaction!2!id],
		VbecsProcess.TransactionType		AS [Transaction!2!type],
		W.DivisionCode				AS [Transaction!2!division],
		dbo.VamcDivision.AccessionAreaId		AS [Transaction!2!accessionArea],
		dbo.fnDateTimeConversionToFileManDateTime(dbo.fnTimeZoneConversionDateTime( W.DivisionCode, 0, W.WorkloadEventDate ))	AS [Transaction!2!dateTime],
		'P'					AS [Transaction!2!status],
		NULL					AS [Workload!3!code],
		NULL					AS [Workload!3!method],
		NULL					AS [Workload!3!multiplyFactor],
		NULL					AS [Patient!4!dfn],
		NULL					AS [VbecsUser!5!duz],
		NULL					AS [Lab!6!accessionNumber],
		NULL					AS [Lab!6!testPerformed],
		NULL					AS [Unit!7!id]
FROM		dbo.WorkloadEvent W

	INNER JOIN	dbo.VamcDivision
	
		ON	W.DivisionCode = VamcDivision.DivisionCode
	
		INNER JOIN	dbo.WorkloadProcess
		
			ON	W.WorkloadProcessGuid = WorkloadProcess.WorkloadProcessGuid
	
				INNER JOIN	dbo.VbecsProcess
				
					ON	WorkloadProcess.VbecsProcessId = VbecsProcess.VbecsProcessId
	
						WHERE		W.WorkloadEventGuid = @WorkloadEventGuid


UNION ALL

-- <Workload code="" method="" multiplyFactor="" />
SELECT		3				AS Tag,
		2					AS Parent,
		2					AS [WorkloadTransactions!1!GroupOrder!hide],
		NULL					AS [WorkloadTransactions!1],
		NULL					AS [Transaction!2!id],
		NULL					AS [Transaction!2!type],
		NULL					AS [Transaction!2!division],
		NULL					AS [Transaction!2!accessionArea],
		NULL					AS [Transaction!2!dateTime],
		NULL					AS [Transaction!2!status],
		WP.WorkloadCode			AS [Workload!3!code],
		RIGHT(WP.WorkloadCode, LEN(WP.WorkloadCode) - CHARINDEX('.', WP.WorkloadCode))  AS [Workload!3!method],
  		W.WeightMultiplier			AS [Workload!3!multiplyFactor],
		NULL					AS [Patient!4!dfn],
		NULL					AS [VbecsUser!5!duz],
		NULL					AS [Lab!6!accessionNumber],
		NULL					AS [Lab!6!testPerformed],
		NULL					AS [Unit!7!id]
FROM		dbo.WorkloadProcess WP

	INNER JOIN	dbo.WorkloadEvent W
	
		ON	WP.WorkloadProcessGuid = W.WorkloadProcessGuid
	
			WHERE		W.WorkloadEventGuid = @WorkloadEventGuid

UNION ALL

--<Patient dfn="" />
SELECT	4					AS Tag,
		2					AS Parent,
		2					AS [WorkloadTransactions!1!GroupOrder!hide],
		NULL					AS [WorkloadTransactions!1],
		NULL					AS [Transaction!2!id],
		NULL					AS [Transaction!2!type],
		NULL					AS [Transaction!2!division],
		NULL					AS [Transaction!2!accessionArea],
		NULL					AS [Transaction!2!dateTime],
		NULL					AS [Transaction!2!status],
		NULL					AS [Workload!3!code],
		NULL					AS [Workload!3!method],
		NULL					AS [Workload!3!multiplyFactor],
		dbo.Patient.VistaPatientId			AS [Patient!4!dfn],
		NULL					AS [VbecsUser!5!duz],
		NULL					AS [Lab!6!accessionNumber],
		NULL					AS [Lab!6!testPerformed],
		NULL					AS [Unit!7!id]
FROM		dbo.Patient

	INNER JOIN	dbo.WorkloadEvent W

		ON	dbo.Patient.PatientGuid = W.PatientGuid

			WHERE		W.WorkloadEventGuid = @WorkloadEventGuid

UNION ALL

--<VbecsUser duz="" />
SELECT	5					AS Tag,
		2					AS Parent,
		2					AS [WorkloadTransactions!1!GroupOrder!hide],
		NULL					AS [WorkloadTransactions!1],
		NULL					AS [Transaction!2!id],
		NULL					AS [Transaction!2!type],
		NULL					AS [Transaction!2!division],
		NULL					AS [Transaction!2!accessionArea],
		NULL					AS [Transaction!2!dateTime],
		NULL					AS [Transaction!2!status],
		NULL					AS [Workload!3!code],
		NULL					AS [Workload!3!method],
		NULL					AS [Workload!3!multiplyFactor],
		NULL					AS [Patient!4!dfn],
		dbo.VbecsUser.UserDUZ			AS [VbecsUser!5!duz],
		NULL					AS [Lab!6!accessionNumber],
		NULL					AS [Lab!6!testPerformed],
		NULL					AS [Unit!7!id]
FROM		dbo.VbecsUser

	INNER JOIN	dbo.WorkloadEvent W

		ON	dbo.VbecsUser.VbecsUserId = W.LastUpdateUser

			WHERE		W.WorkloadEventGuid = @WorkloadEventGuid

UNION ALL

-- Ordered Tests
--<Lab accessionNumber="" testPerformed="" />
SELECT 	6					AS Tag,
		2					AS Parent,
		2					AS [WorkloadTransactions!1!GroupOrder!hide],
		NULL					AS [WorkloadTransactions!1],
		NULL					AS [Transaction!2!id],
		NULL					AS [Transaction!2!type],
		NULL					AS [Transaction!2!division],
		NULL					AS [Transaction!2!accessionArea],
		NULL					AS [Transaction!2!dateTime],
		NULL					AS [Transaction!2!status],
		NULL					AS [Workload!3!code],
		NULL					AS [Workload!3!method],
		NULL					AS [Workload!3!multiplyFactor],
		NULL					AS [Patient!4!dfn],
		NULL					AS [VbecsUser!5!duz],
		dbo.OrderedTest.SpecimenWorkloadUid		AS [Lab!6!accessionNumber],
		dbo.OrderedTest.LabTestId			AS [Lab!6!testPerformed],
		NULL					AS [Unit!7!id]
FROM		dbo.OrderedTest

	INNER JOIN	dbo.WorkloadEvent

		ON	dbo.OrderedTest.OrderedTestGuid = dbo.WorkloadEvent.OrderedTestGuid

			WHERE		dbo.WorkloadEvent.WorkloadEventGuid = @WorkloadEventGuid

UNION ALL

-- Ordered Components
--<Lab accessionNumber="" testPerformed="" />
SELECT 	6					AS Tag,
		2					AS Parent,
		2					AS [WorkloadTransactions!1!GroupOrder!hide],
		NULL					AS [WorkloadTransactions!1],
		NULL					AS [Transaction!2!id],
		NULL					AS [Transaction!2!type],
		NULL					AS [Transaction!2!division],
		NULL					AS [Transaction!2!accessionArea],
		NULL					AS [Transaction!2!dateTime],
		NULL					AS [Transaction!2!status],
		NULL					AS [Workload!3!code],
		NULL					AS [Workload!3!method],
		NULL					AS [Workload!3!multiplyFactor],
		NULL					AS [Patient!4!dfn],
		NULL					AS [VbecsUser!5!duz],
		dbo.OrderedComponent.SpecimenWorkloadUid AS [Lab!6!accessionNumber],
		dbo.OrderedComponent.LabTestId		AS [Lab!6!testPerformed],
		NULL					AS [Unit!7!id]
FROM		dbo.OrderedComponent

	INNER JOIN	dbo.WorkloadEvent

		ON	dbo.OrderedComponent.OrderedComponentGuid =dbo.WorkloadEvent.OrderedComponentGuid

			WHERE		dbo.WorkloadEvent.WorkloadEventGuid = @WorkloadEventGuid

UNION ALL

--<Unit id="" />
SELECT	7					AS Tag,
		2					AS Parent,
		2					AS [WorkloadTransactions!1!GroupOrder!hide],
		NULL					AS [WorkloadTransactions!1],
		NULL					AS [Transaction!2!id],
		NULL					AS [Transaction!2!type],
		NULL					AS [Transaction!2!division],
		NULL					AS [Transaction!2!accessionArea],
		NULL					AS [Transaction!2!dateTime],
		NULL					AS [Transaction!2!status],
		NULL					AS [Workload!3!code],
		NULL					AS [Workload!3!method],
		NULL					AS [Workload!3!multiplyFactor],
		NULL					AS [Patient!4!dfn],
		NULL					AS [VbecsUser!5!duz],
		NULL					AS [Lab!6!accessionNumber],
		NULL					AS [Lab!6!testPerformed],
		BloodUnit.UnitProductCode		AS [Unit!7!id]
FROM		dbo.BloodUnit

	INNER JOIN	dbo.WorkloadEvent

		ON	dbo.BloodUnit.BloodUnitGuid = dbo.WorkloadEvent.BloodUnitGuid

			WHERE		dbo.WorkloadEvent.WorkloadEventGuid = @WorkloadEventGuid

				ORDER BY	[WorkloadTransactions!1!GroupOrder!hide],
							tag
		



FOR XML EXPLICIT

SET NOCOUNT OFF

GO
SET QUOTED_IDENTIFIER ON
GO

GRANT SELECT ON dbo.BloodProduct TO VbecsAppUser
GRANT SELECT ON dbo.ProductAttribute TO VbecsAppUser
GRANT SELECT ON dbo.ProductType TO VbecsAppUser
GRANT SELECT ON dbo.BloodUnitStatusCodeCurrent TO VbecsAppUser
GRANT SELECT ON dbo.V_BloodUnit TO VbecsAppUser
GRANT SELECT ON dbo.vw_ActiveAndInactiveBloodUnits TO VbecsAppUser
GRANT SELECT ON dbo.vw_BloodShipAllCurrent TO VbecsAppUser
GRANT SELECT ON dbo.vw_BloodShipFinanceAllCurrent TO VbecsAppUser
GRANT SELECT ON dbo.vw_BloodShipPatientAllCurrent TO VbecsAppUser
GRANT SELECT ON dbo.vw_GetAdminReportBase TO VbecsAppUser
GRANT SELECT ON dbo.fnGetProlongedTransfusionsForSpecifiedRange TO VbecsAppUser
GRANT EXECUTE ON dbo.batchspRunMarkUnitsPresumedTransfused TO VbecsAppUser
GRANT EXECUTE ON dbo.spGetAuditBloodUnitStatus TO VbecsAppUser
GRANT EXECUTE ON dbo.spGetBloodUnitStatusByGuid TO VbecsAppUser
GRANT EXECUTE ON dbo.spGetBloodUnitWrkLst TO VbecsAppUser
GRANT EXECUTE ON dbo.spGetCrossmatchedUnitsInDateRange TO VbecsAppUser
GRANT EXECUTE ON dbo.spGetEmergencyIssuedUnitsCountForOrderedTest TO VbecsAppUser
GRANT EXECUTE ON dbo.spGetIncomingShipmentsList TO VbecsAppUser
GRANT EXECUTE ON dbo.spGetOrderedUnitByComponent TO VbecsAppUser
GRANT EXECUTE ON dbo.spGetOrderedUnitsForPatientSpecimen TO VbecsAppUser
GRANT EXECUTE ON dbo.spGetOrderedUnitsForRepeatXM TO VbecsAppUser
GRANT EXECUTE ON dbo.spGetPatientAboRHHistory TO VbecsAppUser
GRANT EXECUTE ON dbo.spGetPatientComponentOrdersAll TO VbecsAppUser
GRANT EXECUTE ON dbo.spGetPatientTestOrdersAll TO VbecsAppUser
GRANT EXECUTE ON dbo.spGetPreviousUnitStatus TO VbecsAppUser
GRANT EXECUTE ON dbo.spGetReportBloodUnitHistorySummary TO VbecsAppUser
GRANT EXECUTE ON dbo.spGetShipmentsWithAvailableUnitsFromPastFiveDays TO VbecsAppUser
GRANT EXECUTE ON dbo.spGetTransfusionHistoryForPatientSpecimen TO VbecsAppUser
GRANT EXECUTE ON dbo.spGetTransfusionReport TO VbecsAppUser
GRANT EXECUTE ON dbo.spVistaGetXmlAvailableUnits TO VbecsAppUser
GRANT EXECUTE ON dbo.spVistaGetXmlBloodBankData TO VbecsAppUser
GRANT EXECUTE ON dbo.spVistaGetXmlPatientData TO VbecsAppUser
GRANT EXECUTE ON dbo.spVistaGetXmlPatientReportData TO VbecsAppUser
GRANT EXECUTE ON dbo.spVistaGetXmlSpecimenTestForPatient TO VbecsAppUser
GRANT EXECUTE ON dbo.spVistaGetXmlWorkloadData TO VbecsAppUser

/***************************************************************************************
**	Change the mirror database recovery mode to simple
***************************************************************************************/
ALTER DATABASE VBECS_V1_PROD_MIRROR SET RECOVERY SIMPLE
GO

/***************************************************************************************
**	Blood product updates
***************************************************************************************/
-- Update 9 rows in dbo.ProductAttribute
UPDATE dbo.ProductAttribute SET RetireDate='20080301 00:00:00.000', LastUpdateDate='20091113 13:23:31.837' WHERE ProductAttributeId=N'@B0'
UPDATE dbo.ProductAttribute SET RetireDate='20080901 00:00:00.000', LastUpdateDate='20091113 13:23:31.837' WHERE ProductAttributeId=N'@BD'
UPDATE dbo.ProductAttribute SET RetireDate='20080901 00:00:00.000', LastUpdateDate='20091113 13:23:31.837' WHERE ProductAttributeId=N'@BF'
UPDATE dbo.ProductAttribute SET RetireDate='20080901 00:00:00.000', LastUpdateDate='20091113 13:23:31.837' WHERE ProductAttributeId=N'@CK'
UPDATE dbo.ProductAttribute SET ProductAttributePrintName=N'PLS Red/PA', LastUpdateDate='20091113 13:16:03.823' WHERE ProductAttributeId=N'EE '
UPDATE dbo.ProductAttribute SET ProductAttributePrintName=N'Cplmt Inac', LastUpdateDate='20091113 13:16:03.823' WHERE ProductAttributeId=N'EF '
UPDATE dbo.ProductAttribute SET RetireDate='20090901 00:00:00.000', LastUpdateDate='20091113 13:23:31.837', LastUpdateUser=N'vhaishsmithm' WHERE ProductAttributeId=N'M0 '
UPDATE dbo.ProductAttribute SET RetireDate='20090901 00:00:00.000', LastUpdateDate='20091113 13:23:31.837' WHERE ProductAttributeId=N'M1 '
UPDATE dbo.ProductAttribute SET RetireDate='20090901 00:00:00.000', LastUpdateDate='20091113 13:23:31.837', LastUpdateUser=N'vhaishsmithm' WHERE ProductAttributeId=N'M2 '

-- Update 3757 rows in dbo.BloodProduct
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'00025457-b774-4406-991b-2d6d4175abff'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'0016fd31-9ac0-409f-8448-ba5b5098d0dd'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'002b6ca1-3712-43fc-b4fa-6e0fe6c39bda'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'00422b4b-de4f-4f8a-a2b0-eecd38f8c285'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'0059ce70-aad2-48d9-a61d-0fdb6c5c7923'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'005e093c-1a1e-4c18-9e4c-cbe75bcb3da5'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'0076d7ff-d832-4468-877d-16914b02baf5'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'007cb83c-91e5-4fb8-99bc-aac7b8865ad4'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'00a20666-d95f-4eea-a0a6-08e93e9289f5'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'00a9169d-0e17-4764-a507-0e03cb86d243'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'00abc6f5-438b-482a-b335-2766ab1d2473'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'00e4b0b5-344b-44a7-a902-4e94a270993b'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@B7 B2 C2 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'00f1653b-bdd8-4a46-b342-65647f6781b1'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 D4 HB N2', MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'0123cfab-7ef7-4729-a829-4849b3eef536'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'013a3968-1f41-44fc-aebf-4741620a1800'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'013d66b5-cf80-40bf-9ce9-2d63a6ef9f3c'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@B7 B2 D4 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'01445b93-f2dd-40f4-ba1b-136328b147bd'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'017e081d-a7c2-49a0-8415-e7e2754129e6'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'018aae74-f6e1-446f-85ac-a6552bb51126'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@30 C2 I2 H3', ProductVolume=450, MaximumStorageTime=61320, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'0191485c-6993-41a5-91f4-f20d88e17b2a'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@B7 B2 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'019d8886-a01a-4508-812c-88786b85cb0a'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@18 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'01a468f1-f3f2-4da5-96b2-d79fc1265067'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 C2 D4 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'01bab951-a1a7-4e24-bec5-472f20c2b658'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'01d253d6-b884-4f30-be64-0f71044bdf9c'
UPDATE dbo.BloodProduct SET MaximumStorageTime=4, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'01dd8113-d0fd-483a-b3fa-c151380781cc'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AZ C2 D4 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'01e4670c-ac40-4c8e-9d59-eac78db7e5a6'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'01f2a471-7ce3-4525-b111-8994f492dd17'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'0235cc74-6dc1-4113-9569-9085b790fcda'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'0240f466-ea92-49b0-a129-7b2bb77cc59d'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'024e0933-a9ca-4b7d-9cca-c0bbeaade9e6'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'02526682-3c1d-4240-bbfb-0d71e779818e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'025403cc-983e-4b4a-a45b-d6b35713cb44'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'0279432f-6f7b-40df-b046-9255e107ce2a'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'0284fb94-3a9f-4802-8ae0-e0fe1d7d9caf'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'029f11d6-2e5c-4222-84dd-e7943c28b1d7'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'02b43809-342a-430c-b205-36e82f5894fc'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'02ce1e6d-0439-4001-bb61-68c826fd4c7b'
UPDATE dbo.BloodProduct SET ProductVolume=450, MaximumStorageTime=61320, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'02de27c1-6168-4494-8bfa-0dfa600bda5f'
UPDATE dbo.BloodProduct SET MaximumStorageTime=672, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'02e52764-8dc7-41f5-b818-df6044a8946d'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'02ebadf8-3bd2-4ffc-9c42-c3de62757e64'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'02ed5a05-e993-4e6f-9c2a-81fe1e512f29'
UPDATE dbo.BloodProduct SET MaximumStorageTime=1008, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'02f51180-8890-4178-83f2-c3815c83d943'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'02fafe1c-8f76-486c-925b-1d92f47b5a3e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'032d1112-2160-49c6-b26a-6e9606fdb4e0'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@B7 B2 D4 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'03368624-2b1d-4970-80fa-81f8ee0fef09'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@30 H4', ProductVolume=450, MaximumStorageTime=61320, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'035bae1f-bd61-4ff7-8325-faa820b24bf7'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'0364e181-27cd-40af-9a9f-008e1c526fb1'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'0381a2f8-9a0e-4345-85fe-baf5cc236a06'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'038b68ca-fbd0-4bf9-b2cf-eac647f777a0'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@54 D4 H3', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'0397977b-a84d-4abe-aa0c-5b73d6afd830'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'039d585d-c64d-4d5e-9c99-94ead03cc586'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'03a026d0-93b2-4e15-abe3-610cd64f235d'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'03aa59c5-69b5-4b76-88e4-a59d180e1a7b'
UPDATE dbo.BloodProduct SET MaximumStorageTime=4, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'03dc0ff6-c524-4262-920b-50b7a63fcad2'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'03fafed1-9ae6-41e9-9567-5ed2affea344'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@11 C2 D4 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'03feabc4-24fe-4370-a81f-6f7e9fd90e21'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@33 C2 D4 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'040e8ad3-2306-4a4c-8434-21f426423e60'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'04156061-d1c8-4f80-9525-a5a16a1cf20b'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@07 D4 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'042a5861-e6ba-402e-adbe-51eeb264fa7b'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AZ C2 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'0431f963-5b97-44ab-ae3a-f646ffa695af'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'044e5423-e072-4509-90a5-da0e31d67dac'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'04597948-053b-48c6-9bfc-f4b7043b5f8e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'0465fe3b-eee6-476a-a7ea-63e8ad1445ab'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 C2 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'047230da-88c9-4906-8c04-5f231f0059bd'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'047a2208-9261-4002-b0ee-8e11367c53a3'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AZ D4 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'0480abb4-0b25-4dc8-9c0b-06f82061cc8f'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@11 C2 D4 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'04842478-bd39-4ebc-b181-0b3fb1423a2c'
UPDATE dbo.BloodProduct SET RetireDate='20080301 00:00:00.000', LastUpdateDate='20091109 15:02:22.883' WHERE BloodProductGuid=N'04893592-5e1d-47b1-87ad-a7ff1c2f9891'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'0496a077-534e-4787-8120-53ad4046f956'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'049906f8-8531-4aef-b90b-3a3ea41b889c'
UPDATE dbo.BloodProduct SET ProductVolume=500, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'049dfb33-7f67-4cf5-9f9b-24b3f370551c'
UPDATE dbo.BloodProduct SET MaximumStorageTime=4, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'04a0acb9-8c67-4720-a300-a5bd609368bf'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'04bcbb56-349c-47b5-b36e-075728c11dae'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'04bf80dc-6cd8-4ef8-a461-279b26f4a5ff'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'04c24c36-7971-4af1-a08e-1ed60c8be227'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AY C2 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'04c44538-04e0-4d30-99a8-a362a33fa880'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'04c6f87b-8495-417b-9058-a588d5227e7d'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 D4 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'04cdef8e-4bcd-4b8b-9399-673f58fd8a19'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'04d4d9b2-1f94-4231-b11c-5aa81448e744'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'04e180ec-5bdc-4435-8d2f-18dcf24afd55'
UPDATE dbo.BloodProduct SET ProductShortName=N'FFP AFR None', ProductAttributeForm=N'@84 H3', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'04e3688d-b99c-47a0-b78a-ba64820a45b6'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@B7 B2 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'04fcfe0c-6d0a-4333-93c1-a7ff8079d4c9'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'0507ba4c-45d1-4538-86d0-771cc8f5dfe6'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'050efe97-cc36-48a7-8428-aa6b125b48b1'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'05244089-e384-4fb4-b6f7-8f68a2c1ece4'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 C2 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'05528312-299a-49a4-a0ec-01c5057e247a'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'0558dff1-9926-4b80-bbf4-d2c6f7b92a0a'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@07 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'05699460-f532-4365-a4ce-30d24a9c2a33'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@B7 B2 D4 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'056d6a5f-0a3a-41f1-be6f-21960506ffd6'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'059d99a7-6642-4b7d-a842-c71e92d00c6a'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AY D4 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'05a2e856-49c3-4a7e-b608-3018192f5637'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'05b4a598-8af2-434b-b498-1cb48315fc4f'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'05c50772-210a-4730-b0c4-85a0af1a9680'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'05c8c694-4fd1-4975-b084-5530550f5cb8'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'05db268f-6308-4f18-866a-89256db5774a'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@03 D4 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'05e3a4e2-cbfc-47e6-8656-99abdbd7fac5'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'05f7d446-cd71-4937-b92c-6c0dca96dcdc'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'05fc0037-d661-431b-bd21-4c72cc258e1b'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'062cb67d-152b-4618-8f72-b773a4335e37'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'0633b0d7-a713-4df3-98ae-a67850f7df02'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'0641af84-0236-4180-8952-23208d244e32'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 C2 D4 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'06476fca-bc0d-44b8-a5fc-7026307370ff'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'0649a1f5-52b7-4581-91c0-ae43163a7b48'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'064af6e8-d16f-4fe0-ad62-1177b7e52e12'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'065e907d-5edc-468b-92e1-886d287c0e42'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'066ad462-89e8-475a-9c57-1dbd7f472956'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'06756f09-258e-41a0-8061-735cfb4b21ce'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@07 H6', LastUpdateDate='20100210 13:55:15.970', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'067b0c49-50b6-4180-82a1-dfc8e592fe52'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@09 C2 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'06807afb-5a1f-44e2-8a4e-c2529ea32ad1'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@07 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'06a69853-cb51-4288-9f13-0874b4b10bd6'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'06a909d0-df6e-491f-921b-22cfb9301a86'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@84 C2 D2 H6', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'06b21389-2977-4d71-bcac-0546a5c4526a'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'06b9a8e8-70f9-4a13-8e5d-e50316c77156'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'06c43405-b375-4335-b587-59650e83b6c5'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'06dc2cf3-9ab5-4b84-a855-b5eb1d1cc8e2'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@84 HC', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'06e7ffdc-9587-4644-b63a-7a2455e0722e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'06f0977e-90e2-4d5b-97e3-a3677689641a'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'06f1e348-d673-4f05-8f2d-bbcad5731286'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'06fc627e-da65-443f-a592-8c965b17e4fb'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'070708af-4559-4ab5-822d-31984ad96122'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'070993ce-9947-4863-a987-5f47ebd8bb3a'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'070c4a92-b0e2-4407-bac6-8eac2726539c'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'0729748e-864c-4392-99fe-93807c560762'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'07456b83-79fa-45c2-ae09-6a5425bf2783'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'0778109c-efe1-44cb-8f1c-cd2ed884056e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'077e0471-1cbd-4b80-b6d3-7ff5d14f1f1a'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@11 C2 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'077eb07d-bbf5-4258-a890-b79e36f09d43'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'07a2014a-c448-4db2-a841-378d5d115bd8'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'07a382f0-f424-4b21-ba50-7831ec3eee20'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@03 D4 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'07c10503-31da-4494-9e37-4a3c9e74d0c1'
UPDATE dbo.BloodProduct SET MaximumStorageTime=624, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'07d12d8a-5280-49a3-a826-8d0585bb920d'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS G7 HA', LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'08065650-fbee-4d67-9ca6-a84db600bfe5'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'080a492f-e8dd-48d8-a57d-753be696f9a2'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'0817350b-6465-4c88-b842-2a143ac350e9'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'082c68ae-cbfd-47ba-9f6d-04da93e753e7'
UPDATE dbo.BloodProduct SET MaximumStorageTime=61320, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'08383d37-ca54-4697-87bf-3e3ec74bda83'
UPDATE dbo.BloodProduct SET ProductShortName=N'RBC Deg None IRD', ProductAttributeForm=N'@AS C2 H4', LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'0839092b-df37-4e26-a203-e865f45d941f'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AZ HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'084f0d33-5a0c-4436-a872-bf19354c0ccc'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'085954db-7890-4c7e-aa74-56990a7cf7f8'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'085f9d60-d696-4300-be64-b29fd1ef733b'
UPDATE dbo.BloodProduct SET RetireDate='20090901 00:00:00.000', LastUpdateDate='20091109 15:02:22.697' WHERE BloodProductGuid=N'08666315-9ef0-46ae-8373-25c128fb0883'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'08b8ccbc-5f44-49d0-a98e-c2d20d5faf72'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'08b963ae-448b-4739-a0d3-0a402e291954'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 C2 D4 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'08b97899-17a7-476b-a167-a4ae2cb4c03a'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@B7 B2 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'08e9224f-7a64-40fb-8bfb-b78929caa5fb'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@11 C2 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'08fb91b6-2f08-4e44-a5bf-8aede0d16881'
UPDATE dbo.BloodProduct SET ProductShortName=N'RBC AFR CPDA-1 IRD LUKOPR', ProductAttributeForm=N'@09 C2 D5', RetireDate='20081103 00:00:00.000', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'09099cb8-5e83-4d1c-aeeb-18699ae3e920'
UPDATE dbo.BloodProduct SET ProductVolume=225, MaximumStorageTime=8760, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'0921ac2c-a655-4cd1-ac04-f7964bbfd819'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'093724f6-ff49-424d-8e00-b2fd83ebd95d'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'0943ec68-3b14-4099-ba9d-9340ee5788c1'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'0944c792-cee9-4c09-9a59-89a29b22b96d'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'0950f63a-34fc-4698-bf71-c1b379484baf'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'095b460e-b3f8-4396-a371-72574e2ddbef'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@03 C2 D4 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'097605c5-d534-4014-80a5-4e6a1502c15c'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@30 I2 H4', MaximumStorageTime=61320, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'098f3ca1-ae7c-44b6-bacd-430245cb5a0d'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 D4 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'09910835-ffe6-4915-9116-bef6e43e940b'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@30 I2 H5', ProductVolume=450, MaximumStorageTime=61320, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'099208a6-e354-40c1-a33e-2ddeaacc8bf0'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@33 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'0992b3a8-1d51-4d54-b23c-95e61a36dc4b'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@B7 B2 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'0998ecbf-4377-47b3-9d95-41f88c8c9857'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@30 I2 HB', ProductVolume=450, MaximumStorageTime=61320, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'09c5654c-c5f3-4b00-921d-b16917826819'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'09cc3bbe-9fca-4540-8fa0-85b2789ef919'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'09de9a0b-15c9-4d07-9382-4b1c111a1899'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'09f43035-9f9f-4b1c-a821-25b2affa2617'
UPDATE dbo.BloodProduct SET ProductShortName=N'RBC Deg None IRD', ProductAttributeForm=N'@AS C2 H5', LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'09fb04d7-e24f-4d7b-a610-bf92b9008cd9'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'0a0b8c55-d6c7-4b7c-bd50-fba79b620396'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@07 HC', LastUpdateDate='20100210 13:55:15.970', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'0a0c0146-b992-41c6-81ec-c62d739f9208'
UPDATE dbo.BloodProduct SET MaximumStorageTime=672, RetireDate='20080301 00:00:00.000', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'0a16b675-31bf-4973-905f-ac1737ac6cd5'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'0a2bc861-db6c-4629-b79b-b901abd69f28'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'0a391ff2-26e2-4dd4-8a81-2aeb79648c1e'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 C2 D4 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'0a4beb15-cbf2-4765-a041-2aba89a4edcc'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'0a6cf86a-cfb4-439b-8090-3c215f38160e'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@10 D4 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'0aae6502-c4d6-4839-93e5-f11a8d6d8b43'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'0aaf75ab-94c3-4429-bf86-cf3d180662c4'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'0ace6249-ffc3-41d0-8d57-4516108ac63c'
UPDATE dbo.BloodProduct SET ProductShortName=N'FFP AFR None', ProductAttributeForm=N'@84 H4', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'0acf5b91-98ea-4ac7-9c96-a62cd3fa7ce4'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 D4 H4 N2', MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'0ae25063-4df1-4090-8c09-46a82e5cc3b8'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'0af35230-ba93-45ec-803b-840e177c48ec'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'0afa0efa-b256-4220-b485-8f83be054656'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'0b1b8000-da34-4b60-bdd1-a3da69e8ce5e'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@33 D4 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'0b1f1601-e296-41bf-aea5-22fcc70d72ae'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@33 C2 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'0b3038be-b72e-4878-9610-2d99572253c0'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'0b3add9a-0477-4b28-88d5-f3d1fbc24a15'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AY D4 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'0b534f4b-037f-4cef-a2e6-7b0e87c3190e'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@84 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'0b76b16c-e31a-4fce-90e8-d859dbf1236c'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 D4 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'0b82239e-5cf1-434e-8771-3fc7331020e6'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'0b869f4c-d6cd-41db-b5b9-2bf17c513931'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 D4 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'0b9d6da5-57d9-4090-b01e-dfb249a7e544'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'0b9faf1e-9413-43ad-9954-2e8a7cdf611e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'0bec07bd-1a3c-4d28-a4d3-c176fa32c08f'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'0c00eac6-34eb-4638-b03b-f2fb7c8ce536'
UPDATE dbo.BloodProduct SET ProductVolume=50, MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'0c0605cd-edb9-42e2-96d4-9e7abf5af2de'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'0c1bdefb-75d0-4217-a0bf-a128a2726769'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@22 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'0c1ebe77-6185-460f-812d-c43c3cb262dd'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AZ C2 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'0c453a5a-dcb5-4cef-b328-74147d7e23b8'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@20 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'0c4f26e0-ee37-4ed8-87eb-71bf88e43485'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'0c51c51f-0c4f-466b-a12b-57b09d63077b'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 D4 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'0c579576-d121-4c28-b6a5-c7c057e84633'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@11 C2 D4 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'0c775437-1741-42fc-95b7-e0dd0fcc9868'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'0c7ac9dd-513a-423e-af4c-83e2e134c5f9'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AZ H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'0c8a7884-d41a-41fb-b421-b0a331cec185'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@07 H9', LastUpdateDate='20100210 13:55:15.970', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'0c9222c2-788f-496a-9c51-ecfd23fb6c03'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'0ca318d0-6de4-43ef-baaf-8fc46c368ea4'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'0cb088bd-a195-4b8e-bd5e-af716f5a41e0'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'0cbe7b8e-bc58-4044-bd14-ee28a5b9013d'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'0cc3d421-308b-44b8-9875-9ae23dd552b5'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'0cc635f9-6f2b-4007-b735-3bb4fb87bc30'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'0cd1bdd2-9af5-4727-b357-8c658fb42d9a'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'0cd789f1-8a80-4ee4-9fb9-c28954c188da'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'0cde016b-de20-4cc3-9ddd-795addd57c61'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@10 D4 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'0ce4afcb-09b6-457c-a32f-368027f66553'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'0ce82e23-43ff-459a-8ef7-a5898b869876'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'0d06c25c-538d-4330-83c6-571f75e9cab7'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@84 C2 I2 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'0d140a4b-4d81-47b9-985d-67caf0227974'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'0d41dce1-9160-47e2-b1f6-325efdfcb1c0'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 C2 D4 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'0d44ba24-d0b2-4625-be70-400b88b43ea0'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'0d5155b0-16b4-42c7-b5f8-4a441caf85a7'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'0d522fa6-6e0e-4295-91aa-7a870c879fdd'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'0d61466e-ad69-4471-88bd-30b1da76e16a'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'0d6263d5-e37a-4e34-be0c-b063ed21d987'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'0d69d205-78f1-40e8-a8f3-296f4a918a1c'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'0d742a06-62f3-4ee2-a774-d80879beb70e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'0d75cd4e-558e-44c4-8b9b-d6173a4e637d'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'0d90115f-7e42-4f72-93ab-805bb5c07d51'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'0d93d8b2-9fc9-4b28-ba85-232832b4df1c'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@03 C2 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'0da40803-8bc8-4eb4-ab3b-fbd63403e15f'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AZ C2 D4 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'0de86ed0-4fb7-40b7-8e76-a7b41de8871c'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'0de9ba23-96d1-4697-b0a7-c6db2023b897'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'0df8383a-f81f-4d9d-b019-06e272987e33'
UPDATE dbo.BloodProduct SET ProductVolume=50, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'0dfa11cb-2a4f-4d38-a4a9-0a74a97365ba'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@18 C2 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'0e01f324-3981-4407-80e1-24d0b74805c4'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@10 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'0e1773d6-acd6-4625-8e80-7f6cd93b570f'
UPDATE dbo.BloodProduct SET MaximumStorageTime=1008, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'0e302ba7-176f-4567-982b-f994a7c75e4d'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@10 D4 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'0e5572ea-389d-4fb1-85cf-098ebc3a41db'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'0e6af11c-db8c-4057-8ead-8249b78867fb'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'0e7f3d70-e68e-4fa9-aa39-4c31917ad06c'
UPDATE dbo.BloodProduct SET ProductShortName=N'FFP AFR Thaw None IRD LUKOPR', ProductAttributeForm=N'@AS C2 D2 H4', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'0e9e22cd-6bde-43ca-bda9-7a195d9a2e62'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'0ea4dfcb-3eaa-4d66-a989-1117b485ff2e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'0ea94c73-f4ad-48a6-9788-38975c633f8e'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@03 C2 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'0eb5f2a4-73f8-472e-b2e9-7372297e880b'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'0ebc4cc9-9c24-484e-97de-dd4cafa3c403'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'0eddc40d-e6e5-4c65-b085-febef1408c21'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'0f1c906b-97f8-4f34-97ba-fb507838ae24'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'0f20e6d5-a096-4c3c-bbfb-1f66bb014c13'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'0f21f071-4bbc-4a20-a930-84e92e1dfda8'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@10 C2 D4 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'0f293526-fecf-4588-8fb5-e20f04e422b2'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'0f3c7a33-0ec4-4b61-8c29-1fd16fe67d61'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@10 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'0f41cacb-f129-4671-92f7-de8fbe663847'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AY C2 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'0f62a3ea-7155-4ed2-a22b-58c99afdfa5d'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@11 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'0f62b616-3e73-4534-a554-872d6f01110b'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'0f6cd25d-0901-4f66-b38d-88a335f8f21c'
UPDATE dbo.BloodProduct SET MaximumStorageTime=4, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'0f8bec49-8cc6-44d2-b8e7-142002f00eed'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'0f8cc761-051d-4d49-b9b3-5ba2df7ce04b'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'0f9dc254-4377-446b-af84-b006728f6e9d'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@B7 B2 C2 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'0f9fed78-cb06-48d7-b4d4-9fe42a96ab49'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'0fc1e452-faee-4b80-94f1-63e718f49814'
UPDATE dbo.BloodProduct SET ProductShortName=N'RBC CPD OPN LUKOPR PLS Red/PA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'0fda7510-f499-40c2-befe-7b298048b3b9'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'0ff0d154-130d-49ba-85a7-df78df041909'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'101a4ee5-b215-48b3-a030-d66f2950cbee'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@10 D4 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'101f72bd-7661-4d65-b2ce-1c6a56861f1a'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AZ HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'105c0e5a-ace7-4178-9f05-0298845701ef'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'10662e01-3661-4297-bf70-134b4a269cf8'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'1069bda2-3abc-4030-b5a1-0d6f6ee44d56'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'106beffe-62ff-48b4-8048-dfb3e0248eed'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'106dcd58-ecda-4b01-b0a5-cb4e2fc5edfa'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AY H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'106dfdc6-0b07-4fe7-8e10-f76c977520fc'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'107065fd-dd58-4f54-bf8e-5ec3be9d3fc4'
UPDATE dbo.BloodProduct SET MaximumStorageTime=1008, RetireDate='20081103 00:00:00.000', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'10770a38-f9d8-4a0c-8202-26dd54c2f825'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'1084231c-3b46-49c4-955a-780abfb919e4'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'10a4bd22-de00-462d-bee9-3708071c5720'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'10a96980-6e9b-4e41-90fa-3c5074206f36'
UPDATE dbo.BloodProduct SET MaximumStorageTime=1008, RetireDate='20081103 00:00:00.000', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'10ca41e6-89f9-4aff-b597-80346c057acb'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@84 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'10ceadda-948a-4476-9e26-7950fd655c03'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@22 C2 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'10d18b5f-dc4e-4765-9dd3-82a7b4a7e93e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'10eed16f-1cd4-4d25-802a-0af1d79887e0'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'110e9fad-810b-4027-91a1-cb52e6d27117'
UPDATE dbo.BloodProduct SET ProductShortName=N'FFP AFR Thaw None IRD LUKOPR', ProductAttributeForm=N'@AS C2 D2 H3', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'1127d9f9-1197-410b-abaf-e4bd89a6cf6d'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'113d5aef-435b-48be-a44e-417994e8156c'
UPDATE dbo.BloodProduct SET ProductShortName=N'RBC Deg None IRD LUKOPR', ProductAttributeForm=N'@AS C2 D4 H5', LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'116129f9-ffa7-4a6f-9840-bf8d8ea0e1ac'
UPDATE dbo.BloodProduct SET ProductShortName=N'RBC CPDA-1 OPN IRD LUKOPR PLS Red/PA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'1169610f-2f46-4180-974c-76c1c030b7bd'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'1180fc0b-de14-4995-bea7-3a6287c2a673'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'118372cd-65e9-4992-89f7-c863286f7924'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'1186cb05-f876-446f-b288-21e9bd70fdd8'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@84 C2 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'119e6af5-79ca-477f-b5d3-3b03f6e240c9'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'11a1fbff-6435-464e-831e-a4f91460f115'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'11adad87-b981-4151-bb3c-94e72ce66047'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'11b71298-3ba5-4d6c-9001-3b6b688c3d0d'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 C2 D4 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'11da7f96-b786-4ffb-b363-14e85ab083ee'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'12113fe1-c24e-4898-97d7-305d146f3bf9'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@20 D4 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'1228deac-1d8d-415a-8071-41b475cf85e0'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'1233b1ff-69ba-4893-b837-1e015a8a39f1'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'1256ee6d-5fb6-4f9c-b82d-7687de8307dc'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 C2 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'125822f8-de9f-416c-bf0c-58c071e8ac65'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AZ C2 D4 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'12662cc6-c9fd-40f2-a374-53543c811565'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AZ D4 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'1270de73-1056-4cb8-93a6-d6b347ecfe68'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@09 C2 D4 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'127fa837-932f-4fd8-a18a-099d7f7ab3bf'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'1286007c-1c25-475b-bfec-30cca21037c8'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'128fff9a-9887-4a4c-a7bc-1883ecb224f1'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'12a04836-2e21-48c6-997f-18f3ea906c03'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'12a2b1c6-b972-428d-a761-086c50aad3a4'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@11 D4 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'12a941fc-8d48-499b-b886-ca375088faff'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'12b6f813-4562-4122-9a89-a0a8cb7bbd9b'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@84 G7 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'12c0f2fc-01e1-4999-9a04-6d31829fb3e1'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@22 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'12c398f0-a74e-45a9-9b41-6b6ed8f99b31'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@03 D4 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'12c47211-3748-4864-aa1e-88d2b45150ed'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 D4 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'12c996c2-4f05-439d-b159-7d89143c5c33'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'12dc317a-6861-4ece-81fc-342273c1c192'
UPDATE dbo.BloodProduct SET MaximumStorageTime=4, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'12f0262b-837d-4f7e-a55e-1c01cf957db1'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'130761d9-b4d7-4d26-adf0-102130211394'
UPDATE dbo.BloodProduct SET ProductVolume=50, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'13177e20-72d1-4948-921d-1b9d1dd8213b'
UPDATE dbo.BloodProduct SET MaximumStorageTime=624, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'131a84f9-aeb2-479a-bae8-d8df792e06d9'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'13320291-4e07-495c-bbc1-080b69d0cb0f'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@B7 B2 C2 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'13490ada-9f15-4899-b86c-83b85f95de3b'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AZ H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'134d406d-a1a9-4f3c-bbcb-c671ae8fedc4'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'1351032f-2f89-43f1-87e0-ace8c8265240'
UPDATE dbo.BloodProduct SET MaximumStorageTime=624, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'1369293e-e39f-4a43-ae53-403eeb0a4672'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@03 C2 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'136e7765-915f-4717-8246-db3069c464f5'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'13743654-83ef-496e-8741-37bc62510d92'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AZ C2 D4 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'13845ce8-3482-4f72-9fb5-db65baed9c7e'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AZ C2 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'13b1b4f6-0a9a-4eda-a82d-d25ab1f1ab2b'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'13b3791c-dda3-4c5f-ac97-b0d1a75b821b'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'13b61f93-eab2-42db-94d9-364009636d4e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'13dc22a6-3688-4452-9c67-d211575b7926'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@07 C2 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'13e24cfa-03d3-4a7a-a3bb-1dfcc44bca51'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 C2 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'13f4bcca-2785-47b7-bca8-3f9997bbf369'
UPDATE dbo.BloodProduct SET MaximumStorageTime=960, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'140d2357-e5a0-448d-b07f-54fb147afd33'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'14182210-e040-4817-b534-33bdef54044b'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'141c88ff-d3fe-40d1-a7af-51566cfa4c05'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@07 C2 D4 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'144f5054-b488-473c-b81d-efcb1b94bfaf'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AY C2 D4 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'14836aa0-8482-4f03-8b19-7fe8bb404d33'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AZ D4 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'148416c2-9fd2-4680-a1fc-9c6ae73e1fff'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'14a0cfd5-0984-4996-babc-b37884459ced'
UPDATE dbo.BloodProduct SET ProductVolume=350, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'14a6c63f-fbe9-42c8-a3a9-ac54cbbc3209'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'14c71561-6bfb-4a7c-84d7-f2029315f9d5'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AY H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'14c8405c-289e-4aba-9b84-201ba36863b1'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@33 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'14cfd2ea-175f-4dd2-af19-68bc3f8e4e05'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'14d7b56c-3950-47b3-b4ee-b14052039488'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@10 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'14e25e74-9072-4de2-bec8-0ce48d2a112d'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'14eb34b2-0b46-4b5f-8fb6-7d5b55f93b0e'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@07 C2 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'14ef23eb-7dc7-40b7-b694-3d5e3988bb6a'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 C2 D4 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'15019b6a-e81f-4b52-bc71-a5d0507acf0e'
UPDATE dbo.BloodProduct SET MaximumStorageTime=1008, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'15203cd9-f8c3-41e3-8217-8b257410d89b'
UPDATE dbo.BloodProduct SET MaximumStorageTime=624, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'1523ec67-808c-402d-bdb3-dad5f99cf558'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@33 C2 D4 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'15264baa-0131-406b-8d9f-090706733c9f'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'15364fb7-1de5-40e1-9be8-1320d74f3e7c'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'1556c1da-1c63-4b00-b289-e05410ec6020'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 D4 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'15595545-beea-4af8-ba34-ea1842608ddd'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'155fd515-7c17-46ed-ad28-f4755b871528'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'1566e03d-dcf5-4104-af51-4ffb23ab7280'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'157562f1-a41d-4671-a49e-ccef4d0f6ea6'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'15a4574d-3bcf-496c-973c-3c4934633429'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'15a61afc-fa3c-407f-806e-a62838867e22'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'15b0fc06-5d69-4311-9f75-5ed9ebb19bdb'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'15b9f538-00ae-4458-976d-5dfd24a0a04c'
UPDATE dbo.BloodProduct SET MaximumStorageTime=624, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'15ba9b18-8db3-4033-9381-250b664c3080'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'15c6c05e-bb42-4377-acd8-40ad90f8e8a1'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'15c940e3-3b3b-41e2-9774-a161937d2c7d'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'15cac4be-17a7-40d7-9a97-b6d0143c719a'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'15caf660-d200-4632-b1f0-54586322f851'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'15e68013-6150-473a-bbad-ea22782818fc'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'15fa5e3e-42a8-40db-9ccf-076a94694dd9'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@09 C2 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'16005729-f9ed-458c-8a01-614632d339a3'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'162135fe-945d-475e-a035-292d0d15159e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'1633c52e-fc08-40b0-8fe3-7659e6f5522a'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'16532084-5a3b-4582-9556-85fcd73631b8'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'165ed9c1-30fc-4d9e-9448-6515d8b1b235'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'166c7e31-2ef5-4976-afac-ecdf106eda02'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@33 C2 D4 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'167edfe5-8bb8-4723-b315-bf6e38d6ced2'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'1695a9de-1287-4ee6-b769-91d83c8f25ed'
UPDATE dbo.BloodProduct SET ProductShortName=N'RBC Deg None', ProductAttributeForm=N'@AS H9', LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'16a2f7c9-ac4c-4629-9883-7f35188495a9'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 C2 D4 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'16c49236-f508-4758-a17a-164d7c7ce3a4'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'16d74f5b-6e99-4bc4-a918-3cbb5034682e'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@09 D4 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'170ec478-3a74-478f-8413-801d270f9a42'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'17197e8f-14f3-4e7d-b21d-6921ce3ad31e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'1757e914-d4ef-4595-ac76-02e05f6e0b56'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@33 C2 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'175b6950-ee05-47a8-b1a6-0d26630fff6e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'17618b58-088b-4dcc-9fe1-41fcf70c7584'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 C2 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'1780b055-a91d-4499-8173-7c58664d6c68'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 D4 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'17934872-29a4-4cd5-a723-541230a159a0'
UPDATE dbo.BloodProduct SET ProductShortName=N'FFP AFR Thaw None IRD LUKOPR', ProductAttributeForm=N'@AS C2 D2 HC', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'17965621-fcc3-4ba7-9119-56e8ed38a7c8'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@18 C2 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'17a9d4ae-b361-4ca1-b7ba-727ff8bd2abf'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'17b2006a-e7d3-47ac-8aed-d5ae3c2a4dbc'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'17b528fc-331c-4cfb-8b42-f2e47dd40116'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'17c38809-9f76-4144-b40d-48b845be6178'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'17c52a68-bc55-47ab-b9ed-c08853672534'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@54 D4 HC', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'17dba687-dec0-45d5-af28-2676c5b1b293'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@B7 B2 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'17ee8ef1-5cba-4116-a499-8afcc0313748'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'1801b881-7672-4262-9738-29bf2d845c40'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 C2 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'1802bff1-fd0c-4f86-897d-4398ce122967'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'182333bb-d3b5-43bc-b931-ca42764840bb'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'185a7aee-11ef-4faf-8d91-cc0adafe18d4'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'185e4d28-6bfc-4a12-b387-ceb6251786f1'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'18776dbc-cce7-4c81-ba45-09fa4815f6f0'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 C2 D4 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'188c0162-35a0-4e79-8998-0258bd6d5053'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'188f0149-794a-4468-a3ee-6fccf7cb62ec'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'189951ac-b636-40d2-9e9b-c6f77e0661ec'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'189cbb8b-8af3-49b1-98c4-12049a2d2465'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'18c242c0-f629-4e26-a318-520d1f2feaed'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'18d33287-f04b-44fe-bd74-98efa0a82363'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'18d989dc-62e6-4826-8be1-84abef46ab20'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'18e27f36-917d-4fa8-820d-473afbd8ad7d'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'18e58726-81d4-4e75-8af4-5d7bd4513de2'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'18eb955c-5825-4bb3-b28a-eb276a05d2b4'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'18f1a6b1-b75b-4117-81f0-32416dcbd117'
UPDATE dbo.BloodProduct SET MaximumStorageTime=1008, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'19053c2c-5d95-4cb0-a2f1-b525f097807d'
UPDATE dbo.BloodProduct SET MaximumStorageTime=4, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'19168b9b-2b06-473a-9b3e-b628d15b2fe5'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 D4 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'191f633a-f1dd-453f-8baa-b10f0fafcba8'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 C2 D4 H5 N2', MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'19608e36-b440-4576-92b1-12dae4076643'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'1986d9cc-7b8d-4d5d-9f1c-cfc329a0c256'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@51 D4 H5', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'198d0929-2a42-46f7-b841-dd0b863329c6'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@03 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'19a94be8-0c7d-4266-b137-b5c70b44bf1a'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'19b7b417-d315-4aba-ab33-a527a9c4a0dd'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 D4 HC N2', MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'19bf0893-0468-4385-8c95-96a1f758b815'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'19c2084f-8b52-46fc-a77e-3284f47df59e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'19c49ace-c1bb-4edc-bc4b-01e653771bec'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'19d23a91-718f-49a4-bd65-09700529481c'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'19d94820-0c21-4b72-920c-3b1bcda8cc82'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@07 D4 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'19d9b00c-1899-4026-b0e6-b699e0ff0fce'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AY D4 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'19dba38c-ca46-422e-831e-4435d673cef0'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'19f96430-398b-449e-bd31-2466683e32f1'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'1a0afa4d-b338-4538-a0ba-669c3920c044'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'1a2b8832-313e-4083-9a38-c2e71ff70cce'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'1ad64285-6f21-4f32-bf0f-7575410408df'
UPDATE dbo.BloodProduct SET ProductShortName=N'PLASMA Liq NS IRD', ProductAttributeForm=N'@CG C2', MaximumStorageTime=624, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'1ad8bb20-d3f2-442b-8248-07943467c3b1'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@51 D4 HB', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'1b07471a-8b08-4fad-9081-c315f4153e62'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'1b0c6bbc-2bc0-4208-b301-280b70bdafa5'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'1b0c76b0-1ecd-4028-891b-4257f7d535ee'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'1b5a3355-17d8-4406-979c-e7293875538a'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'1b777e04-2871-4f8e-a325-75cb2fc2779e'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@84 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'1b8acc66-eada-4165-8edc-06eda8cff282'
UPDATE dbo.BloodProduct SET ProductVolume=450, MaximumStorageTime=61320 WHERE BloodProductGuid=N'1baa8f36-7e18-4e29-a739-fe6eccdc3731'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'1bc064c4-2e55-43ac-986e-a164f61b2d5d'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'1bd788b6-f0d8-4399-943c-5740f76dea1f'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'1bd966c6-554d-4731-ac7b-42ef570a7035'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'1bedcb65-35f2-478a-9624-36f55334d30d'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@B7 B2 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'1c02b117-d6a5-4853-850b-31b9328d5578'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AY C2 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'1c07c676-97a2-412a-9ca1-ca8a01c9920b'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'1c153172-9fe6-4942-b1fb-2eb0a3b9b11b'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'1c1b1cf7-d4b8-4ac1-a86b-d61f6319f822'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'1c2b9664-db31-4e07-ab10-6b0ffb6808ff'
UPDATE dbo.BloodProduct SET MaximumStorageTime=4, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'1c2c226b-da1b-4155-ab73-1f4c5f26bf51'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'1c2f9773-2b50-4c5c-bcde-5b9a1e4234d8'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'1c552948-0c72-48bd-bf63-a065443556e6'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'1c638525-1ea1-43a7-a9a7-9039cadad954'
UPDATE dbo.BloodProduct SET MaximumStorageTime=624, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'1c6b0717-33b0-4acf-9a7e-1874728aa3f1'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AZ H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'1c99d9b9-cc9e-4cdb-b43f-5a7c2762cbb7'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@B7 B2 D4 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'1c9c4244-d81b-42a4-8f26-d44f23ce96e0'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'1cdce61d-e2de-4dab-a823-52f3a6268116'
UPDATE dbo.BloodProduct SET ProductShortName=N'FFP AFR Thaw None IRD LUKOPR', ProductAttributeForm=N'@AS C2 D2 H5', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'1ce1ec0d-f53a-4cc4-8d5d-d8d8e13e424c'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'1ce680ec-290d-4a0f-b224-176daa50bd40'
UPDATE dbo.BloodProduct SET MaximumStorageTime=624, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'1cfbd720-57c2-411b-8a85-4e227a667405'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'1d1021b3-36d6-49e0-8164-8f47e9cdc3eb'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'1d170951-db9e-4b9c-b6ad-61e01076691b'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'1d19296b-cfad-4b55-a0dc-7806e07b8786'
UPDATE dbo.BloodProduct SET ProductShortName=N'FFP AFR Thaw None LUKOPR', ProductAttributeForm=N'@AS D4 H9', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'1d3ca635-9027-4e86-8354-40eeecb1b01e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'1d3f6443-0f93-44f9-beb3-182526cc5778'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'1d428224-ce79-4a53-8846-70ac61aec25d'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@10 D4 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'1d4bf086-ecb4-4c7b-a26a-cf54ba0fad17'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'1d4d76dd-2816-4a57-b1e4-b1906e6e7307'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'1d71d92e-0e36-4d5d-ad6d-896c68b8d012'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@33 D4 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'1dc43e38-d636-4bb3-9e2e-d5ef88b927d9'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'1dc523b4-5306-4e58-abc2-5c2e8a5c23b8'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'1dfa73a8-c7fc-4598-8725-98352ddfe25f'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@54 D4 HA', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'1e057ad3-10e8-4702-96ee-0ea4acc15075'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@84 C2 I2 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'1e0677cc-fcfd-41b4-8b5b-a70883c78e8d'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'1e198730-e33f-4e98-8287-2c04d527a6f2'
UPDATE dbo.BloodProduct SET ProductVolume=50, MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'1e1cd46e-e827-421a-9c0e-415c9635f71c'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'1e2f7670-8d02-4370-ac69-9669f0abecd3'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@03 C2 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'1e707147-2dfc-4a4e-8064-fd640c5149ba'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@09 D4 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'1e70f3be-84b6-44b3-81f8-20bd7c36170c'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@10 C2 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'1e7219f5-0715-44fe-9081-588d8e22db82'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'1e72708c-58ef-405f-a5e2-43b9c22a973b'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'1e819c13-062b-4299-859c-769001d26a8f'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'1e90c2cd-3dd7-4b03-b51b-fc6e56ebaf78'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@22 C2 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'1e9b6f83-b66d-4a3e-877a-09e9180650e9'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 C2 D4 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'1ea97638-7572-42d7-803d-69bebe0d83f1'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AZ C2 D4 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'1eb3ca82-9d91-4933-a2df-f7705323734a'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'1ec781d2-be49-44d2-8323-485fc7866fe0'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'1efebe6d-3dd5-4907-a16d-a365d3d339b2'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'1effcfb4-672a-4472-b7a4-34963d0682f4'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@84 G7 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'1f00433b-f1f8-49ca-8038-4e7deeea7423'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'1f02bc07-616f-4257-a607-c50f648a2118'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'1f04fca0-4d4d-4fe9-9b29-ad6606686ef0'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'1f1418eb-c616-4ad5-9e4a-10efaf6a9995'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'1f1fda47-186f-4702-920c-16cbd7443978'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'1f4ffa2b-e288-4148-925d-159bbbe3b358'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'1f5143d7-c111-4447-9114-6f618e62fe0c'
UPDATE dbo.BloodProduct SET RetireDate='20081103 00:00:00.000', LastUpdateDate='20091109 15:02:22.413' WHERE BloodProductGuid=N'1f59c73f-df23-40d6-b508-e4a281db8ca9'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'1f6a022c-c2a0-4b39-a8c7-5f8c26214dca'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'1f7074a0-07f4-404c-bbbd-fa1e6c8f7412'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@B7 B2 C2 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'1f76a1a6-aa67-400f-a532-9fadb30f2584'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'1f8e93e4-5ad0-4d61-9968-e08e5ec937f4'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'1f9ec33b-96b2-4045-a3be-560d0dc43df2'
UPDATE dbo.BloodProduct SET ProductVolume=450, MaximumStorageTime=61320, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'1fda0674-f85f-4b8b-879f-6dfc84cf55f5'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@09 C2 D4 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'1fda9449-1ef1-4624-aa4f-b6fd8d15fbe6'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'1fe050b2-2415-458b-a096-ff92c829d876'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 D4 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'1ff56862-03e9-491c-bc79-eeabb0868c70'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'20158901-62dc-48bc-aa18-b0b63a0c4e19'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'20268976-13ac-411a-b323-1bb998cbd237'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'202f6123-1fd9-4712-8df6-550cd4318325'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'203d40d2-32cf-476c-b9ba-c0ed01033b93'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@84 I2 HB', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'204b1bde-41a1-4a1f-9b15-56908ba2868a'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@B7 B2 D4 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'204bb781-a991-43db-9010-b5515af7d7c6'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'206b44d6-2029-4a97-8beb-990e9688941c'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'207d4fe8-5958-4f8f-bac6-e5a3b0a8ca8e'
UPDATE dbo.BloodProduct SET MaximumStorageTime=4, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'208b3f92-8957-4d5a-84f3-92038b1d5b26'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'20ac84fa-d291-4d29-b8ff-6cee8e6714d4'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@10 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'20db9d84-5c8d-406f-bf67-10891e997b1e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'20e6cebf-78fb-4a5c-bd31-4e86b57c6c4d'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'21053b6d-d86f-45da-b68b-fa7ac1cb3037'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'2105d78b-912e-4d03-9f90-b07cae25f885'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'2112ffa1-27be-408a-9286-c7031a33ed3f'
UPDATE dbo.BloodProduct SET MaximumStorageTime=672, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'21139cbf-39ec-4cd9-89fc-782e7283a6fb'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AY C2 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'211d5149-05fa-4152-b2cd-0296c9b7a7c4'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@B7 B2 D4 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'2139f418-4393-4d28-aa2f-f6de4ee2a314'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'2141c9eb-4288-40c3-920e-def4d99f7bbe'
UPDATE dbo.BloodProduct SET ProductVolume=50, MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'2161276c-7c96-4025-8cc5-432cc7dcc4d7'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'21666c19-1e14-4593-8547-96fd297a5064'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'21812ad6-6e83-4bbb-aea1-e5fde7180da0'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@84 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'219bbea2-7c40-40d9-ab21-078a6071a62f'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'21a23093-bbd8-4857-8144-b7e57b130508'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'21a6eb5e-b3fc-4371-b842-ab5718e12e5b'
UPDATE dbo.BloodProduct SET MaximumStorageTime=960, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'21d56613-bfa6-445b-a675-d6263cac08b7'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'22045022-4609-4e5b-b231-a429f64d08f5'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'2205992d-bf34-4a39-a2c2-9cea40208856'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'220d73f7-f248-4adf-9ef3-a67dd24bfae3'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'220dc111-d52b-4dcd-a396-e38a855d7303'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@30 I2 HA', MaximumStorageTime=61320, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'220f9b56-21fb-41de-b211-1bee298f0473'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@B7 B2 C2 D4 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'221992b7-b643-4610-bb69-34791b15955f'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'221e7807-eb7d-4e7b-81d6-4102da71f59f'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'2247349b-da6f-4b10-b80e-8818e62328bf'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'22577100-dd39-46b8-9360-458eb3a5a522'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'22654020-f8ff-4467-bc74-a17cf0ca2f35'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 C2 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'22693e71-38a6-4b15-a450-d3d68e40e1ae'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@03 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'2283e002-8334-4afd-a516-9c6fae334462'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'229ea480-7a91-49cc-ae18-c683c7b464b3'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'229ead56-8692-4473-9b3e-cb2554efa02f'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'22a35c3b-8f9c-4128-a62a-45b9b1f0f971'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@09 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'22b2e089-e366-446b-89b9-a163b1006376'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'22b6942b-8b19-4f3c-929d-7df0cf4a0941'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@B7 B2 D4 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'22d400a0-609b-4624-8e47-6ece54e98ea7'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'23221036-c095-477b-95a7-9a6a398e29d3'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'23269258-6abd-4856-92c1-a9b8cd89fa3e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'232c85cc-e8d2-4e1c-a46d-2c675c1bde29'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'2336d809-0efa-4f96-bf3b-b262c97e4609'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@18 D4 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'234e28cb-9854-4485-b273-6306a66c3e69'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@84 C2 I2 H4', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'23593a8f-6d9c-4cb3-aece-b0759570b192'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@84 G7 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'2373ab24-1932-4a4f-8e6e-c6817d845093'
UPDATE dbo.BloodProduct SET ProductName=N'FRESH FROZEN PLASMA|CPD/450mL/<-30C|ResLeu:<1log6|Frozen <=6h', LastUpdateDate='20091109 15:02:22.587' WHERE BloodProductGuid=N'23831017-0aad-4c08-8c8c-5dc219cc70b2'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'238e0673-1855-4dd4-9430-188cc914d9b1'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'239ae23f-76d0-4238-97b1-879f7bd1e904'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 D4 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'23add771-b150-42de-a09a-143f80522daa'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'23df5bf6-3834-4a97-a202-5595f8097e19'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'23ea3629-be0e-4cbb-81b8-c33bc04e472d'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@54 D4 H5', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'240a0d07-8535-4f6b-8ed6-a0390ba3f621'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AY H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'2437b15f-ae3b-48b1-bce7-78ffdb14c0f6'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@03 C2 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'24586a20-fb04-451e-aef2-5d3195a50cac'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'245ea715-8697-4517-ab73-72ec69f271a1'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'248890be-66e6-4dc9-a2d8-24033b2b1f86'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@18 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'24977301-7ebd-485a-af98-5426ba8b7c40'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'249e1ded-8295-4485-9bc9-d8cf8d39cb69'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'24aca56e-dae0-4d60-8461-9b7cfdd2f3aa'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 C2 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'24be75f4-d97e-4abf-9e5b-fdee3043b6b0'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AZ D4 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'24c27fb1-ca9d-45a7-99c4-37992930659c'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'24cdf95c-4c1e-468a-8e42-93dfccf47bff'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'24f4daa8-62d8-46e4-bab6-2a5c02d6c3d4'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'25003ee1-c780-4ae7-aeb7-4ae65f8a90c0'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@18 D4 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'2517575a-4e53-4a1f-ba20-164aed367318'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'254d0eb0-6a56-429e-812a-cd98d78a1048'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@33 C2 D4 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'2559cce5-ef75-4d96-9660-6824ff076504'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@10 C2 D4 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'2572749d-5aa5-4eb8-976a-4f10f2acc86c'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'2574d576-265e-41e9-85aa-22552186a374'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'25aa977d-21fe-40c5-84a2-00d53e9bfbf3'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'25d9b867-87eb-47fb-8423-5eb880370da5'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 C2 D4 H4 N2', MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'25e1fdf2-aa99-4633-b1a7-f15d7633f33a'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'25e3233e-bc53-4ba2-b852-9d97a0a0857e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'261251f3-7f07-4a7f-bbeb-a5092b29dc23'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 C2 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'263c56ce-a416-4750-be97-57f640ffac6d'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 D4 H5 N2', MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'2642c0eb-36e4-41f8-955b-49d28242f718'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'264ce7c1-e2b1-4a38-b9bb-cadebe2c0466'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'264e5325-fcd0-4b85-8195-157c746c6051'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'265475c0-7e11-4f85-a1ed-0f34a02e7d3b'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'2673bcb6-e958-4fc8-ad3f-5cb7eeb334dc'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@11 D4 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'26753e6b-559b-4395-86bb-8ea6978ba72f'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'267a99dc-d61b-4d9d-9542-dc2c86e2e546'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 C2 D4 H4 N2', MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'2684fb93-d4da-4dd1-b964-9aca64889a08'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'268bd72b-6f71-48e9-a41a-d49484d19715'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'26b87e3d-894b-4fbe-812e-4c7c943d8f84'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@07 C2 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'26d9c7f0-e752-4596-9bc9-c5191ca44dfd'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@30 C2 D2 H5', ProductVolume=450, MaximumStorageTime=61320, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'26f1823e-f613-40f7-92ce-0464944b660c'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'26f58b4f-6527-4d5f-b087-8350418b84b0'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'272f2c08-3c3b-4762-8f67-9db8a85a6ee4'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'274ce8c8-d014-434d-b5a8-37cdac1832a2'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'27cc91cd-ae3e-4b0d-a2e9-d94283c3382f'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'27d2a603-262b-4a45-9d1e-57df55402535'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@84 HB', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'27d919b8-a58e-4094-a5e6-051fb7ff02be'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'27e0d3fa-f3cd-4e22-a7b2-e6c1b0ab4fc3'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AY C2 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'27e613f2-85af-445f-a5c7-ee869650758b'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'27e72916-ba03-4ef9-954e-fac68579317c'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@22 C2 D4 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'28052ce2-c3c6-47bd-af66-16d66c9fee9a'
UPDATE dbo.BloodProduct SET ProductShortName=N'FFP AFR Thaw None', ProductAttributeForm=N'@AS H1', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'282b0805-c562-4792-9de7-18ae10b3be96'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'2859c702-c8b7-4175-b9e3-40cfd7ba1b45'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'2875be9b-2323-4433-a1a2-51e9af304ede'
UPDATE dbo.BloodProduct SET MaximumStorageTime=624, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'287dc6fe-2973-48a1-8944-b3c72da30c2a'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'28adfc7b-10de-4016-83cd-a37c487f3825'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'28b9ea0a-c8e5-4522-b1cc-d45442b49fde'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'28bbf6cb-1974-4631-bfd2-b9da07e8eeff'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'28c028eb-9b34-49c0-a427-6aa8be5e22c7'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'28dee929-2774-443e-b525-a8299afd7f9e'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@30 I2 H4', ProductVolume=450, MaximumStorageTime=61320, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'28f82bfc-b752-49ed-9bcb-eeb62ed8c6f3'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 C2 D4 H3 N2', MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'29251733-f799-4830-a1ff-df42abe29229'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'292c8bcd-5e5d-4d3c-9248-92de12f7c526'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'293972a2-a3d5-4983-b020-4b3c466f6ba0'
UPDATE dbo.BloodProduct SET ProductVolume=50, MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'293f4ead-a284-4fb3-a60a-d0012b9009c4'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'2941a2cf-84b9-4a43-b538-0fa06964e094'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'29474a29-22a7-4baf-8acc-e45f99e45a3d'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'296535e9-92f2-475e-9884-aeb0c179dde9'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'296a67c6-59dc-4ead-abfc-942051de2e57'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@33 C2 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'2974c528-5271-403b-b6d0-d9ddd0feae30'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@03 D4 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'2976fb4f-cb18-4ea9-ac22-bd60bff6e02b'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'29802d92-9e23-4c2e-9c0e-55c5f5c5e2e3'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'29832e50-d63f-46a0-8a93-3c705b416c40'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'2984c243-991e-4f20-a988-a779bfd97c58'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@10 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'2992ec17-40da-4711-9421-0a4e88528ef2'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'2994ac1e-10b8-464d-bb34-a32f030cac57'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'29a04eb9-154f-4e8a-a271-37fdba6fe2d2'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 C2 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'29aead00-01a8-4590-aaa3-e6c9c148c54d'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'29b31f36-86fd-4e6c-94d9-3ddd376c3925'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'29bb1f00-3d89-43d0-a4a4-85dd88bd40ef'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'29db2565-fdfe-4746-9770-c84cd520cd37'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 C2 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'29f451cc-e31f-4e42-a7c5-e9069054f184'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 D4 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'29f459f6-7595-4a65-99df-424ec368c5bc'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@07 C2 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'29ff6223-b9ce-4ab9-87ad-4b47433049e7'
UPDATE dbo.BloodProduct SET ProductShortName=N'RBC Deg None LUKOPR', ProductAttributeForm=N'@AS D4 H6', LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'2a1e1f39-2c43-42e3-94bd-a03f40e3ae89'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 D4 HA N2', MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'2a2ab50d-8f98-494b-9f50-6f156540cb3c'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'2a4c7b97-7999-4192-a9b4-5c872f0c6210'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@B7 B2 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'2a4f8299-c17f-431d-9e00-f3b193680b14'
UPDATE dbo.BloodProduct SET ProductShortName=N'FFP AFR Thaw None IRD LUKOPR', ProductAttributeForm=N'@AS C2 D2 H9', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'2a579ec7-8c5d-49bb-beea-9487d0212569'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@33 D4 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'2a5e9e0f-6a5f-4222-a2fb-78c93eeca050'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'2a88f8e3-079a-4c53-9756-2683233a7fc9'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'2a8c3d35-311f-4fcd-999d-23aa3f31f522'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@03 C2 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'2a928198-280b-42c4-9bb5-38a7ca4dca54'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'2a98bacb-d59e-4f38-8efb-a353c954448d'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'2aa3dbe4-1235-47b0-8ad8-b030bc11010a'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'2aa535de-56fa-443d-bc4b-324c5267582e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'2aac641e-4044-4b5e-8628-cf359bce23f1'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'2ad79c06-33f8-4e32-bfe4-385c5206c3c5'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'2aec9e17-e566-4a5d-b2ea-6290cafae1e9'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@22 D4 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'2af0c3c2-cc1b-4204-9b7c-b6ae31983aa6'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AY H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'2af433d0-168c-4887-b102-b51843fd9bcc'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'2afbedf9-f56b-466e-a7dd-9c5e7884a0ea'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@84 D4 HB', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'2b478fe8-9513-4ee9-a9f8-ba2f01f7a627'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'2b4eaff8-b166-4a36-8a7d-fe9d73994531'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'2b5c14fc-1b91-46b0-bf46-2f3b86a61eb9'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'2b61b737-c1ce-4f26-b9ff-6e5b0e26423a'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'2b65d5b3-463f-42f6-9a89-00ff458e5ff9'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'2b6e4b4e-4687-4f54-a2ba-e3848efc86dc'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'2b6eac79-7025-4166-b18e-b9eb795e86bd'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@10 C2 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'2b6f4e4a-cac6-4364-8afd-ba83340c1695'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'2b9472bf-01c8-4289-8333-38c1676ba813'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'2bb528e3-ac7d-4d2e-a8d8-ac4033df2cc6'
UPDATE dbo.BloodProduct SET MaximumStorageTime=61320, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'2bb53ad5-31f2-4000-9a1f-13fb714746c5'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@18 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'2bc003d5-7e5d-48d7-9bb1-c70936e405fa'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'2bca9206-881a-4d5e-ab80-02b6a17b34fa'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'2bd168c3-d0a8-4b69-9616-003c5a24bae7'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'2be0d6f0-a111-4aae-8bb6-8b1c2e42e11f'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@10 D4 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'2be959b4-b334-4b95-99aa-ccca9b3b8a09'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@30 C2 I2 H9', ProductVolume=450, MaximumStorageTime=61320, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'2bfa7fe1-8884-4fd7-934f-639e3ee42849'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AY H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'2bff0af9-d9f3-4882-903b-7bdbf0b74ff5'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 C2 D4 HB N2', MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'2c077b6e-89d3-4208-9150-c3473a0c39d7'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@03 C2 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'2c0ef873-3a31-4ba3-b96d-1f74b75766ca'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'2c2565dc-f7cf-4fb9-b747-bc57b930874d'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'2c3e68da-2c3a-49da-b190-a017b353c67e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'2c407b07-7923-4073-bcbe-8409c2121884'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'2c48ef69-6120-4d4d-a6bb-94a4137527ca'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'2c508663-ed19-4891-a68f-b3a6a8c294a4'
UPDATE dbo.BloodProduct SET MaximumStorageTime=1008, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'2c7047a0-54c4-4986-9d6f-f00716260732'
UPDATE dbo.BloodProduct SET ProductShortName=N'RBC Deg None IRD', ProductAttributeForm=N'@AS C2 HB', LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'2c8727db-c6e3-422e-bf13-a5164346eeee'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@11 C2 D4 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'2c8f6ac3-0475-40e8-becc-c2a1f4b85523'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@11 D4 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'2c95be11-d598-48b5-a3a7-b96bb2c9d073'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'2caa6b05-550a-4b8d-b513-3dd365d31de5'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'2cc91ec3-350e-4783-afae-67930bf89a4d'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'2cd71d3e-1148-4a7f-b6e7-c7acef30e2b0'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@30 I2 HC', MaximumStorageTime=61320, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'2cddceb2-e259-4a15-a707-bc342b02dfd8'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'2ce9dfa4-a67d-4c49-9523-e1899b8e072c'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@30 I2 H6', ProductVolume=450, MaximumStorageTime=61320, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'2cec4c9c-40f4-4857-a4f7-31e351819424'
UPDATE dbo.BloodProduct SET ProductShortName=N'RBC Deg None IRD LUKOPR', ProductAttributeForm=N'@AS C2 D4 HC', LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'2cf213b4-2655-4cfc-b1e1-97dedf772ba1'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'2d05e203-6a69-4145-9670-a1ea78bf60d5'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'2d1c426a-94c7-4e68-aaef-5f3c56758bd2'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@10 C2 D4 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'2d1e6e43-1674-4232-8c68-f0517c901ce8'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@03 C2 D4 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'2d21d941-28ea-4560-885d-721f5bad2386'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'2d28426c-5bac-4a17-91d2-9e466ec422e8'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 D4 H4 N2', MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'2d362873-cf2a-4b15-9656-7ace9cd516a4'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'2d48156a-25e2-4d79-a175-95a87a6d9c5a'
UPDATE dbo.BloodProduct SET ProductVolume=450, MaximumStorageTime=61320, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'2d57a7f8-6431-4369-be6e-89e6772cfb03'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'2d6223d2-e185-42c7-be4a-c3fb0cca3217'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AZ D4 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'2d74586a-4196-4996-9d0b-766a2746b059'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@30 H5', ProductVolume=450, MaximumStorageTime=61320, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'2d813e55-2ce3-41e5-b6db-00129a6467b2'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'2d891511-d380-4ada-a591-6571fdd1e6f0'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@30 I2 H9', MaximumStorageTime=61320, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'2d8af4dd-11d1-414a-8140-53200767f8de'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'2da08ad0-92da-4e80-ad5f-7aa535c86901'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 C2 D4 H9 N2', MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'2db7d154-f411-43b9-a33f-cc90b8f3777e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'2deb4d14-3fe0-48a0-b110-fb818c28f843'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@84 I2 H5', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'2e2f000b-307b-4441-9264-e8d3083be5a2'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'2e377e85-1f9b-4c0c-8b34-1c7cc4f30b77'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'2e41a9ca-cfb3-40fb-b83b-1c852cec89eb'
UPDATE dbo.BloodProduct SET MaximumStorageTime=1008, RetireDate='20080301 00:00:00.000', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'2e431b77-de0e-40a5-a541-070000ab89a9'
UPDATE dbo.BloodProduct SET RetireDate='20040901 00:00:00.000', LastUpdateDate='20091109 15:02:22.337', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'2e66834b-a3ec-4999-a9ce-81eabcaa4167'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@11 D4 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'2e6d6a78-0b1c-43fe-9bac-c9ac23728153'
UPDATE dbo.BloodProduct SET RetireDate='20090901 00:00:00.000', LastUpdateDate='20091109 15:02:22.727' WHERE BloodProductGuid=N'2e711b44-a578-4686-84a3-07f27fea6049'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'2e878018-940d-447a-8c37-a89c396a8132'
UPDATE dbo.BloodProduct SET MaximumStorageTime=672, RetireDate='20080301 00:00:00.000', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'2e906a86-211e-4e4d-afbb-b229a51831c9'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@03 C2 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'2e95d487-3cb2-47b6-995b-4f8f2e6c7a67'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'2ea783b0-92a7-4627-877b-83be9f6f04e1'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@54 D4 HB', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'2eaecd73-c6a3-4ad7-a9b9-dc8c5edfa97c'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'2eb29654-b37a-47bb-b249-6f25fe972f25'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@10 C2 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'2ec50628-1ebc-438c-b278-0a260eb55a04'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'2ec9674e-7e76-45ff-b3f7-c1cdcb29b4c8'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'2ecbe557-5a35-4d41-a0b2-e8d44bafc9e6'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'2ecfd3c7-20fd-4a2b-94d9-3fbea0f52beb'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'2ed7646b-83b2-4112-9f1d-bc021e79d3df'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'2eea71d7-8a69-4329-b1a5-9fc6f1ca8c88'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'2efd8127-2fe0-4b20-aa28-599e4185aaa6'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@11 C2 D4 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'2efea195-9699-4aa5-b1ab-e69872e18e39'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'2f163092-d080-4e28-a987-07feb40f40b8'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS G7 H4', LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'2f2a58cb-730a-40aa-9cfe-d6ebdf2fd483'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'2f3015eb-3e1d-48bb-a798-140409b38367'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'2f397523-2966-44fc-85de-03c1a47007df'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'2f3b7ecf-675b-475a-a097-77f99d6710a6'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'2f5e2a9e-0f56-40bf-a72e-bf59507b8686'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'2f6e56d5-7c6e-4e5e-bea0-198740c6507d'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'2f76d8dc-33e9-40c8-990c-a40404acf5f4'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'2f7a1517-940f-4819-b94a-8628b06f54a9'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'2f85405c-54e7-4fb1-b1ea-4a6995a3a103'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'2fad6f6b-deda-40d0-aaa7-562f55b7161b'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'2fc432c3-e5c7-4e6b-ad9b-1ab37d10c4c4'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'2fd3771a-c774-40a7-a29f-192e5c36be87'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'2fef18d3-b0d4-4c32-a2c9-3c4767895d89'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AY C2 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'30027d0c-5c7b-4c48-9e88-9eb00e2e891c'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'30027f88-86e3-4d10-8252-d48dbbe3067b'
UPDATE dbo.BloodProduct SET ProductShortName=N'FFP AFR Thaw None LUKOPR', ProductAttributeForm=N'@AS D4 H4', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'3006fd1e-bc91-40a8-b043-31a5fe4afb25'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'302c38cb-a026-4c97-b89e-69d1ace5d85e'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@84 D4 H4', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'30483d1d-ca14-4b1c-818f-44e52cb68ca6'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@07 D4 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'30562b5a-0d22-4f5a-98bf-b3a42f63bef1'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 C2 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'3059bf0c-e109-4a32-a838-d184b42cb9e2'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'3074df72-0f66-4b35-9c79-91b42d4eab69'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'30779567-0823-4a12-9a7d-9797969174fc'
UPDATE dbo.BloodProduct SET MaximumStorageTime=624, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'30889cb4-7609-42d2-a9b8-a064887f5d14'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'30a49be8-b309-46a8-a3fe-b47431ce450f'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'30ab7c8a-3658-4eca-ad92-7041d6faa9e1'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'30f00efa-f6e1-49af-83cd-3c35c27c0a21'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'30f8d008-dfc1-4a94-a2d4-5cfa36cc21f4'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AY C2 D4 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'30fec2ef-298c-426c-b086-47a47d7f9d74'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@84 G7 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'310dc721-bdd8-4f33-b9de-aa6ac6df4af5'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'3142be1b-b0e2-4619-91d0-248722903a93'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 C2 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'3145c516-4179-49cc-ab75-2a1997df2d98'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 D4 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'315e6408-4fbd-4a7d-910f-f25082b9fbd4'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'31810906-edbe-4458-990d-888b86df2f1f'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 C2 D4 HC N2', MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'31a6833e-5da2-4f25-8a38-ae5873442d21'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'31a817d3-080b-443d-84fa-3be8f77ad810'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'31c1c4fd-7ac5-4ea4-9c87-ba7163778bb5'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'31d9aac7-9886-4997-b2e9-2e1c21820181'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'31e3a7bc-cb84-4584-9a9a-ef901dbdc4b7'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'31efe057-9a80-4e45-972b-9593a51bc96f'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@10 C2 D4 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'31f5c722-daec-41af-938d-07a80b3c861e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'320ce080-6902-43df-bc7e-6cd47836bb89'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@07 C2 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'32230ad1-e64a-45a9-960a-6853c3f36bab'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'32312174-f2d0-4447-ace7-6c969c236fe5'
UPDATE dbo.BloodProduct SET ProductName=N'Apheresis PLATELETS|ACD-A/XX/20-24C|Irradiated|ResLeu:<1log6|Plasma reduced|3rd container', LastUpdateDate='20091109 15:02:22.680' WHERE BloodProductGuid=N'32385685-6894-43b6-b1e4-f1eb81b0bcf1'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'32396fa1-d38f-4c82-8f4a-559aa68ddf5d'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'325c1808-39ff-416d-ac60-03f17e830448'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@03 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'32607a74-0802-4baa-a521-32da91723a17'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'32639b20-3ff4-4025-aa90-afb15fa1be22'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'3272894f-b971-4aa9-919d-4b0b3fe7069d'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AY C2 D4 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'327d9a42-9943-47d1-b775-fb4d72de0767'
UPDATE dbo.BloodProduct SET ProductName=N'Apheresis FRESH FROZEN PLASMA|ACD-A/XX/<-25C|ResLeu:<1log6|Frozen <=6h', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'3286b870-0f16-42ce-964c-e3c5125ff7ce'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'32992e70-0ac6-4f58-86b3-f218fca9a3e5'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'32aa43d6-8ba9-412e-8fd2-7e2b0b92df27'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'32c33ed2-a36b-43d8-a13f-3abae7352f54'
UPDATE dbo.BloodProduct SET ProductVolume=50, MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'32cdad76-7afd-4550-891e-6820c2c203b2'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'32d7c23e-87a5-4cc9-ad46-c23581b96ecb'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'32e0cb4d-cd0c-4022-91ee-c367d36e3ee5'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'331bf566-646e-4b63-84e4-cf3d962f8348'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'3321d571-2959-4db1-96c2-f8ebd81166ac'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'333f725a-d062-424c-a38e-b746ef95cf5e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'33514860-9391-4cbe-88d9-2efc51dadadd'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'335575c4-91a4-4d5f-8644-cc59c3ecdb50'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'3355ac27-6a95-4254-85aa-4371180a9411'
UPDATE dbo.BloodProduct SET MaximumStorageTime=1008, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'3369b33d-7ab9-4e1e-a248-9b3bfb4ed68e'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'338b6a72-aa29-4710-b909-8cd9b66f0f17'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'338e3fdb-c9c6-41aa-92dd-763ddee6f067'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 C2 D4 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'33b4ffae-2dad-4a77-9558-7c8ceb6a1501'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'33c41065-194f-4a58-80f4-ffa8629b56d7'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'33ccd329-420c-41a3-a1bc-b46a422952b7'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'33d0ef8b-33c7-4dec-bd60-693d41fe720b'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'33d6cf37-4501-41c5-ad6e-2d54621007ba'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'33de86a1-e01c-4b6a-8071-0b3bcdbe486a'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@11 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'33e07775-017f-4953-baa0-98560af044b2'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'3407aa67-1ae3-423e-a4fb-4c9ebc8d7554'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@84 C2', LastUpdateDate='20091109 15:02:22.837' WHERE BloodProductGuid=N'340ebcf6-424c-4f23-b492-8b8f80dc5a5b'
UPDATE dbo.BloodProduct SET ProductName=N'POOLED PLASMA|CPD/450mL/<-30C|For mnf:injectable|Frozen <=6h|From 2 donors', LastUpdateDate='20091109 15:02:22.867' WHERE BloodProductGuid=N'34301f1b-e71d-42a6-9303-b68f9b0e77e2'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'3433f54a-ed90-4839-b348-48738d523ddf'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 C2 D4 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'3435f44a-b19f-4551-945d-64372e920ded'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'343f48bf-c131-47f3-8204-baac4ff8319a'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AY C2 D4 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'3443021d-5e14-4a9a-8d2b-365458b4d0bc'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@B7 B2 C2 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'3456bfc7-3a99-49e0-9254-72a4dac164c3'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'347463af-edfe-4039-8c33-51db59a1ed63'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'347a244d-4397-437b-bec6-10e86be6efc5'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AZ HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'348ea3ce-8d15-49b9-9f0b-d4aa1b98a45c'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'3491c4bd-027c-499b-b9a5-900a544e38a5'
UPDATE dbo.BloodProduct SET MaximumStorageTime=1008, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'34ca7763-7307-4534-b829-ebd6f956dedc'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'34cb1e09-ffba-43b7-bdc9-717a960f46bc'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 D4 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'34edf622-f4f7-4f75-b0df-d3a581b58681'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 C2 D4 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'350bc9f1-04f7-4ca3-a309-89e5cbd1fe1d'
UPDATE dbo.BloodProduct SET MaximumStorageTime=1008, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'3513e8ee-e3a4-4da7-9731-30563b5c2b49'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'351ee22a-9457-459d-b8dc-d1fc9dbc94d0'
UPDATE dbo.BloodProduct SET RetireDate='20030901 00:00:00.000', LastUpdateDate='20091109 15:02:22.320' WHERE BloodProductGuid=N'3562c298-f702-4704-aa6a-4b0f33f751cc'
UPDATE dbo.BloodProduct SET ProductShortName=N'PLT AFR Wash NS', ProductAttributeForm=N'@72 JC', LastUpdateDate='20091109 15:02:22.820' WHERE BloodProductGuid=N'3562e5f8-f7d8-4546-a1a0-95d3274d3a9a'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'356af699-3b07-4bc9-bcbd-18fcf94aac8f'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'356cf127-7eb2-4130-a173-587b75deca08'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'3588499e-907b-4e91-9112-b9a388bfafcb'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 C2 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'35b1bfb0-cce1-4bd4-9ea0-48984d2251d6'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'35c91307-faf8-4a74-87a6-6a2840a075f9'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'35ce5d0f-d5ed-43a8-9be6-6641f4ec302d'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'35d2b26c-cb13-4984-84fb-0f7828afedf0'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 C2 D4 H6 N2', MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'35e4e980-c8c7-49e7-98f4-07e33923b347'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'35e749ef-c166-4764-936a-2cefaabafc0e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'35e768fc-17d1-46ba-ad6e-430e5241c8d5'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@03 C2 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'360b3120-0cd6-438c-b377-e734ecbfe28d'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'3615970e-29ea-4e5d-9d92-c2bd3caca143'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'361cbfbf-d3ad-4a10-8f36-3cd9f760a666'
UPDATE dbo.BloodProduct SET MaximumStorageTime=624, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'362265ca-bb77-4b72-a13a-787035f04d02'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'362c7e13-6f0a-4f2a-a9d1-e019674f7fe7'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 D4 H5 N2', MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'362f5218-af4d-4ca0-b364-91c10cd5b103'
UPDATE dbo.BloodProduct SET ProductShortName=N'FFP AFR None', ProductAttributeForm=N'@84 HB', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'3637a9cf-e394-4440-9241-553fb31ce21b'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'3643828a-7742-4898-b9ba-62a4939567c4'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'3664e118-47e6-492e-ac94-f99daac20f8c'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'36672499-9a8a-4834-8a63-f99cb959bf2e'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'367cdd85-3f92-4b0b-b07a-e19d460242d5'
UPDATE dbo.BloodProduct SET MaximumStorageTime=672, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'368f5d45-db9c-42e2-9c79-b11f62047306'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'36a0ff79-8cd6-4627-ac7b-aeba47e58906'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'36ad931b-d01f-4997-8b92-6a52dcd2faf4'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'36bb2f47-75be-41dd-87cf-0b4334f16f1b'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'36df9a97-a579-473f-a475-ec840dd8b666'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@B7 B2 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'36e6b16c-826d-48e4-9dcc-aaa388731ff4'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'37094f89-050a-4045-9cd0-5cfac57341fd'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AZ C2 D4 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'370a121f-403f-479d-9b06-cdb33b770e7b'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'3724a81a-1d75-47bd-850f-7698d535e326'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'3726f905-daf6-4783-8b0d-8479ef948f3d'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@18 D4 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'373d11dd-dfb9-4aa1-a9e3-cb9d8a536178'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'3764a09a-26c3-46f0-8c4c-e88879929308'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'379f237e-115d-41a8-a1f6-b12c17a78985'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@B7 B2 C2 D4 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'37a97906-c713-4a24-bc56-e848c6fc3c66'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 C2 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'37abf122-48f3-4255-996b-375d840ba76e'
UPDATE dbo.BloodProduct SET ProductShortName=N'PLASMA Liq NS', ProductAttributeForm=N'@CG', MaximumStorageTime=624, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'37c361ca-bd93-4e42-8159-6c0f8d8fd57a'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'37eaf440-df16-4d43-92c4-b60b161cebc4'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'37ef2b91-0e6b-4517-9fc0-2b9d84a0b870'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'37f2d02a-3b42-44a6-b934-0d795489061f'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@11 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'38107b24-9bd0-4a55-9995-cccd903c3aa3'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@11 HB', LastUpdateDate='20100210 13:55:15.970', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'382ae367-1f72-4c24-a02d-5d203887fca6'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'382bbceb-ef0c-487d-9fdb-5b9fe701720c'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'38414e6d-17e8-48a7-a6ee-ca1f682d1012'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'38525c45-600b-4384-a730-9fbb3e200a50'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'386f2344-eab9-4d8d-b879-f3d4da67013d'
UPDATE dbo.BloodProduct SET MaximumStorageTime=624, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'3884d6ca-036d-4d72-bb20-ea547ce4a794'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@07 C2 D4 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'38b05d78-f314-4069-ac50-48e03de149eb'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@03 C2 D4 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'38da1efc-2ba1-4b07-a3ec-fff77aba82ec'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@07 HB', LastUpdateDate='20100210 13:55:15.970', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'38e26340-8987-4b1b-892f-e36345ffe216'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'38e31278-5a2d-41da-8242-d669f0456158'
UPDATE dbo.BloodProduct SET ProductShortName=N'RBC CPDA-1 OPN IRD PLS Red/PA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'38f3db0c-f563-4bf8-8e71-e0cb85c04c5a'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@10 C2 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'38f9bf65-1863-483f-b5d2-8e969b186920'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'39092792-ad98-4009-b9fb-610e47bfe1e8'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@20 C2 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'390a1563-1a34-4b52-ba3f-f25313ec0a67'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'390f0eb8-c212-4c35-bc2a-5327926c98e2'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 C2 D4 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'39199341-57c2-4e55-9365-a95654869fb8'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'39230702-bf45-4cee-a378-9cfe8c588fcd'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'39255f80-5186-47a8-a7fd-f07dc0a81c2d'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 D4 H6 N2', MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'392a9cb7-baea-4f90-a798-6aa6bf7fa5f9'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'393a3721-4cd4-4650-89a3-aaba7965d481'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'393affe8-7cf5-4941-844b-7ae1222fa490'
UPDATE dbo.BloodProduct SET MaximumStorageTime=1008, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'39465891-9bc4-41be-a244-dd5afb728a20'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'394dc7cd-f758-4f5f-bf9a-a4b720eeed16'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'39507886-95fc-4d99-ad5f-f688fe8f8f4f'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'395a8eed-5db7-4293-b5ea-bc58d8289e81'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'395f50ae-f632-4601-867c-c76f1e57d2f9'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@09 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'3985ee0d-0ac1-436c-a94d-588a9cc1ed13'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@18 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'39962025-275a-4a1b-889e-fc56a7e73ec8'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'3996963d-ad36-44ef-ab61-fafe1db86f95'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'39b1349e-7bb5-4fca-8e3c-987fe97059c7'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'39b83afd-d25e-4423-81b5-38447dc756e0'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'39bd5148-c581-4434-9698-1edfbb4bf215'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'39c4f586-597e-46e1-bece-5acc5e3d44a2'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AZ C2 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'39d7c8f8-bbc1-471c-aa49-0347535f532a'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'39e4e9f2-4b8c-4fa8-8032-d21bdc943f64'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'39fbefa4-8974-4a75-8131-3cf0da3236c0'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@10 C2 D4 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'39fe817f-8771-4b90-b95f-3db5af0de720'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'3a008efd-75e2-40fa-a0da-9555393c3299'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@18 C2 D4 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'3a0b8f0f-08af-4650-8758-5a04321babd8'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'3a14197f-0741-41e9-a2d6-f59d600dbd57'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'3a15ec67-42de-4aec-9bc1-a0c901bb980f'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'3a19e9ce-ba0f-4c00-b340-05833fbb7e10'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 D4 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'3a30606a-33a2-46e3-a511-d1429c4b9b65'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'3a655f1a-15b2-4a30-88a7-26fe763860bf'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'3a6da786-07cf-42d7-8e47-fdd79a32c224'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AY D4 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'3a72c686-ac0d-4be2-99a0-9aa1aa2fca94'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'3a7f63da-9095-46d0-9811-f8884f0ad0d2'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 C2 D4 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'3a9965d2-d6e4-4e3b-b998-3f0a2f3d374c'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'3a9c4936-4c8b-43c3-a216-e4776e51ca13'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'3aa74b6f-2324-4598-ba6b-e6fa96f118bc'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@B7 B2 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'3ac19c66-15df-4efb-8526-b3d276a70ad9'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'3afc5dc6-47d1-43f6-b4eb-045c381e0334'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 C2 D4 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'3aff0278-a75e-481d-8c87-d8cbb586f053'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'3b01d3e0-c69a-474c-8f2d-8beedd1b8832'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'3b05248d-c73b-4700-b35e-ba4590bf36c3'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'3b20eb7c-b810-480a-8009-6380d1cfe506'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AZ C2 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'3b3806a2-e974-48ae-8f5b-c4db34b230c5'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'3b5488f4-f037-45e5-8561-66e85354efb5'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'3b71e033-71c2-4658-8e50-efd8a6ca1ddf'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AY B2 C2 D4 E4', LastUpdateDate='20091109 15:02:22.570' WHERE BloodProductGuid=N'3b738bdd-f9bb-4743-a81d-2269eb5936ce'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 C2 D4 H3 N2', MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'3b73ea4f-caea-411a-bf1f-1e4b30618dd5'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'3b8effc7-3631-4863-bb7d-14180c84e29b'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'3b910da2-85f1-42ba-a184-4fde336d7800'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'3baab6d8-f846-4268-a758-9aea14d30d7f'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'3bb2b4f1-4ff3-4c78-a8a9-9464719228eb'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@84 C2 I2 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'3bbb03fd-4621-4bbf-ba1c-312836d74025'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'3bec6317-1aa3-48e9-824a-0c3c6b5ee681'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'3bee4b90-acc4-460b-9378-cf9d0f55b1d8'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'3bf00516-3514-4541-b31a-200afe4f28f0'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AY D4 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'3bf3bf07-4d65-465a-bf2a-f93b3d4e821d'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@84 I2 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'3c014544-efe6-44c3-9d57-951b49903b78'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'3c07350c-8773-4ed4-8664-1995677ded5e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'3c0cec08-697a-4631-8abc-3d01aa55ee74'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'3c326cea-b961-401a-917e-c5dcdafa09a2'
UPDATE dbo.BloodProduct SET MaximumStorageTime=624, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'3c3a1a41-d97e-4683-8705-9b027ec88a5c'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'3c42dc86-915c-4a39-aeef-473d8c038fe6'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'3c52fcf4-a559-4618-bad6-20ae230dfc79'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'3c645895-f94b-43e5-9d61-d6a60783f97e'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@07 C2 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'3c754938-3035-4126-89b4-8ef660295f75'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'3c812610-48ee-482f-b9c3-4be535dc92a5'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'3c87563b-07ce-49a3-ba26-78266510d001'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@10 C2 D4 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'3ca23cfa-f6e9-4d7b-9a4d-0446ac0599c2'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'3ca31adf-080b-4f8a-97de-2b9594263df6'
UPDATE dbo.BloodProduct SET MaximumStorageTime=1008, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'3cc467c9-59fe-49c3-9cf9-d6f762d5a85d'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'3d11d61d-2340-4216-9fc5-005717f2418a'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'3d183c31-6e4a-4312-9db6-108fe33c5de3'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'3d2ae287-986d-4f2c-bcb8-98b8ffeb9f7c'
UPDATE dbo.BloodProduct SET MaximumStorageTime=840, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'3d31de04-e922-4ccf-81e4-77fe5b334898'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'3d39bc60-6766-4dbf-b4a5-fa36b888dd5f'
UPDATE dbo.BloodProduct SET ProductShortName=N'PLT Pool Froz DMSO BUFCT ', MaximumStorageTime=87600, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'3d50614f-3f9d-4536-a0cb-f0b64fe539fd'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'3d703efc-18e2-484b-b580-e118465d9c34'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 D4 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'3d8e65da-64b2-4ddb-a73f-964d9b1d8444'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'3d8f9df8-dd8a-43b6-bd21-181cbc5390c1'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'3da147b5-8957-4b92-af41-98084084382e'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'3da523cd-69f8-485e-9fdf-b56fda490eeb'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'3dec1afd-7f29-4b21-80f8-2a692b8f7987'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'3df4b734-c97a-4234-8242-46fa596e9dd8'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@11 C2 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'3e208512-7043-4b7c-8ba1-69190096a267'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'3e2d54dd-0f29-4e23-a7a6-733925a20879'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@22 C2 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'3e3d2516-0a6d-405c-9f58-8a4c465af6fd'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'3e49a2f2-c04f-4871-a87a-408b6a8d5b86'
UPDATE dbo.BloodProduct SET MaximumStorageTime=1008, RetireDate='20080301 00:00:00.000', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'3e5447ed-96f1-43e4-a6bd-bb58d47e203e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'3e57428d-e789-41c9-8990-8efca23bae51'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AZ C2 D4 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'3e79b399-4a78-45b5-8a2a-384486e1bad6'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'3e7f25a1-139d-4795-83c6-a86b89a2e9a1'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'3e853e92-9dec-41cf-a29e-03a189fbab06'
UPDATE dbo.BloodProduct SET MaximumStorageTime=672, RetireDate='20080301 00:00:00.000', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'3e95ffa2-ef67-43bd-96c3-d49f00e4e1da'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@10 C2 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'3e9efd52-315a-47ab-af64-3abd91436f0a'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'3eb5a15f-26ba-44e7-8cc5-5054f2009257'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'3ebc6bf0-db71-4eee-af61-c6953859c3f7'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 C2 D4 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'3edd6947-fda6-4c4d-95ca-02d3233bc595'
UPDATE dbo.BloodProduct SET ProductShortName=N'RBC Deg None', ProductAttributeForm=N'@AS H4', LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'3ede4435-ce16-4363-ac87-5d138e46512a'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'3edf6a37-5778-40c9-ab52-e04f8bff34b1'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'3eeb70ff-85c7-402c-9f4a-3c3ab27f0f15'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'3f1b15e7-b809-4860-8715-962eefaaa41a'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AZ D4 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'3f3ce607-4410-49f8-a7ec-ad5443c5bc11'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@09 C2 D4 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'3f4ab255-2a1f-4b08-841e-ddddcc980e31'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@20 D4 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'3f5cd9e2-3584-42b4-98e1-6171d408a074'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@10 C2 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'3f84e459-5adc-4610-bea2-6c910534d808'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'3f944d58-2202-45d8-88ad-d0527cf08b7d'
UPDATE dbo.BloodProduct SET ProductShortName=N'FFP AFR None', ProductAttributeForm=N'@84 H5', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'3f9881ec-dc14-452a-a447-77e0682df6e2'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'3fa08980-1faf-491e-9cd7-fc5d33bea369'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@33 D4 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'3fac34bd-b215-4d5d-b93f-821685ffb078'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'3fac80b4-2816-4b95-844e-811494b8c92e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'3fb2121b-7d19-484e-9521-49b50bf0739a'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'3fd75a2d-08ee-40fd-9831-912f11ffcb9b'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'3ffb0a1b-f382-4a82-9ab6-1f2e789e21c3'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'3ffe8d6e-0879-4242-8c34-5b4befdc53fa'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'401a17e6-b346-452c-b2d6-a3a7c9a28c09'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'402cfba2-0516-464f-88ac-be2e72047e53'
UPDATE dbo.BloodProduct SET ProductShortName=N'FFP AFR Thaw None IRD LUKOPR', ProductAttributeForm=N'@AS C2 D2 HB', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'402e54d6-d110-408a-b84c-2b9834e11012'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'40301dd3-2858-4005-b3ba-17614552107f'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'403c9ec1-f0d1-4c52-b3f7-12ba1565b8dd'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@07 C2 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'404050f7-b7cb-46f2-ae92-00a9727ed76c'
UPDATE dbo.BloodProduct SET MaximumStorageTime=624, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'40532472-3cd5-4e12-89af-53e27014a296'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'4054a915-7151-431f-aecb-ab304b163d30'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'406ef830-0fd9-4f8f-ba01-5345ac1b253b'
UPDATE dbo.BloodProduct SET ProductVolume=450, MaximumStorageTime=61320, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'40815711-9857-4779-a88c-3fd1742ce619'
UPDATE dbo.BloodProduct SET ProductVolume=50, MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'40819107-5617-4932-ab44-59b6eb1b6507'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'40a045ef-11e8-45fd-9b0a-06c7fdb58f2d'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'40b0937a-557c-4115-99cb-61702159e816'
UPDATE dbo.BloodProduct SET ProductShortName=N'FFP AFR Thaw None LUKOPR', ProductAttributeForm=N'@AS D4 H5', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'40e2bceb-be3f-40ee-96a0-b79bc2dc0cd3'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'40eced93-e586-4887-b57e-6f2a291020dc'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'4108f7ed-af4c-412f-afaf-c78f77943dba'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'411128a1-1f7a-48dc-a426-eb35de30931b'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'4127fba0-5abd-41ec-bd89-9c903a3aed4c'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'41285d4e-7c14-40ee-b242-e97a1f989293'
UPDATE dbo.BloodProduct SET MaximumStorageTime=4, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'4134b81b-d5df-4886-bb64-a218c663a79a'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'41357784-4be4-4f79-b4d7-3d8528f23c0b'
UPDATE dbo.BloodProduct SET MaximumStorageTime=1008, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'413c8514-fa95-4455-94b6-e240aab546fe'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'414a7e92-430c-4aaf-a5e0-f3e036dec2ee'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@03 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'415c75b6-fdd9-4caf-928b-ac0d1ac1adc3'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@09 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'4163a367-7abb-427b-9d55-56fbabec9cbf'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'417cf047-87c2-4c02-a6cf-0ef0b1648327'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'418485ab-9ff9-487c-9469-8ffb15b54abb'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'4187b787-7881-4f32-8b5f-35255a09a7db'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'41a55963-5aa5-4dc0-924b-fef97e8711ed'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'41afc28f-1a9b-4ed6-90ee-255fb695492e'
UPDATE dbo.BloodProduct SET MaximumStorageTime=1008, RetireDate='20080301 00:00:00.000', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'41b77610-bf6a-4294-a457-cc5a59d10c16'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'41b968d2-b0cc-4193-a09f-adafd9507bfc'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@03 D4 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'41cfda4f-fe14-4961-9e95-73aeefb424d8'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'41d57687-dded-41bc-933f-ee257ac0f989'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'41e33aeb-d1e4-4c6f-9f58-376c95f10966'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'41ed1fde-15cd-4e3c-9c4d-30b6c34cadb3'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 D4 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'41fcd77d-ea65-4313-8cb0-7644dacdb858'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@07 H4', LastUpdateDate='20100210 13:55:15.970', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'41ff3394-1266-4bb0-86e3-be0edaf18a50'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AZ D4 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'42370899-2998-4745-9ac9-fbead67b4d2b'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'424eae06-18b5-4851-923e-c8b0474482a1'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'42549e7b-1ec9-48fa-873d-c40eae7f0ebb'
UPDATE dbo.BloodProduct SET ProductVolume=50, MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'42577b5e-3c93-4e92-883d-4b97cfb1fb89'
UPDATE dbo.BloodProduct SET ProductName=N'FRESH FROZEN PLASMA|CPDA-1/450mL/<=-18 C|Irradiated|ResLeu:<1log6', LastUpdateDate='20091109 15:02:22.600' WHERE BloodProductGuid=N'426a103c-8e10-49ad-a1cc-3675c77bc3cc'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@10 C2 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'42737b8e-07c0-4c5e-a822-8e4f1637d5a0'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'4282bfba-de31-4240-9210-b7c6838393fb'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'4296af12-7915-4a08-93b5-03d48f57d791'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@84 C2 D2 HC', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'4299de09-4d45-4718-9da7-6b31dc8e101b'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'42a8d362-8fa3-466a-b808-4e480bc0e309'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'42ad3044-8e8b-4944-847d-a685b0d249c1'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@03 C2 D4 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'42c056b2-b28a-484d-b70b-c6b029119d6e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'42e4c7ee-f86b-41e3-b9fd-e40185b55739'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'42f53b8c-5df7-4450-8177-5d52a95e5d10'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'4317fe01-af0d-4b8b-88d9-c702ab17e9cb'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'431bbd61-cf7c-44c2-beff-81595cb7d148'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@30 C2 H4', ProductVolume=450, MaximumStorageTime=61320, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'4327948c-7ede-48b3-9e5f-9c9cb7d07d91'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@B7 B2 D4 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'432f6de5-c4ea-4f39-81a8-26259afe5257'
UPDATE dbo.BloodProduct SET ProductVolume=50, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'4345dc19-99c1-4c96-b997-40a43fd1ed54'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'4356242d-86bf-4930-8858-d7b56b5e212b'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'436779e0-5f74-41be-9d00-50ea8a5cc5bb'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'436c3da3-9f68-4e60-b6b7-a7fc63caedc7'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'439762aa-133e-46a0-9fa5-39e13a5d40e6'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'439d2e02-1626-464c-8a28-9a88d8248efe'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'43c7d099-4427-4e2f-ae18-0e8da78575c3'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'43e3728b-f86e-4da0-9eeb-8aede3c0c594'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@18 C2 D4 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'43f0c3c6-c190-498e-b3be-ae72635e50c5'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'43fe8568-c2f9-45cb-b243-5876f9db4807'
UPDATE dbo.BloodProduct SET ProductVolume=50, MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'44095c21-6f2b-4797-b2c4-8a57622ae2b8'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'4414a97e-9cde-47b3-8943-4b868fdb66cb'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'4437bd11-d322-4b05-b8c3-da72c504b6b8'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 D4 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'4447bb8d-cd4d-496e-9517-45eafa057b81'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'44516a3c-6f0b-449a-be0b-394eca59f154'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'44549de0-6f50-4449-a81a-484977906277'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@84 C2 I2 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'4495d2d0-7432-4cdf-ad67-fcf4bd2777f3'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@07 C2 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'44b2f3f6-1379-4797-badd-065873b7118b'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'44bdba38-7c5f-4149-a74d-462b6a17ce2c'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'44f39195-b4f1-4a8f-ba16-01390a61e42b'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'450f7c05-1d88-4eda-9982-d8cc9401e4d4'
UPDATE dbo.BloodProduct SET MaximumStorageTime=1008, RetireDate='20080301 00:00:00.000', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'451a00fe-7ad6-4a27-8d07-4628a2d44136'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 C2 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'451f2e23-c5d1-4d56-8199-476c7d502442'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'4561e0f1-1106-45cd-a6bd-0d30c239e816'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'456a36fa-be34-4eeb-bcc6-9448313d770c'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@03 C2 D4 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'456ab147-1a68-403e-bcd7-ecc8f7763df4'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'457ce649-b6d3-424d-aac0-4fafef37c4b2'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'457d67fc-3204-4f1c-a842-9bbde0aa2536'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'4582a2d6-a073-4dc2-aa28-b0557b4399f3'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'4583965f-2763-4941-b36a-18072c56ef13'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@84 C2 H5', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'45986b58-4056-4b98-aa84-98da00a7f643'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'459cb6fa-349b-46f6-91d5-0a6115123f02'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'45bc2066-51a3-4492-8736-bd14907df0c8'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'45ca564f-98bd-4b30-993b-415d4abf5082'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'45d643f8-ec29-4ecf-8eb3-0e5241f9fecb'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@07 C2 D4 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'45ec02cb-5a20-4522-997a-6a7cdc58b02f'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'4607291b-4d63-435d-a3d5-f89b25552643'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'460dff6a-bc84-47c8-bec3-9d193bc33941'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@30 H9', MaximumStorageTime=61320, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'46112c71-a3a1-481a-a7fb-7f772d7554a7'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 D4 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'461f32cf-2327-4abe-b2ff-f01d7c63117d'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'462fe04e-f9b7-4e5d-b6c5-de7671d5fffa'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'4638f8bc-5694-4ee6-8eae-67145a065b7a'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'463e5fc5-e4a6-44bc-9653-820121a85ca7'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'464b189a-a928-4895-952b-33b1c6c9b0a0'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'465263ba-86ce-4fde-8223-66846b5bb2bf'
UPDATE dbo.BloodProduct SET MaximumStorageTime=61320, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'4659340a-9743-413f-817b-a45358e649d8'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@18 D4 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'467efe86-4459-4457-8c64-0e9ab9be7bec'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@84 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'4688ff8b-1b2f-4082-8210-311d2a577e42'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'46980d02-02f3-48e7-89cf-12594850ba51'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@07 D4 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'46a146f3-98ae-4462-af3d-25a4921b85ab'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'46a94c0b-fb3a-411d-bbe3-54603098f524'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@10 D4 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'46bc01c6-5c9e-4cb2-b90b-4c1ff5eda4ed'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'46beff0d-9af2-49fb-bcbf-3dd56594e10f'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'46d40072-8b6b-46fd-b53e-426ab055e8db'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'46d6fd0a-7fbc-4983-9f99-7fdbb3b9565f'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AZ C2 D4 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'46e96e03-9e4b-4f7c-a733-0f034230c6a4'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@20 D4 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'4706e09d-4422-4bd2-9380-5800ae3bdc7e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'471139e8-6c08-4f7d-a053-f9b5a53ce529'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 D4 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'471c351d-e99e-42e1-8e42-31e9f1954020'
UPDATE dbo.BloodProduct SET ProductShortName=N'FFP AFR Thaw None IRD LUKOPR', ProductAttributeForm=N'@AS C2 D2 H4', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'475694f1-c0a6-475d-9801-3e2e4473b362'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'478cd783-aa91-49c3-a07e-67ad4269d3e7'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'478d7db8-f205-4fab-acf3-94c7a8cc0aba'
UPDATE dbo.BloodProduct SET MaximumStorageTime=624, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'479becdd-248a-4d9d-88a9-e62a4688ac55'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'47a37d36-63a2-40b7-aa55-ea8d7b75c90e'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'47c40413-9d46-4892-b469-693e697b1cdb'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'47d0593b-cf72-4c31-a96a-0275d808134c'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'47d6d1ae-664a-4c2a-8fac-516e0f08ab4f'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@03 C2 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'47d9b89f-bb33-44bd-ac57-69599874599e'
UPDATE dbo.BloodProduct SET MaximumStorageTime=624, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'47e06159-a73e-4c66-a98d-7cc1180d0f57'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'47e4d46c-522f-451f-bfff-aef02629281b'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 C2 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'4800f16d-cdd9-449b-991b-4a814b2ab80a'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'48110eaf-6267-46c7-a91c-b2d2c26ee3c2'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@B7 B2 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'482a5f3b-055f-4efc-a76a-6661bcf95988'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'483d77d5-1765-4dae-be3f-0f2aafe7495e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'4886dadc-d438-41aa-9e90-c9e433a7d06d'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'48be3170-83c6-4caa-bcc6-7a17a57ba722'
UPDATE dbo.BloodProduct SET ProductShortName=N'RBC Deg None LUKOPR', ProductAttributeForm=N'@AS D4 HC', LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'48ce2daa-1cd8-4395-9e13-e1f1f4fbe386'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@07 H5', LastUpdateDate='20100210 13:55:15.970', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'4911163e-5062-416b-be22-7a435a0db49a'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'49151a2d-3676-4d33-8081-18506e6b3e3b'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'496bf7f3-df40-4eee-ab1c-7e2161e27582'
UPDATE dbo.BloodProduct SET ProductShortName=N'PLASMA CP2D MNFI ', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'497fe249-f9f6-422f-89b7-cdcb66d3772e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'49a703bd-d3db-4264-a0aa-c1874ff54d0d'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'49ac7763-975e-4ab3-bbe0-7bc173f0cde5'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'49b43135-1c11-4351-8843-3ae6d5965193'
UPDATE dbo.BloodProduct SET MaximumStorageTime=1008, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'49e1ffe1-7dfd-46da-a782-8deb9c724df3'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'4a0d6dcc-39dd-4983-b72d-cb7f4adbe2df'
UPDATE dbo.BloodProduct SET RetireDate='20080901 00:00:00.000', LastUpdateDate='20091109 15:02:22.850' WHERE BloodProductGuid=N'4a2ac25b-4a34-4aa9-b083-41ab600f58f4'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'4a477929-0d66-4df8-aa55-696f95c17c3a'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@11 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'4a497c6c-7b8a-4870-9aec-46c21c9dc8f5'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'4a5b9f3f-60c2-4189-97c7-7f78d0d1c55e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'4a8e3a48-ffc7-412d-96c4-87595f283ba5'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'4aaf25e0-429b-4a08-9bd2-8751f0bc84b6'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'4ac4ccf2-6063-423b-80a1-613440b25fd1'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'4acd6f8c-7989-4a8c-84e4-887a8d7333c6'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@03 D4 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'4ad8e61e-3ee0-4fe5-9bd8-fa2951805a48'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'4aed736d-272f-4e8b-8727-7ea994f6e851'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@54 D4 H4', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'4af44482-ce0a-49d0-9d44-0b92e740c3cf'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 C2 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'4af80350-ff93-4349-8924-98d8d4dfb0af'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 D4 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'4afa5faf-80e2-4ec4-ad1e-a1ce2c0fb867'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AZ C2 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'4b03c7ac-15eb-4215-bad3-a08b7b6e4380'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@11 D4 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'4b200c27-a012-4d4e-aaea-69e8aff7b288'
UPDATE dbo.BloodProduct SET ProductShortName=N'PLT Pool PASII BUFCT', ProductAttributeForm=N'@AE G2', LastUpdateDate='20091109 15:02:22.663' WHERE BloodProductGuid=N'4b333983-0ac5-489b-b962-e1772ddd6b86'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@20 C2 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'4b3e0435-aea6-40ef-a140-d022db99d903'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'4b4484be-3e51-4d59-836f-b0dbd028ca27'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@B7 B2 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'4b62d36f-c1c1-4513-b543-2f8488bb38dd'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'4b6bcd04-0a4a-48c3-ad9c-605548ecc7b1'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'4b820582-5979-4757-9b03-584387d7b2b2'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@84 C2 I2 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'4b835cc7-dad0-4696-875f-8818af6e3397'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'4b883bdc-3827-4f26-8954-3970b155d9cf'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'4b977498-f8c1-483d-be37-855a671fd1e2'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'4b98ad24-268a-4e4c-aa14-e774d3bb6c42'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'4b991fe0-5647-47d1-ae50-4bf5c596664a'
UPDATE dbo.BloodProduct SET MaximumStorageTime=624, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'4bb4e660-80ee-4be6-b65e-155f2a4410cd'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@33 C2 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'4bb9cbe1-9ed6-4663-839e-4a48868b11dd'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'4bc990f3-0738-4207-9dea-bb677ec20dd2'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@10 D4 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'4bd8c53f-3826-44ec-b921-84876810f432'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@22 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'4becdd7b-6961-400a-82c4-5437c8689224'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'4c026fd8-93f6-45e2-bf4d-1efb62472aa6'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 C2 D4 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'4c140c09-11a8-4342-b51e-54e4882badea'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'4c174702-8043-4822-bfa7-f0ea78b7e785'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'4c192ac6-f21e-45e4-b81f-062baeead28f'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'4c332f18-9aee-455a-ba45-5ebe4aa1932b'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'4c354ad5-09bd-48b0-864a-6273b7ef3db3'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'4c56cd1c-0c4f-434b-8b4c-b306db578dfe'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'4c5eb64d-99f7-4a46-b18f-b6ec026f6f3c'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'4c62108d-b311-4f04-9e05-733cf8f52976'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@B7 B2 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'4c6a4600-7016-4671-af54-6cdf85d10fde'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'4c6d4502-f1f4-4d6e-a318-f10d6c6d5006'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'4c89b253-3db4-441d-9211-c673297ae8f2'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'4ca0eb53-30d4-46ee-873a-4de3876f19c8'
UPDATE dbo.BloodProduct SET ProductVolume=50, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'4ca0f6bb-ab5e-4061-9452-e0cc41d330b9'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'4cb497c4-9ded-42e2-8f54-5092b7f11cb1'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 C2 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'4cb4f9b3-72e9-44eb-90df-bb5cfe8100d2'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'4cbc5013-f0bd-48f1-85d9-a8cffcbb7c03'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 C2 D4 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'4cc35711-60f7-47d3-9163-2aa936174414'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'4cd1594f-c1cb-4a21-8c39-32102ad052f3'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 C2 D4 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'4ce1ad4d-4e4a-490a-af98-0269e1c6131a'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'4cfe9a37-ef7c-49a2-9e28-27a8edf17c1c'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'4d250cc5-267c-4e25-a16a-ebacb9db102f'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AY C2 D4 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'4d3cdec0-932d-4214-8583-aae95a45fb31'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'4d503c75-86e8-4c68-8226-f36638c2058b'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'4d53a334-667b-475c-a334-c9c961ed9edb'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@33 C2 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'4d6e806d-b258-4a9a-a8a0-a1e255b49272'
UPDATE dbo.BloodProduct SET MaximumStorageTime=840, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'4d72e117-f1a5-446e-b80f-ae280467a168'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AY H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'4d778b20-3d0f-4050-ac41-f71b01e70baf'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@B7 B2 D4 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'4d815085-aca9-487d-8da4-cde42569ae3b'
UPDATE dbo.BloodProduct SET MaximumStorageTime=624, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'4d8b3cc6-0383-48a1-8a47-a8dcad7c773a'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'4db99aed-5555-42bf-a595-485ebf6c1b1e'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AY C2 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'4ddbd331-1293-4f1d-8197-5ad5cd172031'
UPDATE dbo.BloodProduct SET MaximumStorageTime=624, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'4de9733d-cdb6-47a0-906c-793f95d8b1d0'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'4df436c6-1484-4765-b5b1-0cd578aece94'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@18 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'4df77b98-88aa-4ddf-87d1-105af6b9e0e9'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@10 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'4e0da6d2-5601-40ae-b72e-bcb67f87fb21'
UPDATE dbo.BloodProduct SET ProductVolume=50, MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'4e446ac8-5b57-45d4-bb2d-630ad39ecbfe'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'4e4beef6-3882-4275-94db-50519ab737ea'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@33 C2 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'4e4d817a-3f51-4290-af0a-4d1ce7aeee48'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@84 I2 HC', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'4e588d2b-9564-44a8-9aea-4338600f4040'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'4e614a0d-a045-4676-9037-9b05f295a889'
UPDATE dbo.BloodProduct SET ProductVolume=50, MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'4e7970cb-d863-4b4f-9acc-9bec76ef1ee3'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@20 D4 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'4e7991b0-bbad-4a50-9559-aece0da04a9c'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@33 C2 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'4e96ad9a-56d4-428f-b99a-13af50850ad6'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@33 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'4eba6620-b15f-4ad9-af0f-7343f207672f'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'4ebf8b74-b207-44b5-b03c-96d6115dd084'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@20 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'4ecbb442-ea47-4b75-a027-6be6d826bcbe'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'4edf00bd-8267-4ab1-ba6b-ab983649d249'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@20 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'4edf38e6-9911-4ded-8498-fa68c764b18b'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'4ef86afc-4c8d-4f9b-840d-c839fc319152'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'4efee2bf-52e9-4cbd-baf8-f6666ede326f'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@11 D4 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'4f07b2e7-a570-4a5b-a8ac-425e5686cf0e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'4f0cadb6-b070-4192-8fbe-29f6f0887c3f'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'4f0cfcfb-fbc0-41de-9156-bd403385c39b'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'4f1a32f0-b76d-4636-9a5f-7cafd8bdb4aa'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'4f1f5d42-65ea-4427-b409-6605e7f7f401'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@11 D4 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'4f4cfd52-f4ed-4d15-9f17-fdf88bba6ae1'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'4f512fe7-f423-460b-a2c4-4a532fb93f2b'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'4f514ea7-9325-44a9-8076-a7ca9fc045d5'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'4f5e011f-ba52-4aaf-9e70-f9973686fd30'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'4f67d392-2962-45af-a4ad-24c6331c41a7'
UPDATE dbo.BloodProduct SET ProductShortName=N'FFP AFR Thaw None IRD LUKOPR', ProductAttributeForm=N'@AS C2 D2 HA', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'4f7f276b-65a6-4614-ac13-2bac4c8ea5f5'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'4f856957-578d-4a9b-9dc0-8c439d7044b4'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'4fb7e2b2-49e3-414b-b4d8-6ba14d029635'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'4fcbcd10-9811-48ae-9685-726c78542128'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'4fd22a2d-9df4-4bc6-a9dc-e19a95b34e71'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 D4 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'4fd3ddea-423c-4049-af92-44b68f437d1e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'4fda635f-eddc-4415-878f-7d19df846388'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'4fe0416f-30b1-49fa-a9ff-a0272f7448d6'
UPDATE dbo.BloodProduct SET MaximumStorageTime=1008, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'4ff36c51-91ad-4556-913f-8a99df3fc2d0'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'4ffe5ba0-9c14-4dad-81a8-9157e2f2ea44'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AZ C2 D4 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'5008556e-91e5-48ab-8662-d018fa85bd62'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 C2 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'502ae0dc-277f-4c0c-b741-eac3c6c4769c'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'503347ee-51ae-4b02-9dac-6840ea33edf5'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@B7 B2 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'503772ce-963e-4b6b-b315-a5fadf7e4613'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'504988fe-2ed9-4a3f-90b1-d5c3c110497a'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@30 I2 HA', ProductVolume=450, MaximumStorageTime=61320, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'504f9c4d-ae38-4030-916e-156016ab5a93'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'50548ece-396e-4a1e-beec-28c7f0f7d180'
UPDATE dbo.BloodProduct SET ProductName=N'PLASMA|CPDA-1/450mL/<=-18 C', LastUpdateDate='20091109 15:02:22.617' WHERE BloodProductGuid=N'5074833c-6cf8-4800-8050-a87de320979d'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'507c50b7-f513-4ce3-84ca-d074f924d2d8'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@B7 B2 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'507cbc05-6a50-4cde-b8a5-0a352ea4c523'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'508bb37b-8e36-4af4-aae0-f58407f76182'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@11 D4 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'50f12786-8c7f-4385-861e-c55fd56e1eaf'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'50f39e24-2da1-4b53-beb0-b2937b6c8563'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'51245be0-d1bf-4cfb-baa7-f46b788051f6'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'51307382-8880-4505-9882-398bb961bdb6'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'514a9616-db2a-4048-a05d-44e0cc5a0496'
UPDATE dbo.BloodProduct SET MaximumStorageTime=1008, RetireDate='20080301 00:00:00.000', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'5150eece-8f41-496c-893c-5037560f173b'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'51576c28-1c5b-4cd9-a0ca-05321922ad1b'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@09 D4 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'5157a8fb-a6fc-4c43-92d9-91e56d37e744'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'5159e325-fcd2-442e-9ae9-46bd8f4119d9'
UPDATE dbo.BloodProduct SET ProductShortName=N'FFP AFR Thaw None IRD LUKOPR', ProductAttributeForm=N'@AS C2 D2 HC', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'515eda3b-78bb-4a6c-98c1-0ae2069f0d1b'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'516eb5de-e885-44ae-92e4-22d9b7ca4b84'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'51a58867-8a0b-454c-a0e9-44994f06f94f'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@07 C2 D4 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'51aa6207-f1cd-493b-839a-d65254d949e8'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 C2 D4 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'51b971e3-a492-45da-99d0-b075cbd806d3'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'51c6be48-eb73-4e3c-82df-5d06122f7559'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'51c83ccf-ad59-4c94-a616-fd3c4c032e4d'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@22 C2 D4 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'51e4d226-b61a-4208-9c9b-3ad6eb896e31'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@B7 B2 C2 D4 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'520ca0a9-4097-459c-a2f9-9d808ca8a300'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 C2 D4 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'52572b43-1039-4e93-b123-dd2fefbdabfb'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'5259610e-b12f-496e-afe3-b64197117319'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'52786332-5eb6-4a3d-8813-4a718a1f8dff'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'528d87d7-d109-4bc1-a45d-34c71ad9bd09'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'528f22f7-995d-454e-ba60-42d842581278'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'52b71650-fc98-4d3f-b8e7-1008eff40988'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'52c26247-f433-411a-bb1d-f17b56e3eb2f'
UPDATE dbo.BloodProduct SET ProductShortName=N'FFP AFR Thaw None LUKOPR', ProductAttributeForm=N'@AS D4 H6', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'52c9e9b3-c7ff-4dae-8806-41a9e72d69d6'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'52cef603-d3d6-424e-b57d-d951ca83bf66'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'52ec8622-7271-46d5-9967-01d6732ea52c'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@84 C2 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'52fe2aac-d9dc-42f6-ba90-bebc232e8ef3'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AY C2 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'532b6051-5209-491f-b148-3287802eeb27'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'5332a014-c81e-45eb-a1e4-7fa35d2c9359'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'534c0bfd-3d69-447d-95b3-55ede3a2e4f4'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 D4 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'535a1af3-6795-42de-a379-5a1dc6ceb170'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'535ab155-e2ac-4736-ad65-3660b599234d'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'537aa016-e77a-456f-ba65-9b2d90bb8319'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'5389278b-1105-45ce-bb0c-2f0df1aed236'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'53b732df-a1bd-409c-8f70-87814851b168'
UPDATE dbo.BloodProduct SET ProductName=N'Washed Apheresis PLATELETS|None/XX/20-24C|Open|ResLeu:<1log6', LastUpdateDate='20091109 15:02:22.743' WHERE BloodProductGuid=N'53b92072-0290-469b-93e8-f67a872081f8'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@20 D4 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'53c0b4f2-3b2c-4180-b414-dbf832a53124'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'53c6d384-c7ce-437f-addb-c8e0ec9baab1'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@84 I2 H9', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'53ce0a4e-49f0-441b-b486-b02e438ad2a0'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'53d6d1e6-fc1e-4e17-aa43-d12e7f991281'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@22 C2 D4 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'53e0b737-f03d-4b9c-964d-38467057b569'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'53ff38d9-969f-43f6-9e8d-48df7c609b8d'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@09 C2 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'54075713-4466-4607-bc16-0b34a5d31b0b'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'54102f07-bcf4-40d9-bfea-21fbfa4ce33d'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'541a5793-8fb0-4836-9ab4-984c8ebea224'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@11 C2 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'5429b2ac-1c89-4fb3-aa98-a41e5296fc8f'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'544cba9e-d136-4fa6-81a8-2f46081c46e7'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@B7 B2 D4 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'545bc98d-d8fa-4d8b-b3ff-f6de1dfa5132'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'546b7617-2038-47f5-882f-e26fb9db98a9'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'5471878c-1275-4643-9109-2547b512e7fc'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'5473e61b-7b8f-4acc-90cc-77cac2508f7a'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@10 C2 D4 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'54792a62-9773-4317-82cd-5124a7ef1f6f'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 D4 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'5481eae5-8ee5-454f-877b-8a632b455a2e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'54a02163-73d9-4a8e-8b41-955f40dadc66'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'54d7a051-0cac-4f01-9308-84f05051700f'
UPDATE dbo.BloodProduct SET MaximumStorageTime=4, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'54dd8741-54fd-47cf-b77b-cc8c2c4a6b14'
UPDATE dbo.BloodProduct SET MaximumStorageTime=4, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'54f57f0c-3925-4365-ab28-83cd92c35ea3'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@09 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'550a5fd1-436b-4606-a479-c06e6b724b68'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'5512895e-a9ae-4d38-8120-cce553d5d91d'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 D4 HB N2', MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'551c1144-fa9b-482e-9210-b8c532673f5a'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@10 C2 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'552a1be4-c375-432c-84ae-f75c8e58fdd4'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'555c9685-f73d-48d9-be7b-628f6cda4570'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'555d6e09-f74e-4085-b83b-86f5c915714e'
UPDATE dbo.BloodProduct SET MaximumStorageTime=672, RetireDate='20080301 00:00:00.000', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'557c69ca-10be-46e1-a331-fa130763d96d'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'55826e89-b3f4-4ea8-a614-b00aeb034981'
UPDATE dbo.BloodProduct SET ProductVolume=450, MaximumStorageTime=61320, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'55896b79-c984-4013-ae43-675c0052f68b'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'558ac514-a74d-4c39-9dea-5c66c680b41e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'5593c188-6515-445e-a48e-1624e035f596'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'5594c550-e72a-4943-9399-edd87a4810c3'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'559657e3-155e-4d50-91aa-43c4013aea74'
UPDATE dbo.BloodProduct SET MaximumStorageTime=1008, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'55d0d421-8295-40f1-90c7-5cff402cd7de'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'55e12681-1108-4796-a43f-26f68a8dd88b'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@20 C2 D4 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'55ef4ee7-dd39-4019-94aa-74ac9ef385c8'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@30 C2 D2 HA', ProductVolume=450, MaximumStorageTime=61320, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'55fbdb82-88ee-4855-bf44-270d06ca8766'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@20 C2 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'56001b6a-8575-4f59-a046-42652668db88'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'560873a4-937b-4694-ba67-20831edbd2e7'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'560dd184-0010-4189-aa07-253478c7840c'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'56161580-fe11-4081-be8d-51b82a246444'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'561fcab9-074d-43f2-930d-7176c557a57a'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'56479fac-59d4-4200-b1f9-eedebf5c8b64'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'565cd2d1-a2ac-4d31-916a-1c4015573b2c'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@11 C2 D4 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'567aee49-b127-4e2e-a635-45c545c09daa'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'567b34d0-fabe-43fb-a9f2-f7cd352966e5'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 C2 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'56c77213-da62-4beb-b149-47f985df6978'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'56d83e45-230b-4d6b-85f7-f452808ce7ad'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'56d84a25-e497-43cb-ad57-04fcf629b636'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'57233239-f820-4d2a-b1fc-9485f3019e11'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'57280ed4-feb2-4c01-a713-304d28229162'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'57327824-abd7-4137-aed9-770e16068951'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'57451d50-9b1d-4cd1-b47e-7a9d599e7115'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@B7 B2 D4 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'575c0025-fd08-4499-9077-6866a37f3374'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'575dbf9a-e775-44eb-99f0-62f83f06d8dc'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@B7 B2 D4 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'57643325-53ed-4cb3-af45-7a0202e238ad'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'5767d786-1231-4971-9342-60e3bbd0f82b'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'5768cd62-997c-4e00-92d1-60715d0f20be'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'5769e438-8fa0-436e-bed2-ede658d633ab'
UPDATE dbo.BloodProduct SET ProductVolume=450, MaximumStorageTime=61320, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'57b78cc0-0cb6-481f-aeb4-7dd6b09bb637'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'57bb5731-e9eb-4ba2-a013-2005286ebb70'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'57d8f341-b352-464e-8cc7-b49c03298d00'
UPDATE dbo.BloodProduct SET ProductVolume=450, MaximumStorageTime=61320 WHERE BloodProductGuid=N'57e0a8f6-8a8a-407a-9286-135f861b352c'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@09 D4 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'57e59c5c-ba59-41d0-9cb5-c5e2b307a2b4'
UPDATE dbo.BloodProduct SET ProductVolume=50, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'57f23570-f7be-49b2-b9c2-63f9f93cf1bf'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@84 I2 H3', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'58067761-ad64-4d2b-966b-277224bb019d'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AY H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'58179783-4cc1-4e1f-8dfe-ddabd439b856'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'58327b27-c617-4c39-abdc-321ef4e7c192'
UPDATE dbo.BloodProduct SET ProductShortName=N'PLASMA CPD MNFI ', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'585aa77f-7e10-499a-88e0-ec54d9ec4cc2'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'5887a7d8-5019-4af8-800f-968938e4cfb9'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'589a23c0-d4c1-441b-b3ea-cf9ae2c7f587'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'58a5df9a-3a3a-414c-976b-85a69a1f464f'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'58b56027-6a77-458b-8f72-9a11e435827b'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'58e3ddd5-ec0a-49bc-8de5-07174db40efe'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@03 C2 D4 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'58f27cdf-79f2-4b46-8af9-323a93f7e1db'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@84 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'59049522-c066-4e02-b9fa-9ffa8a1f3cf2'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'590bae47-7079-433e-a64f-327d2958f9c5'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'59132905-77a6-4db1-85bd-940e15d0c7a3'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@84 C2 D2 H4', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'592ddc97-1af5-4a73-b1cd-ce7b14ef9c69'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'59455cf3-fb54-49b9-8a7c-6befe2dfff53'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 C2 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'59655719-e535-458e-97b6-a290e234f4da'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'596e9e2c-8ace-44ed-a572-939329d941d6'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@B7 B2 D4 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'5988fed8-2fb2-430d-9d66-d2c06574dc68'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'59a60483-dbca-4747-ac4b-7419be544f1a'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'59ac0695-dffd-49a0-b0da-395692721940'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'59b62be6-4f63-4862-912a-68298beaa382'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'59de2b1b-b96e-4075-87f5-164dbe0410d3'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'59df50b5-bed8-448a-807d-15a7445d7dc9'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@33 C2 D4 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'59f1dc78-70f4-4c00-a217-3a169f9289c1'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'59fac7ee-45dc-4d9e-a4bc-aeb644789cf9'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'5a03a62d-fcbc-43df-89b1-270772b7c8bb'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'5a0de9e7-0b98-4e92-8a7c-d666b51ead84'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'5a12bca5-ea77-4509-9637-96bc49616a35'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 D4 H9 N2', MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'5a20452f-3f5e-4706-853a-3efa470b0195'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'5a214f1a-a062-4fd5-aa2f-84f836ef8b7d'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'5a2d397c-382e-4bb0-8a3f-77a98113d87e'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@84 C2 D2 H9', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'5a31b9e2-e14f-424b-975a-e1ee4306f299'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 D4 H3 N2', MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'5a3df60d-be0a-47b8-9dfb-8d942f59e32e'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 C2 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'5a4d3905-f384-480c-9925-a0211303fddb'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'5a7e31c1-0fd3-4479-8a76-443e88e280d7'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'5a9f38db-7f07-4fe9-b421-14ce3935d2fc'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'5ab45191-4725-483c-96fe-bd91df24a771'
UPDATE dbo.BloodProduct SET ProductShortName=N'FFP AFR CPD-50 IRD', ProductAttributeForm=N'@AP C2 H4', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'5abdcbe8-6ed9-4e3a-8e03-45da32b3c209'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'5ac37696-e6ca-46c0-aa2d-ba39bb26d9f6'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'5adc555b-8aa8-4aa9-bc77-17ab178b07dd'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@11 C2 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'5ae93d72-6587-4c8b-8545-7920386a3295'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 C2 D4 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'5b00a23e-d589-422b-aa2a-b5dce274a7be'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@10 C2 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'5b1642db-3e92-4d51-a9c0-ed32a01bae74'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'5b1e5238-ef0d-4bd2-b3c5-dad5e9b693db'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'5b2379ab-2f74-4e24-a960-fa5c4d2ee381'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@07 H5', LastUpdateDate='20100210 13:55:15.970', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'5b2604de-c409-469b-a3d2-18ae57866dd4'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'5b35e75b-2448-47c5-a767-541b0b087a62'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'5b54c213-d405-4ef4-903f-e570239879bd'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'5b6599a7-b5ac-4578-91ba-8141d2f2e22e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'5b75a177-f5cf-40cc-9263-c060e122f658'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'5b959b0b-b44a-49f4-8237-90623d4af7dc'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@84 C2 D2 H3', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'5ba43481-faa2-4295-aebc-9c32d3612356'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'5ba47932-a0b1-49c9-aae6-befa6e13da2b'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AZ D4 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'5bb2c461-6b3a-4d41-9744-2cd81963c9cc'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'5bcbc8a5-6fa5-4554-9f80-52d8b5db8810'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 C2 D4 H4 N2', MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'5bf5e650-99d2-4dce-942a-f0cfdb8c5759'
UPDATE dbo.BloodProduct SET ProductShortName=N'FFP AFR NaCit MNFI ', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'5bff222d-90ee-4822-ba52-67bb2ffc8bcc'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AY D4 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'5c000aee-0d44-43cf-a0b8-07991ac6600e'
UPDATE dbo.BloodProduct SET ProductShortName=N'FFP AFR None', ProductAttributeForm=N'@84 H9', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'5c0cb10e-1a82-4978-abaa-d31035a5d406'
UPDATE dbo.BloodProduct SET ProductShortName=N'RBC Deg None', ProductAttributeForm=N'@AS HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'5c18be1b-e163-4717-b0c7-3f9b9f71e200'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 C2 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'5c2829d9-f0bc-4a51-b889-e2b9cf244030'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'5c41d5cf-9af7-4552-9cc5-9a7795705c60'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'5c441153-220d-4811-b259-e50c9a9768a9'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'5c492083-8afe-4b8c-ac80-e8b8f3c0c2b0'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'5c5b2deb-1e49-4cdb-b3e3-0aa4019781a5'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'5c7983c6-50ea-4a2f-8a4d-7cb54c144f89'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'5c7d3cc9-383e-4e4e-abd4-3fdc691fa069'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 C2 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'5c7e2bfe-be7f-4f82-97fd-605234dffc3d'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'5c9fb45f-b3c5-4a4a-87de-a899d02566f8'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 C2 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'5cb05ccc-b751-437a-96c8-fa51200c072a'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'5cbf1ae1-08c9-4ede-a0b1-7375338ccc45'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'5cd4dc51-8652-4a3d-943f-e873cc7eafc7'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'5d131dda-bcc9-479f-9744-c94cae231b89'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'5d1a18e9-93c0-4082-8cef-296babfa78d3'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 C2 D4 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'5d2703eb-ffb9-40cd-9924-0b0c6aa19455'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'5d4a2520-28f2-4fa4-8e45-7ce8cde49f42'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@30 I2 HB', MaximumStorageTime=61320, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'5d61a9e1-6489-40e8-b9b3-e4faa0dacfb6'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'5d9d3efe-edde-44b3-934d-5df329608808'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'5da6e583-f677-4e0e-aec2-c120309b555f'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@10 C2 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'5dbbbf65-129f-41ea-94af-29dc8071c1cc'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'5dbc9278-9a46-4474-91c3-d8b4597c497a'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'5dc5b8e9-7079-4b65-acd8-4a9af64ab4c8'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@10 C2 D4 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'5de038b3-87dd-4128-b7f8-a5368db31714'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'5dfae1b0-0647-4ae6-b5d1-768fe4e6f777'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'5e099c14-7d06-4952-9544-20aea10a0fa8'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@B7 B2 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'5e2d5f93-c955-4375-b3eb-9e3d7f90457d'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'5e3710cc-1d11-4fe8-ad71-833cc31f8790'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@30 I2 H5', MaximumStorageTime=61320, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'5ea59b61-4882-4b09-bbe3-6811efc9dd3c'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'5ea8f42b-18d5-472e-9416-73bdf406bdc3'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'5ea91963-e149-4454-9c0b-8507da00c207'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@07 HB', LastUpdateDate='20100210 13:55:15.970', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'5eb6fd71-aabc-4de9-b72e-af010e9da8d5'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'5ebafebc-bbff-4b0d-88c6-efbc7428a0ad'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'5ed7b324-fe14-481b-aaf7-b84e5f3365c9'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'5efdb7aa-6377-468b-a03d-e6ba77c500e8'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'5f029b2b-96a0-4748-a084-a2a9f51a7b3f'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 C2 D4 HA N2', MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'5f057950-3590-4bfe-a932-12c72cb5556e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'5f14a5fc-f532-4d60-a7ee-09e9eb213010'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'5f44d1cc-8696-4b4e-a0bc-8b6222a4e0ff'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'5f4ae902-82b3-4bbb-970c-edec6e801cf3'
UPDATE dbo.BloodProduct SET MaximumStorageTime=1008, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'5f6ed5ea-2e8f-4b7b-be46-70eceea22de0'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'5f76098e-119d-4b25-a9b9-e30fc3e72e42'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'5f915961-5f3f-4374-b5aa-a4d940032382'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'5f966720-41a5-4fd6-ade8-66a6501555b7'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'5fd9ff3f-ab44-478b-90d9-4676e4a2f18e'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@18 D4 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'5ff41fb5-a5cf-4a46-bbdb-b996f5d5045b'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'5ff9dd7c-9d19-4dac-8efd-bce83d4495a7'
UPDATE dbo.BloodProduct SET ProductShortName=N'RBC Deg None IRD', ProductAttributeForm=N'@AS C2 H9', LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'6001d5cf-89d4-441a-823a-6da600a4df3a'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@11 D4 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'600b8bca-e53e-440d-94ac-497b90c980f6'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 C2 D4 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'6038d765-48f2-44ef-a180-8cb503637b78'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@84', LastUpdateDate='20091109 15:02:22.837' WHERE BloodProductGuid=N'608fb4fb-2454-4da2-be25-0ff88cd10fb7'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 C2 D4 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'60c0298a-f9f7-4ab2-8ec3-5cc8d6f948f9'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 D4 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'60d57b88-a178-4a1d-802b-bb3ce6f4d1a2'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'60db1456-5107-4704-b48b-70f04da0d93f'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'60ea3e4a-f025-40eb-b503-3562bddaa691'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'60f1d127-5097-4ab5-8bbb-272138bb66e7'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@B7 B2 C2 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'61079668-1ecb-43cd-9256-d574022801e2'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'611ceabb-ecdf-47a6-8cff-7ab5c8fad6e9'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@11 C2 D4 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'6125da4d-48a0-4b8d-84d9-d99377172c91'
UPDATE dbo.BloodProduct SET ProductVolume=50, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'6134090f-9418-48f8-a729-195effb6af0c'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@B7 B2 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'6136bc20-2cb1-40ad-9b8b-9a3771e6c457'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'61466f1f-f84a-4efe-aebd-60b6ce5c79fc'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'61638d77-ab0e-4966-a76e-63fe7c8fcb93'
UPDATE dbo.BloodProduct SET MaximumStorageTime=624, LastUpdateDate='20100210 13:55:15.970', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'619cbc86-34c8-40e5-b0b7-950a7e4863cf'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'619f9cda-c631-43ef-9104-fa1671b03ea2'
UPDATE dbo.BloodProduct SET ProductVolume=50, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'619fa05e-e374-43e7-b5dc-3d7894fe55da'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'61aa55c6-d137-4d4e-922c-2302a76fe66a'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'61ab2176-fb97-437c-b1a4-0171db4f0f86'
UPDATE dbo.BloodProduct SET ProductShortName=N'RBC CPD OPN IRD LUKOPR PLS Red/PA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'61c9f02e-3068-470f-b01f-ae0cafe60730'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@03 D4 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'61cc0e12-e56e-440b-b242-4fdb93fadc87'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'61e557a2-2e66-4228-b3c0-62c7bd8d5c88'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'61ecb831-5487-4e7a-a93e-42ac8a3a0be3'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@B7 B2 C2 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'6203e2ed-ff49-4ab6-8879-c48da0c421a6'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'620b8e65-2fd0-41db-af37-35cc64efda91'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@B7 B2 C2 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'6211c82e-35fb-4e10-9c81-d3f4faa08413'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'6213cb92-8a46-4a5c-9ca3-718041da8205'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'62217889-5e58-4ca0-a428-56bceacf8285'
UPDATE dbo.BloodProduct SET ProductShortName=N'RBC Deg None LUKOPR', ProductAttributeForm=N'@AS D4 HB', LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'62320d5e-859c-4311-afd9-281677507638'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'623cfce3-0d77-41e3-b1cd-d2e0ccc9fe13'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@51 D4 HC', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'6242f94b-dd55-4a87-bb77-520eb573a230'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'6251129e-6980-4b52-bbc0-423a535daf0e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'625e3a53-db79-43ab-80d6-2e79a2c9f90f'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'627621d0-9d0b-40fc-9854-52baabf7a052'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'627ac4cb-7be9-4edb-80d9-27d07ad80e48'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'627cf93b-30ec-4b45-b288-db1e052e35fd'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AZ H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'6293b421-52b8-4fbf-984e-582236d6f3a3'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 C2 D4 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'629ed9c0-7ad0-4705-80be-58c3ca8d0f57'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'62a76363-c321-4a12-ac07-3574861ab99e'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@84 HA', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'62c86293-cf5a-482a-a01b-2291e8148335'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@22 C2 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'62d3b321-4029-452c-9221-bc8abeb31b6d'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'62e1fac6-bad5-4020-9e4c-a520c74d5934'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'62efa443-b480-4b71-8d44-79d1474393cb'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@84 C2 I2 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'62f824c7-9f10-453b-95b9-1a76c2378c7c'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'62fcc3f0-dfe5-4eaf-8323-83647f578c16'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'63069187-cc45-401f-834d-05952a4e7636'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'630ae365-1893-4513-957c-83a2b4fb1754'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'630e0d11-a8ae-4373-bcac-7d1ada65d436'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'6314ad52-b4f0-46a1-a5c0-1fcaeb3a2c83'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'6341e3d4-1830-467c-bd72-4386c8d7e9eb'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'6374a9bb-6749-47ee-a1e6-9714491d02f0'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@10 D4 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'63be6f32-d134-427c-9977-10422e40b185'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@22 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'63d189fd-936e-44a2-b6ec-5f4cc3053238'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'63debe80-b956-4e66-9187-0ae0e356eea1'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'64038777-6388-4c18-9e7d-380502ddd027'
UPDATE dbo.BloodProduct SET ProductVolume=150, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'64161403-d650-494e-a3a2-6f9f9bfc116c'
UPDATE dbo.BloodProduct SET ProductVolume=450, MaximumStorageTime=61320, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'6420ee62-f024-4e11-9123-f0a900b938ce'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@22 C2 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'64309538-9c98-4076-a750-325ccb819d8f'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@30 C2 D2 HC', ProductVolume=450, MaximumStorageTime=61320, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'644d489c-4655-43ac-a4e8-da18fa45fd09'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 C2 D4 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'64562dba-754e-4126-b8a4-7d2686d70988'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@51 D4 H4', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'64ae2340-f61b-4912-98bf-1e0d95128c6a'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'64c2f7b2-ab9f-421d-b932-9a74ba4b278f'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'64ca9f23-dba8-4454-8c59-a61cd739847b'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@11 D4 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'64d7fc0e-6bf9-4c35-9abb-b3537b3c9d96'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@20 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'64de95e0-d228-4c01-8ece-2054c0fb2d23'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'650075f6-d80a-449f-ac11-f8c9007c262e'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@33 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'651b3d10-1c32-4e2a-80c0-43b7b95a4461'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'651c3c57-7724-46b1-aceb-c124c4c29f95'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'651dce1d-716a-4cb1-b026-04e0a018d069'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'65220a01-494b-4854-866b-7297f1331f40'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'653808de-331f-43a6-9e73-5cf53342c27e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'6540a49d-8563-4eec-8778-fe035a06198d'
UPDATE dbo.BloodProduct SET MaximumStorageTime=1008, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'654f7037-20eb-4f07-a313-6835be655308'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 C2 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'655cdc7f-5e68-497d-b468-c2a5719e3974'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'656cbf17-173e-4ae6-b194-266f817fc91c'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'656ec57d-e4ce-4906-9234-0e02e96bab46'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@03 C2 D4 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'65700213-b47f-498e-ba7c-2dcc89a9a87a'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@10 C2 D4 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'6579be85-769d-49a8-b1d3-35621590e49c'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'65a1764f-88f2-4934-b497-1197f7582ebe'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@18 C2 D4 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'65a59edf-bb51-46a1-b0fb-fe3aa3ffda7f'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'65a8e048-9729-460f-8dc7-68e09f5b609d'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'65c0647a-530c-42b9-ad4a-ae5f93ec72b1'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'65c747ae-02df-4c31-a8d7-730c2426fafd'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'65ceecd9-3cd7-40af-8d34-ad84c275c672'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'65cf916c-7736-4de3-9963-3952c9145d21'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'65dad306-ebbc-48bf-9462-88e32c0f910b'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@84 C2 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'65de1a31-6115-4e58-950e-a2186bd671be'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'65eaf3e8-c0bb-42e6-81db-84d00492f6b9'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'65f91bf0-bb48-41d3-8a7d-a9bf737f0dd4'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@09 C2 D4 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'660c6b29-e187-471d-ad15-6b89f4e0f099'
UPDATE dbo.BloodProduct SET ProductVolume=250, MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'66118cec-a840-4dac-92fd-a27b3f1b62f7'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AZ H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'6622adf7-fa2c-4334-8cac-f8c32f8c1359'
UPDATE dbo.BloodProduct SET ProductShortName=N'RBC Deg None IRD', ProductAttributeForm=N'@AS C2 HA', LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'662938e0-6816-4a85-b2c4-0c982da270ca'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'666d836a-e6f4-499b-9e99-f23120bb3b96'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@33 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'66ab7ef6-9ddd-4958-87e2-02b85ac78325'
UPDATE dbo.BloodProduct SET ProductShortName=N'PLT Wash None MNFNI OPN', ProductAttributeForm=N'@71 A3 B2', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'66d93106-a159-40cf-a70f-4f77213b00d1'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@33 D4 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'66db1a91-7955-4c4f-9f52-cd2c753f21bc'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'66e566f3-43b9-4c8d-a112-a17dedbe37cc'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'66e89e78-464b-43fb-831c-3027d4f26cd9'
UPDATE dbo.BloodProduct SET ProductShortName=N'FFP AFR Thaw None IRD LUKOPR', ProductAttributeForm=N'@AS C2 D2 H6', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'670e872f-a40d-45ac-95f9-7720af965744'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'671b70de-229e-4247-bcfe-aae738db7fc9'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AY HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'676e8945-2804-4e90-b672-536d684135bf'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'67740f78-1c72-4578-9454-80f6629a1aab'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 C2 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'67b974b6-586b-45f4-ae57-a54c4ede1516'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'67bac524-05f8-49ad-a0bb-eeecb276f516'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'67bc2e6b-9fba-4308-8d95-21b6921a2f02'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 C2 D4 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'67c05062-2814-4a00-8eb1-62cf37055543'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'67defa5b-a280-4e61-81ec-acabde850946'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'67e4bd7a-1873-4d51-bdb1-8a63be9badad'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'67f1730f-a865-4b17-a671-280b4d6f480c'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'67f5f872-62d6-4115-a31f-fc2efcde74f5'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'6809cb72-556e-40ca-9967-09a1995f87e4'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AY H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'682984cc-98b3-49ba-8dba-061fb4eec53c'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'6836a277-a82e-4eb3-9a72-7a8eda0e5d09'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'6847d814-363f-43b8-bae4-6a599483a7ec'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'684f9451-8dd4-4445-a68e-ff310325000d'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'685bd699-141c-45f0-aa63-bf602412278a'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'6865b584-ca5a-4cae-aab8-e2b14e425c9e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'688c2250-8071-4de3-921d-59fc0f8f23fa'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'688f63ce-2078-4fab-b60d-c496b16b93e9'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@11 C2 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'68a89272-4754-4da6-9ef3-fe4e28cb4bad'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'68ad3d99-f87e-44e0-a306-df7cdf65311c'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'68ba8b8f-8066-4a50-b97a-53f288d2ea4f'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'68f0fde9-c954-4650-95b2-f67b8cb42bf7'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'69142e32-e51b-4815-b104-a52312c8485d'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'69354d0d-b975-4422-90a5-fe8be0a8ed87'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'69376e87-3d65-4688-b731-5f627268875d'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@B7 B2 D4 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'6937b18c-ec32-46bc-91a7-560c4e156cf6'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'6950a3a7-c6b6-4d88-ba0b-e67a06c7a041'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'6963921d-ceeb-4202-affa-9eb0fa607dfd'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@11 C2 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'6969a673-af0a-4953-8ef7-360eecf0c452'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'69889167-81ed-4a91-963e-93031b0f9b76'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'699826c6-cdde-4610-8ec8-93b2988c11c0'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'69a4eab3-6aa6-4191-9310-71962e2852b5'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'69bb0e1e-6f62-4f59-b482-ea4c3226022b'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@07 C2 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'69c8ff5f-d3a9-4aa1-81f7-992a439921c5'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'69ca0b35-a06b-4e09-8709-409cacc1a028'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@03 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'6a18f9c9-5b9f-4c51-8c6a-65224958986e'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 C2 D4 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'6a2a885b-e4bf-4526-b0a1-29ec9750aeb0'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 D4 H6 N2', MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'6a30ef82-924f-4083-8c75-7556ef7d24b4'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 D4 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'6a367d09-96dd-4947-9f6e-8b1c3c5b981c'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 D4 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'6a4c5a10-94b4-4014-bb13-9d43be8e6432'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'6a6f345e-eacb-4c8e-827c-ec2c11229870'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'6a8b2b36-2985-4c17-9aaf-80173a5061cd'
UPDATE dbo.BloodProduct SET MaximumStorageTime=1008, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'6a929560-f5a1-4034-a907-dc11f82cf821'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@84 I2 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'6ab14314-79c8-4af0-8d55-f2ac74c688a8'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'6ac83609-9fc3-4614-99e8-e1c376a02075'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'6b062169-7bea-4e65-97ee-e691a0726dc6'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@10 D4 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'6b0c9c2e-7e64-46d0-a926-4762a459d9ac'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'6b1cbe38-82f8-444a-a9b3-09f396253e9a'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'6b2a6998-246b-4e27-ab60-57aea7c3cf65'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'6b2b774f-4e54-438e-96d1-f7a6b8dd84a7'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS G7 H6', LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'6b2d6f76-7d3c-4532-92f4-6b4e3689f76d'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'6b480a2a-367f-410f-8c9b-eb2ba6525c3b'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 C2 D4 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'6b8ac5d6-38ab-4ed6-a34b-f63be625264e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'6b917cae-efa2-4668-a50a-d468b20dd789'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'6b96df48-5037-4ada-bed7-28e4636e186f'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'6ba86f3c-83c5-4bcd-a30b-6eab0f907059'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'6bb595d5-06ec-4746-9b47-8013cd2c5ddc'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'6bb979c1-3bed-409f-b965-7057cf41aa8e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'6bc31c2b-9125-489b-989d-7286cfec1701'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'6bc9cef4-e5e8-4495-9dea-014096a75b3a'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@84 C2 HA', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'6bd1003d-436f-42fb-9648-5a536edb0807'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'6bd76b41-4adb-4da9-bad9-90e1cd67f97e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'6be1d1c0-0be7-4ff8-8e61-9fea59047f78'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'6c7c4845-e535-4308-8e24-8ba6ad8aaf3f'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 C2 D4 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'6c838688-4659-4517-b402-a421824a61f1'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@30 H3', MaximumStorageTime=61320, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'6c9e9858-fa7e-432a-a1c0-3f5e486e4dd1'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@18 C2 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'6cbae4a3-733f-478c-85ad-11d7eaedf021'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'6cc9d730-ad39-4c4b-9505-161ef62fd21a'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'6cd00817-0ecf-4ab9-bf22-855006be6a78'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'6cd56ce8-e13d-45b3-a386-9594b501db99'
UPDATE dbo.BloodProduct SET ProductVolume=250, MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'6cec12cc-4d74-4bb3-9028-f8eb0467c74f'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'6d17cd58-ed03-4c18-a764-a60c58df86ba'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'6d1f1a6a-7ce6-4947-91fc-f1274c45f274'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'6d293dc3-ec53-4998-86d8-99dc01c30101'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'6d3b6241-bbf8-4dff-8d8d-5ed99b01f06b'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 C2 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'6d4e4f88-e0e2-4349-a7fd-d4ce39849dc6'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@30 HC', ProductVolume=450, MaximumStorageTime=61320, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'6d545345-77a5-47fa-ac89-b341f955eb23'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@22 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'6d61383e-7358-42d1-a054-db33d67e98e0'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@B7 B2 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'6d6e02f2-c3f4-47ae-b1fd-05a6aa3413f0'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'6d824a40-1bfe-408b-9336-f186eedfc84c'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'6d9a44bd-4c5a-4ba0-95bc-e28885d4caa1'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'6da0ab06-7fd6-4469-881e-83f3acbc0bea'
UPDATE dbo.BloodProduct SET MaximumStorageTime=960, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'6da3085b-5a8a-4493-8d1b-578dcfc96daa'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'6dbfb6cd-b101-4cc6-9dbd-42e8d691b563'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'6dc72f37-238b-414f-8fe9-fe3bf2f5a843'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'6e03cf02-e30b-439b-80cd-05e1ec8567c0'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'6e0bafae-6a20-4c09-a5d0-52f78983a8f9'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'6e0f564b-8a12-425d-aaa8-2556388159cc'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@33 C2 D4 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'6e217514-a122-4791-b056-3c8561fd53ba'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'6e43d868-5963-4a36-9276-01dd0a4aac03'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'6e47eda2-d112-410a-9398-41afd8024b0b'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@10 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'6e6bb25b-39e9-4894-a44b-a7d5ae7f430f'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'6e8cbda2-2bfa-4a10-87ac-82a53b7ed1ee'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'6ea81db1-3e89-4cb9-9250-c56f7adc3a02'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'6ea95b68-ff5b-494b-a211-598b4b37f313'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'6ebe62a0-3445-4080-bc9d-b22e98ec24e2'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@51 D4 HA', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'6ee8ec26-b742-4f6c-b004-d3e71005dd73'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'6eeb0fdf-098e-4602-bc0e-046f23c77d08'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'6ef0c858-3f32-4559-ac65-3af924cefcba'
UPDATE dbo.BloodProduct SET ProductShortName=N'PLASMA Thaw None IRD', ProductAttributeForm=N'@AS C2 G7', LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'6ef43806-c30f-481c-a0fd-5d1ad237b7c5'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'6f035084-8197-4530-85c0-59f0104576cf'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'6f2aefe0-5bc8-4185-b3d3-512c8ce388be'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AY HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'6f48c9f1-ceaf-4f94-9973-85b8c5890904'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'6f7d05e6-4d2c-4d26-bea9-121bf44753af'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'6f9757f6-71e2-479c-9bc2-3a815f50de46'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@10 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'6fca4b5b-51a5-406f-8a3d-9f3853677bdd'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@84 I2 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'6fd8048e-296e-4067-8640-e1c74aaa8920'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@07 D4 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'6fdd735e-8c80-4a5f-840a-7ebf7713be58'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'6ff468d6-747c-4587-9788-dcd355256cc2'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@33 C2 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'6ffc11c2-17a0-426e-ad55-5fe8bb6ee932'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'700e0623-7bfb-40a8-b4eb-7d38e9b14caf'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@03 C2 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'701d5ea5-8917-4e5b-b1af-795862b7ebb4'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'70207a2d-e0e6-422c-a4cf-71b91a10a6c9'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 C2 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'7040b9e7-4fd9-4bcd-842c-cdd468d2b482'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'7046f86d-46de-465f-89c3-c261930a1f18'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 C2 D4 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'70576807-5893-4dc6-aaba-c3e5529e585b'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@10 D4 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'70579117-28bc-440d-b056-a3863aaa811e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'705ebdc8-fe5d-4a1b-9767-c6910719077e'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@33 C2 D4 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'706144a6-cd50-4f92-8a8d-01f9b6db5212'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@07 D4 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'706fcb8a-1262-4b58-a959-da3eba272701'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AY D4 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'707c873d-ccce-49e8-8460-65930f409587'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AZ H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'708ca055-b0c2-4d44-81b4-5e27648c8724'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@30 HA', MaximumStorageTime=61320, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'70941920-1840-47e3-bca9-9b0015fa48b4'
UPDATE dbo.BloodProduct SET ProductShortName=N'RBC AFR CPDA-1 LUKOPR', ProductAttributeForm=N'@09 D5', RetireDate='20081103 00:00:00.000', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'709dc264-e3e3-4676-b1ab-07e1f4d64225'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 D4 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'709ea564-2e75-44aa-ae7f-917346e426a9'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'70af08b8-399b-40d5-bd1b-508bf03082b7'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@11 C2 D4 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'70b2a85e-ebcb-4062-803b-ec02d15f8ddf'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'70c7750d-3056-44aa-8158-3e6233aef538'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'70daf241-82fa-485f-a834-1a1f53a28dd3'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'70f18bed-fa15-439c-aa79-efcd7290612f'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'70fdb496-9f5c-4b26-8b8a-800e02efbc83'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'71152094-52a0-4037-b3ae-ae29fa8028f1'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 C2 D4 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'71322598-6b1d-40e5-944c-9828873b6e26'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@10 D4 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'714eb1ac-af47-485b-9974-13c7bea51689'
UPDATE dbo.BloodProduct SET ProductShortName=N'RBC Deg None IRD LUKOPR', ProductAttributeForm=N'@AS C2 D4 H6', LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'716d9c69-9805-4d14-8d70-9831eea3d2c9'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'7171257f-73e3-4ba0-be24-4ba8326f743e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'7186758c-3043-4689-b9c3-1ccfedb7acdf'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@84 C2 I2 H6', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'71bd90a3-b315-4adf-b404-33ea58a61e58'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 C2 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'71d1e040-e468-4dc1-9253-88831cd0433e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'71d64386-5792-49b4-9526-2bcba4f00905'
UPDATE dbo.BloodProduct SET ProductVolume=450, MaximumStorageTime=61320, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'71d9158a-946f-4097-8a25-d3559abfabec'
UPDATE dbo.BloodProduct SET MaximumStorageTime=61320, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'71db150b-5877-444e-99d2-1186b83f21a3'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'71dfd170-bede-43e8-876d-7ac99ce0f0cd'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'71f55004-9139-4ab6-81f5-25574a6e7372'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'71fb98f9-af79-4aa6-975a-b92ff2aba250'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'71ff1c52-f8c7-4773-b908-732e3efdbde4'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'71ffdaa7-3313-43fe-a3ca-d6abb16cb06f'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'7202d54a-6ee8-46db-b841-d9455e74bcaf'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'72069650-b54f-40b8-9e13-2cb8ffc0ec37'
UPDATE dbo.BloodProduct SET RetireDate='20040901 00:00:00.000', LastUpdateDate='20091109 15:02:22.350' WHERE BloodProductGuid=N'72211aae-6631-498e-8624-d3b27cc27adf'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@09 C2 D4 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'722ccd7b-df92-4a33-b4e7-a3f1ecd110d2'
UPDATE dbo.BloodProduct SET ProductVolume=50, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'722de1ed-e6ef-4227-87b0-d25207f1f9e0'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@30 C2 I2 HA', ProductVolume=450, MaximumStorageTime=61320, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'72498521-10a6-44be-bd22-7ad5ed34baba'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'724b7db1-2fff-45bc-8f23-9ce2f9e4656a'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'724c08d4-1f51-4ae4-8601-2dbcde44c850'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'725f22e7-6cc7-4eae-81ee-f763067ec328'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@30 C2 I2 HC', ProductVolume=450, MaximumStorageTime=61320, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'7268c0e1-2c21-42e9-a245-0b8b51a77b79'
UPDATE dbo.BloodProduct SET ProductShortName=N'FFP AFR Thaw None IRD LUKOPR', ProductAttributeForm=N'@AS C2 D2 HA', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'727b275d-d30f-462a-a5d5-0dbee8a52b14'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@B7 B2 D4 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'728ab935-bc42-4788-9f4e-ff6cc8e80d31'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'72961c02-24f4-4127-92d9-be5a193d539d'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@33 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'7297e2a7-f6c1-467a-8565-804c703955e7'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'72d62690-0943-4eb8-9ebc-14349ced4d6e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'72e9d14f-e528-4ab3-8b2e-cfe1a3903ff0'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'72eb107f-e066-4f32-8db9-cb2eb4237d43'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'7304e1db-b73d-488c-9fb8-3dc86da04828'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@20 C2 D4 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'73277db4-f25d-46c4-be59-3acbc4d13114'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'732eaa31-bba5-41ef-bfdf-a26b3ad78db2'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'7334438b-a503-4906-8f14-bdaa9e3ea369'
UPDATE dbo.BloodProduct SET ProductName=N'Apheresis FRESH FROZEN PLASMA|ACD-A/XX/<=-18C|For mnf:injectable|Frozen <=24h', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'73450290-2f04-4d7a-9435-3e50e97692e5'
UPDATE dbo.BloodProduct SET ProductShortName=N'RBC Deg None IRD LUKOPR', ProductAttributeForm=N'@AS C2 D4 H3', LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'734ac4ad-d4e9-4ae2-b44c-332c44715504'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'73513bd0-f3c7-43d7-b326-4863a6c7b63e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'73880700-b048-41d3-9399-97cca3e3a1ce'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'7393267b-4b55-4e99-a648-bc31dcd78da4'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'739a16d1-2a4d-4189-8d90-395bbf6f8921'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@30 C2 D2 HB', ProductVolume=450, MaximumStorageTime=61320, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'73a832d5-8f96-4323-a374-1ebd73f7e3a3'
UPDATE dbo.BloodProduct SET RetireDate='20090901 00:00:00.000', LastUpdateDate='20091109 15:02:22.697' WHERE BloodProductGuid=N'73c4dcb9-aeee-4e00-b087-04f0283f3601'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'73d64176-4ebe-4041-babb-9ebd27127a90'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@B7 B2 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'73e1d4e7-427f-4bee-9a74-64c6503d07f4'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 C2 D4 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'73e9bde3-f56a-471f-8992-530dd66bfe58'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 D4 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'73ea7f01-64ab-4354-864c-2994f5af7bac'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'73f7c0f3-ff21-4670-a7b7-7590aa1b3d89'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AZ C2 D4 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'740b79dc-2814-4556-9332-18309adcaeb8'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'741b6474-69f3-44f9-9df8-52a3e492de65'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'741ead08-58c0-4e30-9442-5e23a4b8268c'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'743cc1e8-4525-4288-ae9c-18e99127a73e'
UPDATE dbo.BloodProduct SET MaximumStorageTime=624, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'7447fbbe-7565-4d48-8888-f83284a6d2c0'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 D4 HB N2', MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'744acf3f-8f93-4e20-b48e-0f5fbc956e10'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'7456a940-331c-4c24-803d-e1de486c0de3'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'745757a1-de1f-44bf-93a2-70bd84227915'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@10 C2 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'74779a12-4a34-4c4e-84f2-fc4504d5e867'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'74816556-3fdc-4472-8b48-9a9e214da3fb'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@33 D4 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'74863ac0-1257-4c23-a653-88576aaef14d'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'74911a84-8437-44ee-971e-009d23280b03'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'74c6f844-a166-44d5-a99c-c0c9cfbb614f'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 C2 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'74c9e0ea-0146-4924-a94e-10a330e62d95'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AY HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'74cb4145-3f47-43f0-885e-2807d5c26aeb'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@03 C2 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'74e878fc-0625-4d90-9982-62256985a457'
UPDATE dbo.BloodProduct SET MaximumStorageTime=624, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'74eb30a0-4bda-4984-bc64-4c24f4d1737b'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'74ec4040-0ca4-47c7-b3fe-32a2b8f35994'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'75076e89-e24d-400d-9a68-3df34e7a510a'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 D4 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'75096097-1f00-45e5-a33a-e04805be7d13'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'7511450e-2bec-4ed2-8423-dc3ea6ca8ad0'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'751c8ec2-14ff-45b9-8ec5-dea2cd18dc3f'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@33 D4 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'7523a296-ffc2-44c3-848f-2149be432a6a'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'754946aa-4828-495b-af71-bcd0416d3573'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'757b08ff-3f37-41d4-9f7d-fb43beb7520f'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'75989ddf-6d53-44c1-a490-088fe8ed7e46'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'75adaaf6-c7aa-49ea-a7b6-d3f00ac528f9'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'75adf39d-213d-488f-86b0-33589eb71f09'
UPDATE dbo.BloodProduct SET MaximumStorageTime=624, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'75bd2a9c-b2a2-46ca-8f03-1ffcecac84be'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'75ceb639-7785-4a65-8805-ef45375c503a'
UPDATE dbo.BloodProduct SET ProductShortName=N'FFP AFR Thaw None IRD LUKOPR', ProductAttributeForm=N'@AS C2 D2 H5', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'75d05816-2fe0-486a-96d1-57aa8367799e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'75d7a734-c8f4-4a2e-bfa8-b47d23a08308'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@22 C2 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'75e4c79f-7360-494c-b71a-7ee7b3fd11c8'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'75f9e739-a716-4237-99f2-4957c67ee3d2'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'760906d1-6e67-4a8d-8905-22ede22682cd'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'762ad9b7-ef3c-450d-bb89-aa460eb4578e'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@84 C2 HB', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'762f0656-d64b-4eaa-bd6f-61da73afd353'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'763d29b0-a2d2-488e-972f-2fe5e2759a49'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'7665bb5b-3a15-4f62-9052-27bade8681dd'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AY C2 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'76744f25-bda6-40c1-922a-d1a672c5ebd8'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@07 D4 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'76851312-e85a-406b-a2a8-d5247aa05b3e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'768b7537-3d74-4321-81f3-e8fd335bc134'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'768dfe1e-cb90-4f02-a538-ebfb43eced7a'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'7691ab2a-7fb3-4c3d-b861-bcb89c09106a'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@11 C2 D4 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'769a01bb-a931-4221-8d8a-71c7b6ad220c'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'76b8e306-744a-48f2-a5f6-1bd06428ccbf'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'76bc9483-5c31-4043-9361-f05fbcd577f9'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'76cec99f-5689-4e80-a60d-bbe9aab643e5'
UPDATE dbo.BloodProduct SET ProductShortName=N'PLASMA None LowVol', ProductAttributeForm=N'@84 F3', LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'76d022ba-c7e2-4489-abc8-379eab533908'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AZ C2 D4 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'76de740f-bfa1-44f2-b6f0-f774be86f523'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'76f63987-533f-4aec-8be5-4e2d59d12820'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@03 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'76f6eb30-02ac-4470-a696-7d1132467c83'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 D4 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'7701ee6d-9f57-4d7a-aef9-3ce10e3ff3a4'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'7743486e-9802-479f-b5c3-7847eddc7d7a'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'77445147-0ed1-4d61-8d10-baf92b119a33'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'77497f39-6d6b-4b4c-8872-d24d895a2465'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'7752da29-269a-4c56-9ee4-219109e709aa'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@33 C2 D4 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'778627ec-1f6c-44b5-b550-e3ff306693c8'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20100210 13:55:15.970', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'7788957f-64dd-4c6f-b522-d259b4c1e4ec'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'778ee9ab-5ce8-4cbe-a2ba-e3cec2df28eb'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'7799d988-814c-4e4f-9648-bbb4ce0e9c03'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'779f6976-d71c-4d40-9c7e-5544273d9fc4'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'77a44e41-7b0d-4878-ad4f-847520dbd5a1'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'77aa7e25-b4ba-4e8f-beaa-92fa92baaa33'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@11 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'77b19854-f281-41c1-9616-5f682c10164b'
UPDATE dbo.BloodProduct SET ProductVolume=450, MaximumStorageTime=61320, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'77b2a2a3-a52a-451e-81af-9a54a02c15f5'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'77ba6835-5e8d-46c5-93e3-e1a70023b89f'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'77e64265-cd73-4090-86ed-da611bd35d65'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 C2 D4 HC N2', MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'77f05932-a6de-4808-a68e-2494b61f9bc3'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AY D4 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'77f9efe2-e04b-477e-b7f6-13e5dcebb5cb'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'7811cf22-0100-47b6-bd2e-e10e2e4e2859'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 C2 D4 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'78311f3a-9725-4ffa-893f-b1af845f0bbc'
UPDATE dbo.BloodProduct SET ProductVolume=50, MaximumStorageTime=120, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'787722ef-1d57-4781-b783-5a812b5ea9ab'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@10 C2 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'7881656a-ddfa-4d87-ab4b-177ffda4adb1'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'7891cb23-4941-44eb-bb09-a56792d83cc8'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'78bd6274-255e-432e-8926-1dfe1b41277e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'78c956f7-e800-44bd-8b23-b1f96dfb1972'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'78cbde0d-422e-4df6-a907-9a89db992d6c'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@22 D4 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'7914d0d7-0eb3-45f9-b7a6-6f316b18da8c'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'79163ee9-9b0a-4a57-a5b9-d09268336edf'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'795532d2-63ee-41e8-8ae4-2d33c0f1086a'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'79b80518-8498-49e1-9241-cf1d772bf7f2'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'79bb078b-cf23-4b95-8dec-67df0062a940'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'79cb096d-f838-463f-9d81-a1545ea7398e'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'79fe3ef8-1b83-478b-a8d7-764ac9e05550'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 C2 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'7a0b68b1-f8e6-4629-9631-dcaf618f598e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'7a0db706-329e-4041-bbef-536de5987039'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AZ C2 D4 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'7a1bd1ea-5034-4632-9a70-c0d8e44d246e'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'7a3b28ad-e14c-4c2b-804b-314576380035'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'7a56d698-a37f-4562-aa4a-6a059e8ce2a9'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AZ D4 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'7a6e96c6-8e93-46cf-88a6-c2aa9124a6c9'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@18 C2 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'7a74f83a-1bf5-4567-a411-01305f7b703a'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'7a75346f-19f9-4d10-8d84-7957ef642a99'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'7a8015e8-625d-4945-bc38-a28450ffcea0'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'7a993cfc-93bf-4e07-a69b-bb234ad9ecee'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'7ab9010e-101e-485c-9adc-618cc67a03a6'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@03 C2 D4 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'7b24b30c-b628-4e5b-a795-010694720a6b'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'7b37d531-ccfe-4db2-83e1-d2cea84fef5f'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'7b83cd72-b943-4aad-98e5-098ab60a1f3c'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'7b949d8c-6535-4e07-a73e-12be5c86a008'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'7ba41706-8a33-4906-9551-10b80e10e304'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'7ba5dde8-4a59-4cc7-b924-9a5e2cdf0f03'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@84 C2 I2 HC', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'7bab8baa-3bf5-4895-ab4c-e12957143705'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'7bd2b34c-99e5-49b8-b614-1203b1d16709'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'7bd3c48c-ef5d-4ec4-9cab-b6fd62e7594c'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@30 HA', ProductVolume=450, MaximumStorageTime=61320, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'7bd7bb5c-2e3e-472f-8f1e-0eadc4766775'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'7bdb959d-771b-4bba-94e4-cad01a0a67d3'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'7bff0bf9-8066-4692-ae6d-eb87e05b0608'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'7bff34a8-de16-4bee-9768-d8812ad81aed'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@07 HC', LastUpdateDate='20100210 13:55:15.970', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'7c1597bb-0db3-4f50-9d4b-d29786245a97'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'7c5c2e66-0c3f-4ef0-b380-d9a242ac7ce8'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'7c5d67cf-9ae9-4f10-83c8-92af72153368'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'7c71e80c-01d0-44f6-bbcf-c54b72b9f3b7'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'7c73af5c-d8e7-487e-851a-90ea0115f74d'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'7c7a2eb8-0cfe-4430-8384-15df86cf1384'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'7c8b5196-44dd-48e0-9c6f-3a617623ad11'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@22 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'7c901e2d-e953-4c64-b3df-9616756408a8'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'7c920360-1b1f-45f6-bb4f-c2439d985a1e'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'7cb38fee-2682-4df9-8b77-eeb9569a98ee'
UPDATE dbo.BloodProduct SET MaximumStorageTime=61320, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'7cb7ab29-f09f-428c-9c44-be32841e53e2'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@B7 B2 C2 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'7cbfe74b-eb6a-49cf-951c-10c1dc1ad1fd'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@84 H3', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'7ccc1d48-210d-4b0e-aa6c-daae5932c438'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'7cdd3225-1170-44af-8fea-f0f7b59ead8f'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@07 D4 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'7cde7143-e43e-4fac-bee5-29c31dbc6fb9'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'7cdf1459-ea09-476f-a18a-8fef941b8d5e'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@33 C2 D4 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'7ce09559-1cc3-4bd5-901c-f546c1cbc845'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 C2 D4 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'7ce28fa7-6442-4e0f-b5e7-857ad3080329'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@03 C2 D4 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'7d0e7b85-69cf-495b-9b4b-8311269b2cc3'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'7d331be9-861a-4e50-89b9-394aecc7f97f'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'7d358fa4-18bc-4464-b0ef-03e6f77b1178'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@03 D4 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'7d38a378-0515-4a77-8a09-5b49e4c78b67'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'7d70f7be-64cb-4468-ba65-4157d80af2a3'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'7d771c15-c2d0-45fb-97f5-a53f3d183284'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'7d8d6854-ffda-40a3-81b9-19caf7bf9d3b'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@B7 B2 D4 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'7d96cf11-416a-46ae-9905-5c298bb37f01'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'7d9dd145-c7b5-46b0-b898-69d9deac34c6'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'7dc7d789-8702-4d53-b1ef-7baa983bf86b'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 D4 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'7dc87539-e17a-4a1f-b358-a667f5a7c83d'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'7ddb3530-c198-433c-bf09-8b366d7edf10'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'7ddefe5a-c809-4fda-840a-b4269c5a0509'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'7df002f1-a969-476e-a95f-715dcd585144'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@20 C2 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'7df7be99-192f-432f-a7b1-351507a36215'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'7e11075a-6dd4-4d96-a342-8c024d5295b0'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'7e347d7b-812a-4da2-bc83-419b802a098d'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@84 D4 H3', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'7e3ce649-090a-4fbc-9385-fee88818f263'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'7e5037f8-110e-4045-b6c9-8d64339cf408'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'7e62ca60-7160-4069-9463-a1fd5c8fecac'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@33 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'7e7afa5b-851c-4b9b-96e4-a68ab0a2cc14'
UPDATE dbo.BloodProduct SET ProductShortName=N'RBC Deg None LUKOPR', ProductAttributeForm=N'@AS D4 HA', LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'7e90d100-8169-4b35-a750-ff5c422c0b85'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'7e978acd-561a-4c8a-bf8e-ed0c75626c16'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@11 H3', LastUpdateDate='20100210 13:55:15.970', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'7ea3070a-edfb-4c51-8312-5540df6fd671'
UPDATE dbo.BloodProduct SET MaximumStorageTime=624, LastUpdateDate='20100210 13:55:15.970', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'7eaad411-2d5c-4dbf-b7ac-814c8f99653d'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'7eb3cec6-5886-4860-a981-462e96fc9528'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'7ec2a692-5947-4c3f-b77c-0b24c5cae89f'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'7ef4fdb0-242c-428d-8ce9-0e5a0a72cfe2'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'7efe9a6f-6080-456f-b85a-dfa9fcad53f2'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'7eff8dbd-e6ab-40cb-ad2b-cf98191a74fd'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'7f2b7ffb-c844-4000-9681-4243cd6231c8'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'7f3d21a1-ed5c-4809-aa12-c986662093e1'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'7f4cd791-a780-4c41-b011-1f2e63fb5048'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 C2 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'7f507519-6d0d-495f-ad95-7317318cbae9'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'7f521cc4-f7fa-4950-b8ca-7ad787014e1f'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'7f5d959f-987a-4b8c-8122-92000a8c850a'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'7f5fb5ff-eab9-4348-9094-4be3c25f5854'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AZ C2 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'7f635d3c-8f2d-4d16-8065-759d473a6b67'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 C2 D4 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'7f654bdb-86ae-4095-a271-4be24a24717e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'7f67b30d-f8bb-40cd-a93b-094ff999b207'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'7f9273e4-32a6-49ea-afb9-f8cfa570512a'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'7f957e45-2c74-4d8d-949c-b189f13e83ee'
UPDATE dbo.BloodProduct SET MaximumStorageTime=61320, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'7f9aa8f4-6093-4469-80ae-c8a2fd3e816e'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'7fb143b2-05df-4311-a7e4-6e35d60c437e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'7fb80621-f86d-4d75-8565-9d21b6ef36a2'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'7fbb355a-77ec-4b1a-8662-af97086e42db'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 D4 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'7fcfecd0-3248-4cad-be69-f7d67fbba1d1'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'7fdcaba0-85be-4184-b8af-20bdd27d5a5a'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 C2 D4 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'7fe26723-3412-4028-a3b7-bae19cb59484'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'8000efb0-bcfa-4bb4-8e51-d37a8d5c57d4'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@07 H4', LastUpdateDate='20100210 13:55:15.970', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'80097c83-a6f0-4570-94e0-370f1eebf4a1'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'8018ed95-ab79-4885-8181-5a556f8c5701'
UPDATE dbo.BloodProduct SET ProductShortName=N'RBC Deg None LUKOPR', ProductAttributeForm=N'@AS D4 H3', LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'8046f1b2-a63f-498a-8d8e-4be2661488f1'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@20 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'80526153-cd64-478c-9878-75f26ebe51d3'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'808a01d1-9a98-46bd-88f0-82b2b86d263b'
UPDATE dbo.BloodProduct SET MaximumStorageTime=61320, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'808c17c2-3ea4-47c7-8ab2-4cf97c11fbeb'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'808f052f-7a82-4744-ac99-8f73272d6c33'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'809912bb-e839-4b84-8891-92a6ec37e2d1'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'80ae1fea-f0d1-42e6-9110-a188db115217'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@B7 B2 C2 D4 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'80afb254-4199-4e7f-ae37-2105ef912cf0'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'80afc768-6153-4f80-8335-2eec319c94cc'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'80b4abf0-6b5e-4c6a-a6f2-77decd40c25d'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@18 D4 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'80ec1b75-a12e-46fc-81a1-9d585a737a03'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@22 D4 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'81035114-b5de-402f-ab01-c7d577d1a35b'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 D4 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'812191ce-5a47-45c9-8f13-34d9a560e668'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'8137aabf-7449-48ca-967d-60149389e04f'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@07 D4 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'813cda0d-31d8-484f-a002-8c4721877599'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@33 C2 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'81587248-33b4-4bb5-a75a-4dd169ff54af'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'815bb490-6fe5-4895-97d3-15b06d3ae819'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'815f3cd1-15de-4bb2-b06a-2b3073dfb590'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'816129c6-a0bc-440d-bc31-7349ee3934da'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'8170be5f-7c31-4ed6-9a15-9267f078d0dd'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@09 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'81732b74-2b1d-43b4-9eb0-a6a4d784a13f'
UPDATE dbo.BloodProduct SET MaximumStorageTime=1008, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'817edf32-f74a-45d5-8899-fa36b14f26d0'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'8182144f-f380-4bee-9a41-a9a971cb20b4'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'81880b6f-6751-4c3e-8c8e-74b1ff22ed85'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'81922c8e-fc82-4f2a-8639-13d4c27f8b59'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'819b585d-12f2-4f6d-a96a-35f0fffacc29'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'819f0733-3170-4931-b63e-fdc97d77d850'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'81b0bd04-9256-46ef-86b2-8268b3ea3ce4'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'81b42184-f890-4402-b49b-0ea3297be7a0'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'81c9afa9-4690-4239-8074-60b5ff913f9b'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@11 D4 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'81d0365d-311e-4c89-8884-30d2964968f7'
UPDATE dbo.BloodProduct SET MaximumStorageTime=1008, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'82091158-fef6-45dd-af4c-7c690b0e3d04'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'8235a351-61fb-4f62-8c72-3c3ded34f217'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@18 C2 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'824b7edd-7113-4bb0-a654-022a635ddcd6'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'825a7420-327c-4b9b-88ed-2ded1b1f4f6f'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'8262050d-1467-4620-8c88-efe5db3bf1d9'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 C2 D4 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'826e87cd-933b-4dc5-82dd-552313aeda26'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'8281afdb-d88b-49ad-b49e-ca8c97c6a336'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'8287c8eb-2506-4870-93b4-7727db1f34ff'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'828acee1-56f8-4b88-b931-266078d777b1'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@84 H6', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'82da58b0-facb-49a8-8860-1af591f283df'
UPDATE dbo.BloodProduct SET ProductVolume=50, MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'8320ee86-f2a2-4470-83c2-f0f434d31279'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'8337e7fc-37b0-429d-b4ff-b8359b23228f'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'833887fe-1018-431b-b990-9200cfbad13f'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'83666c53-ea17-478e-8512-b493d309a374'
UPDATE dbo.BloodProduct SET RetireDate='20081103 00:00:00.000', LastUpdateDate='20091109 15:02:22.383' WHERE BloodProductGuid=N'8384428f-9f29-44cd-8990-7fead210fdad'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'838a3ca8-6d4c-479d-8e32-a9bcb26895c7'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'8392d289-6207-4e05-914c-f0cc19968fe8'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 C2 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'8392f0ae-10eb-4338-ad30-c0b6f722ef69'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AY C2 D4 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'83a61059-b970-4671-a390-c6ddf72b6352'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'83a9db89-df11-4f8c-a9c7-b02c15b436b0'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@18 C2 D4 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'83abead1-0fef-4b54-aa98-99e1456c3d56'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'83ad6362-6b45-4711-b14a-46f7e71adabe'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'83ba6518-da29-4de6-9bd1-9d0a9459b15d'
UPDATE dbo.BloodProduct SET RetireDate='20080901 00:00:00.000', LastUpdateDate='20091109 15:02:22.850' WHERE BloodProductGuid=N'83c15194-6ff4-47b5-a300-e803acfb3f39'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'83d754b6-f3d7-4841-9318-a57fc2957743'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'83db8c2a-1bf3-4e1c-8ca1-1fa943a4c1ed'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'83dcc1fe-9ac1-40c7-b6d4-0afc9e717e6b'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@B7 B2 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'840b41ea-7dfb-436c-ab90-ab89ca5d6930'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@30 C2 HB', ProductVolume=450, MaximumStorageTime=61320, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'841f597f-670b-4e34-aa9e-71adc4a08be9'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@20 C2 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'843c98fd-5be7-41ac-a752-6a187a9fc258'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'844129e6-3196-4615-b509-0bff7d311265'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'8504b9cd-0efc-45a6-865b-59ef9ca1ced9'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'850632dd-929e-4a98-8774-fa1ace637f10'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'850a7f78-377a-4323-ba1c-84e85eea0cf3'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'850c89f1-8d50-4ed3-aabc-6d9637aa8b9b'
UPDATE dbo.BloodProduct SET ProductVolume=100, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'851175fc-5fea-4926-a6af-a86f9c459776'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@03 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'8520c344-b89f-452b-945e-f3344331ed62'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@B7 B2 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'85250f5c-1f2a-4e58-9e0b-67920146061d'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'8544b75f-8277-44a8-bee9-e0ff3baae24f'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'854a4be3-1c13-46be-b8b5-fcaa4ac984b3'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'854a632d-6919-4e6a-8c64-0609fb8e34e7'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@84 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'855f2295-09c1-4a7d-b95c-04edb3d5fa11'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@B7 B2 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'85962fa6-1f4b-43a6-a751-97e1177296cb'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AY HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'859ecb9b-2a75-4026-bad2-6e81ecc5bac7'
UPDATE dbo.BloodProduct SET ProductVolume=50, MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'85c0f35d-6bf5-41c7-bb84-ebe1cdf4b7b8'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'85c6f4bd-8017-43ad-b20b-f3f4df41c370'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS G7 HC', LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'85d5b31e-3a96-4cd1-87d9-3903532e31d3'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'860c6e12-5190-44c5-a20f-368893ce45a5'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@03 D4 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'86108c87-a876-4020-a8bd-bbb3332bde15'
UPDATE dbo.BloodProduct SET MaximumStorageTime=4, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'86146d09-40b9-4c55-a610-8df7bb3c0855'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'862389da-4786-44e1-ac9b-0f130ce07086'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@11 C2 D4 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'86255112-f4d9-44eb-9d01-e549b99bc112'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@B7 B2 D4 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'8625664c-2188-4774-9982-7d5259b0a80b'
UPDATE dbo.BloodProduct SET RetireDate='20040901 00:00:00.000', LastUpdateDate='20091109 15:02:22.367' WHERE BloodProductGuid=N'863388c8-6550-4c8a-b0b6-69bb4de1975c'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'8650397f-c983-4b6a-be1a-4cfe4c0dc1d5'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'8657b94b-9356-4eff-804c-6c696edb79b3'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 C2 D4 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'865db562-3212-487f-b4ce-b9438551c74e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'86813557-2713-4835-affb-c4fdf7f5c0fd'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@18 C2 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'86ac928d-5b31-4652-ace3-898efb30446e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'86ba713f-bc95-403c-bfd0-7c373011737e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'86d082c7-b813-4200-8f38-ef1545035570'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'87124af4-88e1-4fbd-96b9-587958c91f43'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'87170cda-af70-422a-8af4-0b17a114ef47'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'87243b02-1e3c-475b-8093-084adcc3a540'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'87352973-d1c1-4e78-b098-e9d6dc0de0c2'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@22 C2 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'874038a7-a69b-471b-b580-a624f2f230f2'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'874ab8b7-d78a-457d-a4cc-742a75ec2467'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@18 C2 D4 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'8782e631-cff3-4fa7-b067-e5cf5f6ed8d0'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AY C2 D4 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'8785eef7-41f2-4ad4-9d2f-4f0354702439'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@51 D4 H3', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'878db69e-205b-406e-b356-5a0698824c13'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'87a00742-5d9c-4e4f-8301-f447f3529a72'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'87a12af3-8c7b-4da8-a109-940ae8cabb7e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'87ad4d5c-ef92-47d0-9132-ba2b69fc98ee'
UPDATE dbo.BloodProduct SET ProductVolume=50, MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'87b10764-9a26-4909-9be1-96f17495cf85'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'87b662c9-9616-4171-bac7-4e666357289c'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'87bcc3ae-c6db-45df-86c8-383f4bbc6f43'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'87c3fc89-3088-42a7-8adc-5c6efd2d3db2'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'87cec13c-d1de-49c7-983d-1662a6fd3910'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'87cfb57b-4b22-4676-8d4a-3ba45a18a238'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 D4 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'87d5b893-0c5e-49a0-b571-ed8e172a8834'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'87d6ab20-0f6a-40ce-9ab1-173140609062'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'87e5fa33-0a13-4d88-bd12-6a3e68e390f3'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'87ec0c25-fd29-44d4-a66d-219a79c35f90'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'87f08eab-65d5-451c-9e04-6fb7ea4e5568'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'8808aff8-c3ae-4fc2-b443-db2a0bd8b0d4'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@22 D4 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'882d7e24-953e-4f94-92c0-4c9e5f6b92d7'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@33 C2 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'8879f690-4a93-4829-ace4-beff0f433126'
UPDATE dbo.BloodProduct SET MaximumStorageTime=624, LastUpdateDate='20100210 13:55:15.970', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'889a1a68-2b9d-4975-831b-e0b66e271874'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'889b9daa-25a9-4f05-bc6c-58158b64d045'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'88af9231-a89c-4456-9e17-5bdf49df9866'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@30 C2 H9', ProductVolume=450, MaximumStorageTime=61320, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'88afd288-733e-469a-9e89-80ff8c089b77'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'88b917bf-38f5-44db-a460-f898a2cc3f29'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'88d447e5-7f91-4182-a41b-ec5ad9a388a2'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@10 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'88e0535f-fe77-4e9e-9a30-9f946f56082b'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'88fbd6b7-7cb9-403b-9934-28e08f98e62f'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'890547b0-e6d9-4a57-b668-94428990a571'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'89062129-409c-4eb4-8b48-e6fdecbcab28'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@B7 B2 C2 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'890ab82b-223a-4aa8-9e2f-f62337a07351'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'8920d585-060a-4952-8e8c-1024757c90be'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@11 C2 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'892829b1-4ddc-4b30-8298-f4a4fd9a38ee'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'892f13be-e1e3-4fee-ada3-9a484fb99563'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@03 C2 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'89344d67-b2cc-4647-858e-40d87aee0c2c'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'8952c799-7c65-4df2-bde8-acf92226e49d'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'89552161-f2c0-4e87-a2ec-e2ccab57aa9b'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'897cbea0-e411-4bac-8329-46d32e2b31b2'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@B7 B2 D4 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'8993118f-e6cf-495a-8090-0b9f2e704020'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 D4 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'89af9665-0df3-4a8b-bb4b-a677a6374c9f'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'89d977bb-9cc4-4d76-9912-f2fd96e6aaec'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'8a0b370a-08eb-4bb3-97ce-91a039b9225f'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@84 H5', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'8a1983a1-c2d9-48b2-8692-2b485f9795fc'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'8a213698-6df8-41e5-a921-8d3395c7acf1'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'8a3447e3-dbea-4259-a6b3-5252dbc5d55e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'8a356896-f4a3-4e6e-bb79-0937b9b70add'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@84 D4 HA', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'8a5b4a90-e5fa-4c70-920c-ee82b184f712'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'8a62015f-60a0-4f8a-834f-803cfd7744ee'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'8a7c8f68-5dad-458a-b878-1735de4900b3'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'8a7d766f-37ea-4702-b56b-fe23d9160442'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'8a85e614-d20a-4cea-bb26-4697b77bd9fb'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@22 D4 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'8ab18371-0acc-4671-a77e-2568ab3eca53'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'8ac6c354-1b49-4e1f-b158-02c6e60c62aa'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AZ C2 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'8ad4cb01-9711-4049-b8a4-2538fa294c9f'
UPDATE dbo.BloodProduct SET RetireDate='20040901 00:00:00.000', LastUpdateDate='20091109 15:02:22.350' WHERE BloodProductGuid=N'8afcdf1c-2e92-43d4-93c6-65404c0ff748'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'8b020238-5520-471f-8fb8-7d35ab595a72'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@11 C2 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'8b10355e-bddb-46f4-aa94-3c872cc4eb9d'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AY C2 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'8b16197e-d829-45fd-8393-cd40621eca2c'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'8b164d20-190a-470a-a8a4-9b60f43f3f31'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'8b268afc-7467-4c44-8b8b-aa99521c2e7b'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 D4 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'8b78972a-586d-4b77-9676-d7daf03233fa'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'8b7f7821-fdc8-4481-8fb8-6ccb8d87d844'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'8b819f4b-0d64-4830-88a9-7d3ea3ed316f'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@22 C2 D4 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'8b943525-b704-4412-8bcf-665bcbe7a90b'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'8bab43de-8af9-408f-aa19-f1c4532bf51d'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 C2 D4 H5 N2', MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'8bb3ac49-a9dc-4f94-a907-76c591d7a860'
UPDATE dbo.BloodProduct SET MaximumStorageTime=1008, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'8bb7a081-7f27-43eb-a6f9-9e3653465ab3'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'8bb93b9c-a8ac-4940-bee4-e68fa0c4b363'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'8bba2af5-c912-4db0-b5d2-cb8ba86085bc'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 C2 D4 HA N2', MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'8bcf8e8f-c91c-4d1c-918a-739f5a61bc0b'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@22 C2 D4 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'8bd7c970-14be-43fb-8482-7edaaf49a99b'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'8be2aa26-c325-452a-b8ea-a79b6b1c580c'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'8bea2fb1-a179-4799-a5af-68be972e15b2'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'8bf0da49-b937-4ee9-bea0-3a2071e81b93'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'8c35a106-93d3-40b2-9ed5-551e8614c7fa'
UPDATE dbo.BloodProduct SET RetireDate='20040901 00:00:00.000', LastUpdateDate='20091109 15:02:22.383' WHERE BloodProductGuid=N'8c3949b3-cc55-4ccb-82d6-04e3fb759101'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@10 D4 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'8c433ec0-ad66-4b48-b85b-f8e5ac13ee34'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'8c55ca53-c1f2-4630-a151-f79e4737cadc'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'8c63cfea-8d09-4788-a4de-ef0d802e600b'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'8c697881-66cb-4010-bcaa-2e9181e13f7a'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'8c8d85e9-1913-4e8a-a2dc-0b5738e3beea'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'8cb01063-b5cf-4571-b1b3-c88be2e31743'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'8cb84262-2a32-4ddd-9e2b-61b2ed7b232e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'8cbbd037-6b91-4913-b769-2472d58ec292'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'8cc2e322-18eb-400f-b1e7-5efd4af4d40a'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'8cd7347a-7508-4f33-b258-80ac61f9b3ea'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'8cdfbde1-dc75-43a1-9dfe-d0c29ffb9d0a'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'8d12c082-6caf-494a-80be-e03b515f26bf'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'8d145ea1-64fe-4792-b1cd-5f0343315347'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 C2 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'8d277d92-486c-4962-b643-6a4fe6bc3672'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'8d324b96-3d63-4edd-994a-9b3d558dbd96'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'8d3685d7-c935-4cac-9ae8-3a0b064a4873'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'8d379270-9889-4896-b2ef-1e3403034dc8'
UPDATE dbo.BloodProduct SET ProductShortName=N'FFP AFR Thaw None LUKOPR', ProductAttributeForm=N'@AS D4 H3', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'8d3ed716-6e7e-4062-b8ed-b695b78eac97'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'8d3fdf65-dc05-40cd-b181-46d206ca23b0'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@07 C2 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'8d4c9c08-91bf-41a9-9b02-83e9da061be6'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'8d5bcc96-9c8b-476d-91e5-54b7768d024e'
UPDATE dbo.BloodProduct SET RetireDate='20090901 00:00:00.000', LastUpdateDate='20091109 15:02:22.820' WHERE BloodProductGuid=N'8d5eee64-73c2-495d-8e60-3555641d5981'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@09 D4 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'8d65082a-7816-448a-8f7f-fbbf13caeb82'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'8d672738-1803-4263-8f54-0a4a36752096'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'8d75f90a-10f6-47fe-9461-32a2687e450b'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'8d87722c-0e76-4ae1-b7e8-43da3a51e460'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'8d9aeb37-3955-40e8-8fc7-774bca4f460b'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'8da1e134-e0f7-461f-8b11-d97ed8b25e48'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'8db9f46c-8b1a-4c08-b6d8-653f105922bd'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@30 C2 I2 H6', ProductVolume=450, MaximumStorageTime=61320, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'8dbe3c2f-e640-42c4-90ce-d651bdcecd8c'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'8dd404b8-1254-4e34-8221-6d4d5d1bbcb1'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'8ddde28e-cacb-4823-900c-ebb7501bd2fb'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'8e050d4d-4df9-4e6f-8b96-eb9c6365f7a3'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'8e16a892-1285-484e-a4e8-989590e3abb0'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'8e1e7d56-cf86-4aca-bab0-2e51765530ae'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@33 C2 D4 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'8e26d3a5-e47a-479e-ad57-6d5f69f47759'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'8e39f78a-1a43-4d8c-ba4f-d1923625c9f7'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'8e4ccc9b-f6a1-4499-8346-41a491fbfda4'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'8e570e47-b30a-4e32-8bf2-a8aa4e556e97'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'8e57aba7-b879-4bc5-8434-7b8d0d57ac94'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@03 C2 D4 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'8e5c9c98-32c2-4809-8649-eb60678e13c9'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@33 C2 D4 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'8e70d2ca-f18b-4e34-9292-54a980290eed'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@10 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'8e79ed73-2848-4b5f-8fdd-0eaccd498fc1'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@20 C2 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'8e863898-8261-458a-abb0-446f2d0a778e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'8e8dad98-7341-4dc5-b1d9-ce0082eede50'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'8e93b9aa-fcc0-4e9f-9f6d-abbc885461ad'
UPDATE dbo.BloodProduct SET ProductVolume=50, MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'8ed27017-83dd-46b5-834b-9766a1c3e930'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@20 C2 D4 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'8edb89a8-9120-4bb8-beeb-64678c1b76cb'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'8ee982b3-7786-4378-a248-73b23f0362a5'
UPDATE dbo.BloodProduct SET ProductShortName=N'RBC CPD OPN PLS Red/PA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'8eed3f42-9882-4976-9456-95bd55967f35'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'8efed44d-2e44-4052-b147-bcdd7130863c'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'8f0209d3-021a-47ed-bfe1-d8cfe8d1c5b2'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@03 C2 D4 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'8f08ba53-cb3c-4098-a2c1-cfd79e850bb8'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'8f11992d-0771-4668-91b4-967ddf4ababa'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'8f3fff60-5736-405b-a55e-3582b7f42f06'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AY D4 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'8f44c22f-1465-4b9a-af8c-6a82573ea82a'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@84 C2 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'8f4f11a7-3b28-4e44-8bc1-1bafac98f45f'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'8f5057fa-d75a-48c1-846e-de0ac3422b62'
UPDATE dbo.BloodProduct SET ProductName=N'Washed Apheresis PLATELETS|None/XX/20-24C|Open|ResLeu:<1log6|2nd container', LastUpdateDate='20091109 15:02:22.773' WHERE BloodProductGuid=N'8f613485-fbbf-4c32-8104-fbbfe58f1487'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'8f64c387-bc6c-4b9d-ae10-05cb45a39811'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@84 I2 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'8f6c3c1e-bda5-452b-b25d-8ecc9d3bca46'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'8f883679-5910-44ac-ac68-ff78a579722d'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@B7 B2 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'8f924e4f-6269-4e3a-af99-deed9bf0a9b8'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'8f979d8e-acd1-4bd5-a551-ea69f3c34f82'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@18 C2 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'8fb04e98-71ff-41bd-80aa-387781fd97cf'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@33 D4 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'8fba04ac-be70-4b3b-8092-6d16ac30861e'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@11 HC', LastUpdateDate='20100210 13:55:15.970', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'8fc0d17a-8846-4676-b18b-8a6972ac142a'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'8fc4f1d4-72ad-4c86-b808-b9f263a91666'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'8fc830c8-3f61-4967-99e9-8192195668a6'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'8fcc100d-48dc-4bbe-8a23-dee5464884a4'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'8fe43139-884a-4f02-bbe8-659031eee575'
UPDATE dbo.BloodProduct SET ProductShortName=N'RBC CPDA-1 OPN LUKOPR PLS Red/PA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'8fe79f5c-b6aa-4af0-beb7-3074d1ac3658'
UPDATE dbo.BloodProduct SET ProductVolume=500, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'9004481f-fe03-44d0-83a7-5caf03257da6'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@07 C2 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'901bf8a6-2656-4967-8bcb-35d99d46fec5'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'903dab46-afb5-451f-8b7d-4b560f468964'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'90410b59-fe4f-4426-ae9f-d26bbbbf1e26'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'905685fb-a9b7-461a-a17f-6f47b0d8a34b'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'90695fb2-92bf-4c34-b724-91e13a0ea4f5'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@33 C2 D4 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'906c24c9-4f25-4ca3-bab0-10d8f17301f8'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'906f9336-0d90-47c9-b649-5553f96b8b8c'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 C2 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'908a0eef-1936-4f15-84b3-d405dcbc7935'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'90bf97f7-db06-417a-8acd-5da19f3933e6'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AZ H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'90cfed04-dc75-492d-8a06-3f39b03d9897'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'90edf8f5-3676-4a33-ab62-72c58da4550d'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'9103069a-7bab-4a61-bc3a-255b2fa271db'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@20 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'9103e352-36d2-4caa-b7f1-4b929cbec640'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'91305cd2-6405-490a-a6ad-43c999a7ad36'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'9149b1ec-28c1-4ef2-b529-efda65792b1e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'915e71fd-048b-444c-b996-26448e2d7f04'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'918c143a-f27d-43b8-9e3a-80c01a1845af'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@33 C2 D4 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'918e7cf5-4c1a-4c6c-b51b-0bf14da833b2'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'918e8c7c-210d-41f1-96f5-fe380e1a3890'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'919231bd-803a-43c8-854f-0dbc0491a537'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@10 D4 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'91a0996a-00a3-4c36-a8ed-9aeb06b71bf9'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'91a310d3-b3e3-4e42-ba5c-c9ddf34b94cd'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AZ D4 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'91c53f8c-bec7-4588-b1dd-fc1b2f445caa'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'91e2e159-a1ed-4842-bf26-03c675c282db'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'91f7566e-158c-4bb9-950d-bfe144e62a55'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'91f8e285-9bcc-450d-9540-a0a708fc7434'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 C2 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'92055ade-7dee-4733-bd51-565fba08691b'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'9208221c-ad4e-48af-b6d0-f56be6744a3f'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'9216d1b6-9168-4295-8ae8-53001042d772'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'9239761e-b195-4d88-a660-b2446e4464fa'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'9248b600-46eb-4895-a980-56d68a13f0ed'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@03 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'925cf063-f890-4b38-9113-215b216fd063'
UPDATE dbo.BloodProduct SET RetireDate='20040901 00:00:00.000', LastUpdateDate='20091109 15:02:22.367' WHERE BloodProductGuid=N'9262bcef-0f4d-43fe-a881-4ae5723b6843'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 D4 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'927a88d7-abab-4686-abc5-87b4c9ee7e9e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'92be95a6-6954-428b-af6a-ae705c8d73f1'
UPDATE dbo.BloodProduct SET ProductShortName=N'RBC Deg None IRD', ProductAttributeForm=N'@AS C2 HC', LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'92c66188-2321-4fea-b1fd-34b56ef1d11c'
UPDATE dbo.BloodProduct SET RetireDate='20081103 00:00:00.000', LastUpdateDate='20091109 15:02:22.430' WHERE BloodProductGuid=N'92c78ab6-75ec-4ff1-87ca-5ef62a30bfc1'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'92f7c668-a684-45f1-909a-520ad32310d7'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@84 C2 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'934809f7-6287-4184-8b91-60e531dc7617'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@33 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'93547e7b-18b5-4c18-988f-a69ac40bde73'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 C2 D4 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'935c2053-db64-4e6b-89ba-709f09ea8602'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'935ef03c-c766-4394-b798-5c18eafb4de0'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'936529d7-ca77-4921-be9e-5395e9847aa1'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 D4 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'9374afed-ef7b-45bf-9cb5-5e582a19b1ff'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'938d64d3-5722-49f4-947b-b8952fee632b'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'939235aa-ca38-47bb-8b99-94f6cee68e7e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'93b15a57-4965-4224-ac32-60fb5ac97ac2'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@B7 B2 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'93bcc7ec-5883-4540-bbfb-60c3e53f070a'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'93cc2b45-eedf-45b4-bcb0-0a0e7755f359'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'93d34fb2-20b3-4426-926a-1e6c1fd9abc6'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'93d5c8ca-2904-45ab-b880-8d7aad71050e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'93f65cfa-c3d9-4708-ade6-52ad26a0a54e'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 C2 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'93fbcb12-6774-4f8c-8ba7-ef8a68f1ebc9'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'93fd945a-9f55-4739-8b10-f0e872a382fb'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@84 C2 I2 HB', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'94180fbf-6a1c-4d54-9bbb-33a04a1e3c1d'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'941d5d12-35cc-4649-80c5-c80375403760'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'9420c4c8-5157-43cf-acab-4703c917731a'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'9438cadc-c861-4c12-8ed3-6ab453f1892d'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'943f3f56-12cf-4e84-8dfc-e31c8fec84d1'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@33 C2 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'945456f4-7b00-487f-bd27-4d4047828e90'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'9460d0b8-6bad-4b35-b353-1bf144aa60cb'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS A3 H1', LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'948c0fbf-011b-42db-b7df-0c40a9ff626d'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 D4 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'9495e71d-7856-454b-853b-20741aeb9031'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'949707f4-5aa5-4106-af24-797ff919bb57'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'94aa1381-4c78-47b8-8c6b-817d5b776c19'
UPDATE dbo.BloodProduct SET ProductShortName=N'FFP AFR None', ProductAttributeForm=N'@84 H6', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'94b4e32f-60a4-4790-82f2-f309848a0fcb'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'94d0f304-ef26-409b-a54d-2d8eb001f112'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'94d5dce2-5070-41e8-a89c-5da8ffd381bf'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'94d9fad5-ed91-433f-8026-8fce7c56c6c7'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'94e5017a-0eb6-4895-a63a-b45e25b0a12d'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@B7 B2 D4 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'94f01caf-e72d-4055-81a8-38a6cdba2db5'
UPDATE dbo.BloodProduct SET ProductShortName=N'RBC Deg None', ProductAttributeForm=N'@AS H6', LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'94f709f3-f00e-4a07-9f53-4f4d450f548c'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@03 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'9519b87a-48d7-48e8-860b-a4f3b870d754'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@10 C2 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'9533a4ac-e469-4291-ae00-819b0fac5ee8'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 C2 D4 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'9537c485-e720-48bc-b569-61e453e2f635'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@84 C2 I2 HA', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'953c4b00-08a5-48ca-b4c7-947b6effb3a9'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'95449a46-02a6-413c-87c5-6e12844f51b4'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'954a8a91-11cd-4964-9d2f-8d0db8a0c281'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@84 I2 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'955db0a2-e3ed-448a-b82a-d42df7b648e7'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@84 G7 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'95776ada-4ce9-4f95-bdf8-c043ab1d456f'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@11 C2 D4 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'958d423e-3d30-4738-9ed8-103a68bf0869'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'959dced3-1ee3-4c24-ae44-426b332e984a'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@03 D4 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'95a50161-0365-485c-b9b9-b8a3f1ab3131'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'95aed581-00f2-469b-93b0-02490867afe2'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'95b159a0-9d49-427f-8a17-2b1174573d8f'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'95b714d7-3cb2-4a00-940c-58dc93c59c9c'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'95d83ba1-0f6f-41ab-bdaf-5b730a38be62'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@11 C2 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'95e824d8-6f6f-4366-a662-877695f5008a'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'95f8d1a3-da3c-4534-a4cd-5148097e61d8'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 C2 D4 HB N2', MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'9617d91c-db5f-49aa-83c9-035d1f74598e'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@33 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'96200b16-ea21-4733-8139-f06673073460'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AY C2 D4 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'96251366-9935-46d1-b8b7-cf9331d9dea4'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'9631e952-bfdb-4c35-ab6e-e4bc33ecac78'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'964db408-c95d-4589-b021-ed68b2f2cf63'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'966c7134-76a0-4ca6-a9f6-915d6ff68712'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'967aba28-cfd9-4665-989a-6d1554b45cb8'
UPDATE dbo.BloodProduct SET ProductVolume=100, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'967b1618-d5e9-44b5-a1c8-889b01ad0be6'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'9693f210-df95-4bfc-8f9d-70c2c3950ce9'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'96f941a9-2f15-404b-b2c8-db6b0a7737f8'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@11 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'970d656e-0f5d-4b55-a860-8d6d1447838e'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@B7 B2 D4 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'974b5916-1344-4aa0-9ec9-6244486a6621'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'977cf507-1d25-49c0-8a00-42fb7b63dde6'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'979214f5-4021-4500-9876-d7caa1951d17'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@10 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'979ec52e-e126-430a-88e2-8d5644c2aa53'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@10 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'979ed533-53e3-4e1a-8874-56000fef8f81'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'97a75c0b-e5c4-4490-83f6-14c49c235b8d'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'97b4c180-5631-4bd9-abf7-1b7069283c4f'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@30 C2 D2 H6', ProductVolume=450, MaximumStorageTime=61320, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'97d6b1f4-13d4-4e0d-bcc9-71bb000f9d3f'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'97dc12df-d8f9-4801-bdd2-b88605b9dc3f'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 C2 D4 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'97e7c70f-703f-4eee-85da-06d914d0dd7d'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'97f4d9dc-af46-4a28-9aa5-6b23c737a8c8'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'97f7ea03-14f6-4284-8170-07b7e403b39c'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'98074582-7f6e-4d6e-8651-6f0808b7f19e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'981350bd-20d9-46ed-ad43-e2d13d57e0d2'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'9823b601-4b21-45d1-9778-480252d64a6f'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'9857f2fe-a82f-43e9-8dab-770bc9fa6807'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 C2 D4 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'985c9e5d-eebb-4215-9229-e6aaeb425508'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@B7 B2 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'98655776-78dc-4410-817d-d5fcb28536f9'
UPDATE dbo.BloodProduct SET MaximumStorageTime=672, RetireDate='20080301 00:00:00.000', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'986acafd-7752-449e-bb55-3414814c9dea'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'9881ce9f-deea-4230-9a50-d5421f30bd81'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@09 C2 D4 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'988b877c-1e41-4475-83aa-b5eaee1f0977'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'988f5d19-9653-4441-ad5f-88b2ddfcfea1'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'989850f1-1e80-4dda-962d-28bf10991765'
UPDATE dbo.BloodProduct SET RetireDate='20090901 00:00:00.000', LastUpdateDate='20091109 15:02:22.680' WHERE BloodProductGuid=N'98a34bb6-cac0-4909-99ed-b7daf448cb8f'
UPDATE dbo.BloodProduct SET MaximumStorageTime=624, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'98aa4c0d-ae10-4faa-8527-6ef1b7df179c'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@33 D4 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'98b37b66-973a-4067-a290-a98f481710df'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@84 C2 I2 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'98b5f42b-f98a-45d4-b183-427ea0b7c12a'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@54 D4 H9', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'98c5b914-6c23-4c51-b6bd-2ce47a9866bf'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'99479587-569f-433a-bb69-e05e45b2a84d'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 C2 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'99481d45-b322-4243-b37c-3b4dd4a1f415'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'994b5a64-d58c-414b-8685-e0bdbbb20bc8'
UPDATE dbo.BloodProduct SET ProductShortName=N'FFP AFR Thaw None IRD LUKOPR', ProductAttributeForm=N'@AS C2 D2 H9', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'995e9d39-8ecf-40fd-b58f-af62d2d62439'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@B7 B2 D4 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'9964485f-e9f4-4768-9e61-4ebffb63a4d0'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'99845bcc-fbca-4b2a-86e6-e793174c3538'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'99852735-1003-4b6a-bdae-7a4ec3329171'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'99a97941-6827-486d-ad7f-103d9ab49c82'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@B7 B2 C2 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'99c35b3f-bab0-4089-8de0-f1beaa9b1ffe'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'99cfe380-15f2-4a58-90bc-50fa69aa594e'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@07 HA', LastUpdateDate='20100210 13:55:15.970', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'99deaa37-ddff-4101-b206-6df1228aa62e'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@33 D4 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'99ff5ca3-93df-40bb-9384-00b0e1d0cca9'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@03 C2 D4 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'9a254b3c-12ed-4fdb-b7c9-2f96711c71ab'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'9a4a60d9-07c6-46d3-bde7-445e7d8b6dd4'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@30 C2 I2 HB', ProductVolume=450, MaximumStorageTime=61320, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'9a4ed130-eabf-4465-a52a-63a9035dcba2'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'9a6076f5-0864-4c9f-83d9-e624d92c86e7'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'9a68603f-c40e-4bd9-a441-bbde9236dea8'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'9a930be0-1e0f-4784-bc70-ca8bf9b18560'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'9aadc3f7-9470-43d7-8008-01e276d269ad'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'9ab6fc5c-196f-412a-b2c4-36b95b0d648c'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@30 I2 HC', ProductVolume=450, MaximumStorageTime=61320, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'9ad82e85-4693-424a-80b1-bbfcb1723489'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'9ae0955f-c932-4bda-bda3-67b2c4a2ff4f'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@30 C2 I2 H5', ProductVolume=450, MaximumStorageTime=61320, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'9ae472d5-7c43-4f2b-b786-e3d42f2d3e57'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'9af92869-3c6e-4c9c-9ce8-2d8194a2a642'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@B7 B2 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'9b0237ac-f4a4-473b-bec0-d0c256f4bee9'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'9b128339-aae1-4f12-816e-7e55a098e449'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'9b1a2408-ecae-44ff-b478-4a7861e835d0'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'9b5bbc23-71df-4736-bb9a-256bc1a4c27e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'9b5c0f3a-1682-4466-81eb-03f4faeb65ff'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'9b713d38-7da8-4761-b975-4e81b47336f7'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'9b77e22d-dd82-4fe3-a836-511ff8c91805'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'9b7980f2-db9f-4519-b928-25a5d00f810e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'9b79f44f-f6b8-4ab2-b5ca-070a40e28bda'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@10 C2 D4 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'9baa87d3-e38c-4cdb-873c-9eb3fccd6711'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'9bbfade5-2343-46fa-8c6d-a5d634c850fe'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'9bd2b6b3-53f5-4892-97ac-e35bd7cbe6a0'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'9be15b29-5e61-4734-9bf6-ab7955ea0a6b'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@84 G7 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'9be9b8ca-4287-4edc-b785-ef29d8d8ea8f'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'9bf47bdd-fe65-4479-a1b1-88af27ec9dc7'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'9bf54aac-4c32-4750-83c5-adede76a988d'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'9c071df0-3f34-49b8-a53a-9ea001cc7e84'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'9c0b9411-27c7-4133-8746-d66f9238a1ed'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@11 C2 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'9c1bc5d7-47f6-49fa-ba26-2bea941b99bf'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 C2 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'9c26a686-b0ad-4050-8aa5-2e78a442ab84'
UPDATE dbo.BloodProduct SET ProductVolume=50, MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'9c2dc98d-539b-472a-a329-6599b09f71aa'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'9c5f1fc5-81b0-45f8-a2a0-834fe8e6e1f7'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'9c8a09c8-ca07-4e3e-b1d2-554f50aeac2c'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'9ca011d7-a07f-4b13-9002-cf28f9ebfb39'
UPDATE dbo.BloodProduct SET ProductVolume=350, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'9ca53666-4990-4e61-ac24-3f6bb7d48087'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'9cb0284e-c372-41a7-b593-2486dbe485b8'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'9cb6a610-9867-467e-a573-50f6e55f3f0c'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'9ccfbfb6-3dc4-4370-b2eb-50ab7224756a'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AY C2 D4 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'9cd9c59f-5670-4e73-958f-fa6a8997923e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'9cddd0b8-64a4-450e-9ee0-2f77e29361e2'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@22 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'9d0d3642-ae4c-476d-a011-41ab9e8aa15e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'9d1275a9-38ba-4a3b-b79a-789513e6e24e'
UPDATE dbo.BloodProduct SET MaximumStorageTime=4, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'9d319603-d2c0-4f92-8285-efe9e52cc15f'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'9d3bf5c1-d4d6-44a8-ac83-9d998c8a07c8'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@07 C2 D4 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'9d485335-b2e0-4e4a-b9b6-28770fe8e8c3'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'9d4e98c4-6e1f-4573-a0f2-7ca9306c4a7c'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'9d539fb4-2219-469c-b3cd-808e7858c30c'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 D4 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'9d66a32c-a5ce-4b16-b674-0ba7e3caaca1'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'9d6ecc1c-7070-4667-858b-ac99fa3287d3'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'9d7544a4-430b-4d85-aeaa-d183633ed839'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'9d79fbfd-71ce-4035-ba6e-b063cbbdf694'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'9d802b6c-d731-45b7-8c48-7ebcd845c955'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@22 D4 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'9d902379-4d73-43a4-8f8f-32e1467b73e4'
UPDATE dbo.BloodProduct SET MaximumStorageTime=1008, RetireDate='20080301 00:00:00.000', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'9d9c1371-66b3-48ec-81b9-a2a51377d50b'
UPDATE dbo.BloodProduct SET ProductVolume=50, MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'9da8aef9-e31d-4421-9eee-e2da3cef5ad0'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'9dad85e8-8ba9-4f04-97e3-bfa6ce00e9ec'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'9db82812-a402-40fd-aec8-dd8f1e7ccfbb'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@84 I2 H4', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'9dc632dd-5e31-43b0-8d3b-00dbaee14a9c'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'9dddd102-15f8-476d-b8cb-08ec2553eb9a'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'9de862c0-f0f0-45d3-b863-ec969edfee11'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'9df5c84c-31c1-4722-aba9-7198f3fdb009'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'9dfa676b-25df-4bd5-b67c-0d24c5c7a0b9'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'9dfab409-dab1-419f-961e-9e15f91c51c8'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'9dfedf29-c325-44f9-b862-97b847d75045'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@84 I2 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'9e02b84d-d628-4d13-8f6c-6583a6912eb0'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'9e0339f4-2c0e-4b6d-a0ad-9ee1ce965d7c'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 C2 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'9e1fcfc7-fadf-45a8-9411-651dffdc1867'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@11 C2 D4 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'9e33298e-2b3c-4e41-84a2-d392375f3168'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'9e33b9b5-d90f-4397-bf0d-c4990e04b97b'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'9e4371a9-2be4-404c-8bb8-35382de0df34'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'9e5fc2e0-d191-42b6-9937-844891e75bcf'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'9e668c35-b765-4018-9c0b-d5361a55746a'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'9e837dac-a0cc-4e93-a5ab-bb2d6780ed41'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'9ea757a5-6cb5-420f-ae53-babd76887b0a'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'9eadd300-400a-41cf-9b2c-08192148a177'
UPDATE dbo.BloodProduct SET MaximumStorageTime=840, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'9eaff252-e9b3-4a69-8088-2948864c8e38'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'9edca461-c907-44c8-bf6e-b72d2f2d4318'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'9ee201d2-76b5-4c78-bf23-7d65ee73c586'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'9ee39617-b86d-41f5-a223-e725d341cd90'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'9ef3d17f-689b-4378-9e5c-ca8c93d78570'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'9ef74e2b-d608-4c41-b6c5-fafeaa43cd4a'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'9f0cbe2e-c588-4773-b92f-cb10ee3af8f4'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'9f3582b0-e6d2-4d6a-9e1e-01fdd0254240'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'9f41e79b-760d-440d-b1a6-6b0f2dc155b6'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'9f434205-a023-466f-ae9a-f90b26b72dcd'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AZ D4 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'9f5eea0e-604c-485f-9a15-1832c93c516e'
UPDATE dbo.BloodProduct SET ProductShortName=N'RBC Deg None LUKOPR', ProductAttributeForm=N'@AS D4 H9', LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'9f80e863-96e3-4a8d-956f-80ad9cfc992a'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'9f8a1d07-d385-4731-bd14-962d760af1cc'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@30 C2 I2 H4', ProductVolume=450, MaximumStorageTime=61320, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'9f92e55c-ab26-4d02-93a0-6e22fa90bee0'
UPDATE dbo.BloodProduct SET MaximumStorageTime=61320, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'9fa24d9f-2623-488c-9eac-66fc43471f92'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'9fa9dc40-de0e-4cb2-be24-feabe304bbe6'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'9fcd2123-36d9-48bf-8b7c-896a8f47fc86'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'9fd14dec-b64b-46a2-a32a-482c63e16c05'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'9fe241f6-deb8-4a1f-bcfa-c09c3f8967eb'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@84 I2 H6', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'9ff79d07-ef3d-411f-a2f4-2601f7e09cae'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'9ffab403-70c0-48f9-a16a-8be5be4c8b0f'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@84 D4 H9', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a00acc09-60a8-477e-94c0-b100b84ee11c'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a01e4621-deb6-4fbc-8818-f3dabd252324'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@09 C2 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'a0200b4a-749d-4779-a080-b49bb36e4806'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a04b365c-3839-4d58-848b-27bdcdf052ed'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a04b7569-3b2b-4ce9-89a3-56865842f376'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 C2 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'a057d45f-c710-4f27-8239-19557f2a60ba'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@84 C2 I2 H3', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a06e3d0d-d709-49f3-b606-99c8b3c8ebfc'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@07 C2 D4 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'a075978c-f7c1-4551-85d5-7116fe3f896e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a087a7cb-d251-4f2c-98e9-17a52456f946'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@09 D4 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'a092c50f-481e-451e-ac52-3f1e0de9c4d8'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a09b8886-2998-4d26-ae48-e4751a12991d'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@09 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'a0ac0f8a-bbf2-46ad-9015-829bb6073a53'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@B7 B2 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'a0b2e420-2f70-4905-bb83-b0c24a9dd719'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@11 D4 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'a0d25c8d-13be-47ee-a65c-aa7601295610'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@09 D4 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'a0e50d45-9be3-46c2-9c65-a56da5260978'
UPDATE dbo.BloodProduct SET MaximumStorageTime=840, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a0f71c09-fe1a-4d4a-84d8-3c9ca74bea85'
UPDATE dbo.BloodProduct SET ProductVolume=50, MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'a0f8481b-5462-4251-b796-894b2138f7a5'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a100aeb0-3148-432e-bb0e-cdbbef8e62bd'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 D4 HA N2', MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'a10f09f5-d707-493b-8564-b28a60d4f298'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a1163a24-e68c-49aa-a98f-5c4ab7c89f81'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 C2 D4 HC N2', MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'a127d38f-0cf7-4af6-af60-34e612b8a9c5'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a12c7783-c328-4e86-907b-35698d68f7a9'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 D4 HC N2', MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'a12e2d39-0650-4aa5-980d-dba62bb3e680'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a14c23f5-351a-4c22-9100-585719f0fa25'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a16fac51-4cec-4375-82a5-8440c3fc53a3'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a17015c4-2722-4284-a9d6-b6e4a328feb4'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a1b2feaa-701a-48e5-8457-bf5e6a1d4d41'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a1bb087c-de1c-4b7d-aac5-d2bbcc965c7b'
UPDATE dbo.BloodProduct SET MaximumStorageTime=1008, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'a1dcacad-d8f3-455c-9d5e-67635df32dda'
UPDATE dbo.BloodProduct SET MaximumStorageTime=1008, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'a207a144-511d-4e39-bad8-fb38a16ca035'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a2235eac-7e29-49eb-956a-1005b1fdf1d1'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a23c273d-8d93-4d34-be1b-2ed40203f2f2'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 C2 D4 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'a2436f48-9d46-4170-96d9-7a29aa28ad72'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 C2 D4 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'a255215c-c1bb-4c04-b762-cf9a208148c4'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a2674b63-47b7-40f6-bbc8-0002da6666d3'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'a2703045-3f9c-4f3d-ac98-fd58bd4634f0'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@30 H6', MaximumStorageTime=61320, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a2703f75-6b25-4719-9b3a-cc6aedb017c4'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@07 C2 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'a2aa3cc8-9169-4381-96f0-9147503840f5'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a2b8db14-1332-4b20-aebf-5bd744328863'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@84 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'a2cc3f88-b18b-4af3-929b-de21259af649'
UPDATE dbo.BloodProduct SET ProductShortName=N'FFP AFR Thaw None IRD LUKOPR', ProductAttributeForm=N'@AS C2 D2 H3', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a2d8f3f7-2b2f-4c13-a4d2-561b08382e77'
UPDATE dbo.BloodProduct SET ProductVolume=50, MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'a2e1d817-1f28-4866-83ed-bc8b82df6945'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@22 C2 D4 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'a2fffa5b-9892-4af4-b279-a0194b2a1477'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'a3133975-6f36-47ad-a325-d66200c9708f'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'a316ec7a-d813-4c46-adba-16041a3b31c6'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@11 D4 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'a32863cf-561d-4cf5-80ef-106495705deb'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a3292720-b3ae-433f-9313-e0620c4b3fc5'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@84 C2 H3', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a349ce5d-fe75-45c1-b0f5-114900edc81f'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a34c97dc-13d1-43c6-b9bd-4f6f0c70a67e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a3647f4f-4e1f-446e-997d-640d82b423d7'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a36e9f5e-b3a7-4d65-85e6-6c997146c2c6'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a370385d-8c46-45f5-b126-60ebce0d8070'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a38a928d-6334-4b74-a471-928c033e7c59'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a3cb5855-38be-4788-85b2-bbb1813c8e88'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a3d85968-3e29-4639-b8c9-3aeab481e94a'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a3d8e580-f20d-4ac9-9612-1742b75cb68a'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a3e3182d-a92a-465d-9a08-dbf6360c7776'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a403547f-b794-4d28-9550-a44ddf0a2181'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a408e2cd-0680-409e-a7d0-6c13218cbe3b'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a40de53f-aa71-4beb-ae4c-4a9b8cf93e66'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a42517e5-472b-433e-ac76-93f2e8e51fad'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@84 D4 H5', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a42df799-cf2d-4259-b4fb-bd271f2469c4'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a42f4033-3ec4-4689-8fb1-b070c15fcb63'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a440d79d-0b18-42bd-a1ae-c15fec6851f6'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'a46f9607-2d8b-4093-ad88-4cf3eb4db398'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a47c8e52-836b-4fce-94eb-b67be1c1dcbf'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a47ea0f9-9b73-4b02-9784-6ad15084e88c'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a48acd4e-49bb-4294-98a1-9676ee64c106'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'a48d74c5-6733-461c-9aa1-b152c7f46a21'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a4943235-b365-4ff4-93af-17df9bb4ac21'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AY D4 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'a4a1dc83-b265-420e-848a-a69983c2754f'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'a4d06c13-b689-4847-b05c-0dc52cee60dd'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a4d8d215-1a39-4a34-b837-b9ed59118b9d'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a4e08046-7849-49e8-aaff-837787537b83'
UPDATE dbo.BloodProduct SET ProductVolume=50, MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'a4e16531-890d-469c-8d3e-9af73419a0f1'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a4e67db1-17ab-4908-babf-1ab1460820d8'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@07 C2 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'a4f20256-7fb5-4ff6-8064-778e0f80dec0'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a500aa10-b727-4167-a0c9-f5d825f6b5f9'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AY C2 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'a513bf8d-380e-431c-89e0-13dfdf4d0371'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a53d9aa1-a9ba-4f94-9e5a-6abf388c7c17'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a5467b61-30df-41e6-a1cd-346c476b506c'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 D4 H9 N2', MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'a5595b64-424b-486e-996e-43959707730e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a58538d4-75b3-4ea8-85cc-7faa7252c54a'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'a593ef26-a8ca-40a0-8ee7-4d15fca4eb49'
UPDATE dbo.BloodProduct SET ProductShortName=N'FFP AFR Thaw None LUKOPR', ProductAttributeForm=N'@AS D4 HA', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a594a1f4-5539-402b-88a9-1a04c7f3e0a9'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a5f9f5ac-6fd8-439e-a18d-8cd22fbe3671'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'a60235fc-d7d2-4d2c-a4c9-1c29a3b755a4'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'a60f91ba-94bf-44ea-bb1e-23df55d84d42'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'a624e1f1-1d6e-44c4-9c15-5b33fbabbf55'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a64ba3d6-35be-4308-92b6-65fbd8e2c449'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AY C2 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'a650709f-8e81-4c01-a8fb-9b240768a8d9'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a663ce07-07f5-49e6-be7c-fca61c273b01'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'a6689c39-02a8-4078-92ef-2b249b163f35'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a669b3ed-d55e-41e4-80f9-468d6d65e499'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a6c61e01-6d38-40c5-ab26-5e7c7a1674c7'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a6db0b48-eacc-4278-9256-cfb6a22debf9'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a6ea87ca-8ac7-4405-90bd-6478468e30b2'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a6f23d0d-085b-4489-a37e-8c7799ea38e4'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a6f28004-4088-4f75-b754-98539779b170'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a70f4723-127c-4f7f-be82-e476d0716a5b'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@84 C2 HC', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a70f6c27-2463-4ac3-a6a7-f5db97a21626'
UPDATE dbo.BloodProduct SET ProductVolume=350, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'a738b202-ad58-4f08-9e7a-0c3c1af2946b'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a739e42f-fb25-4f46-b126-87212de92df1'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a74790e1-f212-4253-b61d-5165a8437f12'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a7511d52-8ca4-44a3-ba23-d0901971bee9'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AY C2 D4 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'a7512ce3-63aa-4b9f-a38c-258048f46d1a'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a759992c-9eee-44c8-813b-3d34487dd86d'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a769c1a0-38b8-4449-a7fc-05a4cebf69e5'
UPDATE dbo.BloodProduct SET MaximumStorageTime=840, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a78870a7-44c8-4793-9363-3a0225997a9c'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS C2 H4', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a78b56f5-06a8-4b5a-9c14-e5de0d8309bf'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@03 D4 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'a78c6048-3113-4d75-af2a-31bd7a4f2235'
UPDATE dbo.BloodProduct SET ProductVolume=50, MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'a7974a8b-f3a2-41bb-9025-3d197c1c070c'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a7b9668e-28de-48e6-b439-f0af63f4661c'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a7b9be7c-e284-428b-9bfe-19e7db69ed2f'
UPDATE dbo.BloodProduct SET MaximumStorageTime=1008, RetireDate='20080301 00:00:00.000', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'a7c28ed5-92ee-4821-ac89-1f88afce2bbb'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a7f8a12d-2750-4a81-a244-fa19d2e9131a'
UPDATE dbo.BloodProduct SET MaximumStorageTime=1008, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'a7f90895-4102-4874-a211-295fb09146ea'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a7fa67b9-028a-4092-a23e-27f91b7efe19'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a804056d-fbc1-49ca-9323-537f6449bb96'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a8094b24-edbc-4ec5-92bc-cca92965bf47'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a80dc102-93c0-4384-a54b-caaa495d6807'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a81e3021-2615-4624-860e-47c064c28fd0'
UPDATE dbo.BloodProduct SET MaximumStorageTime=1008, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'a8294b90-b042-4820-abf3-b4c715ea4161'
UPDATE dbo.BloodProduct SET ProductVolume=350, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'a879a7b6-4eca-4624-87e7-8fa3cdb94826'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a87e4962-ede5-48a3-af9d-bc36bcca2a8f'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 C2 D4 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'a87f75a1-1366-4d15-915e-2b4fc2bb0540'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a8883ce8-8c1e-41d1-9a07-d52a8cf07ab7'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a89694b4-7b1f-472f-9820-b094d5fd37ec'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'a8ba147a-c157-4da4-87ec-c58c9ca998cd'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a8e07af5-e945-4172-97c9-14af3a4da37b'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a909ce04-7677-4f85-96bb-e611e67a845a'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'a912ecf2-0c1d-429b-b038-4e71a095b720'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a914944d-5bbb-42f3-a5e7-9d3ac6e22f57'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a915b863-7606-4e1e-b692-efad7f73dd8f'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a927183f-7510-4fc1-9c0b-22c8e58b4a0b'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@09 C2 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'a92c41b4-3622-42fd-95a0-2ce010d99dc9'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'a93ea18b-ce7f-495d-98fb-b2287090330c'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'a944999b-f4ef-41d8-b3d8-d9a0a89f4a82'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a95127fb-cb35-49cd-af69-88fcd3743a62'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a95c7ef5-ccdf-4c65-9476-51c27c37ad82'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'a9793f19-6199-4e90-8cb2-8237342cb586'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a98084b2-7565-45c7-993b-4bdf057d997f'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@07 C2 D4 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'a989cf90-d5c9-4ef8-9efc-3dea602c25f6'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a9989c07-f190-4cc5-9aca-097da3b13f2e'
UPDATE dbo.BloodProduct SET MaximumStorageTime=624, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a99cfb53-5ef8-46ce-9e00-a4d7e0d7fb9d'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@09 C2 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'a9aec0f1-d128-4b0a-9b97-23873e08d8f2'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@33 C2 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'a9b0df40-6604-4a5d-b8b1-45b6ac2f13b2'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a9bf7aab-a275-4810-840c-be5534f00592'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a9c255c8-ee9c-49e8-95ad-3918895b4b2d'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a9c363a7-b814-4cd6-b41b-1fd70860c7ed'
UPDATE dbo.BloodProduct SET MaximumStorageTime=61320, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'a9f7ab04-4b6e-4537-aedf-8c0f7365c937'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@10 C2 D4 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'aa03c396-8f75-450f-8ddf-8dd1668f886f'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'aa0be3e6-71c7-4069-aa6d-2674a517af89'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'aa0c86ca-56b5-4083-a0a0-f082e6590cee'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@33 D4 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'aa110c06-a428-4424-bc4d-96b39b2f7c8b'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'aa16983b-4f01-4b68-8ce5-81dc60fb69f5'
UPDATE dbo.BloodProduct SET RetireDate='20090901 00:00:00.000', LastUpdateDate='20091109 15:02:22.710' WHERE BloodProductGuid=N'aa281147-d8e1-4169-b3e9-10a4403c8a91'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'aa2b73ad-c83e-4777-ae28-90b9c09a9541'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'aa513a64-48f2-4202-b441-6ec31f9dfe91'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AZ C2 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'aa671965-58d4-4742-a414-69b7b8e0dd60'
UPDATE dbo.BloodProduct SET RetireDate='20030901 00:00:00.000', LastUpdateDate='20091109 15:02:22.303' WHERE BloodProductGuid=N'aa90a7bf-20bb-418e-88e2-2d5d89003e9f'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'aa975df1-b998-46a0-a6a6-e96e44f4839b'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'aa9c94bb-5caf-4c40-92b8-f998442a50f1'
UPDATE dbo.BloodProduct SET MaximumStorageTime=1008, RetireDate='20080301 00:00:00.000', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'aaa1aae0-88df-4601-a1a7-a5a0eb08d452'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 C2 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'aac3b917-0a53-465c-bf83-ffd5a2f27f42'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'ab10af18-fa18-4fbd-969c-78c7c90d2007'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'ab2b6622-b500-46b0-92e4-b031fc595927'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'ab2deef9-6c4b-40a5-bca6-878738401ebd'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 D4 HC N2', MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'ab57e1f3-71c7-4b11-a085-41223576f344'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'aba6a992-60f5-45fb-b043-909d5b270e24'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'abb473d9-b9c9-4730-93d1-e0d134a71389'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'abd53cb8-10a6-4726-9879-e84bbff625a7'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'abdafdcc-521a-4519-8b08-791d29df6f3b'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'abdd0322-5759-4373-8050-f4c15cf3a41d'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AY C2 D4 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'abf4014f-d498-4429-a3bb-c9ba5cdc77b7'
UPDATE dbo.BloodProduct SET ProductShortName=N'FFP AFR None', ProductAttributeForm=N'@84 HC', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'ac1681ea-ceda-4b1a-b899-de64a6d4e66b'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'ac33e10c-685c-4e9a-9564-660c43801cb5'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'ac34fd39-7b6d-45ca-8d0d-7ecfc8dd7781'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'ac48c4da-bf05-40b5-86cf-1d2780b72cf2'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 C2 D4 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'ac4eb8cb-695b-4b76-a065-893d307d4015'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'ac53f3de-2efc-425a-a110-69ca7c31e684'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'ac826d0f-f966-447d-bf5b-2d7caff74d32'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'ac854129-d2b6-4d28-af16-a921fb86014e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'ac8f3c1c-f173-4485-880e-9795a8338a49'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@B7 B2 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'aca6eb49-309e-4a73-91db-cdbb1b1a3330'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'acbf11e7-7d78-4970-b342-dcc826881510'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'acbfef99-c430-4328-8fac-fa26ce18d9e6'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'acc30840-5056-4d81-96d6-7c856094d5fc'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 D4 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'acdb0daa-11a1-4342-bb9c-7f89ef7864b7'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'ad0700d9-b1ae-4419-b8f2-359729a92144'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'ad3a0500-a50e-434c-8be2-df27b20e9bea'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'ad3c9f70-6f5f-4e8a-a18d-25e944082390'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AY HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'ad4ce9f2-65c4-42b7-8e5c-ae0b9e30a2a3'
UPDATE dbo.BloodProduct SET RetireDate='20090901 00:00:00.000', LastUpdateDate='20091109 15:02:22.803' WHERE BloodProductGuid=N'ad798004-07cb-4eec-b75d-9747a32f92a5'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'ad9fc5a8-aa0a-4d6c-8594-d914de76476d'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'ada01b97-8a7b-48a8-9cd8-f32cade293ad'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'ade47b22-f427-4e16-800c-0e9203b5e91b'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'ade49671-430e-41b8-985e-6dc65da94cb5'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'adf10467-e74d-41f9-b5ac-5ebc705b5c08'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'adfec4d7-3ff2-4a52-ab00-98a1b058db86'
UPDATE dbo.BloodProduct SET MaximumStorageTime=672, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'ae1e3bc0-a7df-48e7-83a2-d17f5cf7e4ab'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'ae227866-0ce4-4ce8-b2af-5436cf831f9d'
UPDATE dbo.BloodProduct SET ProductVolume=450, MaximumStorageTime=4, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'ae3121f2-70a8-449f-87e0-47ecd3f0def4'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'ae457ca7-fcfc-4386-935e-f929dea40af0'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'ae66ddf4-e272-4df7-89f6-8163ec1864ff'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'ae693884-cc54-45c1-bffd-77db9b9a9a18'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'ae74547d-9dce-479b-9c13-cfdce20bb3b9'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'ae8c98c0-4252-42f4-9e7f-221919473fac'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'ae8f9cf9-4629-4ada-927d-859d77ab19c3'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'aeaf2261-351c-4b8c-8fba-84d41ef4dbb4'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@03 C2 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'aec05ec1-3c02-40b8-8e7f-3ea34e674e2a'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'aed31213-c44e-4c3a-bdf1-fde279faef09'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'af0bcdad-36c1-4ae9-87c7-422826325303'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@B7 B2 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'af3600b3-eaed-4adb-bebe-0aa8cedb7e2c'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'af39ddd1-2c38-4e69-928a-8e8457f2e580'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@30 I2 H3', ProductVolume=450, MaximumStorageTime=61320, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'af52811b-736f-4b02-bfaf-8bc3e293db33'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'af579068-9d61-49e2-9f0e-3267bcc133a5'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'af5ea588-0de5-474d-b00f-72f6f0336047'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'af6955e3-f26e-471f-b899-a41addf89088'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 D4 HA N2', MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'af72d752-0f51-424f-b90e-a2b3bdfe51be'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@33 C2 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'af76ef82-7e00-4790-887f-efdec6378367'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'af9c2eb2-5264-47d0-b5f3-fc9353d83471'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'afb8da63-4e1a-4cda-8501-7468c4887207'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'afc7de67-96b9-4104-b1c2-5fb941974b3c'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AY C2 D4 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'afd269fa-cafc-47cd-b2b1-7a3abf564701'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@09 D4 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'afd90a91-3df9-4c05-a4c4-de33c001f8b2'
UPDATE dbo.BloodProduct SET ProductName=N'Washed Apheresis PLATELETS|None/XX/20-24C|Open|ResLeu:<1log6|1st container', LastUpdateDate='20091109 15:02:22.757' WHERE BloodProductGuid=N'afea7dee-48db-4733-8573-4efe2eb10e18'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'affab2ac-cb0c-4e17-87eb-46c931209efa'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b00f3891-2e78-400b-aa59-2f70303e615b'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b02908d3-456f-464e-844d-81888e3d4b31'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b0355af3-f0cd-4118-aafa-aa02c73bc1d9'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b056c52f-205f-4822-bc65-1cd51dfb4c1b'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@33 C2 D4 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'b07a7a0b-65c9-419a-a292-4e5b93d63c47'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b07edf47-b339-47e2-8dd9-f156fd20ad19'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b08c5a34-c12b-47f2-88bd-18c9cddbc6c5'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AZ H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'b09e6012-289b-4d71-87f2-bfec6393ace1'
UPDATE dbo.BloodProduct SET MaximumStorageTime=624, LastUpdateDate='20100210 13:55:15.970', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'b0b18aa0-f321-46c7-a76d-4e847c4f8666'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 C2 D4 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'b0bedad1-90f7-46a5-99d2-d871b238dcdd'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b0ddf3e6-98d5-4559-9b64-e69ef3dd0a38'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b0f50092-f58f-4969-ac3d-79f221f46bb5'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b10d982f-8784-4079-ad81-01841e9aee32'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b1269a74-e949-4007-97ed-f4fa29806886'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b13f2da8-9ef1-47c2-aaf1-b10de698b107'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b1420b61-6f19-4d0f-8eef-4e54cb97d38c'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@84 C2 H6', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b1462fb5-16bc-486f-a3d9-92159bc8968e'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'b15a68db-ba7a-4feb-bcd8-9cd29f86c76c'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b1649f17-f670-4c3d-8f62-4579daae014c'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b166cd8c-bc24-4b29-93f2-15321f744cd7'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b16fae06-a2e1-4ad1-9e90-afebe05eaef9'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b18db563-04cc-4d00-a6fb-e7b001b4f85f'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 C2 D4 H6 N2', MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'b19df7dc-6676-48a8-afa9-7ec67dedcbee'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 C2 D4 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'b1afb387-0b54-4e56-b91e-b30c6248c662'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b1d2afed-9bd2-43d7-9398-1e92ad7d91a9'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 C2 D4 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'b1d7fc85-1c15-4acb-be22-986a32f51f50'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'b1daaca7-949c-42b0-bd21-306358a14c83'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 D4 H4 N2', MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'b1dbff09-24c2-416b-9c6c-2e990516e295'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b1f26a42-a8d3-4d6b-9a17-6c53291fafdc'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b1f9f326-0ad2-45ba-927f-ca33fd678d1b'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'b1fa65e4-3aeb-4ce6-b66d-90151aedbadd'
UPDATE dbo.BloodProduct SET ProductVolume=450, MaximumStorageTime=61320, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b22dba62-3c78-494a-aba7-dfed5e3f3f35'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@33 D4 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'b23185b7-b49c-4318-abe9-f556a4c18019'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AY D4 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'b256663e-617c-4481-ad20-cb03fa70fff3'
UPDATE dbo.BloodProduct SET ProductShortName=N'PLT AFR Wash NS IRD', ProductAttributeForm=N'@72 C2 H4 JC', LastUpdateDate='20091109 15:02:22.790' WHERE BloodProductGuid=N'b258684b-4ff6-40a4-a277-d5d692b2388c'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b2609bd1-c5f6-472f-9ed9-af20f89275d3'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b281420e-c0df-4ee6-9157-e776e093c073'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b2936ade-293b-4512-9bb5-0166b80bcc91'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@18 D4 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'b2b341b2-bbf7-42a7-942f-7a7d1734a6ab'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b2c2890a-bc58-4340-a811-878955c4e1e0'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b2c4b691-af23-4f08-94b3-c510b401663e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b2c8891d-0603-4310-a9d7-70de83441d6c'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'b2f81d57-e78c-4b54-be51-33968c969d50'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@33 C2 D4 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'b2ff2d7e-fb86-41d4-aea6-5accc974adbe'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b32cf506-a0a0-4799-9257-2cc1ed707390'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b3351a3d-a6b9-4331-857f-963e0f3ba2e9'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b342097b-a12c-43c7-8bfa-e951991486bb'
UPDATE dbo.BloodProduct SET ProductName=N'POOLED PLASMA|CPD/XX/refg|Open', MaximumStorageTime=120, LastUpdateDate='20091109 15:02:22.867' WHERE BloodProductGuid=N'b35a144b-78ff-4273-a8fe-ff75d30d8d4a'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b35aad53-6695-41cd-bdb2-77a3855b0d62'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b35f4d04-95ad-4228-a1f7-37337cf6b80b'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@09 C2 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'b360929c-0345-400d-938f-9e28d5ae2674'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AZ HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'b376d978-3059-4173-97a4-5753063d2496'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'b3823c25-de16-4bb6-900a-2de48074fe3c'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b3878283-a225-4d82-87a6-3d195aa5fcdc'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b39235ad-9e32-4382-b959-c9c630d2f46d'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b3afe139-989f-4720-a837-92417b059170'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b3b6cff8-bf3c-41f0-9dbd-a9b9ef75d484'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b3bc9249-10e5-4d9c-93a0-d240ea529b6d'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@07 D4 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'b3c0b141-c229-425f-9b1a-f3134f270b64'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@10 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'b40ee16d-1534-4123-8685-2c9cd56a2029'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b424211e-4558-451c-b2df-b2b2f7d8bfa6'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@B7 B2 D4 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'b425c93b-776c-4acf-b369-91aa551dabfe'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@84 C2 H9', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b43a6ea6-8334-4fb1-8151-61333325544a'
UPDATE dbo.BloodProduct SET ProductShortName=N'PLASMA None LowVol', ProductAttributeForm=N'@84 F3', LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b43c7f5e-148e-4f61-8f04-28c5aafcaff4'
UPDATE dbo.BloodProduct SET MaximumStorageTime=624, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'b4663c01-a0ea-429f-8136-8223754c6d35'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b470b179-07ac-479e-8b14-0e5b677f46b5'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b48282a1-8c43-4072-847f-46c7cc145a9e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b4844c4b-2186-4649-946f-908a99cf3a81'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 D4 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'b48638a8-920c-46be-a85a-fc81b877c30a'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b48a957a-0d06-4a64-816d-ccb862a92aa8'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b48fd89c-f402-4ab9-ab04-75ab5b02a345'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b492d2b5-9826-4af5-ba7d-7e09c527c43b'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 D4 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'b496dc82-c12f-4d0e-a8cd-5a450ffea0c8'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'b4bf5cbe-3ab5-469c-8594-a6f09e54c8f6'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b4ca1bcf-61ae-4ac1-aab0-b3750feee769'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b4caf7b1-98d6-49de-a53a-facac6c66218'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b4cf3e2c-c0f8-4631-9167-a9f044fa82e0'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b4e3ae0a-aac4-4870-a60f-d06bc20d5fbe'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b4e63a87-7842-4920-b4b4-408e1f7fac6e'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AZ H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'b50cea2d-a6ef-4f80-bda6-0840f6447a25'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b5148ba4-330c-450e-bdac-f71e43653665'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b53d63e2-b964-4b6a-973e-e97d0f4665b6'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@33 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'b546c144-e3ed-410f-9ec0-228db5132adc'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b5bbfd24-4b33-46e4-b140-34c4e4e4d46e'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AZ D4 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'b5c18e00-0ffa-4469-abe0-273a274a60b1'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b609b2b9-580a-4c77-8a9b-52ff13140e00'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b619330d-a128-425c-8711-555e5c0e10b5'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'b620aec8-91fc-421c-a77b-9cace8dc0695'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'b636cd06-e1df-4d17-92a8-aa4fbf01ca10'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@30 HC', MaximumStorageTime=61320, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b65103db-9ef8-4aad-b884-c468cdd2cfcb'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b6517583-e492-487c-a9fb-cab33b25161c'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b6519942-6400-45df-8c8a-df1003e287d5'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b652e23e-7d8e-4947-9f2b-69b5a05b50fd'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b6656b35-dc40-4053-96b0-0b6d2f04ff37'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@11 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'b66f3e4d-81ac-49bd-8cf4-fff1923e821d'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b67461fc-f8cb-4f49-b890-1260e72795a7'
UPDATE dbo.BloodProduct SET MaximumStorageTime=61320, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b6798449-31b6-435a-b03e-6dfd992655be'
UPDATE dbo.BloodProduct SET MaximumStorageTime=960, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b6922311-d192-4573-a7f0-f8546b90f09a'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b6988f3b-e28e-4aa6-b9ac-42d38615db79'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b6c3558e-94d3-4694-9cf1-9d7d56f73a3b'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b6d4afb6-ebab-4b7f-808c-24a2b1a8957d'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b6dd8e34-3f9f-4e3b-b9b5-2782bb2f03aa'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b6e250d4-6c9c-4763-98e4-1161c2fd929c'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b6e9c554-3f2d-4000-9552-c2bc1430185b'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b6f00165-1c25-4338-a6e7-f080908196b8'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@30 C2 HA', ProductVolume=450, MaximumStorageTime=61320, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b7104bdf-c779-4574-b543-5ed3244507b5'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b718f791-5c94-4743-b657-385e06a267d0'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b72efb2d-3011-4581-be13-d52219456ae9'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b739ccc4-55a3-4d5d-a056-7192ec13975c'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b7726a4c-fb89-4432-a3b2-976344552898'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@B7 B2 C2 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'b779091f-a4d9-450e-a88a-e045ad97afa2'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 C2 D4 HA N2', MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'b7b1d470-f753-4036-a14f-5ac61c75079c'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@30 I2 H6', MaximumStorageTime=61320, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b7bf6b1f-2695-4566-8507-33aadfed34c6'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b7c9f1fa-b746-487c-a34b-1c63162b91cf'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b7cc7958-06a5-4a16-9416-da3599228e09'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b7e67167-395e-4a24-94c3-2af5fa7dcf37'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'b7e84c31-92b6-4882-a749-c24b1057cbbb'
UPDATE dbo.BloodProduct SET MaximumStorageTime=624, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'b82a7fe4-ddaf-4bc4-a81e-587f25446b8f'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b8410a4d-13ed-4871-a082-dd86771f8322'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b8449908-fd68-4876-b0ef-57fd864e8977'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b84d1341-79a0-42b0-b951-d4255fd58661'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@11 H9', LastUpdateDate='20100210 13:55:15.970', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'b86dd204-73fa-4a65-8da2-d3bb548fbe89'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b87ef841-6098-4834-8dc6-039337506dcf'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@09 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'b8861457-92ed-4f87-979b-57137882ce43'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b8910215-bba0-41f1-b279-2808e9b6c9f3'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b8ccb9f1-b56b-4eb2-ba02-57df39efff8c'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 C2 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'b8ce8cb9-24db-4c21-8587-d7419900a38b'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b8e04eff-4a9e-4fac-b6ab-f45fc89b7168'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b8f8a95f-a77a-47ff-ae7e-99be594be743'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b8fcff41-55f3-4f54-b8dc-3a205ef7a2b5'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@20 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'b931cfa6-de42-46b9-9f37-89f78e0d2caa'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@33 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'b9380e93-7c88-4c53-a24d-5ad6735f63db'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b940be40-0295-4e02-8064-ecbfb92c4088'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b94334d4-2847-40f1-8e13-09658199dc78'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'b96f0980-96dc-4a55-a531-ed758de2efd0'
UPDATE dbo.BloodProduct SET ProductVolume=50, MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'b9702387-d7ba-4d0f-b0f2-ac5170828d0f'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'b97ff4ec-565e-4ffe-805d-fe5e8902f783'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b9a72106-992c-4ff6-834e-4745960ed5b4'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AY D4 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'b9b57ac0-c689-43e4-b387-611faf884d15'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b9dfcb17-ed4f-4e5d-8b03-a58c18759b76'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b9f73a88-1c89-4176-9bdf-4128c8cce58e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b9f90562-9707-4d75-8370-b3f2485243d0'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'b9fbf7fa-add4-4b37-9184-0771dcaf0be0'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'ba0a8c4d-c5cc-4284-81fb-59f95fed77de'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'ba0b299a-e838-4cfd-b63c-159607b4a0b7'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'ba11e29c-0776-4b98-b54b-07dc01431bcc'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'ba314d06-39c9-48d1-887d-8008d8d5c70e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'ba37dc62-3dcd-4631-b28f-76fe6c0aea53'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'ba465f2c-c434-4365-9a5c-75aa9ce5a15e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'ba57ee8c-5e12-4ba9-a601-b518fde6aac0'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 C2 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'ba5b51e4-83ed-4969-98b4-2c458a28ccdf'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'ba5fdbc0-dad1-46f0-827f-ee40d19ad88b'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'ba7dd334-d7f2-446e-ac3f-604a465bf710'
UPDATE dbo.BloodProduct SET ProductName=N'Washed Apheresis PLATELETS|None/XX/20-24C|Open|Irradiated|ResLeu:<1log6|2nd container', LastUpdateDate='20091109 15:02:22.757' WHERE BloodProductGuid=N'bacad020-1408-47c8-9245-9b076d766837'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@09 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'bacf6c7e-140c-4316-81e0-b6fa5300d4c0'
UPDATE dbo.BloodProduct SET MaximumStorageTime=1008, RetireDate='20080301 00:00:00.000', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'bad4893b-ab73-4824-be39-84b097420bd9'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'baed917d-5f98-48bf-b2d1-61767d9fba83'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@B7 B2 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'bb0e65c9-15ce-4bc7-a3e9-6ae3d20ea97b'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@84 H9', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'bb1569e3-8984-4a80-b0ae-c06a0c75773c'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'bb32e6f4-be25-42f4-b015-c3aa4d81a8b8'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'bb4cf0ea-a066-4d53-8fab-421acc4d2049'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@20 C2 D4 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'bb4f717a-d9b8-45c0-97a7-a041fce98313'
UPDATE dbo.BloodProduct SET MaximumStorageTime=1008, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'bb596afb-1ba8-4015-b0f7-a28fa0f5560b'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'bb72a5e0-d8fd-4a0e-8e24-3a28b2f4b39c'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'bb76c632-f7eb-4552-9b82-413100f08e85'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'bb7b28b2-7c1d-43bb-a7f8-23144e291ddf'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'bb8bc438-0339-4070-b41a-d0e7b24e1d25'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'bb92d448-406b-4ab4-97af-1603fd9994ec'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'bba91000-ba4e-4208-8061-e9fafd3d2fe0'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'bba9543c-334a-4fbe-a74c-fb2450374848'
UPDATE dbo.BloodProduct SET ProductShortName=N'RBC Deg None', ProductAttributeForm=N'@AS HB', LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'bbb0b45f-9fe2-4faf-ace8-0cae62e4fede'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'bbb0ea95-b393-4a05-89af-791fb66ccde9'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'bbb56cbd-09f2-4b08-a6bc-591a2a6509aa'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 C2 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'bbd3c27a-a9dd-45a1-916f-495d645904d8'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 C2 D4 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'bbd4dbe9-4ea0-4bcf-8fdb-94b7f2ea249c'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'bbfa6e73-c436-4b97-b109-527c4dc3d0d4'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'bc0c05db-de5b-49f9-9169-538d93bfcb40'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'bc1218ea-38a8-4069-b292-fcb265827dc7'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@03 D4 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'bc300839-6852-44fa-b3c8-eb03b54ccfa2'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@03 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'bc31f924-d747-432a-8e70-5c4b064c0b5c'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 C2 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'bc36b1ee-eb0e-4e45-a38f-37dbef456c8c'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'bc3d09ab-c682-4080-ac4e-b594e450b3b0'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'bc707dcb-98be-4bd5-84a6-e375681d87e0'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'bcac14f5-7883-430f-a047-a969d69f908c'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 D4 H9 N2', MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'bcc2891b-59ba-4ba4-bf78-b0ac3348c379'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'bccf2864-7743-4181-b592-1ccf18bf6576'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'bcd35da3-a961-473c-92b5-dcda4ddd5766'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'bce4a9c1-7957-43c6-b92b-7f4058ce5962'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'bcef76b1-613a-449d-ad18-01e0efd8b493'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AZ C2 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'bcf618bb-3ce3-4078-8918-c2cd40e44be1'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 C2 D4 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'bcf9e5ae-4e3b-4297-a411-6c8a18ee8672'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AZ C2 D4 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'bcfe8cd1-0717-4ae2-8e4a-8bfaee1d05a4'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 C2 D4 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'bd08a9e2-a083-4bdb-9c94-cd1fe9fb492c'
UPDATE dbo.BloodProduct SET ProductShortName=N'FFP AFR NaCit MNFI ', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'bd28eeeb-0d5a-4bf7-9075-6d816b7238ae'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'bd28fb18-9824-4d17-a020-2cea534dcfd6'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@30 C2 H3', ProductVolume=450, MaximumStorageTime=61320, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'bd38cf4c-6054-4b14-a74b-11b595c08cbd'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'bd3ecf9a-9455-4a7d-aa7f-6c6667ef943d'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@09 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'bd612e6a-a21d-43b0-9ee3-9d68cd374a0e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'bd6a5039-354f-4729-aeea-c3a1e1de4c6b'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'bd8f80be-32b1-4934-a22a-3716b5e36c98'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'bdb3c0ec-6b3c-49dc-8ec5-b8b0c123afd9'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'bdb6bb76-3c46-444d-90a5-4198573990b9'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'bdd1d697-d58a-4979-a58a-c776a1e6e0d0'
UPDATE dbo.BloodProduct SET RetireDate='20090901 00:00:00.000', LastUpdateDate='20091109 15:02:22.790' WHERE BloodProductGuid=N'be025e8d-e75b-479d-bdc6-4d28ad82af59'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@11 C2 D4 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'be26d807-bbfe-409f-ada2-4e8193703170'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'be4a988e-f8e3-4f46-bc31-6224edee493e'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AY D4 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'be4ac940-9102-46d9-939b-16e3966626a8'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'be6fffaf-3c97-41dd-92ff-31c390b50e73'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'be77b065-fd88-4ddb-900f-ddc25d72dd6b'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@11 C2 D4 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'be7df365-3431-4dc4-8e1c-8a85e104e7e5'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'be852f17-0020-4afc-a800-5c00c4a52d20'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AZ C2 D4 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'be8e8961-e02d-4512-8d9a-5b12c11c7d74'
UPDATE dbo.BloodProduct SET MaximumStorageTime=1008, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'be922ae3-c2fe-427a-86bd-47b04ded5d27'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'bea89edd-0793-4441-bd02-96032626a77a'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@10 C2 D4 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'beb9a33d-28a5-49b0-a7ee-ba23d5b20125'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'bebfa1b6-fd1e-49b7-b35b-9a25c3489212'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'bec50adb-cf53-4e32-a26f-b020a1e3aa66'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'bec7abc7-62e1-4636-8d0a-043055b94e66'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'bed09427-51ab-4748-b937-2607a3113f9d'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'bed18717-b5b6-4e65-aa9e-83824cbe2694'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@33 D4 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'bef5cd20-55e9-4309-b52a-d9473feeb713'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@07 C2 D4 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'bef6ace1-8a46-4fcd-ba97-a0a9542f9d7b'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 C2 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'befb59e8-c580-43d9-b0ff-6c3939964e3e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'bf023cd6-4749-4683-bb76-7886d8a638f2'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS G7 H9', LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'bf0661e2-484e-4e1b-80f8-ed6b70423509'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@18 C2 D4 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'bf1d28dd-3e7a-4913-b6ed-d87902525f9a'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'bf269664-4231-4dc0-81f1-9713d8c5ce9f'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@03 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'bf3baf3d-f1b4-4644-9663-08049fb28de2'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'bf6fcac5-bb15-416c-b009-82cd1ba5f25a'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 C2 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'bf775131-5f45-4431-b15d-3f78e133f1d5'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'bf7ccf8d-5afd-40e7-a987-a9c3336eeca6'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@20 D4 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'bf84ecb2-79ba-44e6-b895-2b6f7c2e05eb'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'bfa9fa91-7405-4569-82b0-9b40796432ad'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@11 D4 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'bfaab3b9-27b7-48c5-8139-ff8f42d56b0b'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'bfb2bf86-883d-4fa1-8f0d-ad1fddd5c645'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'bfc01f75-9bbd-4e7f-bbd8-bb46a51f3c2e'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@09 D4 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'bfcbcfc1-c4f8-4a6d-ac71-a25de3cc6be4'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@11 C2 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'bfcd7a98-38cd-4d4c-8126-0cce57d2c2b4'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'bfd703f7-95ac-4f64-a074-3e7a5c4b9510'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@33 D4 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'bfd7a58f-ece4-4717-bffa-79c8c41ebe58'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'bfe834db-94d8-41b3-bc32-413d1c2dfbf7'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'bffad210-f917-43e9-bb44-cf66fb7484ed'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'c040909b-80c3-434e-ad2f-74230519b84f'
UPDATE dbo.BloodProduct SET MaximumStorageTime=1008, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'c040dec9-92ce-4dad-a7af-fb2b3f8c6052'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'c0464b9a-bd4d-40f3-bedc-e1b8441a53f9'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@03 C2 D4 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'c0534e9e-3d96-4cfc-8a0d-df922ecfb08e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'c087ddfb-4ed2-44ae-8a23-f74891e3b11f'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'c08fb7f1-c2e0-4f6c-a502-ea5260db4f15'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'c095b482-33af-4a4b-8f82-95d1cfa51b7b'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'c0960a9a-d99a-4cec-ad63-c614061583f2'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'c098b989-ccff-4044-8ccd-abb50d8014d3'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'c09a7f8a-ca87-4194-9258-e04ec05cf77b'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'c09ba01f-7969-4409-9906-f718d498ed9a'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'c0a2d0a7-0071-4671-b861-30f113c93c4d'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'c0b3430f-6b5d-431e-bd5a-51cfd6d9d1f6'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@10 D4 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'c0bad035-68cf-4912-a667-eaa43f93219e'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 C2 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'c0c42d6d-0961-46eb-bb58-c9b18894f2fb'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@22 C2 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'c0cfc91a-2fcf-4e9c-a57f-38a420794efd'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'c0e89202-a1c0-41f8-8252-1a74c3dc48b1'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@B7 B2 C2 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'c0f8e8cc-fcf5-4811-b58f-d932f7a53892'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'c120959c-7154-45a9-ac6d-35be798bb0e9'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'c1257b28-1600-4326-b7a7-c035f7c19e38'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'c12909f2-f5a6-4327-b341-eac3baec91dc'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@07 HA', LastUpdateDate='20100210 13:55:15.970', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'c12b66f1-fcd9-4594-9108-035d6871efb0'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'c15de35c-0958-4058-931a-0ec014c1faab'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'c188e043-d87f-4fc8-a98f-0798fc2dddbe'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'c19c84c0-ab1c-4a5e-a8ad-2e54993546a5'
UPDATE dbo.BloodProduct SET MaximumStorageTime=4, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'c1a2a4b4-c46b-4a8d-b68b-0ae4faa2f125'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'c1d11744-9590-4cba-bccd-f64ed6bd5889'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'c1e09f6b-6d2f-41dc-a34b-125581015017'
UPDATE dbo.BloodProduct SET ProductShortName=N'RBC Deg None', ProductAttributeForm=N'@AS H5', LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'c20f4feb-9a04-494a-827f-c6f6e9793483'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'c250ecb1-33ae-4258-b04c-a561efe90a51'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'c260ef12-536e-489d-92e2-24d95117e78d'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'c276c0c4-ed69-4da4-ae36-1e41950bcac0'
UPDATE dbo.BloodProduct SET ProductShortName=N'RBC Deg None', ProductAttributeForm=N'@AS HC', LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'c2838b43-a9e3-42a2-9c7a-bf9d432cd81a'
UPDATE dbo.BloodProduct SET MaximumStorageTime=4, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'c2d34647-76c9-4ac2-8766-e5033760a321'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@84 D4 HC', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'c2d625b7-0713-47bc-9430-cb438cf60925'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'c2dc29c2-1da3-444f-abdd-0c09b8a31e3b'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'c2ebf0e6-1fec-4e27-96d3-26a1ca727efc'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'c3013efd-5eeb-4718-a9d7-ba404c150778'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'c31298f5-047e-4d7c-826e-619336266529'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AZ D4 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'c314ace0-68d5-4df9-b227-d4c202578758'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'c32f7129-1c37-48c9-8220-348f13d08c94'
UPDATE dbo.BloodProduct SET ProductShortName=N'RBC Deg None IRD', ProductAttributeForm=N'@AS C2 H3', LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'c35ab501-d605-43a8-b79f-a13d55c729d0'
UPDATE dbo.BloodProduct SET MaximumStorageTime=61320, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'c361a1ec-5b77-43d4-80b4-b150ddab3b54'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'c3a419bb-24f9-4628-8811-c8737472159f'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'c3c495cf-39ad-46d7-a9de-4bf33d8ac657'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 C2 D4 H9 N2', MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'c3f25eb0-59dc-42c8-b47b-a7665f7aaaa6'
UPDATE dbo.BloodProduct SET ProductShortName=N'FFP AFR Thaw None IRD LUKOPR', ProductAttributeForm=N'@AS C2 D2 HB', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'c3f7cf41-c038-480e-969c-6828eeef3873'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'c425dd42-3ceb-4755-82fc-6f0c7c5ad48c'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'c42c7004-bf08-4e73-b682-636734387dab'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'c45662a7-b59d-48ef-8905-33bc68bad6c8'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'c456d412-cf41-415c-8862-097ac61285a2'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'c457e0c0-7e0e-4240-a392-e389eb671ae1'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'c492f894-e86b-4f95-a1fa-a097934567ff'
UPDATE dbo.BloodProduct SET MaximumStorageTime=4, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'c496f5c9-ebdb-40d0-96bb-f40ab1f0a076'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@11 H6', LastUpdateDate='20100210 13:55:15.970', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'c4ac6354-e893-4a71-a508-ac1057976e72'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'c4dd7803-70fd-4d7a-bbdb-597630ec7e9d'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'c4e1a309-b2d3-44b7-bdd9-000dfd4cd380'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'c4fa00a4-a5e7-48f9-ba48-f6384ebbed23'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'c5161c74-4cf0-4ebc-b31d-dce45c74264f'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'c52e2717-0a4a-4b68-959b-8bbfa9be3fb4'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'c535dd3d-e014-4d5f-ae42-1ec6195c305f'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'c5625a07-c3b1-4c6f-aeea-f0b1a6846fe3'
UPDATE dbo.BloodProduct SET ProductShortName=N'RBC Deg None IRD LUKOPR', ProductAttributeForm=N'@AS C2 D4 HA', LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'c5923ab0-5f35-4e81-b7c8-ce6f73bd9e11'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'c5a5a96d-10d1-4b58-8040-e06772404c25'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'c5ad6675-aea7-4286-a487-626f0a01c8a4'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'c5ba5382-9919-47d6-bc8d-1008f070c0e4'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'c5ce0513-f12b-4bb3-9c17-78ed9803b186'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@11 HA', LastUpdateDate='20100210 13:55:15.970', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'c5ecc4aa-5e7a-4d96-8abc-c5f4e088b8cf'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@11 C2 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'c5fd004c-2d9e-45ca-8ca6-59666387e766'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'c603c5f3-2150-4429-a57e-5f56d5d5bc85'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'c61f7624-af4c-472e-93d7-8bfe5d441297'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@22 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'c6205d28-7881-43e4-a382-67f95e5252ec'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'c629ef39-590f-4354-9c6e-ca28f990cfa6'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'c644117a-2922-4e76-b021-bda4a5f30aa7'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'c644c0f1-335f-4bc7-bb84-e1369c98c100'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AZ C2 D4 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'c6469d4c-1bb5-42b2-86ef-4959cb7b3055'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'c65c872f-12a6-4376-9b75-6bccf6bbdaed'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'c69f42fb-c296-42a7-b404-0740519711f3'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'c6a1e396-fba3-493c-86ad-2b9629e58c7e'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 C2 D4 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'c6b04034-83bb-441d-9f43-45d159cad760'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 C2 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'c6dac27c-3774-4d90-b9a6-b6ba7a95b4f7'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'c70b616c-d668-4017-b448-7c152560a747'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'c71f6908-1031-4ed9-9119-2effd0a305f8'
UPDATE dbo.BloodProduct SET MaximumStorageTime=1008, RetireDate='20080301 00:00:00.000', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'c79566a9-33c8-4862-9a1c-ea585a9ec3bd'
UPDATE dbo.BloodProduct SET RetireDate='20040901 00:00:00.000', LastUpdateDate='20091109 15:02:22.337' WHERE BloodProductGuid=N'c7b032c7-4cd8-4560-9aeb-2596abc1cb9b'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'c7bda07d-b8a3-4b85-9fb8-877e65300cba'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'c7c6b068-a1d4-412d-a653-73eb49e41835'
UPDATE dbo.BloodProduct SET MaximumStorageTime=624, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'c7d478ff-88e4-4d4c-823e-691100f19785'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'c7e6246d-fef7-4855-ad28-1aa11c1dea5e'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@30 HB', ProductVolume=450, MaximumStorageTime=61320, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'c8011fd5-225c-4328-8c62-ae891ad9679e'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 C2 D4 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'c8159167-fda1-4d4f-a100-a75042cba413'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'c8247654-c8d0-4885-9140-78a417e6a514'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'c828fa0e-7991-44b0-84c8-4f17745989a9'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 C2 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'c82a1d4f-2dd9-458f-a285-c82b33b9a255'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@03 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'c897d35b-37d1-40b0-b24f-2cc5a561e007'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'c8aa935a-dd57-4bed-bc95-917c08730244'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@07 D4 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'c8c3a640-f8b8-4194-a253-e7d8f42d5334'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@10 D4 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'c8d6c90f-7d91-4995-9f34-cbbcc570967b'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'c8dbb9e3-542f-4e88-8bc7-7d6370f98bb3'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'c8e75aed-f9c1-4ae4-9303-9c77f68b7e53'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@03 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'c8f56cbf-26dc-488c-8811-c7e1775eb53a'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'c920cc2a-c939-4f77-ad69-97a6e37cfe13'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 D4 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'c963c069-5bae-408d-93ed-e3dc4feda5af'
UPDATE dbo.BloodProduct SET ProductShortName=N'RBC Deg None LUKOPR', ProductAttributeForm=N'@AS D4 H4', LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'c96fc002-1e65-4473-bc66-2aac5b5a6b31'
UPDATE dbo.BloodProduct SET ProductVolume=50, MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'c9731ca1-3b37-43a2-9004-0e189b2aa9e3'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'c97ce3b8-fbcf-4029-80e9-69a9b3dd3386'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'c9a9aedd-12cd-496f-9c1f-6db3be6b4998'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'c9bc1aff-a356-46c7-b283-f0cb28c63147'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 C2 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'c9c10833-e2b9-4253-8d29-6aa3c9b9c958'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'c9c8dd60-6d53-441e-a2cf-66d4c3b0bf9a'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'c9f25694-9e44-4beb-8c91-53aa45606ac7'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'ca1ad963-2eca-4767-97a2-5ca9a4986b06'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'ca259a4c-b8e1-4fdb-aedb-26e14e53c693'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@07 C2 D4 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'ca41163c-26b1-438e-a974-d693556a8240'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'ca4652fa-5748-4c55-b21c-47d5ed85b52c'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'ca53e8fd-ddfb-4139-86f0-c14fcbf0f5ab'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@18 C2 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'ca593f51-e189-4e25-a3f1-8212d209a26b'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'ca5c0f64-8551-45f1-bfc6-c53ad3ca1d74'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@09 C2 D4 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'ca5f9497-84a7-4bc8-84e3-fddae7774b89'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'ca6368b7-abbb-4515-a5ec-e590ab4f266f'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AZ C2 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'ca663fe2-925b-41e4-ac38-bd7af45aaf35'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'ca6a9425-4a25-4f19-9d65-529dc9ffc92c'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'ca778ce5-ebbc-4203-8290-7ce5fa5731ca'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'ca796be0-75ab-45c5-b8aa-f17755505c2b'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@07 C2 D4 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'ca7b2d2a-eefe-44a4-8fdb-1c66312b4557'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@03 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'ca844eef-fec8-4512-8c60-ada28012b1b2'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'ca84a53d-9b34-4ceb-bc80-387ce875f729'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@33 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'ca893d44-283e-430d-b329-3de7421ef43e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'ca936df5-a9ab-4a3a-b089-cb221f6a4672'
UPDATE dbo.BloodProduct SET ProductShortName=N'RBC CPDA-1 OPN PLS Red/PA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'cacc9ebc-b650-4a19-8e63-a1df82aed7eb'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'cad80b39-2728-40ae-93e3-5152f7b95509'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'cadd9151-a70a-4b85-8208-a8fba349a6a3'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'cae6da5f-99a7-4823-8d5f-b21d52e32f4f'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'cae6f0f3-bd36-41ec-8a0f-0f49d7ce5a65'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'cafd3cee-bdb1-4a38-90ae-77eb5af6aaa5'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@20 C2 D4 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'cb19221e-8408-4922-aa0e-0a7d15dafeb4'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@33 C2 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'cb48e972-41dd-45e2-b7cf-933ee24834c3'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'cb4f840f-e12a-437b-b507-3c63e86a1638'
UPDATE dbo.BloodProduct SET ProductName=N'FRESH FROZEN PLASMA|CPDA-1/450mL/<=-18 C', LastUpdateDate='20091109 15:02:22.587' WHERE BloodProductGuid=N'cb6e0bdd-d77e-4e74-b7da-f19e5b139444'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'cb72c9de-a488-4351-bd6b-efe1e2cb6f20'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'cb80211e-e808-4e4e-b54f-be5ae0a23924'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'cb9256cf-267f-405a-8769-a9c55300d696'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 C2 D4 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'cb976418-7086-48e2-8bd3-2eeded6da71e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'cb9b99ea-9be4-4b47-b90f-47ce874f7006'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'cbbb8b00-ea6b-4f52-a462-b97a5d258fbb'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'cbc53053-9c3f-4424-9ac7-c763ca98c619'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'cbccb67e-8ed0-4c13-bfdb-1f5dd8395134'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'cbd27016-2fb9-463f-a52d-5b4b0a6a141e'
UPDATE dbo.BloodProduct SET ProductVolume=350, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'cbe799cc-0d21-481d-b53f-d89ced9c88d7'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'cbe9f5d5-a8d3-4546-b488-4c37890ea842'
UPDATE dbo.BloodProduct SET MaximumStorageTime=624, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'cc0ed791-5767-4f2e-b6e7-398b0ccf20e0'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'cc204cad-a8ce-452f-ae7d-44be5a6bf308'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'cc6cd527-d9e8-4d43-b8b3-d85dd6a286d5'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'cc747738-9bbc-40fa-ba5b-ab4de172ad04'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@07 C2 D4 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'cc7f6ff7-8503-4d15-9748-474cc2ea7917'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'cc97afc9-39ca-449f-a283-0da363e6dfde'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'cca3fad7-54fc-47a9-91cc-6974a7502285'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 D4 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'ccbc0ffd-4fa2-44b3-8a62-765f1bc385b0'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'ccd56fc8-0c86-4b3c-be2b-60b489c823fd'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'ccdb854e-2bc5-4339-8ba4-8fd9d4a93dda'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'ccdbc5e4-bc4c-423f-9be3-182591d7bfe7'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'cce0edc2-f557-4a2a-a3e4-5844d6f9218e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'ccfbb195-853c-4867-8acb-6dfb5e1dd499'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'cd1078b9-13d6-4639-b809-6f50beb7f1b3'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@30 C2 D2 H9', ProductVolume=450, MaximumStorageTime=61320, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'cd1374d6-31e7-4dbc-9e39-571fe1902ddf'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'cd204ff8-9908-44f0-8128-f8edfff8a15f'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'cd2249ac-8b7e-46e2-97ff-56f6a649c0a0'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'cd3164b6-1dae-4a71-9071-b512ea5f23f3'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS G7 HB', LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'cd5ac32b-f668-4918-887c-52efc72d18e1'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'cd62a120-913e-4704-8626-f2edd8213bc9'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'cd70712c-74cd-4861-baf9-4ca24baed26d'
UPDATE dbo.BloodProduct SET ProductVolume=50, MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'cd7c3769-c213-46db-92c5-5ab4c09a0389'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'cd9e4f68-ee32-4c60-a8bd-54f1d884ff0e'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@11 H4', LastUpdateDate='20100210 13:55:15.970', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'cd9ff45e-7a06-4379-b00c-c9a5771073c5'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'cda1ed3a-2340-49ac-9ba0-ffe1e54c7a73'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@30 I2 H9', ProductVolume=450, MaximumStorageTime=61320, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'cdac81da-cd77-4e13-8c47-4c03ab1a12ad'
UPDATE dbo.BloodProduct SET MaximumStorageTime=1008, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'cdbb653a-d17b-4208-b968-a8b9aa5fdbc4'
UPDATE dbo.BloodProduct SET RetireDate='20090901 00:00:00.000', LastUpdateDate='20091109 15:02:22.710' WHERE BloodProductGuid=N'cdd7261b-4965-4812-a338-11009b07f3c7'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 C2 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'cddb33ea-812f-4f26-911f-bdea4cdca30c'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'ce02cd11-6bbe-4271-89c1-fb008acad45d'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'ce077d8f-848f-472e-87e7-b81ce8d8ce36'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'ce0df3de-66ee-4014-9833-b8e48730a6a0'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@20 C2 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'ce1cc5a2-b3fd-47d3-a9b8-c35827bdb2fd'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'ce2d908f-ae37-4484-9d46-869c5ebbc4a1'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'ce69e0f5-6ab5-4722-ad2c-2ec5ca45c14f'
UPDATE dbo.BloodProduct SET MaximumStorageTime=624, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'ce86806d-87de-422b-a073-f8a84817e7f2'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'ce9c7b0c-7d17-4f71-8540-9064715c3ea1'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@33 D4 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'cea4f3b9-3625-4ffb-9fb9-2a9ff2d0273e'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'ceb6ab67-baa4-4bcc-9c34-3e45e9ebe59b'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@10 C2 D4 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'cecff4cc-370a-4009-96ed-e95d409281d8'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 D4 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'cee3dac6-2b4e-4fb5-84d8-e0bde940d047'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AY C2 D4 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'cf12d814-ce94-43d6-97fb-cd5919a568ef'
UPDATE dbo.BloodProduct SET ProductShortName=N'RBC CPD OPN IRD PLS Red/PA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'cf1dc61f-9a1d-4a1e-8ad3-18662b26f939'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'cf25a787-1e0b-4371-9012-ee6bf6348e12'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'cf2df929-621d-4cd6-90a1-8c875534515a'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'cf3bd62c-06ec-4d9a-9cc6-647424e7f45b'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'cf4a6589-b8ab-44a0-9018-18224d746080'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'cf5c593b-64cb-40a0-864a-3061d2ec6325'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'cfb16d87-3cc2-417c-87bb-3474ac792e5e'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 D4 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'cfd4cd2a-2e75-4c76-99cf-a636549f8a0e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'cfeb4953-c1f5-4241-9db4-e2843f13b0da'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'cffba452-e80b-4671-ac70-605b4340fe5c'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'cffc1e40-9642-4443-89cc-e06b9e924fa0'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 C2 D4 H6 N2', MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'd005eb3f-3836-4628-b1c2-7d20e3329501'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'd008631d-d980-4307-84d6-bf0a975c9aa3'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'd02249b9-316b-4d24-98eb-559367927989'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'd04c5d63-1489-4e6f-ba85-1d025625c5a4'
UPDATE dbo.BloodProduct SET ProductVolume=50, MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'd06bd8a8-15c6-4195-8d6c-7946fd9deaea'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'd07aa64c-e1a5-42ee-9288-4ebe06a250af'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'd088c387-167f-4dcf-9a40-e6278c4fee8d'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'd0899f56-044b-4f52-a889-d4a1645a32e3'
UPDATE dbo.BloodProduct SET RetireDate='20030901 00:00:00.000', LastUpdateDate='20091109 15:02:22.320' WHERE BloodProductGuid=N'd092e18c-b289-439d-bf14-874bf60d0efb'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'd09a741c-9f6b-43d4-895c-be0f7a813181'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'd09cd63d-e7a0-40f0-930e-07e76c5fb09c'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'd0a050b5-4e20-4632-bc24-285c8c34655f'
UPDATE dbo.BloodProduct SET ProductVolume=50, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'd0a1de87-a2ad-4da3-81e2-1d61dee9e231'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'd0a3e4e2-c9e1-4fde-9894-4b38d6125215'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'd0bf5288-be1c-4e04-abff-8a7eda12c7b1'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'd0c17c9a-8dfa-429b-82fa-69dd38b1558d'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'd0e6308c-8d8f-41ea-98e9-facd18517605'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@84 I2 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'd0f9b442-cf31-4aeb-8eb8-e403ae53c5dc'
UPDATE dbo.BloodProduct SET ProductVolume=450, MaximumStorageTime=4, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'd0fdfca6-fe42-42ef-b16c-852704245304'
UPDATE dbo.BloodProduct SET MaximumStorageTime=960, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'd10ca37e-8d6e-4171-938b-44139c2ffbb4'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'd10dd248-309c-43bd-b33e-6ad9bc389cd7'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AY H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'd12586a4-43b0-4c96-9252-9c824b40a42f'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@30 H9', ProductVolume=450, MaximumStorageTime=61320, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'd1379c92-4a00-4f1c-9b58-69fdb8ad7a2d'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'd137e3dc-2858-475c-bd87-58e04887a7ec'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'd1723e73-1dfa-4b35-a11a-8ef516a9754b'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'd175366f-9775-477b-ba70-dcf7d1a84922'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'd17f2dce-cb99-4ae9-a588-227b589b5ba3'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'd1864320-514f-4ea9-a013-e9eb13fbea9a'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@18 D4 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'd19d1fd1-f813-4c6b-8b75-b28265337d70'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@33 D4 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'd1a1b2c5-5b4c-4a8b-a70b-f2181f2ab050'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'd1a4d6c0-7c22-4187-ba2b-337227a0ddd4'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 D4 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'd1a5f3ad-29a1-4479-bec1-26a06e9bad23'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'd1b68519-7b8d-4944-b2e6-ab778c0714f0'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'd1b7c9dc-5632-4aa6-a2b3-51dbad08f6f9'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@10 C2 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'd1ca4ce8-cabb-4c79-94cd-bc6ce268f835'
UPDATE dbo.BloodProduct SET MaximumStorageTime=1008, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'd1f1de75-7f53-4037-96c1-b882bf1dd380'
UPDATE dbo.BloodProduct SET ProductVolume=450, MaximumStorageTime=61320, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'd1f4d7a8-d672-435e-b2c1-8836d847e0c6'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@10 C2 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'd1f67e64-0d40-4574-95a4-d130998dcd95'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'd1f83bd9-914e-4845-a6af-3b80aecc7c68'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'd1fa5bce-1755-477d-9668-6d17cbc44db0'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'd20fed82-b718-481b-a7c7-fd9f912c77fe'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@07 D4 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'd221a7dc-c62c-44c1-9a02-cee40a05c3ba'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'd25d3d54-f03a-4d7d-b98f-832144895755'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@11 C2 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'd2670dd0-f79f-4789-9006-0b7709800319'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'd28b1c61-3c53-4eb8-a7b5-6aab9c21d5d0'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'd2ac8a5d-d618-44fb-b0a7-a19e9ea2fd09'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@84 G7 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'd2c54586-21d2-496e-bc48-22198b5ceb79'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'd2cfea7f-3cf2-41bb-85fe-67e4fe388337'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@B7 B2 C2 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'd2e24f66-9843-4dc4-ac3e-4c68490be7ff'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'd2fb7ee3-4e5a-4053-9405-afd9433d3771'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AZ C2 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'd31474cc-ce9b-4dde-bdf3-a957f1186fed'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'd3195c69-7902-4e38-9339-4b36c997d6b0'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 D4 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'd322576e-e6ba-4ffa-b54d-9023f8ad0d4f'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'd32e6da9-16b3-4802-a5f8-2cff20c0af20'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@B7 B2 C2 D4 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'd34f3913-f7e4-488c-9593-c6e15f81458f'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'd3665e80-be74-4f97-ab71-1d4dc169abe3'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'd36dcf5d-aff6-4bfd-8c66-a6d3e4b7378e'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@20 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'd371af48-b024-4ab8-b707-3e983e44100e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'd377a97a-a8c3-4c35-bb29-994273258945'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'd38252e5-32eb-4b28-9e71-7020d1079d41'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'd3a76b31-7960-46c1-a6ac-f83904585e68'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@84 C2 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'd3aa16ba-7bf2-4f86-ad79-f31ec56abc02'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'd3ba843a-6d76-4735-85aa-3bae8b2f2907'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@10 C2 D4 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'd3c939b7-75f1-4cd0-ba4d-e9e24880b08d'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'd3fdaec2-7a8f-42d4-b25c-b7dc3a849e86'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'd3fe2198-c8c5-4e16-ac93-d79849213e11'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 C2 D4 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'd40d87e9-1be9-42e2-afce-5ae39956ce3b'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'd424daa5-a3f2-44fb-92eb-ca28a5c7f267'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'd42eeb5c-429b-47af-bc4a-49184db1ec0c'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'd444290b-bf32-4d93-a9a5-33383e31be4d'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@11 D4 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'd44491e5-ee83-4120-8d63-ca36c5cbd1de'
UPDATE dbo.BloodProduct SET ProductVolume=450, MaximumStorageTime=61320, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'd455558e-1472-415e-bc36-cbd09a474421'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'd460b64b-48c9-485d-9b53-d4eb8ed2d8ce'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'd46783fd-3e08-43dc-a348-5a9ff4fcfad7'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 C2 D4 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'd47550e2-2bfc-4150-971b-04f2ad64e8da'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'd4770e87-c046-4d2a-8555-8bf54d1cce32'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'd4911cea-7b3a-48e3-ba30-92fb922ae067'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'd4b639e8-3637-45af-8f65-c0d882f95d76'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'd4c77626-98c8-499d-8e1e-886a24246c61'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'd4d0e1de-5807-4f13-9541-0854f43f3dab'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AZ D4 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'd4dfe030-d4d5-4682-857b-a689328071e1'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'd4e8fcb4-b7af-4db4-87e7-1ee598a17d6d'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'd51b58ad-62ac-4cf0-876f-d8ab209c9f16'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'd51bfa2f-5313-488e-ad15-902feeca2a9a'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'd51d3b01-d860-4d85-8439-0a626e789d95'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'd51ebc70-ed1f-47d9-94d8-b2ead86701de'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'd52cb57c-4946-4864-a68b-4c71a5535721'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@84 H4', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'd5311abc-5c31-43cf-901e-c747ca5db5ec'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'd542eb2f-2d7d-48a8-9d33-8f0a1aed53cb'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'd56c18c1-e3bf-4435-ac29-8ee8bdb13a87'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'd58b12f2-3ff7-41b4-9dfb-8d74d5bd4f0d'
UPDATE dbo.BloodProduct SET MaximumStorageTime=4, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'd5aab6ac-e491-45f6-9a81-21832c1e6816'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'd5abc95f-a03e-4e6d-810b-934be5b5b5ff'
UPDATE dbo.BloodProduct SET MaximumStorageTime=960, LastUpdateDate='20100514 14:47:38.847', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'd5b1deb2-0573-48e0-ad7f-6c9fd24daed5'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'd5b77853-2c05-4d98-9480-0f2e9a961f6f'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'd5ccb6eb-43ac-47b0-850e-91ef2f165f1f'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'd5ed8188-86f9-4a8d-bfd8-ff816b14ac9a'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'd612334b-a3b2-4e27-8184-755780d4e666'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'd613e45d-aa4b-4c37-9591-031e8d89c299'
UPDATE dbo.BloodProduct SET MaximumStorageTime=672, RetireDate='20080301 00:00:00.000', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'd631f52d-6361-4042-88b5-de4b956a1479'
UPDATE dbo.BloodProduct SET ProductShortName=N'RBC Deg None', ProductAttributeForm=N'@AS H3', LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'd64902a8-623d-45c6-96e5-cfc459a1de85'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@10 C2 D4 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'd64d56f0-c9a5-4ad7-bf04-f0aba4b595ac'
UPDATE dbo.BloodProduct SET MaximumStorageTime=1008, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'd6576bdf-8de9-45a7-8db0-aedbcee370e7'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@33 C2 D4 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'd660bc27-9db7-4ed8-bfda-622994354019'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'd67be5c8-106d-4d73-9b47-29e1ad82be3d'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS G7 H3', LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'd68ddc0a-a325-41a8-8891-9623789fae85'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'd69b90ff-c0c2-4798-8665-0a3246231c4f'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@09 D4 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'd6c35aec-85c7-4aac-be30-15fb4a6906e5'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@B7 B2 C2 D4 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'd6f4feaf-2267-4d0f-808c-7c9ad4a59551'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@18 C2 D4 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'd6f5c50f-e3d5-4e36-af19-b71331beea24'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@07 D4 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'd70c2e8e-cd10-4fd6-99fb-c96c1e761fba'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'd71d60e4-6596-4b06-921a-6bcdc5d1e3c5'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'd73b2d28-7aab-4f18-b7d4-86fb06a891b9'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AY C2 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'd7425d13-b480-4e67-9f2b-96c196a46fdd'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'd758ce49-e018-4e45-8391-ee836044f8dd'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'd7692d54-0dea-403e-979f-f4e9a6afbe15'
UPDATE dbo.BloodProduct SET ProductVolume=50, MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'd76fb06c-15f8-419d-9a73-24577bae4a34'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@07 D4 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'd77c07a1-2e98-4030-b5d7-1e3604a7e810'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@03 C2 D4 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'd7845c76-3341-40e0-8fc2-7430c3f0cc29'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AZ C2 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'd791614d-91ec-45eb-838e-e32a69fa26c5'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'd797beca-ed4f-45fb-b8bc-d55828936ac2'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 C2 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'd7bc9fb4-77c9-4b06-8640-c66440afa4e2'
UPDATE dbo.BloodProduct SET MaximumStorageTime=61320, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'd7d4ff37-6c70-4d3a-a30f-1c0de3ec20e0'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'd80110c2-1cb9-4b17-9f2e-0b1a317e6a82'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AY HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'd80a2f0c-afbb-4f6a-8a05-e97f34d4f254'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'd834acea-59ae-407a-85ae-a70d225255d5'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'd842d277-9ab2-49fd-ac02-732277ce2e63'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'd8466f14-a8cc-4d64-9dc3-b21aa3ec8ede'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'd8481200-657c-4f97-9b08-ad756967ba4e'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@18 C2 D4 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'd87b7f7b-979e-4c39-a070-1334a94aea59'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'd88cfc4d-9d62-45ce-9829-ba61c405010c'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@30 C2 HC', ProductVolume=450, MaximumStorageTime=61320, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'd899707b-5a6e-4e82-ac11-683a294b8f13'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'd8add11c-bff5-4937-98e1-a5e3cb5334e1'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'd8c3a988-fb49-416f-8636-5aeb7edc9ca4'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'd8d5ffe0-7a84-4e25-afb7-459e1616d1da'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'd8dac708-19ab-44d1-a2c7-17833e9b6110'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'd8e8b2dd-3f4e-49db-bcfc-416152b99092'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'd930f2ee-6ba2-4e47-b186-838a2243d37a'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'd955811a-f068-4b1f-aca7-d1fe0da1f69b'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'd956ada1-cce6-4c0b-b8e6-4f00af351901'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'd97357f1-be40-4de2-a05b-27bc83cd6927'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'd97e55f2-d384-4792-b648-442edae3e7bb'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'd989ecbc-5a1c-4f72-baf0-d7da867e3778'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 C2 D4 H9 N2', MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'd9bd96dd-99bb-4c70-b616-258e1109d0fa'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'd9c592a9-e4b2-4bbf-b293-b9db9a1debac'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@03 D4 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'd9cc4d09-87ae-4e0b-becf-adb7a09c6614'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'd9e2737f-196d-46f0-acd4-c9a8ba2d75d0'
UPDATE dbo.BloodProduct SET MaximumStorageTime=1008, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'd9eed85e-b5cc-4730-83c4-c5c5f359a1cd'
UPDATE dbo.BloodProduct SET ProductShortName=N'FFP AFR Thaw None LUKOPR', ProductAttributeForm=N'@AS D4 HB', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'd9f2e137-353b-43ca-8215-cd469e713ce2'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'd9f52aee-862b-4d27-a478-a68cecd91974'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'd9f74eb1-79a4-4949-acf6-48bb62223524'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'd9fc98ca-2bc0-4dec-a196-d4bd028360d5'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'da121927-2345-4f29-98e3-5571bf002062'
UPDATE dbo.BloodProduct SET ProductShortName=N'PLASMA Liq NS', ProductAttributeForm=N'@CG', MaximumStorageTime=624, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'da133446-af61-464b-bb1f-1996530e9431'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'da228981-31a0-45f5-9e2c-b92ccf1b22c8'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'da35ea21-af67-4b5a-95da-a0f28ea59481'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'da69b792-fd2f-465a-a6a0-2c0322ce5578'
UPDATE dbo.BloodProduct SET ProductShortName=N'FFP AFR CPD-50 IRD', ProductAttributeForm=N'@AP C2 H3', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'da6c6863-7ec3-4ff2-9488-3308bfc1aa28'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'da7639f6-f867-435f-a447-43a66555a610'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 D4 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'da8ba88a-c4d2-4fa3-bbd2-727c288de1c9'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@09 C2 D4 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'da8ed84b-354a-4756-9e26-9e34628c0451'
UPDATE dbo.BloodProduct SET MaximumStorageTime=4, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'da92ce40-c385-4590-9765-1d8a71ac58ed'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'da961b4b-e2e1-40d7-8c84-25e439460d81'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@07 C2 D4 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'da9766b1-157e-4453-adbc-501dc99d3b10'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'da981cfc-5fea-4885-bd35-c8172952d93a'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@10 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'dac527e9-8d6d-4dd7-8469-841ac57d1098'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@84 C2 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'daca76c4-343e-4c9d-93c5-f14414156c82'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'dad0cfaa-9d93-4696-8ca6-808349d345af'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'daf8097c-cf60-47e9-acd3-934fba595e88'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'db20c658-b3c1-4b03-ab1d-17abf2c32017'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'db2595a6-a9a5-481b-89e0-8a61019f697d'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'db40e0a8-d692-4646-8ac0-5cea77135072'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'db484828-26df-4555-af08-f04a39f93a9e'
UPDATE dbo.BloodProduct SET ProductShortName=N'RBC Deg None IRD LUKOPR', ProductAttributeForm=N'@AS C2 D4 H4', LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'db4a070f-63c8-453e-bb51-7ffdcfe8751d'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AZ HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'db4cea5b-c8f7-4d18-b79c-da16b32c1c6e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'db55f237-74bd-4387-8588-37d70ccf9adb'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'db5bb915-b4d2-44fe-8eca-6d97a9148a1d'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'db660c58-c4b3-4be4-9d57-e60fb62a41dd'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@09 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'db6aa0fe-3ac4-48a8-b5dc-ecdb5d2b54ec'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'db7ac81d-6088-4eff-89d6-e61eed9294d6'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'db8ff156-1f55-42fc-b5eb-9bf61729eb2a'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'db957a22-b61b-40f5-8d67-95dc2aa9c796'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'dba5d15e-c220-44ae-b782-9995d97541bc'
UPDATE dbo.BloodProduct SET MaximumStorageTime=61320, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'dba9012d-1da3-482b-9583-38e79d4d12a4'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@07 C2 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'dbac4afa-4a2c-4651-9960-458be8fbd870'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 C2 D4 H3 N2', MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'dbb0c353-c0e0-416d-988c-eac765025e86'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@03 D4 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'dbbacc76-5859-4d20-9237-668c34ac3bbd'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'dbea63ce-b550-4a7d-977e-19b261322aaa'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@84 C2 D2 H5', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'dbfbf38e-5641-47d8-b467-24b74cef7d7d'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'dc3799b0-70dc-423d-a9a0-eb444851d7cb'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AZ C2 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'dc45eb2a-7a14-45d5-abd1-65effd49d1ca'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@22 C2 D4 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'dc783f74-dab1-4045-bd16-1385711978b7'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'dc7fbad1-ce34-4573-b7df-27049d2875c3'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'dc8af030-2119-4b89-94b3-92eaeb1f710f'
UPDATE dbo.BloodProduct SET MaximumStorageTime=624, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'dcb02279-9b01-4a79-8a49-c8edafca3062'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 C2 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'dcbdf1d7-7549-4fe1-9663-d7eedb682662'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'dcc8b607-c2df-4911-89c4-554541e0af57'
UPDATE dbo.BloodProduct SET ProductShortName=N'PLT CPD OPN PLS Red/PA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'dceeb1db-7b3c-4ec9-bdae-a9200b0c76b6'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'dcff10d9-a82c-4b48-8433-8e1aa3a7589b'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@B7 B2 C2 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'dd00aed0-53f5-4f3b-b5cb-4f7b1d358740'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AY D4 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'dd040f00-9380-465b-95b3-27052654c720'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'dd278194-e3d2-4eb7-9fe2-8bbabe78951e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'dd337ae6-2e19-4bc4-adf7-3e5a696d6fa2'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'dd40bca0-a29d-461f-8b85-80904e93355b'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@30 H3', ProductVolume=450, MaximumStorageTime=61320, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'dd43bc3f-f976-476a-a763-f319e33860ac'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AY H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'dd4810d5-6008-4da9-8496-191f4a2f7a65'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'dd4e4dea-14e8-49b5-b17b-621ce283d972'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'dd4f4e6f-1ec0-499f-8bdf-cccf0c8622df'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'dd52cb0d-9c51-4a8b-b915-3869ddf55ec2'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'dd5ca20a-9614-4627-9fca-440f2111701b'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@84 C2 H4', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'dd5fbccb-564d-4d35-9a27-7786d8112f2b'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@B7 B2 D4 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'dd6d52aa-296e-434a-a143-a1009269121c'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'dd82c5e7-239d-4a1a-a8a1-59c3510fc69b'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'dd9e5375-00dd-40b2-8220-dbeac6e263e0'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'dddcc285-e8ae-4659-9414-9fc8f74c9030'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'ddfc16fc-c621-456f-bb28-1cd50022b8b3'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'de071807-9640-4357-81ee-53a01a0aab38'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'de4ddbe8-4800-42da-9aae-ab0a2e21f0c0'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'de5a87ad-38de-4237-92be-b1f2dab0b575'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@11 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'de5eb70f-82c9-442d-91f9-ebfa38380705'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@B7 B2 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'de6d13d9-99a5-4060-8802-2994d3d1a57d'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'de714c35-6912-4153-9d72-81951b43d28a'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'de8121d2-2ca3-40c6-ab23-4fa78fc78b16'
UPDATE dbo.BloodProduct SET MaximumStorageTime=960, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'de89270c-550e-4c95-92db-f1adb01eb104'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'dec12f91-4bcd-405b-ab5c-2b06256ffaaf'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'dec2fab4-2618-46b0-8f25-61b6a54ce0bd'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@07 H9', LastUpdateDate='20100210 13:55:15.970', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'dec8cb24-a7b9-4f97-812f-04d10e5205a7'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'dedf0595-81ce-44b9-914a-560a6dab7ece'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'def7d3c1-ac1e-4b81-8e29-ce3efbe7cdb8'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'defdb9d4-5190-4dd0-9f7b-0acf23f0edc6'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'df0d253d-3aaf-43a1-bdc7-56465ea402a4'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AY D4 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'df0dc164-c0b6-49ad-a374-1a47b5ea034d'
UPDATE dbo.BloodProduct SET ProductName=N'Washed Apheresis PLATELETS|None/XX/20-24C|Open|Irradiated|ResLeu:<1log6', LastUpdateDate='20091109 15:02:22.727' WHERE BloodProductGuid=N'df2227d5-db0f-4c50-bf4c-5a3b58a2be22'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'df2402dd-ee86-4a15-a64a-d632f0fdde5d'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'df47e307-3be6-4ee6-9e5a-fecd5f3fafb6'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'df4ef575-3037-4e2c-8a63-1b796e704827'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@84 C2 I2 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'df65c566-6d51-4955-8843-db86ec05cf6d'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'df7ecd17-cf79-40df-b8df-7d0a763bcb35'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'df8fba1c-2ff9-4ac4-8599-a41971ce534d'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'df95e759-e309-4098-94a6-33200a1b5ce1'
UPDATE dbo.BloodProduct SET MaximumStorageTime=4, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'dfbf8995-3992-4fe0-9fc8-ec8a493fec33'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'dfc9b6f8-a259-4181-9396-708f6b168f27'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'e00d34b0-529a-4c23-aacb-b109d9a7cb46'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 C2 D4 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'e0258f0e-55e8-4097-bcb1-756477947574'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'e03a84cf-28df-4d28-beb9-65e5ea203efd'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 C2 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'e03c088e-d7fb-4111-acfa-2492efe12adf'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'e044d8d5-4754-468c-92a4-2a0af0652cb2'
UPDATE dbo.BloodProduct SET ProductShortName=N'RBC Deg None LUKOPR', ProductAttributeForm=N'@AS D4 H5', LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'e04a61a2-05ec-4cbf-babf-24eed003463a'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'e05826ca-9fce-459f-a3b0-22eec8e372ea'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'e0669ed9-a4dd-45fc-990f-4238d4e6b015'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AY D4 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'e0716104-5e4e-44a1-bf8d-fc2341de8c88'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 C2 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'e09ad06a-4729-4fb2-bd95-7045dd0de804'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'e0a2b2d2-8d04-4e0a-8323-83403a2cb09b'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'e0d0770f-c880-4323-8c2f-1f3c53554e70'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@B7 B2 D4 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'e0def8a4-ee19-4683-bf53-523a333821ef'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'e0e4ab2b-5e1c-4181-85dd-77c83b07944c'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@11 C2 D4 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'e0ed8308-b825-40b1-b1a2-ac77b5a33fad'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'e104364e-587d-4f17-bde0-13c566c6f633'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@09 C2 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'e111dcd4-d16d-4d4c-a14e-f2706c4a6ef4'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'e13aa1cf-eee0-4e96-be23-6ca40b739918'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'e13c5f57-ad7e-43fc-8f77-c9feb9372d51'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 C2 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'e1574731-74e5-424d-b80f-50175418bab7'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@07 C2 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'e1675861-6c4b-4472-908e-69fe7d027665'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'e17002a2-6d3e-46e7-bc0d-ce064b8ceaa7'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 C2 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'e171612c-3cdc-43fb-b4db-0ee3eb781063'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@20 C2 D4 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'e18203fe-d6e1-461e-b530-57cc29200d22'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'e189ac7a-fe45-4951-ab70-1719b53a1aab'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'e18ab3c2-d22c-421c-b3cc-83175343938a'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'e18cc34f-26aa-4424-bf0e-3860543e43ff'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'e18e0722-31a1-455c-a072-8cffcd2f4c98'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'e192450c-0eeb-4e25-b411-5fed544b5093'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'e1a3ee16-520c-49bd-834e-e77957ecc2ee'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'e1aeab5a-0dd5-4417-a630-e83bd86c5f06'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@07 D4 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'e1ce0cd2-fce4-4ab6-8aaf-5d76c5e47eee'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'e1e98ee8-fc76-4011-89f6-a4b4e37f4a6c'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'e206b99d-a844-4fff-9d29-c81836c176c5'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'e20af921-bddb-4536-ba36-887b52123f33'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'e20e860c-888b-4dd5-be55-7d2d67d1769d'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'e21dec58-bb24-494e-a89a-32d11a481e31'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 C2 D4 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'e2249747-2acf-4fd2-8b47-6f1973fc07b6'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'e24312a8-4521-434e-a484-e3c74f2c8bc8'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'e24d11e3-4412-4aef-aace-dfef671144f4'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 C2 D4 H5 N2', MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'e25bfbdd-f4ce-4d38-8630-1b5544ebfe62'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'e272ed86-3d1f-44e3-a61f-0ef87be09b79'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'e296b6df-330e-4249-9ce3-31934418a568'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@09 C2 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'e29f780b-809b-455e-8025-1a1188170997'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'e2a31a85-bab0-4c09-819e-32fd44ed829f'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'e2b3d742-2be5-421b-bd10-405c856d1311'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'e2eedaa1-3aff-4fca-b802-15a8be8d9608'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@B7 B2 C2 D4 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'e2f70d47-367b-4f84-895c-a0f6d83a7851'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AY C2 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'e2fd8f38-52fb-4f18-9ad6-1dc374307d90'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'e31bd70e-47ca-49df-823f-a3f543b21fbd'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@07 C2 D4 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'e326dccc-1807-4843-90fd-5842679e94bb'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'e3505c79-cf2d-4bfe-9066-5ef2b8c449cf'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@30 C2 D2 H3', ProductVolume=450, MaximumStorageTime=61320, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'e3823771-6101-4d64-834f-e0171236f5e5'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'e38b463c-3f0f-4fff-8735-54fa7786087f'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'e39e2736-6869-49e5-98e4-453c991f51cf'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'e3b42afe-65f3-4f45-b1fd-e7143161e970'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@22 D4 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'e3c6306a-6ae6-4793-88fe-791aac80b692'
UPDATE dbo.BloodProduct SET ProductVolume=150, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'e3d1139c-510f-4071-956d-178feb7132e3'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'e3dfa37c-ef4e-46db-a876-d407a5472d98'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'e3e0d245-95a3-4ac4-8596-78bb48b0d965'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'e3ebda82-373e-4d7c-9322-fd937019fc82'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 D4 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'e3fbcd3e-e1f3-4def-8b1e-d569bcbbf0eb'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@30 I2 H3', MaximumStorageTime=61320, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'e4041e48-6cba-4f60-a3ed-2ee3d24bbb5e'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@84 C2 I2 H9', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'e42485dc-6c26-4f95-b61a-8ce49ec1fb82'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'e42dac78-7a13-49fd-b2ff-ca57167c3043'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'e435d44c-6149-4be6-a212-b55cdcf82b19'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'e44a944b-58d4-46a0-bebc-e03991f073a1'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'e45953e0-50ab-4504-93bf-f714575667c3'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'e496e8b1-dca2-49d0-b811-ea1726ab3e38'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'e49ed73e-e6be-4a4d-a7b3-b613596e84e0'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'e4a77e0b-f16b-45ef-9fc4-749ef2df4f79'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'e4a89a72-5693-4216-aa97-4fe7862d2342'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'e4b5b516-28eb-4d2d-912e-42852db09641'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@20 D4 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'e4c5b75c-b5ac-4829-b4ef-3961197fbd73'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'e4ceb0e4-a6bd-45f1-83ee-eb8609981c0b'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'e50df5a4-7664-40ef-8138-97037cb91d67'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AY C2 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'e526a010-f304-42e1-ba10-4e351ef22fd8'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@33 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'e52882da-5f87-471c-aebd-210485654cf1'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@11 H5', LastUpdateDate='20100210 13:55:15.970', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'e52f0609-d86e-4550-a551-09e035e7ded2'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'e53060ec-51d1-4366-bf8a-1c333a9d7564'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@30 HB', MaximumStorageTime=61320, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'e532287f-1c5d-4749-8eb0-a07e9df99304'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'e5548a42-5f75-41a1-82d7-849d2df31725'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AY C2 D4 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'e55cf62f-6f92-411b-b102-a11510e12032'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'e5613c48-d296-4cf2-8c85-92465d484a29'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@10 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'e577be38-38f6-4dab-9112-92249745f68b'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'e5a7bd59-584e-4c72-93d2-a56dd90bf3e2'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'e5bb5058-f7fd-482e-9773-842c39557a9e'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@33 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'e5caca9a-3f33-4c30-b8d5-ec2cbb2910e3'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@B7 B2 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'e5d7d794-2af1-47f5-84c4-e10569a9e58d'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'e5f1f80e-d209-4d0f-8d52-1ce2e379718d'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@30 H5', MaximumStorageTime=61320, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'e6258cd1-f447-447e-9d66-a1825ca69953'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'e629fb11-5e8e-4db9-8a02-9ec4ae21d564'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'e63042ce-1c9b-45a9-b87f-64abc7f6050a'
UPDATE dbo.BloodProduct SET MaximumStorageTime=1008, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'e6327c35-77db-4cee-af22-794439060091'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'e652a42d-6cd4-4e61-aa7d-45e6e5394607'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'e6612747-475d-4cb9-adf8-3252fcf02489'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 D4 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'e67bd78a-b407-41a7-ad00-9d2b820a6ca0'
UPDATE dbo.BloodProduct SET MaximumStorageTime=960, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'e67cb953-460c-49dc-9d2d-0f33c4d9e2a3'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@30 C2 H5', ProductVolume=450, MaximumStorageTime=61320, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'e69af77e-63c7-486a-958d-1a8e55824a7b'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'e6aeb811-b64f-42d7-8674-835ecd5bcee0'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AZ D4 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'e6b8c1e1-fa47-40c8-8dc6-ce12eec2527f'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 C2 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'e6bf7192-e321-443b-a163-21c58196a287'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@84 I2 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'e6cba251-d899-45b5-8027-f4f16de0fe00'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'e6dc4475-e000-4993-919c-6e0ba9900c2d'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'e6fdf87e-3c4e-4186-a2d4-7a12c2f87886'
UPDATE dbo.BloodProduct SET MaximumStorageTime=840, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'e7253f81-cda7-442e-b45c-9e64402c3145'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'e72d380c-94e2-40e8-b43a-8a187f222d48'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'e75a3097-654a-4ed6-bbfb-f557e5d55953'
UPDATE dbo.BloodProduct SET ProductVolume=350, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'e764573b-3e5b-46ac-b796-242e2b39bf79'
UPDATE dbo.BloodProduct SET MaximumStorageTime=624, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'e778b5b6-0ca1-4a04-ad6b-47703a09c856'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'e78ca5fc-e692-4419-bf56-f361fed72c0d'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'e78fd8be-2d1b-46af-b729-20da09d23674'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'e7c4404d-cb97-4781-b7b2-af0f6ecc353e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'e7df202f-4f39-4711-be4b-c574553c6dea'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'e7e16d9e-a8c1-4b2a-89e2-8aa3580a5669'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'e7f7a44e-be91-4bff-9fc0-9796a7328f22'
UPDATE dbo.BloodProduct SET ProductVolume=50, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'e8004382-89c3-47f6-8cc1-f0143c456820'
UPDATE dbo.BloodProduct SET MaximumStorageTime=4, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'e80d9a6f-93e7-42e5-a5c3-0c88db90f237'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'e81710d8-7947-4680-9f3d-5eebd3bfea35'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@51 D4 H9', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'e824c684-451b-40ef-961d-b703fc672e80'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'e83b2f9f-389b-4b07-bbee-aba2c8924431'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 D4 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'e84504f9-7bff-4ecc-844a-381fc65d8ef2'
UPDATE dbo.BloodProduct SET ProductVolume=50, MaximumStorageTime=120, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'e8484e9d-be00-4cde-8ada-43709886e50c'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 C2 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'e84922bc-d5bf-4c03-bd54-c6f4e6339dc3'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'e84fd7f2-44b5-4c49-8afb-9c86a5f19265'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'e85b44a4-6138-4b51-a54d-2eea0846c26b'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@30 H6', ProductVolume=450, MaximumStorageTime=61320, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'e85c7837-85c5-44d5-a5ba-523ed9937908'
UPDATE dbo.BloodProduct SET ProductVolume=450, MaximumStorageTime=4, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'e860e4f6-b735-438a-ac2b-eef1a4d7603c'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'e874028e-e2ce-43d4-bd40-73ad01f51d51'
UPDATE dbo.BloodProduct SET MaximumStorageTime=8760, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'e8859cad-3e9c-4e9b-8845-7ebdbc2dd27e'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@33 C2 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'e89014fd-c93b-4f35-91a2-d877879e842e'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@03 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'e8b132f7-6e01-4bf1-ad50-974afeab153c'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 D4 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'e8bfcf6e-92e1-4742-b8b2-d9c15ac5af82'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'e8c5f842-5440-4c8d-92b8-c64de6a63e27'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'e8cdfde8-aea5-43c6-af81-d09a4d8d578a'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@11 C2 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'e8eea9eb-a993-4f75-a2f7-99c4a949606d'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'e8ff2c46-b211-4e00-8cd8-a50186cf5144'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'e8ffbc37-21f4-43cd-8df9-93765188f2d9'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@20 C2 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'e91c53e0-425f-4381-8ecb-1a45ed3cfafc'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 D4 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'e9334f7e-57c9-4838-88d1-f49538224a27'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'e934b552-b38f-463e-a0f4-0b12a8b5c749'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'e93d9376-7a92-4f17-be70-03af610cbc95'
UPDATE dbo.BloodProduct SET ProductName=N'Thawed Apheresis PLASMA|ACD-B/XX/refg|Open|Irradiated|>=600mL|Frozen >24h|Aphr not automated', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'e93e553a-99d2-447f-8756-b4380c06b687'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'e93f8b57-8592-491a-a44d-8f92037d37d2'
UPDATE dbo.BloodProduct SET ProductShortName=N'PLT Pool PASII LUKOPR BUFCT', ProductAttributeForm=N'@AE D5 G2', LastUpdateDate='20091109 15:02:22.663' WHERE BloodProductGuid=N'e94734da-a054-4bc0-a0e0-579918a9943a'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'e9553cbe-9098-4a30-ae9d-30c7579baf58'
UPDATE dbo.BloodProduct SET ProductShortName=N'PLASMA CPDA-1 MNFI ', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'e95a08fe-5a17-4053-908d-4b7a600c8780'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'e97d88c6-5c11-4d4d-a44d-f3e42a4456c0'
UPDATE dbo.BloodProduct SET ProductVolume=200, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'e98084a0-94e6-4e02-bf3c-308290acdd06'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'e98e847e-13c6-48c3-b494-a2ab457d1222'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'e98ff397-d7c6-4da5-86e0-5df2ccc07eae'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'e9a25268-365d-43af-b920-ae8970a8504f'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'e9abe521-6bd7-4654-83e7-49540c294aa1'
UPDATE dbo.BloodProduct SET ProductShortName=N'RBC Deg None IRD', ProductAttributeForm=N'@AS C2 H6', LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'e9b6c3a2-ec65-4b94-b978-fbcb3a13cf1f'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'e9e27e7b-26fc-46c3-a025-2c85eba556b2'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'e9e2adf9-f41a-467c-826a-f70e6e71d705'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'e9ec4370-dacd-49f7-9e85-d6dbb7175ada'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 C2 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'e9ff7890-1b76-4f34-bed6-ca5116ad7819'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'ea14b146-9fc1-413a-91c3-089f4a33f07f'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@07 C2 D4 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'ea4e7812-7f15-46c1-a80b-7f8984e7d2b3'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'ea74e646-aa1e-442a-b5e1-134433c735fd'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@22 D4 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'ea82acca-d317-416f-9630-4560dc2c97b7'
UPDATE dbo.BloodProduct SET ProductShortName=N'PLASMA Liq NS IRD', ProductAttributeForm=N'@CG C2', MaximumStorageTime=624, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'ea8d8f94-a0f5-4f7b-8d25-4fbdd9ee4cb3'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AZ C2 D4 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'eabfd231-324c-4764-b785-c8c62e120bcc'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'eac3a424-c92d-4cae-b85e-637faead8f26'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'eac40ecc-42c3-41f3-8a2c-ea059f1541d5'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'ead89291-548d-4a22-b25f-8a76053120b9'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'eae0e7ef-58b3-4806-9bfe-3458d8fa2d57'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'eae1b739-697d-419c-98cc-8e39b18edd23'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'eae4eab4-2661-46db-821d-1ab0d937d4e1'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'eafb904c-c816-4878-b5f4-97057e813794'
UPDATE dbo.BloodProduct SET MaximumStorageTime=960, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'eb213380-9dba-49c9-aabb-f1b82860774c'
UPDATE dbo.BloodProduct SET ProductShortName=N'RBC Deg None IRD LUKOPR', ProductAttributeForm=N'@AS C2 D4 HB', LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'eb23d726-cfaa-4209-a291-83c3b6b56ecc'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'eb255f9c-6ac3-4ed3-86eb-fe5b8828aecc'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'eb396b76-1de2-4b5c-b472-9d6498623ca9'
UPDATE dbo.BloodProduct SET ProductVolume=50, MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'eb3ac287-6fd5-4b65-b83d-77ba391b40ea'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'eb520a2a-8781-4859-96d3-c4a0f2bd4a21'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'eb7dc56a-9e94-4ebe-b9d1-99065816d7ca'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'eb987ac7-5192-476e-9204-515ef1229f9d'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'eba6d93c-d7c7-4123-8248-d68e0e8e4720'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AZ C2 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'ebb3e7f4-afb9-40a9-a31b-97d8fc4b86eb'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 C2 D4 HB N2', MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'ebdd5824-8eb6-4001-9597-269faec0c6c0'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'ebf909ff-52c6-4707-9740-a106df183cc6'
UPDATE dbo.BloodProduct SET MaximumStorageTime=960, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'ec0d588f-335f-4d7a-b501-5fa91e96cafa'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'ec6026d5-a25e-492a-82b2-dd251d9d3db8'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@33 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'ec6b8127-3318-4ebc-81cf-04810db05ba4'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'ec7498c6-6e38-41e4-a627-8c388f3a8a65'
UPDATE dbo.BloodProduct SET ProductVolume=50, MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'ec76eafa-8d3f-490d-bb16-dbbf018fa94c'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@33 C2 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'ec8222b3-8a7e-49f4-9efa-2fd934fadf58'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'ec918aa4-248d-4772-8fe2-e98e1da2f608'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'eca0caa4-b5ca-4173-a9ae-27f112cd0a6f'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'ecbe64a5-bd81-4453-bb24-bf1a1ebafa62'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'ecbe7581-4178-4d26-b153-fdb43039161c'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AY C2 D4 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'ed1a789d-1e6c-4b9f-a732-17d5a217c1f4'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'ed32f500-4b84-490c-949f-e5febc09ad36'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'ed37cba0-413a-42ab-8207-324d68ea0ff0'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'ed543ebf-3448-4679-be59-e600926739e0'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'ed578b25-7d3b-41d4-a24c-a91ad8b46b72'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'ed5c4a9d-c7bd-4c0a-b4bb-81bc045972ce'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'ed6af9c1-fbbd-4565-82b8-a8711185070d'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AZ C2 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'ed7c38f3-645c-49ef-913d-93871ac5176c'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'ed7ddc67-e130-45d7-8a78-31d556d52923'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@18 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'ed7ef446-f4c4-463e-815d-ffb6fe3b0f48'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'ed8d52d0-919a-4bb7-80b9-92a96e08831c'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'eda1caf9-8e6f-4e95-a3d5-58e870669513'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'eda86712-d37b-4b8f-bb20-c9f95671d48f'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'edcd7f05-93ed-4ed2-9831-464d91afc40b'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'eddd5ac4-78fb-48f1-9161-b2a7f40d4954'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@03 C2 D4 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'ee032aee-ba45-4332-bc94-bba3a02c2ce9'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@84 C2 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'ee0fe0b2-1ba1-497b-b3c3-9094c163c20e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'ee318c38-dda3-470d-b674-799ab598cd55'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'ee410618-49f9-4ab1-a0b9-419055f0db83'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@10 C2 D4 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'ee42f753-9a48-46b4-8bab-e749aaacafa8'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'ee464842-8ac1-4554-a6c7-218070018fe7'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'ee5639af-c049-493f-bc22-401a4ce22f5d'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@10 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'ee5f8029-2d2b-44fe-9b0d-12babfaae559'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'ee6361f3-d522-4a73-b479-de28c564c173'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'ee848648-0a4f-4108-b506-16d3a9fe9865'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'ee8c755f-90af-495a-abee-2d7c270a2412'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'ee8e4769-0ef7-43cb-9955-993cd92263e3'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 C2 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'ee99607e-e6a1-4641-869a-4ce5941f4b79'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 C2 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'eeac0321-41f4-431a-8bc6-be0449805ad8'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'eedebb1e-ffcc-4bb6-a711-2420e9ba77c2'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'eeee8882-f32a-4cea-bd11-5f5e1339e388'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@20 D4 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'eef0210b-ed02-413a-938b-81952ff91d00'
UPDATE dbo.BloodProduct SET ProductVolume=50, MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'eef2f3dd-6a09-4ad6-bdba-48a5f39b99e0'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'ef13923b-c5a0-4354-a26c-d0c76f7012a4'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'ef18e9fe-25b1-4053-8450-4ed6834c95ca'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'ef197bb0-d99c-4c5f-a7c4-64d1fb345d73'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'ef1faa87-bcbd-48ba-aef9-460a7457f577'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 D4 H3 N2', MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'ef2669d0-c750-41c2-b94c-43752d015930'
UPDATE dbo.BloodProduct SET ProductShortName=N'RBC Deg None IRD LUKOPR', ProductAttributeForm=N'@AS C2 D4 H9', LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'ef2c8a47-c2c0-4afc-a727-4542219bad7a'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'ef30e1c8-7553-4347-b0d7-0df5d5b6ce9a'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@22 C2 D4 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'ef5d345b-eb6c-4d3d-81f4-d7051a6366b5'
UPDATE dbo.BloodProduct SET RetireDate='20090901 00:00:00.000', LastUpdateDate='20091109 15:02:22.803' WHERE BloodProductGuid=N'ef782151-9f44-443a-819b-83bfaec233c2'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'ef7e03c8-df92-4d32-988d-7f4c9e986349'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AZ HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'ef956baf-5df6-4681-a96b-b0ea6ac924ba'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'efa1439d-dc28-4494-a752-6dedae03f1bd'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'efad28b2-27b2-4d96-abb2-20080ee69178'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@07 C2 D4 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'efd46370-003b-4714-b5d6-2c12c3f95e41'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'efd47c86-5a3f-46cf-8679-6475c31745ea'
UPDATE dbo.BloodProduct SET ProductVolume=350, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'efd86db2-fede-4747-8f99-b2e9b17bb989'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@51 D4 H6', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'efe72339-3fbe-4d75-9e51-c8ed8c304700'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'eff659cf-f445-46fc-b4ba-6fc6df267065'
UPDATE dbo.BloodProduct SET ProductVolume=250, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'eff93f9f-9dc0-4119-99f6-339aebdf216d'
UPDATE dbo.BloodProduct SET ProductShortName=N'FFP AFR Thaw None IRD LUKOPR', ProductAttributeForm=N'@AS C2 D2 H6', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'f02d0796-2248-42cf-9dcf-b1fbd596acd7'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'f0337d5d-e140-4991-bbd0-125ebb1be241'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'f0520546-e3fa-4d6e-9cd7-be98eb6c701e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'f054993f-9279-40ca-8d44-6ba8b395f36a'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'f06606bb-30f7-4b5b-b991-cff4803e0d12'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'f06ffee9-63ad-49dd-8227-4b947065ac8a'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'f08b62f9-6651-44d6-aafb-b7d0930dd652'
UPDATE dbo.BloodProduct SET MaximumStorageTime=4, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'f0a745d3-a843-47d1-8a46-778947e3fe35'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'f0af45f4-0dea-4b99-8c6a-61582f295529'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 C2 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'f0b9a999-49e4-4b3e-80bc-266b6057ac85'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'f0bcdf57-1d17-4cfb-baa4-3c8799946ca6'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'f0bd0f62-80de-4012-b45f-23c48cc20334'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 C2 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'f0cb5659-f44d-4553-ac22-669e048d4cda'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'f0d9d2c9-cbb9-46e3-b89c-a0ffb3e241de'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'f0e21130-fec0-469f-9d1b-5faef222a722'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@84 C2 D2 HB', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'f0e9f395-577f-45bd-9828-83bf29b38717'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@09 C2 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'f0f2c394-bc7b-46e0-a48f-0725d3f6f0e2'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'f10cdae2-c426-41e5-8a3b-b20c5cc55497'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 C2 D4 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'f116a022-956b-4c4b-bbb0-247b124f43ed'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'f125f84a-97dc-4ab1-8877-6c38d6bf087e'
UPDATE dbo.BloodProduct SET MaximumStorageTime=4, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'f138466e-0e35-46ee-b3e4-5ca6fb49f8d0'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'f13ab787-505e-4fdf-ac3e-6bec74cff1ae'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'f17277ea-826d-4238-92b1-0e366a352c5a'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'f174576c-8603-46be-a515-7c45adaa7a19'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'f187265e-6a86-4887-8a17-1ec96893c38e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'f19e2e3a-4b28-44b2-869d-459f2840f803'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@07 C2 D4 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'f1b20a14-00f7-4e3f-bb0a-5d69c47ae23c'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 D4 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'f1d03c5a-e822-4310-8a7f-317e193aa893'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@07 H3', LastUpdateDate='20100210 13:55:15.970', LastUpdateUser=N'vhaishsmithm' WHERE BloodProductGuid=N'f1da18c9-b2b3-43d4-aef0-0c5e6d1e2ab9'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'f1f83226-f4f5-459b-b615-a71b7b2fcd7f'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'f206b1f1-5538-4faa-898a-ae971072da79'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'f2293ceb-c145-4612-8c45-4eea04ec29a1'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 D4 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'f25a8c8e-5c1b-4dd9-9a38-c248f4a7623c'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'f2927735-1a64-4c39-a3c3-9a028e5220b2'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'f29a0418-1c9d-4b24-8bf2-bdacc3a37701'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@84 D4 H6', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'f29f50ad-0484-4cf9-bef3-abf6c26dee28'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'f2a3032b-d882-4258-a6bf-3c5983b9dd01'
UPDATE dbo.BloodProduct SET RetireDate='20030901 00:00:00.000', LastUpdateDate='20091109 15:02:22.303' WHERE BloodProductGuid=N'f2b9b055-0b98-4777-88c5-af7b2bee8762'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'f2c81cc0-6c28-461c-bd67-3b01fd587367'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'f2f12a12-ab5e-4d23-8f2e-124a6ce5802c'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@07 C2 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'f31dab7e-ca99-47c7-910f-a4ba0d1de77b'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'f3404584-2d8b-44da-b4cd-9d2e117de066'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'f3408a57-4ae5-451b-9bab-ffc1e8eaeeaa'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@18 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'f345b024-f123-4344-b4bf-9ebef5daa5d1'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@07 D4 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'f37c92cb-24d6-44ee-b834-a49406627358'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'f3a0c583-b7bd-4d34-8bb8-d4f0533a5308'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'f3a83f90-6889-452a-a077-be0610061745'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'f3b6c470-97f4-49c7-a5cd-e89f354db81b'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@20 C2 D4 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'f3bbf1ba-29f4-4035-865a-8f022cd3a485'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'f3bc53ec-8647-494d-9c27-c894cf6e8c6b'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@11 D4 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'f3fcb738-fe9d-4d7d-8416-6a70f8d6dd58'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'f41df4a1-46fb-4134-8bea-69aebc58b32a'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@33 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'f424f0c2-91d3-4824-a395-43f80e163ee0'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'f42b1342-8546-48ee-9134-3f260ee46096'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20100302 06:47:21.227' WHERE BloodProductGuid=N'f4349b32-b244-4d2b-9517-1752ab5b8a0f'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@54 D4 H6', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'f447f73e-0e12-44b9-9ca8-3d64991745d1'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@B7 B2 C2 D4 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'f45a2983-59b1-497e-9e3e-04129e63f639'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@30 C2 D2 H4', ProductVolume=450, MaximumStorageTime=61320, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'f4867fd0-0ad5-40df-908f-e17abb0319fc'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'f493b51a-555d-4c24-bdec-65c70b492b07'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'f49d7f2d-54a0-4be9-9ded-81b63e0b840b'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@84 C2 I2 H5', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'f4b4d1c0-32b3-4689-bc0b-e79d1b185a1c'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'f4cd1aac-413c-4642-81de-3041ef6d6fd5'
UPDATE dbo.BloodProduct SET MaximumStorageTime=4, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'f4d6ada9-ce26-4fe2-a8d4-773f542e5797'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'f4e784c8-c255-4b4c-9fec-05769510397a'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 D4 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'f4f2e5bd-76ba-48de-a646-d8c98cc377ee'
UPDATE dbo.BloodProduct SET ProductVolume=50, MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'f506b583-93d6-436b-b44b-11c4a480b4da'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'f5226ac1-af22-4761-9a3c-daedcb423d3c'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'f526acd0-db6f-45c3-8050-6ff376d5c534'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 D4 H6 N2', MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'f5318ed4-42f2-46e7-af75-5577f0355282'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'f5404bc8-793c-456d-93ec-f87393888b11'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'f5413783-f932-40b6-9e4c-13e35723f00b'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'f54f6718-5698-438d-a595-dcdc96cfdf26'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'f553563f-5016-40a6-bd46-23a8cc7c58f0'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'f5570a22-f198-4b6d-a0bc-dc4f3244386f'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 D4 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'f56664c6-373d-4a2b-8913-b15df13790f1'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'f57687e9-8814-4414-afd3-0b137be32249'
UPDATE dbo.BloodProduct SET ProductShortName=N'FFP AFR Thaw None LUKOPR', ProductAttributeForm=N'@AS D4 HC', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'f5809f5e-abe1-4a6b-93f8-54b48db19113'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'f5aa481e-2c49-4853-a1df-f23bd4fd1508'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@20 C2 D4 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'f5b30f21-03ca-43ad-a430-564ae7282301'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@84 G7 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'f5d505fd-bd6e-4954-bd29-3fbbbd89b9d5'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'f5d660e9-eeb7-4370-8b9b-78e491af985c'
UPDATE dbo.BloodProduct SET MaximumStorageTime=1008, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'f60da0cd-8a70-4133-a919-fd08fd14769c'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'f61b3709-0c93-403e-b375-5bd4d0a334ff'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'f63c0a87-1b8d-4b6c-8970-c7235520c1fa'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'f646c562-eaa8-47cf-b6d4-d08ca81a0164'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'f64ce0ca-9c5a-4bc8-873c-e6ee65c9bd94'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'f652542f-bf73-4959-8287-e45025a7727f'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'f657edbf-c9fe-4fb7-8620-7d1e79d52c16'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@10 C2 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'f6589d35-94b1-4827-804b-7442079168eb'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'f6605c2d-8178-4240-8edf-5682e0f0da69'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 D4 H5 N2', MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'f6651068-afa3-42ad-a34d-b4ea42652ef4'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'f6659bd5-51f3-4762-bf0e-457ccef4bbfd'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'f66ca02c-2324-4164-8efe-0f4ba451a257'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'f67b84dc-359e-4259-a1bb-d2ec4a29fa15'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 D4 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'f6801ee1-d2b5-414c-b2b8-86283e24f844'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'f6983478-4420-44d5-86a4-8b2515538069'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@84 I2 HA', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'f6a19b16-3190-400c-936d-6844c364fdb3'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'f6ba9fc9-99fc-4e60-a142-f7e74962f1c2'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'f6bb58c6-fac3-4450-8085-5856f630b93b'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'f6bc5d13-b869-4b08-99e0-75581d126b08'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AZ H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'f6fb2132-52b4-41f4-9ca6-cc363e2a0c9c'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'f711519f-a879-4076-af92-9b068c6814ff'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'f7511bf5-3136-46c6-8048-0002d234403c'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'f75133e6-b14a-4cf1-ab22-b2d8e13e18fe'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'f7593345-ddfb-419d-9e81-0e9ed7c71778'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 C2 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'f759a180-196f-42e3-97de-2f12120d67d7'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 D4 H3 N2', MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'f7897504-4ac2-4c72-ac84-eda2256701e3'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'f790e7cc-7f34-4cca-97ff-a7486d0345f3'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'f7a80419-ef33-49ef-b579-a875ec731f95'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'f7c83c50-ccd7-4adb-8069-0c130d148964'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@B7 B2 C2 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'f7ddd839-e204-4528-9661-8c65efa50015'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@09 C2 D4 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'f832523a-4694-43b4-9d18-8fa0b9f40b08'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 C2 D4 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'f853f113-660d-4efa-93d3-2382cbe9827f'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'f858dbb0-2e84-41f2-9cbe-e9e41d464a1b'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'f8688c31-68a0-4d87-9acf-b01ae776dbc8'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'f87cbf4d-bde8-499c-b2c6-4984479da587'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@03 C2 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'f891673f-0c38-41bb-8df6-a39953023b27'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@03 C2 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'f89fb596-e011-430f-b0cf-d9e1f61294e2'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'f8a3caff-a7f9-4fa8-94ff-fd2d5b46f15e'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'f8a536fe-da76-43aa-858e-4b0f912fc0a5'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'f8b674e6-8b16-45e9-9088-92ca4a125373'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'f8ecd1a3-fa6e-450c-b243-1857c0deba74'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'f8f091b8-7b05-4328-9b4a-e723c6e2f716'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@11 C2 D4 H5', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'f8fb625f-0fdb-4551-8bf7-a09144728f3f'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'f95b4108-713c-4779-8323-e7e67e18119d'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'f95e05f5-ebc0-47a7-9587-8695b82a6271'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'f973833a-c69b-4694-ba64-6783d2d5c484'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@03 D4 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'f979dbb3-5342-48e3-91d1-abb0f56c1a00'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@03 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'f9947ba4-2f94-4ddb-a1d9-3acd0442912a'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@B7 B2 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'f9995263-2d44-4d12-b34b-8a01717bf515'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'f9b46ae4-4e73-4acf-95c0-0a8a34b98a28'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 C2 D4 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'f9cb0f9c-7c53-4407-a953-2077dba6b5a9'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'f9d4b0a9-b926-4b9e-aa48-b7f845bff2d1'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS G7 H5', LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'f9da739d-903d-46e5-b128-16c3b5e9220a'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'fa1b5395-fac9-44b6-b4f5-0d70daacc0db'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'fa1bf434-90d6-43a6-a03e-4dfa0e2d0dc7'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@11 C2 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'fa498ab5-6127-492b-9d14-b64a97a01c67'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'fa60610e-db80-46e5-a1d5-34ead12a1b61'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AY C2 D4 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'fa6453a8-2f88-48d4-9efd-2933ca146dc4'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'fa77341b-fbe5-484c-99b2-c6dc4b6e7bb8'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 D4 H6', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'fa7bd40d-fc35-48f6-8bab-7e7d53806739'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'fa84735e-264a-46c9-9406-5c754639f646'
UPDATE dbo.BloodProduct SET ProductVolume=50, MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'fa8cea76-fc8a-4fe6-9f84-d6056fcba2ef'
UPDATE dbo.BloodProduct SET MaximumStorageTime=4, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'fa931e84-4d09-452c-84c2-769a056b138c'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AZ D4 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'fabf205d-f13d-490c-a89e-5893b94ed86b'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'facb493f-28eb-49f5-b5ad-d6377a32ea28'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'facdb859-c0fb-4dfa-b644-d5791ac050f0'
UPDATE dbo.BloodProduct SET ProductShortName=N'FFP AFR None', ProductAttributeForm=N'@84 HA', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'fad319c7-764d-4a60-b226-2861614be8d5'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@18 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'fadfed0b-fb7e-4ed6-ac16-d99dc9012136'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'faeb0a92-0f18-43c8-8f29-1a7eec3c230c'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'faebf997-9d7a-497f-891a-2c0c4a89e6a0'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 HB', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'faf0bec7-9a8e-4d67-8a17-003edd518e1c'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'fb176624-4ac0-4022-9f5c-ab2204ceb6b9'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'fb28a957-18fa-4939-992e-240b17a6dbf3'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'fb3b622a-e271-4c2a-a8b1-48577ef6b570'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@84 C2 D2 HA', ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'fb658605-d43b-42b2-8339-99e8373f7457'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'fb881282-460c-4802-99a5-90b0036dfb4b'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'fb89f11d-778f-409e-8f59-0aa6ec8ae395'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AY C2 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'fba10161-55ca-43c9-83c7-d43ed65b8a94'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'fbbfcc10-b2c8-41f6-b146-4a266e14bb43'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@73 C2 D4 HC', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'fbbfdc87-b4f0-4199-96d0-06ad449fa101'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'fbd91ed7-87c9-4af6-9d26-d0b9c3915f5f'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'fbfa6ef2-f58b-40c1-8711-92acf3247836'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'fc2588c0-8fe9-429c-b82d-76d1401a0c35'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@03 C2 D4 H4', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'fc3cf28f-1e81-4cca-87d5-6a3416ead923'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 C2 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'fc4325e5-4eb7-444a-a9d2-31f059d645d4'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'fc6e06da-573b-4b43-a8a6-7cc677891cbb'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@03 D4 HA', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'fc850d0b-5ab4-4b43-a163-86fbf9f9d71a'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'fcc0ecc2-dad5-42d4-98e1-34fd50e6c7e9'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@30 H4', MaximumStorageTime=61320, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'fce16035-52f7-48cd-a5d9-2e0d787c2b2f'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'fce442ec-f56d-4b35-bd83-a1fe6c3aa6eb'
UPDATE dbo.BloodProduct SET ProductName=N'Washed Apheresis PLATELETS|None/XX/20-24C|Open|Irradiated|ResLeu:<1log6|1st container', LastUpdateDate='20091109 15:02:22.743' WHERE BloodProductGuid=N'fd8c9a4e-a215-47c0-9f92-81ccd2061c76'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'fdaba984-836a-49b6-b0d3-2bdb05698f74'
UPDATE dbo.BloodProduct SET MaximumStorageTime=24, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'fdb7dc0b-9e88-432c-8854-57d740670982'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@AS B2 H9', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'fdeb82a9-ff55-4231-bb19-517bd56ffe45'
UPDATE dbo.BloodProduct SET MaximumStorageTime=120, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'fe047e0a-e36a-4d49-aa61-f6783784ea06'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@30 C2 H6', ProductVolume=450, MaximumStorageTime=61320, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'fe127ab0-da69-443a-9b56-127d0580c12a'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'fe28fd73-e34a-4715-b4c0-7578c9e7f781'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'fe2a075e-22b8-43e3-8180-98cb926d530c'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'fe402cce-ffc2-4bd7-ba22-24855d10b9b9'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'fe4c1af0-2430-4858-9bfc-046c6cc8c51a'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'fe670c21-bf0f-49fa-ac3b-0bd82985e908'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'fe6c6068-f555-449b-9db9-929dfc818d14'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'feb7c4ef-b23b-4eda-81cc-b28e9c4cd956'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'fec854a5-54d5-43d1-b5fc-39ba1c0f72aa'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'fedbf2c2-81d8-479f-8a76-fb432959acf9'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'fee6c847-8509-4cbd-a05a-7fabb34e6282'
UPDATE dbo.BloodProduct SET ProductAttributeForm=N'@09 C2 D4 H3', LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'fee9a25e-4ed6-4e40-8964-91a5392b2ced'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'ff1fc422-d917-4654-a15a-642556ae70cc'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'ff211bda-3afb-4193-9e66-bf7dc1d15eef'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'ff30828d-0378-4c5e-80b8-ca5a194c60d1'
UPDATE dbo.BloodProduct SET MaximumStorageTime=4, LastUpdateDate='20100210 13:55:15.970' WHERE BloodProductGuid=N'ff74cad9-52e9-4924-81a7-e01861c53527'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'ff889b81-2ef9-411d-82d1-9ba2474b3b22'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'ff9d0325-1068-43af-ba88-d928cd6ed695'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'ffc04628-4562-405b-bfe6-26bd0d3ad026'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'ffe1f1cc-7979-450c-8350-9c1aecd79b62'
UPDATE dbo.BloodProduct SET ProductVolume=450, LastUpdateDate='20100514 14:47:38.847' WHERE BloodProductGuid=N'ffe3fb1e-db75-4067-8e49-6cffd76aad23'

-- Add 554 rows to dbo.BloodProduct
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'00049d35-baea-4d83-85eb-23d133253281', N'PLATELETS|CPDA-1/500mL/20-24C|Open|Irradiated|ResLeu:<8.3log5|Plasma reduced', N'PLT CPDA-1 OPN IRD LUKOPR PLS Red', N'E020', N'@67 B2 C2 D6 E5', 50, N'E6168', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:23.290', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'008c81ca-390f-4396-bcfc-e17b253e6b10', N'Washed POOLED PLATELETS|None/XX/20-24C|Irradiated|ResLeu:<1log6|From 6 donors', N'PLT Pool Wash None IRD LUKOPR 6DNR', N'E023', N'@71 C2 D5 J6', 200, N'E6274', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:37.963', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'016b31bb-d246-426e-aca6-a1884875835e', N'RED BLOOD CELLS|CPD>AS5/450mL/refg|ResLeu:<5log6|Supernat reduced', N'RBC CPD>AS5 LUKOPR SUPRed', N'E002', N'@22 D4 EA', 350, N'E6395', 1008, 0, 0, 1, NULL, N'A', '20091109 15:17:58.943', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'02751ffa-6b02-4aff-9e84-fe51d13f1aba', N'Thawed FRESH FROZEN PLASMA DIVIDED (by pheresis)(-18C)(Part G or 7)', N'FFP AFR Thaw None', N'E013', N'@AS HB', 450, N'48217', 24, 0, 0, 0, NULL, N'A', '20100514 15:01:54.953', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'030ce05a-d60a-49a6-bb63-1acf4e2e4535', N'Thawed CRYOPRECIPITATE|None/XX/rt|Open|Irradiated|ResLeu:<5log6', N'CRYO Thaw None OPN IRD LUKOPR', N'E029', N'@83 B2 C2 D4', 15, N'E6613', 4, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'03898446-5a0c-48a2-aaa9-32f0639d84cf', N'Apheresis PLATELETS|ACD-A/XX/20-24C|Open|Irradiated|ResLeu:<1log6|Supernat rem/Plasma added', N'PLT AFR ACD-A OPN IRD LUKOPR SR/PA', N'E024', N'@73 B2 C2 D5 E8', 200, N'E6551', 4, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'050d3ba1-d6b7-4980-90a8-fe0d1403cb06', N'Thawed POOLED PLASMA|CP2D/XX/refg|Open|Irradiated', N'PLASMA Pool Thaw CP2D OPN IRD', N'E011', N'@13 B2 C2', 500, N'E6619', 4, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'0588c6b9-7500-4bb9-91a9-8346a416b084', N'POOLED PLATELETS|CPD/XX/20-24C|From 3 donors', N'PLT Pool CPD 3DNR', N'E022', N'@A7 J3', 200, N'E6223', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:23.307', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'061adb62-5df5-43c2-a363-97fff46fc849', N'Thawed PLASMA|CP2D/450mL/refg|ResLeu:NS|Cryo reduced', N'PLASMA Thaw CP2D LUKOPR CRYORed', N'E011', N'@11 D2 E3', 225, N'E6433', 120, 0, 0, 1, NULL, N'A', '20091109 15:19:05.993', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'0677bcbd-4aa8-496d-92e3-16837a28ed42', N'Liquid PLASMA|CPDA-1/XX/refg|For mnf:noninjectable restr use', N'PLASMA Liq CPDA-1 MNFRNI', N'E011', N'@10 A5', 225, N'E6486', 960, 0, 0, 1, NULL, N'A', '20100514 14:47:38.847', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'074a6f21-d200-441b-9447-30fe4c34a6d0', N'Apheresis PLATELETS|ACD-A/XX/20-24C|For mnf:noninjectable|Irradiated|ResLeu:<5log6|3rd container', N'PLT AFR ACD-A MNFNI IRD LUKOPR', N'E024', N'@73 A3 C2 D4 H5', 200, N'E6450', 120, 0, 0, 1, NULL, N'A', '20091109 15:19:52.150', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'0755bc5c-de9e-45a8-a034-6912d790c8f7', N'Washed POOLED PLATELETS|None/XX/20-24C|Irradiated|ResLeu:<1log6|From 2 donors', N'PLT Pool Wash None IRD LUKOPR 2DNR', N'E023', N'@71 C2 D5 J2', 200, N'E6270', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:37.963', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'0800c1ec-b228-4dcf-9bf6-1917be92175f', N'PLASMA|CP2D/XX/<-25C|For mnf:injectable|Frozen <=15h', N'PLASMA CP2D MNFI', N'E010', N'@CW A2 G5', 225, N'E6380', 8760, 0, 0, 1, NULL, N'A', '20091109 15:18:54.163', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'08324b9a-a8e4-4684-b239-78b0d0e6caa8', N'Washed RED BLOOD CELLS|AS3/450mL/refg', N'RBC Wash AS3', N'E003', N'@D3', 200, N'E6499', 24, 0, 0, 1, NULL, N'A', '20091109 15:18:36.150', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'08af260f-e9bc-4c28-a3f8-c5fece19365f', N'Washed POOLED PLATELETS|None/XX/20-24C|Irradiated|ResLeu:<1log6|From 4 donors', N'PLT Pool Wash None IRD LUKOPR 4DNR', N'E023', N'@71 C2 D5 J4', 200, N'E6272', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:37.963', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'08f9b402-e3d2-44ca-89f9-67f0b415ef7e', N'POOLED PLATELETS|CPD/XX/20-24C|Irradiated|Buffy coat plts prep|From 6 donors', N'PLT Pool CPD IRD BUFCT 6DNR', N'E022', N'@A7 C2 G2 J6', 200, N'E6253', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:37.947', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'098a3133-e1cf-4c0e-9d69-015dc0e433eb', N'FRESH FROZEN PLASMA|CPD/350mL/<-30C', N'FFP CPD', N'E010', N'@CZ', 225, N'E6504', 8760, 0, 0, 1, NULL, N'A', '20091109 15:18:54.163', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'099c4c6d-3ea2-45d8-8585-3e8b6f27c8dd', N'Thawed FRESH FROZEN PLASMA DIVIDED (-18C or colder)(Part A or 1)', N'FFP Thaw None', N'E011', N'@AS H3', 225, N'48201', 24, 0, 0, 0, NULL, N'A', '20100514 15:01:54.953', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'09fe0abd-bab5-4c73-9b87-5a6d9117ca49', N'RED BLOOD CELLS|CPD>SAGM/500mL/refg|Open|Irradiated|ResLeu:<5log6|Supernat rem/Plasma added', N'RBC CPD>SAGM OPN IRD LUKOPR SR/PA', N'E002', N'@CM B2 C2 D4 E8', 350, N'E6375', 24, 0, 0, 1, NULL, N'A', '20091109 15:17:58.943', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'0a465329-8471-49e7-a78b-85eac67101b7', N'FRESH FROZEN PLASMA|CPD/450mL/<-25C|Frozen <=8h|Quar:>=112d/retested', N'FFP CPD QUAR', N'E010', N'@A2 GB I4', 225, N'E6303', 8760, 0, 0, 1, NULL, N'A', '20091109 15:18:54.163', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'0a5f57fc-61f2-4b7c-86c9-9d6a02bf3e7c', N'Thawed Apheresis CRYOPRECIPITATE|None/XX/rt|Irradiated|ResLeu:<5log6', N'CRYO AFR Thaw None IRD LUKOPR', N'E033', N'@83 C2 D4', 100, N'E6630', 6, 0, 0, 1, NULL, N'A', '20100514 14:47:38.847', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'0a876b13-e4f4-4a11-901f-8f43d3ef915e', N'Apheresis PLATELETS|ACD-A/XX/20-24C|Irradiated|Plasma reduced/Plasma added|2nd container', N'PLT AFR ACD-A IRD PLS Red/PA', N'E024', N'@73 C2 EE H4', 200, N'E6479', 120, 0, 0, 1, NULL, N'A', '20091109 15:20:06.887', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'0ac025fa-19c7-4115-bf03-9df6f9ad7b55', N'Apheresis PLATELETS|ACD-A/XX/20-24C|For mnf:noninjectable|Irradiated|ResLeu:<5log6', N'PLT AFR ACD-A MNFNI IRD LUKOPR', N'E024', N'@73 A3 C2 D4', 200, N'E6462', 120, 0, 0, 1, NULL, N'A', '20091109 15:19:52.150', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'0b02803c-1578-4a45-b565-ed88bf3f1dfb', N'Liquid PLASMA|CPD/XX/refg|For mnf:noninjectable restr use', N'PLASMA Liq CPD MNFRNI', N'E011', N'@06 A5', 225, N'E6485', 624, 0, 0, 1, NULL, N'A', '20091109 15:19:05.993', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'0b697bce-84fa-4c6d-ac26-f6e8e9424160', N'Washed Apheresis PLATELETS|None/XX/20-24C|Open|ResLeu:<5log6|3rd container|<3log11 plts', N'PLT AFR Wash None OPN LUKOPR', N'E027', N'@71 B2 D4 H5 JI', 200, N'E6411', 4, 0, 0, 1, NULL, N'A', '20091109 15:20:06.887', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'0bd76b9a-2235-48fb-b3cc-6dd8941e04d8', N'Apheresis RED BLOOD CELLS|SAGM/XX/refg|Irradiated|ResLeu:<1log6', N'RBC AFR SAGM IRD LUKOPR', N'E009', N'@A9 C2 D5', 350, N'E6550', 672, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'0c0fccbf-a89f-424f-8dda-96298336c160', N'Thawed FRESH FROZEN PLASMA DIVIDED (by pheresis)(-65C)(Part H or 8)', N'FFP AFR Thaw None', N'E013', N'@AS HC', 450, N'48318', 24, 0, 0, 0, NULL, N'A', '20100514 15:01:54.953', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'0c46ff67-b7c0-4991-8957-572e550e259f', N'FRESH FROZEN PLASMA|CPD/450mL/<-25C|For mnf:noninjectable|Frozen <=8h|Quar:>=112d/retested', N'FFP CPD MNFNI QUAR', N'E010', N'@A2 A3 GB I4', 225, N'E6307', 8760, 0, 0, 1, NULL, N'A', '20091109 15:18:54.163', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'0dc80a2c-0849-47d8-9224-631d3264c04b', N'POOLED PLATELETS|PAS-E/XX/20-24C|ResLeu:<1log6|Buffy coat plts prep|Riboflavin-treated', N'PLT Pool PAS-E LUKOPR BUFCT Ribo', N'E022', N'@D5 D5 G2 K6', 200, N'E6643', 4, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'0dfe3188-29ea-4689-ae9f-d1cd03105ee1', N'POOLED FRESH FROZEN PLASMA|CPD/XX/<-30C|ResLeu:<1log6|>=600mL|From 5 donors|Psoralen-treated', N'FFP Pool CPD LUKOPR LowVol 5DNR Psoraln', N'E010', N'@A4 D5 F7 J5 K5', 500, N'E6438', 8760, 0, 0, 1, NULL, N'A', '20100210 13:55:15.970', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'0ea2f43a-bfa6-44d4-9086-74180d5c1e0c', N'Apheresis PLATELETS|ACD-A/XX/20-24C|Open|Irradiated|Plasma reduced|<3log11 plts', N'PLT AFR ACD-A OPN IRD PLS Red', N'E024', N'@73 B2 C2 E5 JI', 200, N'E6555', 4, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'0ebf5df5-b730-4521-9aea-7d0509be02b8', N'Apheresis PLATELETS|ACD-A/XX/20-24C|Irradiated|Plasma reduced/Plasma added|1st container', N'PLT AFR ACD-A IRD PLS Red/PA', N'E024', N'@73 C2 EE H3', 200, N'E6478', 120, 0, 0, 1, NULL, N'A', '20091109 15:20:06.887', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'0ee71b7e-14ab-496d-be9b-e0aa6ee1bb94', N'POOLED PLATELETS|CPD/XX/20-24C|Irradiated|ResLeu:<1log6|Buffy coat plts prep|From 3 donors', N'PLT Pool CPD IRD LUKOPR BUFCT 3DNR', N'E022', N'@A7 C2 D5 G2 J3', 200, N'E6264', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:37.963', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'10a7f760-02e3-451b-93b8-38c13bf287ad', N'Thawed PLASMA|CPDA-1/XX/refg|Irradiated|ResLeu:<5log6', N'PLASMA Thaw CPDA-1 IRD LUKOPR', N'E011', N'@10 C2 D4', 225, N'E6622', 120, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'10d70eea-c0d5-40d3-a741-6b52b1479a67', N'Thawed PLASMA (from 250 ml Whole Blood)(Storage -18C or colder)', N'PLASMA Thaw None LowVol', N'E011', N'@AS F3', 225, N'18431', 120, 0, 0, 0, NULL, N'A', '20100514 15:01:54.953', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'11b174e9-51e5-4934-85de-90f17f1b2b1a', N'RED BLOOD CELLS|SAGM/350mL/refg|Irradiated|ResLeu:<1log6', N'RBC SAGM IRD LUKOPR', N'E002', N'@D4 C2 D5', 350, N'E6503', 672, 0, 0, 1, NULL, N'A', '20091109 15:17:58.960', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'11dccb58-beb7-4234-8157-5ceff89d8d92', N'Thawed PLASMA LEUKOCYTES REDUCED', N'PLASMA Thaw None LUKOPR', N'E011', N'@AS D2', 225, N'18441', 120, 0, 0, 0, NULL, N'A', '20100514 15:01:54.953', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'11ec0816-9bf3-4218-9475-81ed8f3dd5cf', N'Thawed CRYOPRECIPITATE|None/XX/rt|Open|Irradiated', N'CRYO Thaw None OPN IRD', N'E029', N'@83 B2 C2', 15, N'E6612', 4, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'139c76cd-60c2-4f70-993c-935e263ef774', N'Apheresis GRANULOCYTES|ACD-A/XX/rt', N'GRAN AFR ACD-A', N'E035', N'@93', 150, N'E6325', 24, 0, 0, 1, NULL, N'A', '20091109 15:22:26.077', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'13b67ec8-6409-4f42-920b-8154461d3784', N'Apheresis PLATELETS|PASIIIMgK/XX/20-24C|ResLeu:<1log6|1st container|Bacterial test', N'PLT AFR PASIIIMgK LUKOPR BacTest', N'E024', N'@CI D5 H3 N3', 200, N'E6590', 120, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'14085b86-7a72-4f94-b11c-66686f7fccdb', N'Apheresis PLASMA|NaCitrate/XX/<-25C|Frozen <=6h|Quar:>=112d/retested', N'PLASMA AFR NaCit QUAR', N'E012', N'@CQ G4 I4', 450, N'E6315', 8760, 0, 0, 1, NULL, N'A', '20100514 14:47:38.847', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'142b0bdf-aeeb-4a55-9092-663967bf0825', N'PLASMA|CPD/XX/<=-18C|For mnf:noninjectable restr use|Frozen <=24h', N'PLASMA CPD MNFRNI', N'E010', N'@35 A5 G7', 225, N'E6482', 8760, 0, 0, 1, NULL, N'A', '20091109 15:18:54.163', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'1453f4cb-186e-48c9-bbfe-6d8caff4b8a1', N'RED BLOOD CELLS|CP2D>AS3/500mL/refg|Open|Irradiated|ResLeu:<5log6|Supernat rem/Plasma added', N'RBC CP2D>AS3 OPN IRD LUKOPR SR/PA', N'E002', N'@21 B2 C2 D4 E8', 350, N'E6391', 24, 0, 0, 1, NULL, N'A', '20091109 15:17:58.943', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'14709128-474c-4dcd-8921-59555c791f54', N'Washed Apheresis PLATELETS|PASIIIMgK/XX/20-24C|ResLeu:<1log6|2nd container', N'PLT AFR Wash PASIIIMgK LUKOPR', N'E027', N'@CI D5 H4', 200, N'E6601', 4, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'14712109-8165-4662-82f9-4e0f854fc062', N'Thawed FRESH FROZEN PLASMA|CP2D/450mL/refg|ResLeu:NS', N'FFP Thaw CP2D LUKOPR', N'E011', N'@11 D2', 225, N'E6430', 24, 0, 0, 1, NULL, N'A', '20091109 15:19:05.993', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'147a8023-4b3f-4189-8b1d-1e9e760e97ba', N'RED BLOOD CELLS|CPD>SAGM/500mL/refg|Open|Irradiated|ResLeu:<5log6', N'RBC CPD>SAGM OPN IRD LUKOPR', N'E002', N'@CM B2 C2 D4', 350, N'E6428', 24, 0, 0, 1, NULL, N'A', '20091109 15:17:58.943', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'153fac62-e379-4394-acbc-c8ff16ae5f41', N'Thawed FRESH FROZEN PLASMA DIVIDED (-18C or colder)(Part H or 8)', N'FFP Thaw None', N'E011', N'@AS HC', 225, N'48208', 24, 0, 0, 0, NULL, N'A', '20100514 15:01:54.953', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'157a5a72-df41-4a33-bf86-593a3f69aa90', N'Deglycerolized Rejuvenated RED BLOOD CELLS|None/XX/refg|Open|ResLeu:<5log6|Plasma added', N'RBC Deg Rej None OPN LUKOPR PA', N'E007', N'@AS B2 D4 E4', 200, N'E6456', 24, 0, 0, 1, NULL, N'A', '20091109 15:18:36.150', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'170b70a3-eb66-495e-9f98-344015aed97b', N'WHOLE BLOOD|None/500mL/rt|Not for tx or mnf', N'WB None NMT', N'E001', N'@82 A4', 500, N'E6390', 24, 0, 0, 1, NULL, N'A', '20091109 15:17:51.943', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'17861d3d-172e-45b0-af14-7571c7e50782', N'Apheresis PLATELETS|ACD-A/XX/20-24C|Open|ResLeu:<5log6|Plasma reduced|2nd container|Approx 300 log9 plts', N'PLT AFR ACD-A OPN LUKOPR PLS Red', N'E024', N'@73 B2 D4 E5 H4 JC', 200, N'E6420', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:52.150', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'18155b78-1915-40af-9e44-2f854e3fe8c4', N'Apheresis PLATELETS|PASIIIMgK/XX/20-24C|Irradiated|ResLeu:<1log6|1st container', N'PLT AFR PASIIIMgK IRD LUKOPR', N'E024', N'@CI C2 D5 H3', 200, N'E6578', 120, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'189dd813-e848-4590-a836-0722c89e824c', N'POOLED PLATELETS|PASIIIMgK/XX/20-24C|Irradiated|ResLeu:<1log6|Buffy coat plts prep|Bacterial monitoring', N'PLT Pool PASIIIMgK IRD LUKOPR BUFCT BacMtr', N'E022', N'@CI C2 D5 G2 N2', 200, N'E6567', 4, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'19c80719-5397-4bee-9e05-607c79434127', N'Washed Apheresis RED BLOOD CELLS|None/XX/refg|ResLeu:<5log6', N'RBC AFR Wash None LUKOPR', N'E049', N'@AS D4', 200, N'E6184', 24, 0, 0, 1, NULL, N'A', '20091109 15:22:26.077', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'1a01f8a7-1623-436f-9700-fcefc5a518cb', N'RED BLOOD CELLS|CPD/XX/refg|Open|LowVol:anticoag not adj', N'RBC CPD OPN LowVol', N'E002', N'@06 B2 F3', 250, N'E6470', 24, 0, 0, 1, NULL, N'A', '20091109 15:17:58.943', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'1a47c66c-a8ee-4d4d-bf99-5e25b2a5f000', N'Apheresis PLATELETS|PASIIIMgK/XX/20-24C|ResLeu:<1log6|Supernat reduced', N'PLT AFR PASIIIMgK LUKOPR SUPRed', N'E024', N'@CI D5 EA', 200, N'E6598', 120, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'1a48c53a-1d39-4398-87f6-6a6ff2661561', N'PLATELETS|CPD/450mL/20-24C|Open|ResLeu:<8.3log5|Plasma reduced', N'PLT CPD OPN LUKOPR PLS Red', N'E020', N'@64 B2 D6 E5', 50, N'E6163', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:23.290', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'1a511302-f948-409a-a692-46d50f529dfe', N'Thawed POOLED CRYOPRECIPITATE|NS/XX/rt|Open|ResLeu:NS', N'CRYO Pool Thaw NS OPN LUKOPR', N'E031', N'@92 B2 D2', 100, N'E6464', 4, 0, 0, 1, NULL, N'A', '20091109 15:22:26.077', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'1af2564c-9c6f-48f9-a68b-26f5d18dec62', N'Thawed FRESH FROZEN PLASMA DIVIDED IRRADIATED (by pheresis)(-18C or colder)(Part A or 1)', N'FFP AFR Thaw None IRD', N'E013', N'@AS C2 H3', 450, N'48611', 24, 0, 0, 0, NULL, N'A', '20100514 15:01:54.953', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'1b173789-1ac5-40af-8c39-cfbcbd564dc2', N'Washed Apheresis PLATELETS|PASIIIMgK/XX/20-24C|ResLeu:<1log6|3rd container', N'PLT AFR Wash PASIIIMgK LUKOPR', N'E027', N'@CI D5 H5', 200, N'E6602', 4, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'1b375171-819b-459a-b73e-04cb3eb0526f', N'RED BLOOD CELLS|CPD>AS1/450mL/refg|ResLeu:<1.2log9', N'RBC CPD>AS1 LUKOPR', N'E002', N'@18 D9', 350, N'E6179', 1008, 0, 0, 1, NULL, N'A', '20091109 15:17:58.943', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'1c94be0c-3a0b-49de-ad2e-c973b45e818a', N'Apheresis PLATELETS|PAS-E/XX/20-24C|ResLeu:<1log6|Psoralen-treated', N'PLT AFR PAS-E LUKOPR Psoraln', N'E024', N'@D5 D5 K5', 200, N'E6640', 120, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'1cd4d04b-cfde-4fa4-9a95-fbd2490fd477', N'RECOVERED PLASMA NON-INJECTABLE (frozen <24 HRS)', N'PLASMA CPD MNFNI ', N'E010', N'@35 A3', 225, N'19205', 8760, 0, 0, 0, NULL, N'A', '20091109 15:18:36.150', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'1ce86b88-361e-4fdb-b99e-601147e95f61', N'Thawed POOLED FRESH FROZEN PLASMA|CP2D/XX/refg|Irradiated', N'FFP Pool Thaw CP2D IRD', N'E011', N'@13 C2', 500, N'E6173', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:05.993', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'1d1f2c3b-2f2c-4545-9c92-537b3cf3bfb8', N'Apheresis PLATELETS|PAS-E/XX/20-24C|Irradiated|ResLeu:<1log6|Supernat reduced', N'PLT AFR PAS-E IRD LUKOPR SUPRed', N'E024', N'@D5 C2 D5 EA', 200, N'E6639', 120, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'1eac9efe-4887-4032-81a2-9aa54a114eaa', N'RED BLOOD CELLS|SAGM/350mL/refg|ResLeu:<1.2log9', N'RBC SAGM LUKOPR', N'E002', N'@D4 D9', 350, N'E6501', 1008, 0, 0, 1, NULL, N'A', '20091109 15:17:58.960', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'1ee47702-f5d4-4c39-b652-f1502ecc8822', N'Apheresis PLATELETS|PASIIIMgK/XX/20-24C|ResLeu:<1log6|3rd container|Bacterial test', N'PLT AFR PASIIIMgK LUKOPR BacTest', N'E024', N'@CI D5 H5 N3', 200, N'E6592', 120, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'1fd842a3-7aa6-4b50-b7b3-f528f2bd83bb', N'PLATELETS|CPD/350mL/20-24C', N'PLT CPD', N'E020', N'@D0', 50, N'E6506', 120, 0, 0, 1, NULL, N'A', '20091109 15:19:23.290', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'2005cb12-112c-42e2-aebc-e4ae3fbc348e', N'Washed Apheresis PLATELETS|PASIIIMgK/XX/20-24C|Irradiated|ResLeu:<1log6|1st container', N'PLT AFR Wash PASIIIMgK IRD LUKOPR', N'E027', N'@CI C2 D5 H3', 200, N'E6604', 4, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'2034b9b6-7024-416c-a978-5121479cfb7c', N'Thawed FRESH FROZEN PLASMA DIVIDED (-18C or colder)(Part B or 2)', N'FFP Thaw None', N'E011', N'@AS H4', 225, N'48202', 24, 0, 0, 0, NULL, N'A', '20100514 15:01:54.953', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'20426e41-7d6d-4314-8aab-1c555827f69d', N'Frozen Apheresis PLATELETS|DMSO/XX/<-65C|Open|ResLeu:<1log6|2nd container', N'PLT AFR Froz DMSO OPN LUKOPR', N'E025', N'@76 B2 D5 H4', 200, N'E6286', 8760, 0, 0, 1, NULL, N'A', '20091109 15:20:06.887', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'204377ed-86f6-4da6-a49d-f1bfb1b2f546', N'Apheresis PLATELETS|ACD-A/XX/20-24C|ResLeu:<1log6|Approx 240 log9 plts', N'PLT AFR ACD-A LUKOPR', N'E024', N'@73 D5 JB', 200, N'E6383', 120, 0, 0, 1, NULL, N'A', '20091109 15:19:52.137', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'218dd7c1-947a-482c-8787-e30f71e5b033', N'POOLED PLATELETS|PASIIIMgK/XX/20-24C|Irradiated|ResLeu:<1log6|Supernat reduced|Buffy coat plts prep', N'PLT Pool PASIIIMgK IRD LUKOPR SUPRed BUFCT', N'E022', N'@CI C2 D5 EA G2', 200, N'E6571', 4, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'220238a4-67be-4faa-b4dd-f1af4181434b', N'Washed POOLED PLATELETS|None/XX/20-24C|Open|Irradiated|ResLeu:<1log6|Buffy coat plts prep|From 6 donors', N'PLT Pool Wash None OPN IRD LUKOPR BUFCT 6DNR', N'E023', N'@71 B2 C2 D5 G2 J6', 200, N'E6353', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:52.137', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'220f514e-e5b0-4b9a-988a-fe13884665fd', N'Washed Apheresis RED BLOOD CELLS|None/XX/refg|Open|ResLeu:<1log6', N'RBC AFR Wash None OPN LUKOPR', N'E049', N'@AS B2 D5', 200, N'E6218', 24, 0, 0, 1, NULL, N'A', '20091109 15:22:40.077', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'221dc913-83ec-488b-9693-651b105d91a4', N'Thawed POOLED PLASMA|CP2D/XX/refg|Open|Irradiated|ResLeu:<5log6', N'PLASMA Pool Thaw CP2D OPN IRD LUKOPR', N'E011', N'@13 B2 C2 D4', 500, N'E6620', 4, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'224fe3ae-066d-4c91-a565-4cfd60b05292', N'FRESH FROZEN PLASMA|CPD/450mL/<=-18C|ResLeu:<1log6,WB filtr', N'FFP CPD LUKOPR', N'E010', N'@AM DA', 225, N'E6526', 8760, 0, 0, 1, NULL, N'A', '20091109 15:18:54.163', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'2294fcf0-b170-4352-b681-d028cadaa7ea', N'POOLED PLATELETS|CP2D/XX/20-24C|ResLeu:<5log6', N'PLT Pool CP2D LUKOPR', N'E022', N'@B9 D4', 200, N'E6235', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:23.307', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'22c4ad49-e7cf-4d04-b92d-a780ae0691be', N'Apheresis RED BLOOD CELLS|CPD-50>SAGM/XX/refg|Irradiated|ResLeu:<5log6|2nd container', N'RBC AFR CPD-50>SAGM IRD LUKOPR', N'E009', N'@CX C2 D4 H4', 350, N'E6444', 672, 0, 0, 1, NULL, N'A', '20091109 15:18:36.150', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'2322368d-4bc5-4b8f-93ea-17fd2f38ebc4', N'PLATELET-RICH BUFFY COAT|CPDA-1/450mL/20-24C|Irradiated', N'BUFFY PltRch CPDA-1 IRD', N'E042', N'@66 C2', 200, N'E6446', 24, 0, 0, 1, NULL, N'A', '20091109 15:22:26.077', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'2332e536-8ced-4f23-a7fb-28a49c69567d', N'PLATELETS|CP2D/500mL/20-24C|Open|ResLeu:<8.3log5', N'PLT CP2D OPN LUKOPR', N'E020', N'@69 B2 D6', 50, N'E6158', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:05.993', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'23ed377c-917b-4458-b5d8-5034aeaf6a89', N'POOLED PLATELETS|CPD/XX/20-24C|From 6 donors', N'PLT Pool CPD 6DNR', N'E022', N'@A7 J6', 200, N'E6225', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:23.307', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'26ccbba5-76d0-4c13-a07b-cb3b6cad7580', N'POOLED PLATELETS|CPD/XX/20-24C|Irradiated|ResLeu:<1log6|Buffy coat plts prep|From 4 donors', N'PLT Pool CPD IRD LUKOPR BUFCT 4DNR', N'E022', N'@A7 C2 D5 G2 J4', 200, N'E6265', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:37.963', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'29669990-5970-4d43-9e48-b616b269a2f2', N'Deglycerolized Apheresis RED BLOOD CELLS|None/XX/refg|ResLeu:<5log6', N'RBC AFR Deg None LUKOPR', N'E051', N'@AS D4', 200, N'E6190', 336, 0, 0, 1, NULL, N'A', '20100514 14:47:38.847', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'296c565c-b14c-4f3f-8b3b-7799ff0daeae', N'FRESH FROZEN PLASMA|CPDA-1/450mL/<-25C|For mnf:injectable|Frozen <=8h|Quar:>=112d/retested', N'FFP CPDA-1 MNFI QUAR', N'E010', N'@CV A2 GB I4', 225, N'E6313', 8760, 0, 0, 1, NULL, N'A', '20091109 15:18:54.163', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'2996ca90-c390-4e2b-ac17-3444e42f05c8', N'POOLED PLATELETS|PASIIIMgK/XX/20-24C|ResLeu:<1log6|Supernat reduced|Buffy coat plts prep', N'PLT Pool PASIIIMgK LUKOPR SUPRed BUFCT', N'E022', N'@CI D5 EA G2', 200, N'E6570', 4, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'29f55d41-465c-4382-adda-f083219e8b25', N'Washed Apheresis RED BLOOD CELLS|None/XX/refg|Irradiated|ResLeu:<5log6|2nd container', N'RBC AFR Wash None IRD LUKOPR', N'E049', N'@AS C2 D4 H4', 200, N'E6189', 24, 0, 0, 1, NULL, N'A', '20091109 15:22:40.077', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'2a57374c-35e4-4d63-b453-c6449d78930d', N'Apheresis PLATELETS|PAS-E/XX/20-24C|Irradiated|ResLeu:<1log6|Bacterial monitoring', N'PLT AFR PAS-E IRD LUKOPR BacMtr', N'E024', N'@D5 C2 D5 N2', 200, N'E6637', 120, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'2b692847-b31c-4dcf-ac90-01e79eb4e1a8', N'POOLED PLATELETS|CPD/XX/20-24C|ResLeu:<1log6|Buffy coat plts prep|From 3 donors', N'PLT Pool CPD LUKOPR BUFCT 3DNR', N'E022', N'@A7 D5 G2 J3', 200, N'E6257', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:37.963', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'2b71982b-375c-4967-88c9-99a4fdc1ed1b', N'POOLED PLATELETS|CPD/XX/20-24C|Irradiated|ResLeu:<1log6|Buffy coat plts prep|From 8 donors', N'PLT Pool CPD IRD LUKOPR BUFCT 8DNR', N'E022', N'@A7 C2 D5 G2 J8', 200, N'E6269', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:37.963', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'2bb9c735-f481-47ad-8e68-0c3854b5b6da', N'Thawed PLASMA|CP2D/450mL/refg|ResLeu:NS', N'PLASMA Thaw CP2D LUKOPR', N'E011', N'@11 D2', 225, N'E6432', 120, 0, 0, 1, NULL, N'A', '20091109 15:19:05.993', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'2c0c6e59-5adc-49fa-840c-d3455d852290', N'Thawed POOLED FRESH FROZEN PLASMA|CPD/XX/refg|Irradiated', N'FFP Pool Thaw CPD IRD', N'E011', N'@06 C2', 500, N'E6172', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:05.993', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'2c497a23-bc18-4f4b-9407-dbdf3d4c33ab', N'Thawed PLASMA DONOR RETESTED (From 500 ml ACD-A Whole Blood)', N'PLASMA Thaw ACD-A', N'E011', N'@54', 225, N'17421', 120, 0, 0, 0, NULL, N'A', '20100514 15:01:54.953', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'2c855716-3aab-4129-bcec-640164fc33f1', N'Apheresis PLATELETS|PASIIIMgK/XX/20-24C|ResLeu:<1log6|1st container', N'PLT AFR PASIIIMgK LUKOPR', N'E024', N'@CI D5 H3', 200, N'E6574', 120, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'2cd4656d-b718-45d7-b340-73d419858b9d', N'Thawed FRESH FROZEN PLASMA DIVIDED (-18C or colder)(Part D or 4)', N'FFP Thaw None', N'E011', N'@AS H6', 225, N'48204', 24, 0, 0, 0, NULL, N'A', '20100514 15:01:54.953', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'2cec8fad-440d-4be9-b851-dbcae43b9e6a', N'POOLED PLATELETS|CPD/XX/20-24C|Irradiated|ResLeu:<5log6|From 6 donors|Bacterial test', N'PLT Pool CPD IRD LUKOPR 6DNR BacTest', N'E022', N'@A7 C2 D4 J6 N3', 200, N'E6211', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:23.307', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'2d258ae8-5984-4d64-a329-7fde7677e1eb', N'Thawed PLASMA DONOR RETESTED', N'PLASMA Thaw None', N'E011', N'@AS', 225, N'17401', 120, 0, 0, 0, NULL, N'A', '20100514 15:01:54.953', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'2d48e345-a460-4dc9-b13e-01d19e29f532', N'POOLED PLATELETS|CPD/XX/20-24C|Irradiated|ResLeu:<1log6|Plasma reduced/Plasma added|Buffy coat plts prep|From 4 donors', N'PLT Pool CPD IRD LUKOPR PLS Red/PA BUFCT 4DNR', N'E022', N'@A7 C2 D5 EE G2 J4', 200, N'E6344', 4, 0, 0, 1, NULL, N'A', '20100210 13:55:15.970', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'2d5d0cd1-e28f-4d1d-9607-638ce7d69e38', N'Apheresis RED BLOOD CELLS|CP2D>AS3/XX/refg|For mnf:injectable|ResLeu:<5log6|1st container', N'RBC AFR CP2D>AS3 MNFI LUKOPR', N'E009', N'@33 A2 D4 H3', 350, N'E6204', 1008, 0, 0, 1, NULL, N'A', '20091109 15:18:36.150', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'2e324e48-1d23-4018-a122-8d9c0ddc2a13', N'Thawed CRYOPRECIPITATE|CP2D/450mL/rt|ResLeu:NS', N'CRYO Thaw CP2D LUKOPR', N'E029', N'@89 D2', 15, N'E6436', 6, 0, 0, 1, NULL, N'A', '20100210 13:55:15.970', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'2e9ebb30-c30a-44dc-a60e-5a755ed0d2b1', N'Thawed POOLED CRYOPRECIPITATE|None/XX/rt|From 5 donors', N'CRYO Pool Thaw None 5DNR', N'E031', N'@83 J5', 100, N'E6552', 4, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'2ed921ba-844a-4190-aa36-a882ef042621', N'Thawed PLASMA|CPDA-1/XX/refg|ResLeu:NS|Frozen <=72h', N'PLASMA Thaw CPDA-1 LUKOPR', N'E011', N'@10 D2 GD', 225, N'E6563', 120, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'2f1e330d-45e2-4a0c-b26d-2d68a5ea9cde', N'Apheresis PLATELETS|PASIIIMgK/XX/20-24C|ResLeu:<1log6|2nd container|Bacterial test', N'PLT AFR PASIIIMgK LUKOPR BacTest', N'E024', N'@CI D5 H4 N3', 200, N'E6591', 120, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'2f334487-1c28-4698-a2e1-b186553ef65b', N'Apheresis PLATELETS|PASIIIMgK/XX/20-24C|ResLeu:<1log6|2nd container|Bacterial monitoring', N'PLT AFR PASIIIMgK LUKOPR BacMtr', N'E024', N'@CI D5 H4 N2', 200, N'E6583', 120, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'2f8415f0-e4a2-4682-956f-9b046ad57667', N'Thawed POOLED PLASMA|CP2D/XX/refg|Irradiated', N'PLASMA Pool Thaw CP2D IRD', N'E011', N'@13 C2', 500, N'E6616', 4, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'2fc2383a-5699-454d-b1ab-48785e89e7b6', N'Apheresis PLATELETS|ACD-A/XX/20-24C|Irradiated|Plasma reduced/Plasma added', N'PLT AFR ACD-A IRD PLS Red/PA', N'E024', N'@73 C2 EE', 200, N'E6477', 120, 0, 0, 1, NULL, N'A', '20091109 15:19:52.150', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'305e8efd-e752-49dc-ad3a-36e0f8897bd9', N'POOLED PLATELETS|CPD/XX/20-24C|Irradiated|ResLeu:<1log6|From 5 donors', N'PLT Pool CPD IRD LUKOPR 5DNR', N'E022', N'@A7 C2 D5 J5', 200, N'E6245', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:23.307', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'318ce356-986c-4b3b-bfaf-9ebb48c31c33', N'Thawed Apheresis POOLED PLASMA|ACD-A/XX/refg|Open', N'PLASMA AFR Pool Thaw ACD-A OPN', N'E013', N'@54 B2', 225, N'E6489', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:05.993', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'31edff07-e143-492d-8256-d889642fa51d', N'POOLED PLATELETS|CPDA-1/XX/20-24C|ResLeu:<5log6|Bacterial monitoring', N'PLT Pool CPDA-1 LUKOPR BacMtr', N'E022', N'@B8 D4 N2', 200, N'E6451', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:37.963', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'31fd3440-3d19-459b-9c6c-5e55d42a87b5', N'POOLED PLATELETS|CPD/XX/20-24C|ResLeu:<1log6|Buffy coat plts prep|From 7 donors', N'PLT Pool CPD LUKOPR BUFCT 7DNR', N'E022', N'@A7 D5 G2 J7', 200, N'E6261', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:37.963', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'33ae431a-7cb4-4355-a1c1-a034ee54b537', N'POOLED PLATELETS|PAS-E/XX/20-24C|ResLeu:<1log6|Buffy coat plts prep|Bacterial monitoring', N'PLT Pool PAS-E LUKOPR BUFCT BacMtr', N'E022', N'@D5 D5 G2 N2', 200, N'E6644', 4, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'35d7588a-8249-43ea-bc0c-abde4e919425', N'Frozen Apheresis PLATELETS|DMSO/XX/<-65C|Open|ResLeu:<1log6', N'PLT AFR Froz DMSO OPN LUKOPR', N'E025', N'@76 B2 D5', 200, N'E6284', 8760, 0, 0, 1, NULL, N'A', '20091109 15:20:06.887', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'3650dda4-7299-4119-836a-3a01ba3bb1bc', N'Thawed FRESH FROZEN PLASMA DIVIDED IRRADIATED (by pheresis)(-18C or colder)(Part G or 7)', N'FFP AFR Thaw None IRD', N'E013', N'@AS C2 HB', 450, N'48617', 24, 0, 0, 0, NULL, N'A', '20100514 15:01:54.953', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'36e3a399-d460-4ea6-83b3-800c62522da4', N'RED BLOOD CELLS|CPD>AS5/450mL/refg|Open|Irradiated|ResLeu:<5log6|Plasma added', N'RBC CPD>AS5 OPN IRD LUKOPR PA', N'E002', N'@22 B2 C2 D4 E4', 350, N'E6510', 24, 0, 0, 1, NULL, N'A', '20091109 15:17:58.960', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'3747cb82-e1c4-45c4-bbcb-c67f342fc0c8', N'PLASMA|CPD/XX/<=-18C|For mnf:noninjectable restr use|Cryo reduced', N'PLASMA CPD MNFRNI CRYORed', N'E010', N'@35 A5 E3', 225, N'E6212', 8760, 0, 0, 1, NULL, N'A', '20091109 15:18:36.150', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'374c1271-a6de-4f7c-819d-e0c62c4306e4', N'PLASMA|CPD/450mL/<=-18C|ResLeu:NS|Frozen <=24h', N'PLASMA CPD LUKOPR', N'E010', N'@AM D2 G7', 225, N'E6516', 8760, 0, 0, 1, NULL, N'A', '20091109 15:18:54.163', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'37d1dc6e-1129-4528-ad84-8027570ce513', N'Apheresis PLATELETS|PASIIIMgK/XX/20-24C|Irradiated|ResLeu:<1log6|2nd container|Bacterial monitoring', N'PLT AFR PASIIIMgK IRD LUKOPR BacMtr', N'E024', N'@CI C2 D5 H4 N2', 200, N'E6587', 120, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'386eda0d-c2a8-4c38-b230-871b37adff21', N'RED BLOOD CELLS|SAGM/350mL/refg|ResLeu:<1log6', N'RBC SAGM LUKOPR', N'E002', N'@D4 D5', 350, N'E6502', 1008, 0, 0, 1, NULL, N'A', '20091109 15:17:58.960', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'388f2b9f-5072-4ff3-a12b-d46a332be9f9', N'POOLED PLATELETS|CPD/XX/20-24C|Irradiated|ResLeu:<1log6|From 8 donors', N'PLT Pool CPD IRD LUKOPR 8DNR', N'E022', N'@A7 C2 D5 J8', 200, N'E6248', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:23.307', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'38cabcf4-7ffc-4177-8a5c-047143eec97a', N'POOLED PLATELETS|CPD/XX/20-24C|Irradiated|ResLeu:<1log6|Buffy coat plts prep|From 2 donors', N'PLT Pool CPD IRD LUKOPR BUFCT 2DNR', N'E022', N'@A7 C2 D5 G2 J2', 200, N'E6263', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:37.963', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'38d98104-b367-4122-a275-529bdd27fda7', N'Washed POOLED PLATELETS|None/XX/20-24C|Irradiated|ResLeu:<1log6|Buffy coat plts prep|From 6 donors', N'PLT Pool Wash None IRD LUKOPR BUFCT 6DNR', N'E023', N'@71 C2 D5 G2 J6', 200, N'E6281', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:52.137', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'392851cd-1227-4665-995b-6ece15fe3231', N'Thawed FRESH FROZEN PLASMA DIVIDED (-18C or colder)(Part G or 7)', N'FFP Thaw None', N'E011', N'@AS HB', 225, N'48207', 24, 0, 0, 0, NULL, N'A', '20100514 15:01:54.953', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'3a31f48c-861e-4a0a-8c34-3ebdd98f083e', N'FRESH FROZEN PLASMA|CPDA-1/XX/<=-20C|For mnf:injectable', N'FFP CPDA-1 MNFI', N'E010', N'@BR A2', 225, N'E6633', 8760, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'3a9d0a1c-a857-4ab3-b452-6817ad963419', N'Apheresis FRESH FROZEN PLASMA|NaCitrate/XX/<-25C|For mnf:noninjectable|Frozen <=24h', N'FFP AFR NaCit MNFNI', N'E012', N'@CQ A3 G7', 450, N'E6546', 8760, 0, 0, 1, NULL, N'A', '20100514 14:47:38.847', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'3ab898b6-4475-409c-b142-6fc763f5df6c', N'WHOLE BLOOD|CPD/350mL/refg', N'WB CPD', N'E001', N'@D1', 350, N'E6507', 504, 0, 0, 1, NULL, N'A', '20091109 15:17:58.943', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'3b3158d5-d86e-4d27-be6f-4cb114ec56fe', N'FRESH FROZEN PLASMA|CPDA-1/450mL/<-30C|Quar:>=4m/retested', N'FFP CPDA-1 QUAR', N'E010', N'@BQ I3', 225, N'E6324', 8760, 0, 0, 1, NULL, N'A', '20091109 15:18:54.163', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'3b4e319a-a425-4bae-aac4-4be11b90bfe5', N'Thawed FRESH FROZEN PLASMA DIVIDED IRRADIATED (-18C)(Part B or 2)', N'FFP Thaw None IRD', N'E011', N'@AS C2 H4', 225, N'48602', 24, 0, 0, 0, NULL, N'A', '20100514 15:01:54.953', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'3b6d5d75-cda2-44e4-a7fb-82da72b09f52', N'Thawed FRESH FROZEN PLASMA DIVIDED (by pheresis)(-65C)(Part D or 4)', N'FFP AFR Thaw None', N'E013', N'@AS H6', 450, N'48314', 24, 0, 0, 0, NULL, N'A', '20100514 15:01:54.953', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'3cfd96e3-1c9f-4560-a58f-ec48d5d4f44f', N'PLATELETS|CPD/450mL/20-24C|Open|Irradiated', N'PLT CPD OPN IRD', N'E020', N'@64 B2 C2', 50, N'E6518', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:23.290', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'3efd0732-6616-440d-b0e8-876d14480142', N'POOLED PLATELETS|CPD/XX/20-24C|ResLeu:<1log6|From 4 donors', N'PLT Pool CPD LUKOPR 4DNR', N'E022', N'@A7 D5 J4', 200, N'E6230', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:23.307', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'405eae20-6f52-4fc0-a641-a75bd8d98579', N'RED BLOOD CELLS|SAGM/350mL/refg', N'RBC SAGM', N'E002', N'@D4', 350, N'E6500', 1008, 0, 0, 1, NULL, N'A', '20091109 15:17:58.960', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'409f278c-f862-49b1-a032-a4c5b89c1bfc', N'RED BLOOD CELLS|CPD>AS1/500mL/refg|ResLeu:<5log6|Plasma added', N'RBC CPD>AS1 LUKOPR PA', N'E002', N'@19 D4 E4', 350, N'E6169', 1008, 0, 0, 1, NULL, N'A', '20091109 15:17:58.943', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'414c6d0c-2211-4cf7-8d6f-9e0b44d4a172', N'POOLED PLATELETS|NS/XX/20-24C|ResLeu:NS', N'PLT Pool NS LUKOPR', N'E022', N'@72 D2', 200, N'E6404', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:37.963', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'41cde27e-195d-4ba6-a022-d8ce335a29af', N'Apheresis PLATELETS|PASIIIMgK/XX/20-24C|Irradiated|ResLeu:<1log6|3rd container', N'PLT AFR PASIIIMgK IRD LUKOPR', N'E024', N'@CI C2 D5 H5', 200, N'E6580', 120, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'41ecc2ee-2441-4c4a-a363-0a07c17c493c', N'PLATELETS|CP2D/450mL/20-24C|Open|Irradiated|ResLeu:<8.3log5|Plasma reduced', N'PLT CP2D OPN IRD LUKOPR PLS Red', N'E020', N'@68 B2 C2 D6 E5', 50, N'E6162', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:23.290', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'42182058-dbe2-4f3d-b850-e3909ea90bf4', N'Apheresis PLATELETS|ACD-A/XX/20-24C|Open|Irradiated|ResLeu:<5log6|3rd container|<3log11 plts', N'PLT AFR ACD-A OPN IRD LUKOPR', N'E024', N'@73 B2 C2 D4 H5 JI', 200, N'E6406', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:52.137', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'42c318a5-94e4-4c58-bffc-b129f3373f04', N'Thawed FRESH FROZEN PLASMA DIVIDED IRRADIATED (by pheresis)(-65C or colder)(Part C or 3)', N'FFP AFR Thaw None IRD', N'E013', N'@AS C2 H5', 450, N'48713', 24, 0, 0, 0, NULL, N'A', '20100514 15:01:54.953', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'432a0fad-6935-48ae-a856-a62a54e2703e', N'RED BLOOD CELLS|CPD>AS1/450mL/refg|ResLeu:<1log6', N'RBC CPD>AS1 LUKOPR', N'E002', N'@18 D5', 350, N'E6178', 1008, 0, 0, 1, NULL, N'A', '20091109 15:17:58.943', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'432dadb0-8146-4296-9e48-87541672d07a', N'Apheresis RED BLOOD CELLS|ACD-A>AS1/XX/refg|Open|Irradiated|ResLeu:<5log6|Supernat reduced', N'RBC AFR ACD-A>AS1 OPN IRD LUKOPR SUPRed', N'E009', N'@AY B2 C2 D4 EA', 350, N'E6387', 24, 0, 0, 1, NULL, N'A', '20091109 15:18:36.150', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'436aac2f-a0f3-45df-b8db-a9cbb7b37c7d', N'FRESH FROZEN PLASMA|CPD/450mL/<-25C|For mnf:injectable|Frozen <=8h', N'FFP CPD MNFI', N'E010', N'@A2 A2 GB', 225, N'E6310', 8760, 0, 0, 1, NULL, N'A', '20091109 15:18:54.163', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'446ab5be-94a6-4ee3-b703-e543780cd5fd', N'Washed POOLED PLATELETS|None/XX/20-24C|Irradiated|ResLeu:<1log6|From 5 donors', N'PLT Pool Wash None IRD LUKOPR 5DNR', N'E023', N'@71 C2 D5 J5', 200, N'E6273', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:37.963', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'4498a44b-0ef5-4fae-adc1-d455de1171c4', N'POOLED PLATELETS|CPD/XX/20-24C|ResLeu:<1log6|Buffy coat plts prep|From 4 donors', N'PLT Pool CPD LUKOPR BUFCT 4DNR', N'E022', N'@A7 D5 G2 J4', 200, N'E6258', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:37.963', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'44b51c8e-4ffc-4862-9e35-91badc6beea5', N'POOLED PLATELETS|CPDA-1/XX/20-24C|Buffy coat plts prep|Riboflavin-treated', N'PLT Pool CPDA-1 BUFCT Ribo', N'E022', N'@B8 G2 K6', 200, N'E6559', 4, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'44fb8389-3752-4b29-be04-eb791332119b', N'FRESH FROZEN PLASMA|CPD/450mL/<-25C|Frozen <=8h|Riboflavin-treated', N'FFP CPD Ribo', N'E010', N'@A2 GB K6', 225, N'E6547', 8760, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'45620c60-a4be-4191-a6a4-998498822dbd', N'POOLED FRESH FROZEN PLASMA|CPD/XX/<-25C|Frozen <=8h|From 2 donors|Psoralen-treated', N'FFP Pool CPD 2DNR Psoraln', N'E010', N'@A1 GB J2 K5', 500, N'E6536', 8760, 0, 0, 1, NULL, N'A', '20100210 13:55:15.970', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'4599a584-e490-42e9-b8b6-a1cea2a2eace', N'Deglycerolized Apheresis RED BLOOD CELLS|None/XX/refg|Irradiated|ResLeu:<5log6', N'RBC AFR Deg None IRD LUKOPR', N'E051', N'@AS C2 D4', 200, N'E6193', 336, 0, 0, 1, NULL, N'A', '20100514 14:47:38.847', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'461382c7-a3de-47d6-ae2f-1afb3fbacda8', N'POOLED PLATELETS|CPD/XX/20-24C|Irradiated|Buffy coat plts prep|From 2 donors', N'PLT Pool CPD IRD BUFCT 2DNR', N'E022', N'@A7 C2 G2 J2', 200, N'E6249', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:23.307', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'464795ce-81b2-471b-a564-9099fea5ff34', N'Thawed PLASMA', N'PLASMA Thaw None', N'E011', N'@AS', 225, N'18401', 120, 0, 0, 0, NULL, N'A', '20100514 15:01:54.953', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'46f3d994-67bc-4336-8847-8253735929b2', N'POOLED PLATELETS|CPD/XX/20-24C|Irradiated|ResLeu:<1log6|Plasma reduced/Plasma added|Buffy coat plts prep|From 6 donors', N'PLT Pool CPD IRD LUKOPR PLS Red/PA BUFCT 6DNR', N'E022', N'@A7 C2 D5 EE G2 J6', 200, N'E6346', 4, 0, 0, 1, NULL, N'A', '20100210 13:55:15.970', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'481dd0a3-7430-40f9-a2a7-1e7426ac5481', N'Thawed FRESH FROZEN PLASMA DIVIDED IRRADIATED (by pheresis)(-18C or colder)(Part D or 4)', N'FFP AFR Thaw None IRD', N'E013', N'@AS C2 H6', 450, N'48614', 24, 0, 0, 0, NULL, N'A', '20100514 15:01:54.953', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'494d18be-f9a5-48c1-bbe0-c66799da2e3c', N'Apheresis PLATELETS|ACD-A/XX/20-24C|Irradiated|ResLeu:<5log6|Plasma reduced/Plasma added|3rd container', N'PLT AFR ACD-A IRD LUKOPR PLS Red/PA', N'E024', N'@73 C2 D4 EE H5', 200, N'E6336', 120, 0, 0, 1, NULL, N'A', '20091109 15:19:52.137', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'498ec715-4da3-4784-8999-aa23eb66e90c', N'RED BLOOD CELLS|CPD>AS5/XX/refg|Open|LowVol:anticoag adj', N'RBC CPD>AS5 OPN LowVol', N'E002', N'@A0 B2 F8', 350, N'E6472', 24, 0, 0, 1, NULL, N'A', '20091109 15:17:58.960', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'49aee7c7-95b3-474b-ba76-85f861b84164', N'Thawed POOLED PLASMA|CP2D/XX/refg|ResLeu:<5log6', N'PLASMA Pool Thaw CP2D LUKOPR', N'E011', N'@13 D4', 500, N'E6618', 4, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'4a6568f7-2a67-4071-8bec-80d85ab7c93e', N'POOLED PLATELETS|CPD/XX/20-24C|ResLeu:<1log6|Buffy coat plts prep|From 5 donors', N'PLT Pool CPD LUKOPR BUFCT 5DNR', N'E022', N'@A7 D5 G2 J5', 200, N'E6259', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:37.963', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'4aa62e2d-d783-46d7-bf42-43d4eae54f8b', N'RED BLOOD CELLS|CPD>AS1/450mL/refg|Buffy coat removed', N'RBC CPD>AS1 BuF Rem', N'E002', N'@18 ED', 350, N'E6466', 1008, 0, 0, 1, NULL, N'A', '20091109 15:17:58.943', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'4aab9f42-9850-4447-a613-d2396dcf2442', N'Washed POOLED PLATELETS|None/XX/20-24C|Open|ResLeu:<5log6|Buffy coat plts prep|From 4 donors', N'PLT Pool Wash None OPN LUKOPR BUFCT 4DNR', N'E023', N'@71 B2 D4 G2 J4', 200, N'E6367', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:52.137', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'4ab05e66-238e-408a-bf4e-df8a0f16bb73', N'Apheresis PLATELETS|ACD-A/XX/20-24C|Open|ResLeu:<5log6|Plasma reduced|1st container|Approx 300 log9 plts', N'PLT AFR ACD-A OPN LUKOPR PLS Red', N'E024', N'@73 B2 D4 E5 H3 JC', 200, N'E6419', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:52.150', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'4ab81596-52f3-43c2-bb47-844be137d046', N'PLASMA|CP2D/XX/<=-18C|For mnf:noninjectable restr use|Frozen <=24h', N'PLASMA CP2D MNFRNI', N'E010', N'@37 A5 G7', 225, N'E6481', 8760, 0, 0, 1, NULL, N'A', '20091109 15:18:54.163', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'4b4f840a-783a-448f-ab7d-471868933f69', N'Thawed Apheresis PLASMA|NaCitrate/XX/refg|1st container', N'PLASMA AFR Thaw NaCit', N'E013', N'@55 H3', 450, N'E6512', 120, 0, 0, 1, NULL, N'A', '20100514 14:47:38.847', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'4b701fa0-9601-4683-8a70-88b13586ce24', N'RED BLOOD CELLS|CPD>SAGM/500mL/refg|Open|Irradiated|ResLeu:<5log6|Supernat reduced', N'RBC CPD>SAGM OPN IRD LUKOPR SUPRed', N'E002', N'@CM B2 C2 D4 EA', 350, N'E6370', 24, 0, 0, 1, NULL, N'A', '20091109 15:17:58.943', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'4c5e7045-7715-460a-8795-e691e94e3bf1', N'POOLED PLATELETS|CPD/XX/20-24C|Irradiated|ResLeu:<1log6|Plasma reduced/Plasma added|Buffy coat plts prep|From 5 donors', N'PLT Pool CPD IRD LUKOPR PLS Red/PA BUFCT 5DNR', N'E022', N'@A7 C2 D5 EE G2 J5', 200, N'E6345', 4, 0, 0, 1, NULL, N'A', '20100210 13:55:15.970', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'4c9c0ae4-5c7b-40ae-b5b6-5f721fba20df', N'POOLED PLATELETS|CPD/XX/20-24C|ResLeu:<5log6|From 6 donors|Bacterial test', N'PLT Pool CPD LUKOPR 6DNR BacTest', N'E022', N'@A7 D4 J6 N3', 200, N'E6209', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:23.290', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'4ca4fe3c-ad68-4953-a074-7cab31929df7', N'Apheresis FRESH FROZEN PLASMA|NaCitrate/XX/<-25C|Frozen <=6h|Riboflavin-treated', N'FFP AFR NaCit Ribo', N'E012', N'@CQ G4 K6', 450, N'E6545', 8760, 0, 0, 1, NULL, N'A', '20100514 14:47:38.847', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'4cc075d7-144b-42c7-9bc1-2ee17cd3e0f2', N'PLASMA|CP2D/XX/<-25C|For mnf:injectable|Frozen <=24h', N'PLASMA CP2D MNFI', N'E010', N'@CW A2 G7', 225, N'E6322', 8760, 0, 0, 1, NULL, N'A', '20091109 15:18:54.163', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'4d284252-4048-4be6-bb43-2fdc31bf2aa4', N'Thawed PLASMA|CP2D/XX/refg|ResLeu:<5log6', N'PLASMA Thaw CP2D LUKOPR', N'E011', N'@13 D4', 225, N'E6627', 120, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'4dee5307-fa00-4416-9c72-6cbdbb8106da', N'RED BLOOD CELLS|CPD>SAGM/450mL/refg|ResLeu:<5log6', N'RBC CPD>SAGM LUKOPR', N'E002', N'@CY D4', 350, N'E6514', 1008, 0, 0, 1, NULL, N'A', '20091109 15:17:58.960', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'4ef25e19-9ef8-42cd-82c2-90f5cd31f953', N'Deglycerolized Apheresis RED BLOOD CELLS|None/XX/refg|ResLeu:<5log6|2nd container', N'RBC AFR Deg None LUKOPR', N'E051', N'@AS D4 H4', 200, N'E6192', 336, 0, 0, 1, NULL, N'A', '20100514 14:47:38.847', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'4f0b42ed-a019-436e-9d1a-71377cf54982', N'Thawed Apheresis PLATELETS|DMSO/XX/20-24C|Open|ResLeu:<1log6|Supernat rem/Plasma added|2nd container', N'PLT AFR Thaw DMSO OPN LUKOPR SR/PA', N'E026', N'@77 B2 D5 E8 H4', 200, N'E6291', 4, 0, 0, 1, NULL, N'A', '20091109 15:20:06.887', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'4f2decae-7cf8-4ac3-ae0c-4526e3279d85', N'FRESH FROZEN PLASMA|CP2D/XX/<=-20C|For mnf:injectable', N'FFP CP2D MNFI', N'E010', N'@BS A2', 225, N'E6631', 8760, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'4f431cb7-aa73-45ef-8e43-d9c8ca504fe4', N'Apheresis PLATELETS|ACD-A/XX/20-24C|ResLeu:<1log6|Approx 300 log9 plts', N'PLT AFR ACD-A LUKOPR', N'E024', N'@73 D5 JC', 200, N'E6384', 120, 0, 0, 1, NULL, N'A', '20091109 15:19:52.137', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'4f609bce-1994-43c0-abc5-00797f5ecb87', N'Apheresis PLATELETS|PASIIIMgK/XX/20-24C|ResLeu:<1log6|3rd container|Bacterial monitoring', N'PLT AFR PASIIIMgK LUKOPR BacMtr', N'E024', N'@CI D5 H5 N2', 200, N'E6584', 120, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'4f97c474-2fef-41a3-b154-a26ea1e79756', N'Apheresis FRESH FROZEN PLASMA|CP2D/XX/<=-18C|1st container', N'FFP AFR CP2D', N'E012', N'@37 H3', 450, N'E6460', 8760, 0, 0, 1, NULL, N'A', '20100514 14:47:38.847', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'4fee17ce-81f1-44fe-9af5-ac37def9d717', N'Washed POOLED PLATELETS|None/XX/20-24C|Open|Irradiated|ResLeu:<1log6|Buffy coat plts prep|From 7 donors', N'PLT Pool Wash None OPN IRD LUKOPR BUFCT 7DNR', N'E023', N'@71 B2 C2 D5 G2 J7', 200, N'E6354', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:52.137', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'502ed116-bff3-4f5b-a797-d9abc03cc179', N'Apheresis PLATELETS|ACD-A/XX/20-24C|Open|Plasma reduced|1st container|<3log11 plts', N'PLT AFR ACD-A OPN PLS Red', N'E024', N'@73 B2 E5 H3 JI', 200, N'E6414', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:52.150', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'50414cb3-564a-4b2f-bb95-0df9f0093926', N'Apheresis PLATELETS|NS/XX/20-24C|ResLeu:<1log6|2nd container|Approx 300 log9 plts|Bacterial monitoring', N'PLT AFR NS LUKOPR BacMtr', N'E024', N'@72 D5 H4 JC N2', 200, N'E6379', 120, 0, 0, 1, NULL, N'A', '20091109 15:19:52.137', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'50530d6a-6ef7-4e96-9f04-208ae2a6ab84', N'Thawed Apheresis PLASMA|NaCitrate/XX/refg|2nd container', N'PLASMA AFR Thaw NaCit', N'E013', N'@55 H4', 450, N'E6513', 120, 0, 0, 1, NULL, N'A', '20100514 14:47:38.847', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'50ba45aa-10dd-43d5-86c7-0cf9c8f07519', N'FRESH FROZEN PLASMA|CPD/XX/<=-20C|For mnf:injectable', N'FFP CPD MNFI', N'E010', N'@BN A2', 225, N'E6632', 8760, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'50e6fb03-c842-46c1-b91c-928eb6e2b183', N'Apheresis FRESH FROZEN PLASMA|NaCitrate/XX/<-25C|Frozen <=6h', N'FFP AFR NaCit', N'E012', N'@CQ G4', 450, N'E6494', 8760, 0, 0, 1, NULL, N'A', '20100514 14:47:38.847', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'5268cf49-6e3d-4bd5-ab63-72628c4f16f4', N'RED BLOOD CELLS|CPD>AS1/450mL/refg|Irradiated|ResLeu:<1log6|Supernat rem/Plasma added', N'RBC CPD>AS1 IRD LUKOPR SR/PA', N'E002', N'@18 C2 D5 E8', 350, N'E6220', 672, 0, 0, 1, NULL, N'A', '20091109 15:17:58.943', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'529170f0-93ca-4545-a7af-2670226ae260', N'Thawed FRESH FROZEN PLASMA DIVIDED (by pheresis)(-65C)(Part A or 1)', N'FFP AFR Thaw None', N'E013', N'@AS H3', 450, N'48311', 24, 0, 0, 0, NULL, N'A', '20100514 15:01:54.953', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'535ea2b7-a84b-40c6-8c03-3c62a1ccb8e1', N'Deglycerolized Apheresis RED BLOOD CELLS|None/XX/refg|ResLeu:<5log6|1st container', N'RBC AFR Deg None LUKOPR', N'E051', N'@AS D4 H3', 200, N'E6191', 336, 0, 0, 1, NULL, N'A', '20100514 14:47:38.847', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'537a9c89-59ae-4a5e-80f9-162d9ef07116', N'PLASMA|CP2D/XX/<=-18C|For mnf:noninjectable|Cryo reduced', N'PLASMA CP2D MNFNI CRYORed', N'E010', N'@37 A3 E3', 225, N'E6608', 8760, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'5456899c-462c-4e74-932b-1f5479cca572', N'Frozen Apheresis PLATELETS|DMSO/XX/<-80C|Open|ResLeu:<1log6', N'PLT AFR Froz DMSO OPN LUKOPR', N'E025', N'@CP B2 D5', 200, N'E6497', 8760, 0, 0, 1, NULL, N'A', '20091109 15:20:06.887', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'54b01901-b839-4eeb-b2bc-9deb6f8a17c4', N'RED BLOOD CELLS|CPD/450mL/refg|ResLeu:<5log6|Plasma added', N'RBC CPD LUKOPR PA', N'E002', N'@03 D4 E4', 250, N'E6394', 504, 0, 0, 1, NULL, N'A', '20091109 15:17:58.943', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'54c8c9ce-c67e-420b-b3eb-12ce8674bb4c', N'Apheresis PLATELETS|PASIIIMgK/XX/20-24C|Irradiated|ResLeu:<1log6|4th container', N'PLT AFR PASIIIMgK IRD LUKOPR', N'E024', N'@CI C2 D5 H6', 200, N'E6581', 120, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'55c94a59-553f-4876-a811-30f161c6802a', N'POOLED PLATELETS|CPDA-1/XX/20-24C|Irradiated|ResLeu:<5log6|Bacterial monitoring', N'PLT Pool CPDA-1 IRD LUKOPR BacMtr', N'E022', N'@B8 C2 D4 N2', 200, N'E6452', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:37.963', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'55db4ba0-e37e-4aa7-a89d-fb4a724bff51', N'Apheresis PLATELETS|PASIIIMgK/XX/20-24C|Irradiated|ResLeu:<1log6|1st container|Bacterial test', N'PLT AFR PASIIIMgK IRD LUKOPR BacTest', N'E024', N'@CI C2 D5 H3 N3', 200, N'E6594', 120, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'561bffd7-eca4-4935-8a16-69e580b1be00', N'Washed Apheresis PLATELETS|None/XX/20-24C|Open|ResLeu:<5log6|2nd container|<3log11 plts', N'PLT AFR Wash None OPN LUKOPR', N'E027', N'@71 B2 D4 H4 JI', 200, N'E6410', 4, 0, 0, 1, NULL, N'A', '20091109 15:20:06.887', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'5637969d-8510-498b-b1df-9f45a414c276', N'POOLED PLATELETS|CPD/XX/20-24C|Irradiated|ResLeu:<1log6|From 2 donors', N'PLT Pool CPD IRD LUKOPR 2DNR', N'E022', N'@A7 C2 D5 J2', 200, N'E6242', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:23.307', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'5687bde7-bc3e-4b2b-9edb-ecfbc9316dec', N'Apheresis PLATELETS|ACD-A/XX/20-24C|Irradiated|ResLeu:<5log6|Plasma reduced/Plasma added|2nd container', N'PLT AFR ACD-A IRD LUKOPR PLS Red/PA', N'E024', N'@73 C2 D4 EE H4', 200, N'E6335', 120, 0, 0, 1, NULL, N'A', '20091109 15:19:52.137', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'56a0aeb0-7099-465c-9613-92d2d50cb788', N'POOLED PLATELETS|CPD/XX/20-24C|Irradiated|ResLeu:<5log6|From 5 donors|Bacterial test', N'PLT Pool CPD IRD LUKOPR 5DNR BacTest', N'E022', N'@A7 C2 D4 J5 N3', 200, N'E6210', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:23.307', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'573c55d3-c780-43ab-90d7-810ed9f48511', N'Apheresis PLATELETS|PASIIIMgK/XX/20-24C|ResLeu:<1log6|2nd container', N'PLT AFR PASIIIMgK LUKOPR', N'E024', N'@CI D5 H4', 200, N'E6575', 120, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'5780845f-8131-4638-a869-692dce2c1aa5', N'POOLED PLATELETS|CPD/XX/20-24C|ResLeu:<1log6|Buffy coat plts prep|From 8 donors', N'PLT Pool CPD LUKOPR BUFCT 8DNR', N'E022', N'@A7 D5 G2 J8', 200, N'E6262', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:37.963', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'58de1729-3be6-4797-9d78-748e4079cf73', N'FRESH FROZEN PLASMA|CPDA-1/450mL/<-25C|For mnf:noninjectable|Frozen <=8h', N'FFP CPDA-1 MNFNI', N'E010', N'@CV A3 GB', 225, N'E6308', 8760, 0, 0, 1, NULL, N'A', '20091109 15:18:54.163', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'595449af-1eda-4a4e-baac-462275895e57', N'Washed Apheresis PLATELETS|None/XX/20-24C|Open|Irradiated|ResLeu:<5log6|3rd container|<3log11 plts', N'PLT AFR Wash None OPN IRD LUKOPR', N'E027', N'@71 B2 C2 D4 H5 JI', 200, N'E6408', 4, 0, 0, 1, NULL, N'A', '20091109 15:20:06.887', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'5aebcfbb-4f90-496e-a018-e60599b4cdb6', N'Thawed FRESH FROZEN PLASMA DIVIDED IRRADIATED (by pheresis)(-18C or colder)(Part E or 5)', N'FFP AFR Thaw None IRD', N'E013', N'@AS C2 H9', 450, N'48615', 24, 0, 0, 0, NULL, N'A', '20100514 15:01:54.953', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'5af6d421-4812-4ab7-a48d-f0845806c5c0', N'Apheresis PLATELETS|ACD-A/XX/20-24C|Irradiated|ResLeu:<5log6|Plasma reduced/Plasma added|1st container', N'PLT AFR ACD-A IRD LUKOPR PLS Red/PA', N'E024', N'@73 C2 D4 EE H3', 200, N'E6334', 120, 0, 0, 1, NULL, N'A', '20091109 15:19:52.137', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'5af742e1-a84c-4bf2-90e3-8faab08b81d7', N'Apheresis RED BLOOD CELLS|SAGM/XX/refg|ResLeu:<1log6|Supernat rem/Plasma added|1st container', N'RBC AFR SAGM LUKOPR SR/PA', N'E009', N'@A9 D5 E8 H3', 350, N'E6540', 1008, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'5b3bf9a5-0607-4ec3-888c-ca690eab55c2', N'PLASMA|CPD/XX/<=-20C|For mnf:injectable|Frozen <=8h', N'PLASMA CPD MNFI', N'E010', N'@BN A2 GB', 225, N'E6447', 8760, 0, 0, 1, NULL, N'A', '20091109 15:18:54.163', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'5b443d11-e1f8-466c-9159-962afeefabc0', N'Thawed POOLED FRESH FROZEN PLASMA|CPDA-1/XX/refg|Irradiated', N'FFP Pool Thaw CPDA-1 IRD', N'E011', N'@10 C2', 500, N'E6174', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:05.993', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'5c0bb9a4-6b0e-4e79-b836-6606c81a7c01', N'Washed POOLED PLATELETS|None/XX/20-24C|Irradiated|ResLeu:<1log6|Buffy coat plts prep|From 5 donors', N'PLT Pool Wash None IRD LUKOPR BUFCT 5DNR', N'E023', N'@71 C2 D5 G2 J5', 200, N'E6280', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:52.137', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'5ce051ad-10ff-4d16-8b67-45b1b848e257', N'PLATELETS|CPDA-1/450mL/20-24C|Open|Irradiated|ResLeu:<8.3log5|Plasma reduced', N'PLT CPDA-1 OPN IRD LUKOPR PLS Red', N'E020', N'@66 B2 C2 D6 E5', 50, N'E6166', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:23.290', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'5ee0bab4-3833-4e73-bffe-139ae563e580', N'CRYOPRECIPITATE|CPD/450mL/<=-18C|ResLeu:<1log6,WB filtr', N'CRYO CPD LUKOPR', N'E028', N'@AM DA', 15, N'E6525', 8760, 0, 0, 1, NULL, N'A', '20091109 15:21:16.200', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'5efb4d73-52dd-45de-9368-ca9456617d62', N'Washed POOLED PLATELETS|None/XX/20-24C|Irradiated|ResLeu:<1log6|From 8 donors', N'PLT Pool Wash None IRD LUKOPR 8DNR', N'E023', N'@71 C2 D5 J8', 200, N'E6276', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:37.963', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'5f785f48-10c7-47e0-8d7d-563119c4bfbc', N'PLATELETS|CPD/450mL/20-24C|Open|Irradiated|ResLeu:<8.3log5', N'PLT CPD OPN IRD LUKOPR', N'E020', N'@64 B2 C2 D6', 50, N'E6520', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:23.290', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'5f8bd221-c431-4b6a-b837-0f8edaea0429', N'POOLED PLATELETS|CPD/XX/20-24C|ResLeu:<1log6|Buffy coat plts prep|From 6 donors', N'PLT Pool CPD LUKOPR BUFCT 6DNR', N'E022', N'@A7 D5 G2 J6', 200, N'E6260', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:37.963', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'5fca2c2f-b83b-47dd-878a-d2f8e8417aec', N'POOLED PLATELETS|CPD/XX/20-24C|Irradiated|ResLeu:<1log6|Buffy coat plts prep|From 6 donors', N'PLT Pool CPD IRD LUKOPR BUFCT 6DNR', N'E022', N'@A7 C2 D5 G2 J6', 200, N'E6267', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:37.963', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'5fcacfcb-a402-4f1e-9654-4c2e58b1b7c4', N'Apheresis RED BLOOD CELLS|CP2D>AS3/XX/refg|For mnf:noninjectable|ResLeu:<5log6|2nd container', N'RBC AFR CP2D>AS3 MNFNI LUKOPR', N'E009', N'@33 A3 D4 H4', 350, N'E6208', 1008, 0, 0, 1, NULL, N'A', '20091109 15:18:36.150', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'5ffe9459-4499-4bc8-981d-6d84efdd376b', N'Washed RED BLOOD CELLS|None/XX/refg|Open|Irradiated|ResLeu:<5log6|Supernat rem', N'RBC Wash None OPN IRD LUKOPR SR', N'E003', N'@AS B2 C2 D4 E7', 200, N'E6326', 24, 0, 0, 1, NULL, N'A', '20091109 15:17:58.960', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'5fff13bd-0723-4b43-bbc2-031d2b5dd83e', N'Thawed FRESH FROZEN PLASMA DIVIDED (by pheresis)(-18C)(Part B or 2)', N'FFP AFR Thaw None', N'E013', N'@AS H4', 450, N'48212', 24, 0, 0, 0, NULL, N'A', '20100514 15:01:54.953', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'6039ff86-36ae-4bed-8947-e36f71bf5cf8', N'Deglycerolized Apheresis RED BLOOD CELLS|None/XX/refg|Irradiated|ResLeu:<5log6|2nd container', N'RBC AFR Deg None IRD LUKOPR', N'E051', N'@AS C2 D4 H4', 200, N'E6195', 336, 0, 0, 1, NULL, N'A', '20100514 14:47:38.847', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'603a0e73-9b95-41b4-b99b-426ee9ed0825', N'PLASMA|CPD/XX/<=-20C|For mnf:injectable|Cryo reduced', N'PLASMA CPD MNFI CRYORed', N'E010', N'@BN A2 E3', 225, N'E6634', 8760, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'60a0a7ea-d335-4b8a-a6ff-d39cae8582d7', N'Apheresis PLASMA|NaCitrate/XX/<-25C|Frozen <=6h', N'PLASMA AFR NaCit', N'E012', N'@CQ G4', 450, N'E6314', 8760, 0, 0, 1, NULL, N'A', '20100514 14:47:38.847', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'60f8bae5-1cf9-4db0-8089-0979a4c6f430', N'RED BLOOD CELLS|CPD>AS1/500mL/refg|Not for tx or mnf|ResLeu:<5log6', N'RBC CPD>AS1 NMT LUKOPR', N'E002', N'@19 A4 D4', 350, N'E6401', 1008, 0, 0, 1, NULL, N'A', '20091109 15:17:58.943', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'614465e6-340a-4df6-a1a9-b3f27194cba0', N'POOLED PLATELETS|CPD/XX/20-24C|Irradiated|ResLeu:<1log6|Buffy coat plts prep|From 5 donors', N'PLT Pool CPD IRD LUKOPR BUFCT 5DNR', N'E022', N'@A7 C2 D5 G2 J5', 200, N'E6266', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:37.963', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'61a0f2b5-9f5c-4449-9371-767b70042904', N'Apheresis PLASMA|ACD-A/XX/<=-18C|For mnf:noninjectable restr use', N'PLASMA AFR ACD-A MNFRNI', N'E012', N'@47 A5', 450, N'E6327', 8760, 0, 0, 1, NULL, N'A', '20100514 14:47:38.847', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'61ba4ed9-6041-433b-ab96-e11b829b79a9', N'Apheresis PLATELETS|PAS-E/XX/20-24C|ResLeu:<1log6|Bacterial monitoring', N'PLT AFR PAS-E LUKOPR BacMtr', N'E024', N'@D5 D5 N2', 200, N'E6636', 120, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'62211d5a-b45b-47b8-bd59-09af2d96ddb6', N'Apheresis PLASMA|NaCitrate/XX/<-25C|For mnf:noninjectable|Frozen <=6h', N'PLASMA AFR NaCit MNFNI', N'E012', N'@CQ A3 G4', 450, N'E6316', 8760, 0, 0, 1, NULL, N'A', '20100514 14:47:38.847', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'627a24a1-2e71-4932-a69a-06c02f85a6a2', N'POOLED PLATELETS|CPD/XX/20-24C|Open|ResLeu:<5log6|Plasma reduced|Buffy coat plts prep|From 4 donors', N'PLT Pool CPD OPN LUKOPR PLS Red BUFCT 4DNR', N'E022', N'@A7 B2 D4 E5 G2 J4', 200, N'E6365', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:37.963', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'6284128d-b52b-4828-95e0-96056fa2078f', N'Deglycerolized RED BLOOD CELLS|None/XX/refg|Open|ResLeu:<5log6|Plasma added', N'RBC Deg None OPN LUKOPR PA', N'E006', N'@AS B2 D4 E4', 200, N'E6454', 24, 0, 0, 1, NULL, N'A', '20091109 15:18:36.150', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'633ff56f-9896-46aa-ab60-2e4382d5d29a', N'Apheresis PLATELETS|ACD-A/XX/20-24C|ResLeu:<5log6|Plasma reduced/Plasma added|1st container', N'PLT AFR ACD-A LUKOPR PLS Red/PA', N'E024', N'@73 D4 EE H3', 200, N'E6330', 120, 0, 0, 1, NULL, N'A', '20091109 15:19:52.137', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'63f9c68d-b252-4e0c-8ea2-1d63ddfab333', N'RED BLOOD CELLS|CP2D>AS3/XX/refg|Open|LowVol:anticoag not adj', N'RBC CP2D>AS3 OPN LowVol', N'E002', N'@33 B2 F3', 350, N'E6471', 24, 0, 0, 1, NULL, N'A', '20091109 15:17:58.960', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'644f82ce-a5ad-40f6-aeaa-21fc45633d7c', N'Apheresis PLATELETS|ACD-A/XX/20-24C|Plasma reduced/Plasma added|3rd container', N'PLT AFR ACD-A PLS Red/PA', N'E024', N'@73 EE H5', 200, N'E6476', 120, 0, 0, 1, NULL, N'A', '20091109 15:19:52.150', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'64d6f9cf-89d9-4e96-ab9a-d483f2f92e87', N'Washed Apheresis PLATELETS|PASIIIMgK/XX/20-24C|ResLeu:<1log6|1st container', N'PLT AFR Wash PASIIIMgK LUKOPR', N'E027', N'@CI D5 H3', 200, N'E6600', 4, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'650248d2-d6fc-46d2-9ac8-6d3628997237', N'Apheresis CRYOPRECIPITATE|ACD-A/XX/<-25C', N'CRYO AFR ACD-A', N'E032', N'@AI', 100, N'E6298', 8760, 0, 0, 1, NULL, N'A', '20091109 15:22:26.077', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'655367e8-cedb-40a6-b2d0-f690866c7f08', N'WHOLE BLOOD|CPD/350mL/refg|Irradiated|ResLeu:<1log6', N'WB CPD IRD LUKOPR', N'E001', N'@D1 C2 D5', 350, N'E6509', 504, 0, 0, 1, NULL, N'A', '20091109 15:17:58.943', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'65eb00af-869a-482e-9a8c-a98a894fd3fb', N'Thawed Apheresis POOLED FRESH FROZEN PLASMA|CP2D/XX/refg|Open', N'FFP AFR Pool Thaw CP2D OPN', N'E013', N'@13 B2', 225, N'E6381', 4, 0, 0, 1, NULL, N'A', '20100210 13:55:15.970', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'65f2df5a-4b4a-454a-9288-3b03cbf75120', N'Washed Apheresis PLATELETS|None/XX/20-24C|Open|Irradiated|2nd container|<3log11 plts', N'PLT AFR Wash None OPN IRD', N'E027', N'@71 B2 C2 H4 JI', 200, N'E6424', 4, 0, 0, 1, NULL, N'A', '20091109 15:20:06.887', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'66637877-7ef9-418f-be97-6702f0e634d0', N'Thawed FRESH FROZEN PLASMA DIVIDED IRRADIATED (-18C)(Part G or 7)', N'FFP Thaw None IRD', N'E011', N'@AS C2 HB', 225, N'48607', 24, 0, 0, 0, NULL, N'A', '20100514 15:01:54.953', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'66964d3f-a653-4ede-b700-3e53b5835b73', N'POOLED PLATELETS|PASIIIMgK/XX/20-24C|ResLeu:<1log6|Buffy coat plts prep|Bacterial test', N'PLT Pool PASIIIMgK LUKOPR BUFCT BacTest', N'E022', N'@CI D5 G2 N3', 200, N'E6568', 4, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'677d1e1d-5858-45d8-8430-df88bc7e3dba', N'Apheresis PLATELETS|PAS-E/XX/20-24C|ResLeu:<1log6|Supernat reduced', N'PLT AFR PAS-E LUKOPR SUPRed', N'E024', N'@D5 D5 EA', 200, N'E6638', 120, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'67d1309f-6c51-45f1-9826-d3e98bd2075d', N'Apheresis FRESH FROZEN PLASMA|NaCitrate/XX/<-25C|Frozen <=6h|Quar:>=112d/retested', N'FFP AFR NaCit QUAR', N'E012', N'@CQ G4 I4', 450, N'E6495', 8760, 0, 0, 1, NULL, N'A', '20100514 14:47:38.847', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'67dde31c-02f0-47a7-a034-9457db993a58', N'POOLED PLATELETS|CPD/XX/20-24C|ResLeu:<1log6|From 8 donors', N'PLT Pool CPD LUKOPR 8DNR', N'E022', N'@A7 D5 J8', 200, N'E6234', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:23.307', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'681f50d6-544e-4186-b223-4ee283ad7c34', N'Apheresis PLATELETS|ACD-A/XX/20-24C|Open|Plasma reduced|2nd container|<3log11 plts', N'PLT AFR ACD-A OPN PLS Red', N'E024', N'@73 B2 E5 H4 JI', 200, N'E6415', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:52.150', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'6829724d-fa8b-442a-9149-ca7f573935e9', N'POOLED PLATELETS|PASIIIMgK/XX/20-24C|ResLeu:<1log6|Approx 300 log9 plts', N'PLT Pool PASIIIMgK LUKOPR', N'E022', N'@CI D5 JC', 200, N'E6386', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:37.963', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'6857b774-7322-4d6f-89b2-a9bc44091762', N'Apheresis PLATELETS|PASIIIMgK/XX/20-24C|ResLeu:<1log6|4th container', N'PLT AFR PASIIIMgK LUKOPR', N'E024', N'@CI D5 H6', 200, N'E6577', 120, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'689af45a-0009-4638-9b42-360f33c25f8e', N'Washed Apheresis PLATELETS|None/XX/20-24C|Open|ResLeu:<5log6|<3log11 plts', N'PLT AFR Wash None OPN LUKOPR', N'E027', N'@71 B2 D4 JI', 200, N'E6409', 4, 0, 0, 1, NULL, N'A', '20091109 15:20:06.887', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'69562e77-67de-4c16-9f76-b9e7a865a03e', N'Apheresis FRESH FROZEN PLASMA|NaCitrate/XX/<-25C|For mnf:noninjectable|Frozen <=6h', N'FFP AFR NaCit MNFNI', N'E012', N'@CQ A3 G4', 450, N'E6523', 8760, 0, 0, 1, NULL, N'A', '20100514 14:47:38.847', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'6a71f836-9f4c-4a24-9844-61307bfc688f', N'PLASMA|CPDA-1/XX/<=-20C|For mnf:injectable|Cryo reduced', N'PLASMA CPDA-1 MNFI CRYORed', N'E010', N'@BR A2 E3', 225, N'E6635', 8760, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'6a8ef913-4db9-4ff1-bbd9-44cf4de97eea', N'Thawed Apheresis POOLED PLASMA|NaCitrate/XX/refg|Open', N'PLASMA AFR Pool Thaw NaCit OPN', N'E013', N'@55 B2', 225, N'E6490', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:05.993', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'6ac6dead-197a-4340-8dee-9d3ae21d65c9', N'POOLED PLATELETS|PAS-E/XX/20-24C|Irradiated|ResLeu:<1log6|Buffy coat plts prep|Bacterial monitoring', N'PLT Pool PAS-E IRD LUKOPR BUFCT BacMtr', N'E022', N'@D5 C2 D5 G2 N2', 200, N'E6645', 4, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'6b692148-b35e-4aec-b518-fd97927e821a', N'Thawed POOLED CRYOPRECIPITATE|CPD/XX/rt|Open|ResLeu:<1log6,WB filtr', N'CRYO Pool Thaw CPD OPN LUKOPR', N'E031', N'@BT B2 DA', 100, N'E6556', 4, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'6b7f0d70-d24f-4273-96c0-0db054abefc5', N'RED BLOOD CELLS|CP2D>AS3/500mL/refg|Not for tx or mnf|ResLeu:<5log6', N'RBC CP2D>AS3 NMT LUKOPR', N'E002', N'@21 A4 D4', 350, N'E6399', 1008, 0, 0, 1, NULL, N'A', '20091109 15:17:58.943', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'6bcd3738-619e-4dc4-8f46-140ef23c90fe', N'FRESH FROZEN PLASMA|CPDA-1/450mL/<-25C|Frozen <=6h', N'FFP CPDA-1', N'E010', N'@CV G4', 225, N'E6214', 8760, 0, 0, 1, NULL, N'A', '20091109 15:18:36.150', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'6c25c7e6-4a3d-4162-806f-c73349a7e75f', N'Thawed FRESH FROZEN PLASMA DIVIDED (by pheresis)(-65C)(Part F or 6)', N'FFP AFR Thaw None', N'E013', N'@AS HA', 450, N'48316', 24, 0, 0, 0, NULL, N'A', '20100514 15:01:54.953', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'6c7f1b5f-7006-4975-9850-84d9e7add83e', N'Apheresis RED BLOOD CELLS|CP2D>AS3/XX/refg|For mnf:noninjectable|ResLeu:<5log6', N'RBC AFR CP2D>AS3 MNFNI LUKOPR', N'E009', N'@33 A3 D4', 350, N'E6206', 1008, 0, 0, 1, NULL, N'A', '20091109 15:18:36.150', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'6c84a7e5-fe81-40bb-8516-8098a52eeaa3', N'RED BLOOD CELLS|CPD>AS1/450mL/refg|Irradiated|ResLeu:<1log6', N'RBC CPD>AS1 IRD LUKOPR', N'E002', N'@18 C2 D5', 350, N'E6217', 672, 0, 0, 1, NULL, N'A', '20091109 15:17:58.943', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'6c966c1d-6c6e-41a7-9432-a31d78db733f', N'POOLED PLATELETS|PASII/XX/20-24C|ResLeu:<1log6|Approx 300 log9 plts', N'PLT Pool PASII LUKOPR', N'E022', N'@AE D5 JC', 200, N'E6385', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:37.963', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'6cd73a0f-2d3d-49d7-9b24-186c69519462', N'Thawed FRESH FROZEN PLASMA DIVIDED (-65C or colder)(Part D or 4)', N'FFP Thaw None', N'E011', N'@AS H6', 225, N'48304', 24, 0, 0, 0, NULL, N'A', '20100514 15:01:54.953', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'6cf2a53b-31ee-40ab-8e4a-91462c41e49c', N'Liquid PLASMA|CP2D/XX/refg|For mnf:noninjectable', N'PLASMA Liq CP2D MNFNI', N'E011', N'@13 A3', 225, N'E6170', 624, 0, 0, 1, NULL, N'A', '20091109 15:19:05.993', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'6df51e1e-6029-4b78-9053-b276bfb96b14', N'Thawed PLASMA|CP2D/XX/refg|Irradiated|ResLeu:<5log6', N'PLASMA Thaw CP2D IRD LUKOPR', N'E011', N'@13 C2 D4', 225, N'E6626', 120, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'6e08530a-b0b9-4a30-aed0-438f19dea067', N'Frozen RED BLOOD CELLS|None/450mL/<-65C|ResLeu:<5log6', N'RBC Froz None LUKOPR', N'E004', N'@29 D4', 200, N'E6197', 87600, 0, 0, 1, NULL, N'A', '20091109 15:18:36.150', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'6e166dc1-f8cd-4a3a-b7c5-947c86b646c9', N'POOLED PLATELETS|PASIIIMgK/XX/20-24C|ResLeu:<1log6|Buffy coat plts prep|Riboflavin-treated', N'PLT Pool PASIIIMgK LUKOPR BUFCT Ribo', N'E022', N'@CI D5 G2 K6', 200, N'E6646', 4, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'6eb0b436-15c4-4567-8e72-1b2dc8229e86', N'Plasma (-18C or colder), (by pheresis) Unliscensed', N'PLASMA AFR None', N'E012', N'@84', 450, N'18451', 8760, 0, 0, 0, NULL, N'L', '20100514 15:01:54.953', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'6f1ff58e-23f3-4ee8-9194-90cf90b7609f', N'Washed Apheresis PLATELETS|None/XX/20-24C|Open|Irradiated|ResLeu:<5log6|2nd container|Approx 300 log9 plts', N'PLT AFR Wash None OPN IRD LUKOPR', N'E027', N'@71 B2 C2 D4 H4 JC', 200, N'E6426', 4, 0, 0, 1, NULL, N'A', '20091109 15:20:32.810', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'70e30723-6a80-48c0-a330-9201d92864fe', N'Washed POOLED PLATELETS|None/XX/20-24C|Open|Irradiated|ResLeu:<1log6|Buffy coat plts prep|From 4 donors', N'PLT Pool Wash None OPN IRD LUKOPR BUFCT 4DNR', N'E023', N'@71 B2 C2 D5 G2 J4', 200, N'E6351', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:52.137', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'725ba79b-3138-4629-a843-7612223ed3c4', N'Apheresis PLATELETS|ACD-A/XX/20-24C|Open|Irradiated|Plasma reduced|2nd container|<3log11 plts', N'PLT AFR ACD-A OPN IRD PLS Red', N'E024', N'@73 B2 C2 E5 H4 JI', 200, N'E6417', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:52.150', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'7263993c-12c0-4897-9785-48cd370a0afb', N'Thawed FRESH FROZEN PLASMA DIVIDED (-65C or colder)(Part A or 1)', N'FFP Thaw None', N'E011', N'@AS H3', 225, N'48301', 24, 0, 0, 0, NULL, N'A', '20100514 15:01:54.953', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'72a87f90-c333-409e-b416-f0b331680f28', N'Thawed FRESH FROZEN PLASMA DIVIDED IRRADIATED (by pheresis)(-18C or colder)(Part H or 8)', N'FFP AFR Thaw None IRD', N'E013', N'@AS C2 HC', 450, N'48618', 24, 0, 0, 0, NULL, N'A', '20100514 15:01:54.953', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'72b1457c-ab18-4923-974f-fb4fa1d7e540', N'FRESH FROZEN PLASMA|CPDA-1/450mL/<-25C|For mnf:injectable|Frozen <=6h', N'FFP CPDA-1 MNFI', N'E010', N'@CV A2 G4', 225, N'E6215', 8760, 0, 0, 1, NULL, N'A', '20091109 15:18:36.163', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'73c28ed8-774e-4251-99b7-7a137a16b7bb', N'Thawed FRESH FROZEN PLASMA DIVIDED IRRADIATED (by pheresis)(-18C or colder)(Part F or 6)', N'FFP AFR Thaw None IRD', N'E013', N'@AS C2 HA', 450, N'48616', 24, 0, 0, 0, NULL, N'A', '20100514 15:01:54.953', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'73c2b2e3-ef44-47dc-8dd4-60339db9b8e0', N'Washed Apheresis PLATELETS|PASIIIMgK/XX/20-24C|ResLeu:<1log6|4th container', N'PLT AFR Wash PASIIIMgK LUKOPR', N'E027', N'@CI D5 H6', 200, N'E6603', 4, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'73fc306b-7d95-4a3b-a2c2-18cf4e5ce6a3', N'Apheresis CRYOPRECIPITATE|NaCitrate/XX/<-25C|Quar:>=112d/retested', N'CRYO AFR NaCit QUAR', N'E032', N'@CQ I4', 100, N'E6301', 8760, 0, 0, 1, NULL, N'A', '20091109 15:22:26.077', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'74a2f5d5-81ec-4434-8a08-a3088971c8a0', N'Thawed PLASMA|CPDA-1/XX/refg|Open|ResLeu:<5log6', N'PLASMA Thaw CPDA-1 OPN LUKOPR', N'E011', N'@10 B2 D4', 225, N'E6625', 24, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'74af68a0-d2eb-4e86-8d66-37baf244f15a', N'Thawed CRYOPRECIPITATE|None/XX/rt|Irradiated|ResLeu:<5log6', N'CRYO Thaw None IRD LUKOPR', N'E029', N'@83 C2 D4', 15, N'E6610', 6, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'751ad44a-b6fd-477b-a828-3b419033dcfe', N'Apheresis PLATELETS|ACD-A/XX/20-24C|ResLeu:<5log6|Plasma reduced/Plasma added', N'PLT AFR ACD-A LUKOPR PLS Red/PA', N'E024', N'@73 D4 EE', 200, N'E6329', 120, 0, 0, 1, NULL, N'A', '20091109 15:19:52.137', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'75c07b0d-2f1d-476d-9429-e23a440fface', N'Apheresis RED BLOOD CELLS|CP2D/XX/refg|Open|Irradiated|ResLeu:<5log6|Plasma added', N'RBC AFR CP2D OPN IRD LUKOPR PA', N'E009', N'@13 B2 C2 D4 E4', 350, N'E6459', 24, 0, 0, 1, NULL, N'A', '20091109 15:18:36.150', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'75e6cc56-dcee-411a-a758-37810d3fac5e', N'Thawed PLASMA|CPD/500mL/refg|ResLeu:NS|Cryo reduced', N'PLASMA Thaw CPD LUKOPR CRYORed', N'E011', N'@04 D2 E3', 225, N'E6435', 120, 0, 0, 1, NULL, N'A', '20091109 15:19:05.993', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'7697daca-99a2-440c-9cf5-694e3ee87a86', N'Washed POOLED PLATELETS|None/XX/20-24C|Irradiated|ResLeu:<1log6|Buffy coat plts prep|From 7 donors', N'PLT Pool Wash None IRD LUKOPR BUFCT 7DNR', N'E023', N'@71 C2 D5 G2 J7', 200, N'E6282', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:52.137', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'769ec36f-4d63-4f40-b3c8-a2d64c9b6757', N'Apheresis PLATELETS|PASIIIMgK/XX/20-24C|Irradiated|ResLeu:<1log6|2nd container', N'PLT AFR PASIIIMgK IRD LUKOPR', N'E024', N'@CI C2 D5 H4', 200, N'E6579', 120, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'77176b3b-1c8b-4ebd-85d3-e64c0b796167', N'Washed Apheresis PLATELETS|None/XX/20-24C|Open|ResLeu:<5log6|1st container|<3log11 plts', N'PLT AFR Wash None OPN LUKOPR', N'E027', N'@71 B2 D4 H3 JI', 200, N'E6363', 4, 0, 0, 1, NULL, N'A', '20091109 15:20:06.887', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'7795d740-ed7f-45ad-9bd7-9aca65127bae', N'Apheresis PLASMA|NaCitrate/XX/<=-18C|For mnf:noninjectable|Open', N'PLASMA AFR NaCit MNFNI OPN', N'E012', N'@48 A3 B2', 450, N'E6328', 8760, 0, 0, 1, NULL, N'A', '20100514 14:47:38.847', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'7805a3ce-754c-4df4-a2cf-7de7fa5cc817', N'Thawed PLASMA DONOR RETESTED (by pheresis)', N'PLASMA AFR Thaw None', N'E013', N'@AS H1', 450, N'17411', 120, 0, 0, 0, NULL, N'A', '20100514 15:01:54.953', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'785ed71c-1be4-47d0-8ee8-39e51a0ba609', N'RED BLOOD CELLS|CP2D/500mL/refg|Not for tx or mnf|ResLeu:<5log6', N'RBC CP2D NMT LUKOPR', N'E002', N'@12 A4 D4', 250, N'E6398', 504, 0, 0, 1, NULL, N'A', '20091109 15:17:58.943', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'78a7c48e-03c8-4ef9-99d2-97b22fb3ec21', N'RED BLOOD CELLS|CPDA-1/500mL/refg|Open|ResLeu:<5log6|Plasma added', N'RBC CPDA-1 OPN LUKOPR PA', N'E002', N'@08 B2 D4 E4', 250, N'E6453', 24, 0, 0, 1, NULL, N'A', '20091109 15:17:58.943', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'793813f4-3b8a-495f-b9f4-1ea8e299ec20', N'Apheresis PLATELETS|PASIIIMgK/XX/20-24C|Irradiated|ResLeu:<1log6|4th container|Bacterial monitoring', N'PLT AFR PASIIIMgK IRD LUKOPR BacMtr', N'E024', N'@CI C2 D5 H6 N2', 200, N'E6589', 120, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'799c0d85-9009-49cc-a9cf-17d0156a5aa5', N'POOLED PLATELETS|CPD/XX/20-24C|Irradiated|ResLeu:<1log6|Plasma reduced/Plasma added|Buffy coat plts prep|From 7 donors', N'PLT Pool CPD IRD LUKOPR PLS Red/PA BUFCT 7DNR', N'E022', N'@A7 C2 D5 EE G2 J7', 200, N'E6347', 4, 0, 0, 1, NULL, N'A', '20100210 13:55:15.970', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'79e068c7-4fb7-48b1-b6be-9bd7815b6799', N'Apheresis PLATELETS|PASIIIMgK/XX/20-24C|Irradiated|ResLeu:<1log6|1st container|Bacterial monitoring', N'PLT AFR PASIIIMgK IRD LUKOPR BacMtr', N'E024', N'@CI C2 D5 H3 N2', 200, N'E6586', 120, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'79e13ba6-63f2-4e65-b38c-d26dfba056af', N'Washed POOLED PLATELETS|PASIIIMgK/XX/20-24C|Irradiated|ResLeu:<1log6|Buffy coat plts prep', N'PLT Pool Wash PASIIIMgK IRD LUKOPR BUFCT', N'E023', N'@CI C2 D5 G2', 200, N'E6573', 4, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'79f2764e-62d0-4671-9ad1-014b972e5969', N'Frozen Apheresis PLATELETS|DMSO/XX/<-80C|Open', N'PLT AFR Froz DMSO OPN', N'E025', N'@CP B2', 200, N'E6535', 8760, 0, 0, 1, NULL, N'A', '20091109 15:20:06.887', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'7a3b591b-de46-4c27-8dc0-e04f8b866e95', N'POOLED PLATELETS|CPD/XX/20-24C|From 4 donors', N'PLT Pool CPD 4DNR', N'E022', N'@A7 J4', 200, N'E6224', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:23.307', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'7a4a4e79-b62b-4f43-94cc-87a3a867bc83', N'Thawed POOLED PLASMA|NS/XX/refg|Open', N'Plasma Pool Thaw NS OPN', N'E011', N'@CG B2', 500, N'E6371', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:05.993', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'7ae3116a-052d-402f-9953-366b88cf1d93', N'Apheresis GRANULOCYTES|NaCitrate-HES-ACD-A/XX/rt|Irradiated', N'GRAN AFR NaCit-HES-ACD-A IRD', N'E035', N'@CC C2', 150, N'E6201', 24, 0, 0, 1, NULL, N'A', '20091109 15:22:26.077', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'7b57fa3b-f69f-4b73-b536-ef4b19fc3ef3', N'Washed POOLED PLATELETS|None/XX/20-24C|Open|Irradiated|ResLeu:<1log6|Buffy coat plts prep|From 5 donors', N'PLT Pool Wash None OPN IRD LUKOPR BUFCT 5DNR', N'E023', N'@71 B2 C2 D5 G2 J5', 200, N'E6352', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:52.137', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'7c51dff0-d34e-4283-9024-82a5e4fe0244', N'POOLED PLATELETS|CPD/XX/20-24C|Irradiated|ResLeu:<1log6|Plasma reduced/Plasma added|Buffy coat plts prep|From 2 donors', N'PLT Pool CPD IRD LUKOPR PLS Red/PA BUFCT 2DNR', N'E022', N'@A7 C2 D5 EE G2 J2', 200, N'E6342', 4, 0, 0, 1, NULL, N'A', '20100210 13:55:15.970', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'7c5bc92c-6c0b-4cd8-b786-c60a41f2a0b9', N'Thawed FRESH FROZEN PLASMA DIVIDED (by pheresis)(-18C)(Part A or 1)', N'FFP AFR Thaw None', N'E013', N'@AS H3', 450, N'48211', 24, 0, 0, 0, NULL, N'A', '20100514 15:01:54.953', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'7c9a8926-1b50-4dfb-b795-ce4748c2c43e', N'Thawed FRESH FROZEN PLASMA DIVIDED (by pheresis)(-65C)(Part C or 3)', N'FFP AFR Thaw None', N'E013', N'@AS H5', 450, N'48313', 24, 0, 0, 0, NULL, N'A', '20100514 15:01:54.953', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'7e9fb19b-607f-48fc-96b1-73b7255c3d01', N'Thawed FRESH FROZEN PLASMA DIVIDED (-65C or colder)(Part G or 7)', N'FFP Thaw None', N'E011', N'@AS HB', 225, N'48307', 24, 0, 0, 0, NULL, N'A', '20100514 15:01:54.953', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'7eae9b76-e3d2-4fb8-821f-dc9d3e561e2c', N'Apheresis RED BLOOD CELLS|CPD-50>SAGM/XX/refg|Irradiated|ResLeu:<5log6|1st container', N'RBC AFR CPD-50>SAGM IRD LUKOPR', N'E009', N'@CX C2 D4 H3', 350, N'E6443', 672, 0, 0, 1, NULL, N'A', '20091109 15:18:36.150', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'7f83fce8-06af-4e95-b2c7-ce80dea66798', N'Apheresis RED BLOOD CELLS|CPD-50>SAGM/XX/refg|ResLeu:<5log6|1st container', N'RBC AFR CPD-50>SAGM LUKOPR', N'E009', N'@CX D4 H3', 350, N'E6441', 1008, 0, 0, 1, NULL, N'A', '20100514 14:47:38.847', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'8093ebf7-c9da-44e7-a242-b75eb2a3723b', N'Washed RED BLOOD CELLS|None/450mL/refg', N'RBC Wash None', N'E003', N'@17', 200, N'E6318', 24, 0, 0, 1, NULL, N'A', '20091109 15:17:58.960', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'80eacf91-09cf-4d34-b9ac-3b79b0e33db3', N'Thawed FRESH FROZEN PLASMA DIVIDED IRRADIATED (-18C)(Part H or 8)', N'FFP Thaw None IRD', N'E011', N'@AS C2 HC', 225, N'48608', 24, 0, 0, 0, NULL, N'A', '20100514 15:01:54.953', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'80ffff2e-cba0-4835-8c73-1ae80bfa6efb', N'Washed Apheresis PLATELETS|PASIIIMgK/XX/20-24C|Irradiated|ResLeu:<1log6|2nd container', N'PLT AFR Wash PASIIIMgK IRD LUKOPR', N'E027', N'@CI C2 D5 H4', 200, N'E6605', 4, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'82b617f4-a373-4215-b130-2885961c6a3f', N'Apheresis FRESH FROZEN PLASMA|ACD-A/XX/<-25C|Riboflavin-treated', N'FFP AFR ACD-A Ribo', N'E012', N'@AI K6', 450, N'E6544', 8760, 0, 0, 1, NULL, N'A', '20100514 14:47:38.847', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'82bce095-f976-48b0-a026-38dfeaad63d2', N'RED BLOOD CELLS|CPD>SAGM/500mL/refg|Open|ResLeu:<5log6|Supernat rem', N'RBC CPD>SAGM OPN LUKOPR SR', N'E002', N'@CM B2 D4 E7', 350, N'E6372', 24, 0, 0, 1, NULL, N'A', '20091109 15:17:58.943', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'82e639b1-0baa-40d9-9e24-96f2241d4014', N'Thawed POOLED PLASMA|CP2D/XX/refg', N'PLASMA Pool Thaw CP2D', N'E011', N'@13 ', 500, N'E6615', 4, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'82fa38fe-380b-4440-8cf6-c8cbc83f2f1e', N'Thawed FRESH FROZEN PLASMA DIVIDED IRRADIATED (by pheresis)(-65C or colder)(Part B or 2)', N'FFP AFR Thaw None IRD', N'E013', N'@AS C2 H4', 450, N'48712', 24, 0, 0, 0, NULL, N'A', '20100514 15:01:54.953', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'82fe85d6-a1f4-49c1-aadb-557a1931cb30', N'POOLED PLATELETS|CPD/XX/20-24C|ResLeu:<1log6|From 2 donors', N'PLT Pool CPD LUKOPR 2DNR', N'E022', N'@A7 D5 J2', 200, N'E6228', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:23.307', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'83e1f886-e1d8-4c40-a02a-f9dcee93c7b4', N'Apheresis RED BLOOD CELLS|CPD>SAGM/XX/refg|Open|Irradiated|ResLeu:<5log6', N'RBC AFR CPD>SAGM OPN IRD LUKOPR', N'E009', N'@CL B2 C2 D4', 350, N'E6558', 24, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'841fcf4b-b592-4a65-aa4b-5b0ea8d84ab5', N'Apheresis PLATELETS|PASIIIMgK/XX/20-24C|Irradiated|ResLeu:<1log6|2nd container|Bacterial test', N'PLT AFR PASIIIMgK IRD LUKOPR BacTest', N'E024', N'@CI C2 D5 H4 N3', 200, N'E6595', 120, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'8476c0ff-264c-4f14-b1ca-a2ab80ce95f9', N'Apheresis PLATELETS|ACD-A/XX/20-24C|Plasma reduced/Plasma added|1st container', N'PLT AFR ACD-A PLS Red/PA', N'E024', N'@73 EE H3', 200, N'E6474', 120, 0, 0, 1, NULL, N'A', '20091109 15:19:52.150', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'84efbb51-77b5-4979-b109-2addfe2b9653', N'Thawed PLASMA|CPD/500mL/refg|Open|ResLeu:NS|Frozen <=24h', N'PLASMA Thaw CPD OPN LUKOPR', N'E011', N'@04 B2 D2 G7', 225, N'E6439', 24, 0, 0, 1, NULL, N'A', '20091109 15:19:05.993', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'85a00247-559d-498f-a657-d28066a91a31', N'LEUKOCYTES|CPDA-1/XX/<37C|For mnf:noninjectable', N'LEUK CPDA-1 MNFNI', N'E038', N'@62 A3', 200, N'E6200', 24, 0, 0, 1, NULL, N'A', '20091109 15:22:26.077', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'85e9927f-f9b8-45ac-80af-9a39ae64bfca', N'Thawed PLASMA|CPDA-1/XX/refg|Open|Irradiated|ResLeu:<5log6', N'PLASMA Thaw CPDA-1 OPN IRD LUKOPR', N'E011', N'@10 B2 C2 D4', 225, N'E6624', 24, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'8606f5b8-7349-45d8-9f0f-827d5d6f21da', N'Apheresis RED BLOOD CELLS|CP2D>AS3/XX/refg|For mnf:injectable|ResLeu:<5log6', N'RBC AFR CP2D>AS3 MNFI LUKOPR', N'E009', N'@33 A2 D4', 350, N'E6203', 1008, 0, 0, 1, NULL, N'A', '20091109 15:18:36.150', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'86179d68-ef63-439a-8cef-5314c8b69991', N'Apheresis RED BLOOD CELLS|ACD-A>AS1/XX/refg|Open|Irradiated|ResLeu:<5log6|Supernat reduced|2nd container', N'RBC AFR ACD-A>AS1 OPN IRD LUKOPR SUPRed', N'E009', N'@AY B2 C2 D4 EA H4', 350, N'E6389', 24, 0, 0, 1, NULL, N'A', '20091109 15:18:36.150', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'861ad6e5-640f-4352-9d54-c2d66c337b13', N'Thawed POOLED PLASMA|CP2D/XX/refg|Irradiated|ResLeu:<5log6', N'PLASMA Pool Thaw CP2D IRD LUKOPR', N'E011', N'@13 C2 D4', 500, N'E6617', 4, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'86352c3b-b7f6-46de-b9d7-014eb3e4f937', N'Thawed PLASMA (From 500 ml ACD-A Whole Blood)', N'PLASMA Thaw ACD-A', N'E011', N'@54', 225, N'18421', 120, 0, 0, 0, NULL, N'A', '20100514 15:01:54.953', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'86b42ab4-d5b6-448e-8eba-99cf1046b540', N'Washed Apheresis RED BLOOD CELLS|None/XX/refg|Irradiated|ResLeu:<5log6', N'RBC AFR Wash None IRD LUKOPR', N'E049', N'@AS C2 D4', 200, N'E6187', 24, 0, 0, 1, NULL, N'A', '20091109 15:22:26.077', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'885ca279-cd94-4d74-9f86-995db84a2915', N'Thawed FRESH FROZEN PLASMA DIVIDED (by pheresis)(-18C)(Part H or 8)', N'FFP AFR Thaw None', N'E013', N'@AS HC', 450, N'48218', 24, 0, 0, 0, NULL, N'A', '20100514 15:01:54.953', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'893588ae-938d-4e9c-b88e-9066a4ab3117', N'Thawed FRESH FROZEN PLASMA DIVIDED (-65C or colder)(Part E or 5)', N'FFP Thaw None', N'E011', N'@AS H9', 225, N'48305', 24, 0, 0, 0, NULL, N'A', '20100514 15:01:54.953', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'89bdaee5-f34a-41b7-8b26-ab8941924b9f', N'POOLED PLATELETS|CPD/XX/20-24C|From 8 donors', N'PLT Pool CPD 8DNR', N'E022', N'@A7 J8', 200, N'E6227', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:23.307', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'8abe4492-487c-4c2b-b08d-84963ad28387', N'FRESH FROZEN PLASMA|CPD/450mL/<-25C|Frozen <=8h', N'FFP CPD', N'E010', N'@A2 GB', 225, N'E6302', 8760, 0, 0, 1, NULL, N'A', '20091109 15:18:36.163', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'8b6bf26b-0353-4573-80b8-da83d3b84487', N'CRYOPRECIPITATE|CPD/450mL/<-25C|Quar:>=112d/retested', N'CRYO CPD QUAR', N'E028', N'@A2 I4', 15, N'E6183', 8760, 0, 0, 1, NULL, N'A', '20091109 15:20:32.810', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'8c28163b-e635-4251-9fcc-fe4dde79eaa5', N'POOLED PLATELETS|CPD/XX/20-24C|Irradiated|ResLeu:<5log6|Bacterial monitoring', N'PLT Pool CPD IRD LUKOPR BacMtr', N'E022', N'@A7 C2 D4 N2', 200, N'E6339', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:37.963', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'8c61331f-2f0f-4502-9908-6d905b6c63bd', N'PLASMA|CPD/XX/<-25C|For mnf:injectable|Frozen <=24h', N'PLASMA CPD MNFI', N'E010', N'@A1 A2 G7', 225, N'E6323', 8760, 0, 0, 1, NULL, N'A', '20091109 15:18:54.163', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'8cc15691-b951-4721-ad01-56e491818a06', N'Thawed PLASMA IRRADIATED DONOR RETESTED (Storage -18C or colder)', N'PLASMA Thaw None IRD', N'E011', N'@AS C2', 225, N'17801', 120, 0, 0, 0, NULL, N'A', '20100514 15:01:54.953', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'8cf23db1-e5e5-494d-ba6c-ad887c483f50', N'Washed POOLED PLATELETS|None/XX/20-24C|Irradiated|ResLeu:<1log6|Buffy coat plts prep|From 8 donors', N'PLT Pool Wash None IRD LUKOPR BUFCT 8DNR', N'E023', N'@71 C2 D5 G2 J8', 200, N'E6283', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:52.137', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'8e16a052-9647-445a-825a-c0de5638f9a0', N'POOLED PLATELETS|CPD/XX/20-24C|Irradiated|ResLeu:<1log6|Plasma reduced/Plasma added|Buffy coat plts prep|From 8 donors', N'PLT Pool CPD IRD LUKOPR PLS Red/PA BUFCT 8DNR', N'E022', N'@A7 C2 D5 EE G2 J8', 200, N'E6348', 4, 0, 0, 1, NULL, N'A', '20100210 13:55:15.970', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'8f5a7f3e-5253-4ef6-a31c-4376979a18c4', N'POOLED PLATELETS|CPD/XX/20-24C|Irradiated|ResLeu:<1log6|From 4 donors', N'PLT Pool CPD IRD LUKOPR 4DNR', N'E022', N'@A7 C2 D5 J4', 200, N'E6244', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:23.307', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'8fabb059-4664-4375-95ea-b6334f39901a', N'Washed RED BLOOD CELLS|None/450mL/refg|Open|ResLeu:<1log6,WB filtr', N'RBC Wash None OPN LUKOPR', N'E003', N'@17 B2 DA', 200, N'E6521', 24, 0, 0, 1, NULL, N'A', '20091109 15:18:36.150', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'900ede66-650c-40a4-9282-0d2fe3d05284', N'FRESH FROZEN PLASMA|CPDA-1/450mL/<-25C|For mnf:noninjectable|Frozen <=24h', N'FFP CPDA-1 MNFNI', N'E010', N'@CV A3 G7', 225, N'E6216', 8760, 0, 0, 1, NULL, N'A', '20091109 15:18:36.163', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'90103c5c-0e22-482c-b63a-d180c36c2d2e', N'Frozen RED BLOOD CELLS|Gly40%/450mL/<-65C|ResLeu:<1log6,RBC filtr', N'RBC Froz Gly40% LUKOPR', N'E004', N'@AT DB', 200, N'E6465', 87600, 0, 0, 1, NULL, N'A', '20091109 15:18:36.150', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'90746fbc-5822-4599-b81b-6a450330d396', N'FRESH FROZEN PLASMA|CPD/450mL/<-25C|For mnf:injectable|Frozen <=8h|Quar:>=112d/retested', N'FFP CPD MNFI QUAR', N'E010', N'@A2 A2 GB I4', 225, N'E6311', 8760, 0, 0, 1, NULL, N'A', '20091109 15:18:54.163', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'90ef88a8-b551-47a4-9e1d-8af680448288', N'Thawed FRESH FROZEN PLASMA|CPD/450mL/refg|Frozen <=18h', N'FFP Thaw CPD', N'E011', N'@03 G6', 225, N'E6157', 24, 0, 0, 1, NULL, N'A', '20091109 15:19:05.993', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'92a875a5-28f2-45f4-9142-31c3c80c07d6', N'Thawed CRYOPRECIPITATE|CPD/500mL/rt|ResLeu:NS', N'CRYO Thaw CPD LUKOPR', N'E029', N'@86 D2', 15, N'E6437', 6, 0, 0, 1, NULL, N'A', '20100210 13:55:15.970', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'933240b8-98de-48ac-996c-21b4b78cb264', N'Thawed FRESH FROZEN PLASMA DIVIDED (by pheresis)(-18C)(Part C or 3)', N'FFP AFR Thaw None', N'E013', N'@AS H5', 450, N'48213', 24, 0, 0, 0, NULL, N'A', '20100514 15:01:54.953', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'9393c727-8b3c-4e18-b6ff-8aa64f199f71', N'Liquid Apheresis PLASMA|CPD-50/XX/refg|ResLeu:<1log6|2nd container|Psoralen-treated', N'PLASMA AFR Liq CPD-50 LUKOPR Psoraln', N'E011', N'@AX D5 H4 K5', 225, N'E6357', 120, 0, 0, 1, NULL, N'A', '20091109 15:19:05.993', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'93e21d84-6f75-4f30-9192-866019a6900c', N'Thawed PLASMA CRYOPRECIPITATE REDUCED IRRADIATED', N'PLASMA Thaw None IRD CRYORed', N'E011', N'@AS C2 E3', 225, N'18436', 120, 0, 0, 0, NULL, N'A', '20100514 15:01:54.953', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'964b58a2-28ca-4184-bde5-e4fe59cfaa85', N'POOLED PLATELETS|CPD/XX/20-24C|Irradiated|From 4 donors', N'PLT Pool CPD IRD 4DNR', N'E022', N'@A7 C2 J4', 200, N'E6238', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:23.307', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'97114df0-ed1a-4af3-b84e-54d81c4639e9', N'Thawed FRESH FROZEN PLASMA DIVIDED (by pheresis)(-65C)(Part G or 7)', N'FFP AFR Thaw None', N'E013', N'@AS HB', 450, N'48317', 24, 0, 0, 0, NULL, N'A', '20100514 15:01:54.953', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'974b93a3-cf5f-41aa-b952-82ad3eeb6962', N'POOLED PLATELETS|CPD/XX/20-24C|Irradiated|Buffy coat plts prep|From 4 donors', N'PLT Pool CPD IRD BUFCT 4DNR', N'E022', N'@A7 C2 G2 J4', 200, N'E6251', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:23.307', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'97dcc505-7eac-4952-9b93-b912b028409d', N'Thawed Apheresis FRESH FROZEN PLASMA|CPD-50/XX/refg|ResLeu:<1log6|1st container|Psoralen-treated', N'FFP AFR Thaw CPD-50 LUKOPR Psoraln', N'E013', N'@AX D5 H3 K5', 450, N'E6358', 24, 0, 0, 1, NULL, N'A', '20100514 14:47:38.847', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'981f00eb-a43d-4144-b90d-ae8e376c6986', N'RED BLOOD CELLS|CPDA-1/450mL/refg|Irradiated|ResLeu:<1log6|Plasma reduced/Plasma added', N'RBC CPDA-1 IRD LUKOPR PLS Red/PA', N'E002', N'@07 C2 D5 EE', 250, N'E6321', 672, 0, 0, 1, NULL, N'A', '20091109 15:17:58.943', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'98a2fca7-db92-44e4-8d26-786c98189e60', N'Washed POOLED PLATELETS|None/XX/20-24C|Open|Irradiated|ResLeu:<1log6|Buffy coat plts prep|From 8 donors', N'PLT Pool Wash None OPN IRD LUKOPR BUFCT 8DNR', N'E023', N'@71 B2 C2 D5 G2 J8', 200, N'E6355', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:52.137', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'98e06cc5-c90d-4a01-b47a-355080fec083', N'Apheresis PLATELETS|PASIIIMgK/XX/20-24C|Irradiated|ResLeu:<1log6|3rd container|Bacterial test', N'PLT AFR PASIIIMgK IRD LUKOPR BacTest', N'E024', N'@CI C2 D5 H5 N3', 200, N'E6596', 120, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'994f43d4-2435-458f-a43e-a36cdd9b4f58', N'POOLED PLATELETS|CPD/XX/20-24C|Irradiated|Buffy coat plts prep|From 8 donors', N'PLT Pool CPD IRD BUFCT 8DNR', N'E022', N'@A7 C2 G2 J8', 200, N'E6255', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:37.963', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'99da7903-9969-48e1-96da-4a5cd735d07e', N'Thawed Plasma (-18C or colder), (by pheresis) Unliscensed', N'PLASMA AFR Thaw None', N'E013', N'@AS', 450, N'18451', 120, 0, 0, 0, NULL, N'L', '20100514 15:01:54.953', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'9a5fd5f8-90e3-484f-a099-20ec803af45a', N'RED BLOOD CELLS|CPD>AS1/500mL/refg|For mnf:injectable|ResLeu:<5log6', N'RBC CPD>AS1 MNFI LUKOPR', N'E002', N'@19 A2 D4', 350, N'E6202', 1008, 0, 0, 1, NULL, N'A', '20091109 15:17:58.943', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'9aa03e44-bfe7-41ad-8036-f6c7f3c5ce2b', N'POOLED PLATELETS|CPD/XX/20-24C|ResLeu:<1log6|From 3 donors', N'PLT Pool CPD LUKOPR 3DNR', N'E022', N'@A7 D5 J3', 200, N'E6229', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:23.307', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'9aa707f3-3591-4080-a81d-fffc38a4fe45', N'POOLED PLATELETS|CPD/XX/20-24C|Irradiated|Buffy coat plts prep|From 3 donors', N'PLT Pool CPD IRD BUFCT 3DNR', N'E022', N'@A7 C2 G2 J3', 200, N'E6250', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:23.307', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'9acbddd3-2f5b-450d-8095-265678f21668', N'Washed RED BLOOD CELLS|AS3/350mL/refg', N'RBC Wash AS3', N'E003', N'@D2', 200, N'E6498', 24, 0, 0, 1, NULL, N'A', '20091109 15:17:58.960', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'9ad4c100-d818-4f6b-b2d4-ee55032e5459', N'POOLED CRYOPRECIPITATE|None/XX/<=-18C|From 10 Donors', N'CRYO Pool None 10DNR', N'E030', N'@84 JN', 100, N'E6553', 8760, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'9b1af311-7ac2-4444-919c-1d782c0a619a', N'Washed Apheresis PLATELETS|PASIIIMgK/XX/20-24C|Irradiated|ResLeu:<1log6|4th container', N'PLT AFR Wash PASIIIMgK IRD LUKOPR', N'E027', N'@CI C2 D5 H6', 200, N'E6607', 4, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'9b267ce0-ca22-4671-b951-97a83daa1cc9', N'Apheresis PLATELETS|ACD-A/XX/20-24C|Open|ResLeu:<5log6|Plasma reduced|2nd container|<3log11 plts', N'PLT AFR ACD-A OPN LUKOPR PLS Red', N'E024', N'@73 B2 D4 E5 H4 JI', 200, N'E6418', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:52.150', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'9d1db4c0-ea19-4499-9129-487efbc3cd69', N'RED BLOOD CELLS|CPD/500mL/refg|Not for tx or mnf|ResLeu:<5log6', N'RBC CPD NMT LUKOPR', N'E002', N'@04 A4 D4', 250, N'E6400', 504, 0, 0, 1, NULL, N'A', '20091109 15:17:58.943', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'9d53843b-6078-4c90-b8c7-9cad16cb80b2', N'PLASMA|CPDA-1/XX/<-25C|Cryo reduced|Riboflavin-treated', N'PLASMA CPDA-1 CRYORed Ribo', N'E010', N'@38 E3 K6', 225, N'E6543', 8760, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'9dbf11dc-58f2-4f9c-97ac-18a1de774d49', N'POOLED PLATELETS|PASIIIMgK/XX/20-24C|Irradiated|ResLeu:<1log6|Buffy coat plts prep|Bacterial test', N'PLT Pool PASIIIMgK IRD LUKOPR BUFCT BacTest', N'E022', N'@CI C2 D5 G2 N3', 200, N'E6569', 4, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'9f46008b-48b7-4678-8ba6-1164f8600041', N'Thawed FRESH FROZEN PLASMA DIVIDED (-65C or colder)(Part H or 8)', N'FFP Thaw None', N'E011', N'@AS HC', 225, N'48308', 24, 0, 0, 0, NULL, N'A', '20100514 15:01:54.953', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'a2fc104e-3395-4d1b-84da-8a16255c48cc', N'Thawed FRESH FROZEN PLASMA|CPDA-1/450mL/refg|ResLeu:NS', N'FFP Thaw CPDA-1 LUKOPR', N'E011', N'@07 D2', 225, N'E6431', 24, 0, 0, 1, NULL, N'A', '20091109 15:19:05.993', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'a3b12392-4f01-453f-8874-aacef13363f2', N'RED BLOOD CELLS|CPD>SAGM/500mL/refg|Open|ResLeu:<5log6|Plasma reduced', N'RBC CPD>SAGM OPN LUKOPR PLS Red', N'E002', N'@CM B2 D4 E5', 350, N'E6369', 24, 0, 0, 1, NULL, N'A', '20091109 15:17:58.943', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'a4540412-3b2e-432f-b93e-d902822329c5', N'Apheresis PLATELETS|ACD-A/XX/20-24C|Irradiated|ResLeu:<5log6|Plasma reduced/Plasma added', N'PLT AFR ACD-A IRD LUKOPR PLS Red/PA', N'E024', N'@73 C2 D4 EE', 200, N'E6333', 120, 0, 0, 1, NULL, N'A', '20091109 15:19:52.137', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'a5436947-2e8d-43d2-8d66-a78635a53906', N'Washed Apheresis RED BLOOD CELLS|None/XX/refg|ResLeu:<5log6|2nd container', N'RBC AFR Wash None LUKOPR', N'E049', N'@AS D4 H4', 200, N'E6186', 24, 0, 0, 1, NULL, N'A', '20091109 15:22:26.077', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'a5b16d14-a33b-4890-8696-05c59caeb166', N'POOLED PLATELETS|CPD/XX/20-24C|Irradiated|From 6 donors', N'PLT Pool CPD IRD 6DNR', N'E022', N'@A7 C2 J6', 200, N'E6239', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:23.307', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'a67d41fa-8eb7-4fdb-9252-777189cbf00c', N'Washed POOLED PLATELETS|None/XX/20-24C|Open|Irradiated|ResLeu:<1log6|Buffy coat plts prep|From 3 donors', N'PLT Pool Wash None OPN IRD LUKOPR BUFCT 3DNR', N'E023', N'@71 B2 C2 D5 G2 J3', 200, N'E6350', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:52.137', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'a6aee923-c778-4571-b201-f0feeffc2e35', N'Apheresis PLATELETS|PASIIIMgK/XX/20-24C|Irradiated|ResLeu:<1log6|4th container|Bacterial test', N'PLT AFR PASIIIMgK IRD LUKOPR BacTest', N'E024', N'@CI C2 D5 H6 N3', 200, N'E6597', 120, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'a6b8489f-dea1-42e2-87ec-6d09d1b01133', N'Apheresis PLATELETS|PASIIIMgK/XX/20-24C|ResLeu:<1log6|3rd container', N'PLT AFR PASIIIMgK LUKOPR', N'E024', N'@CI D5 H5', 200, N'E6576', 120, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'a7273086-d448-41a8-b58c-6d4f64b18f3e', N'Washed Apheresis RED BLOOD CELLS|None/XX/refg|Open|Irradiated|ResLeu:<1log6', N'RBC AFR Wash None OPN IRD LUKOPR', N'E049', N'@AS B2 C2 D5', 200, N'E6219', 24, 0, 0, 1, NULL, N'A', '20091109 15:22:40.077', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'a75c6fe4-d6bf-4322-9011-d562b4ffb020', N'Thawed FRESH FROZEN PLASMA DIVIDED IRRADIATED (by pheresis)(-65C or colder)(Part F or 6)', N'FFP AFR Thaw None IRD', N'E013', N'@AS C2 HA', 450, N'48716', 24, 0, 0, 0, NULL, N'A', '20100514 15:01:54.953', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'a77273d1-a6d4-436a-bb0e-8394d256d77c', N'FRESH FROZEN PLASMA|CPDA-1/450mL/<-25C|Frozen <=8h', N'FFP CPDA-1', N'E010', N'@CV GB', 225, N'E6304', 8760, 0, 0, 1, NULL, N'A', '20091109 15:18:54.163', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'a773eb60-7e69-4086-8c98-9eb0f24bf3f9', N'Washed RED BLOOD CELLS|None/450mL/refg|Open|Irradiated|ResLeu:<1log6,WB filtr', N'RBC Wash None OPN IRD LUKOPR', N'E003', N'@17 B2 C2 DA', 200, N'E6522', 24, 0, 0, 1, NULL, N'A', '20091109 15:18:36.150', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'a88d9a22-6ea1-4733-aab5-dd0698286a9b', N'FRESH FROZEN PLASMA|CPD/450mL/<-25C|Frozen <=6h|Quar:>=112d/retested', N'FFP CPD QUAR', N'E010', N'@A2 G4 I4', 225, N'E6181', 8760, 0, 0, 1, NULL, N'A', '20091109 15:18:36.150', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'a9180c5e-f8d1-4a92-a105-0c1e32c7de1a', N'PLATELETS|CPD/450mL/20-24C|Open|Irradiated|ResLeu:<8.3log5|Plasma reduced', N'PLT CPD OPN IRD LUKOPR PLS Red', N'E020', N'@64 B2 C2 D6 E5', 50, N'E6164', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:23.290', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'aa7ab5c9-b1e2-4bf8-a81c-cae9c0f5456d', N'CRYOPRECIPITATE|CPD/450mL/<-25C', N'CRYO CPD', N'E028', N'@A2', 15, N'E6296', 8760, 0, 0, 1, NULL, N'A', '20091109 15:21:55.357', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'aa7ce910-04bc-4795-b825-ad4c94850497', N'Apheresis PLATELETS|ACD-A/XX/20-24C|Irradiated|Plasma reduced/Plasma added|3rd container', N'PLT AFR ACD-A IRD PLS Red/PA', N'E024', N'@73 C2 EE H5', 200, N'E6480', 120, 0, 0, 1, NULL, N'A', '20091109 15:20:06.887', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'aacc0032-49e7-4f2c-8149-463ad13db0ff', N'Frozen RED BLOOD CELLS|None/450mL/<-65C', N'RBC Froz None', N'E004', N'@29', 200, N'E6196', 87600, 0, 0, 1, NULL, N'A', '20091109 15:18:36.150', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'aadf343c-eb9a-47da-b9b6-f13190533aae', N'POOLED PLATELETS|CPD/XX/<37C|For mnf:noninjectable|ResLeu:<5log6', N'PLT Pool CPD MNFNI LUKOPR', N'E022', N'@61 A3 D4', 200, N'E6340', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:37.963', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'abc66837-041d-4f34-8495-3a54a5caf530', N'POOLED PLATELETS|CPD/XX/20-24C|ResLeu:<1log6|Plasma reduced/Plasma added', N'PLT Pool CPD LUKOPR PLS Red/PA', N'E022', N'@A7 D5 EE', 200, N'E6198', 4, 0, 0, 1, NULL, N'A', '20100210 13:55:15.970', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'acdc3b00-da80-49e6-bb8c-62d44eff4b24', N'Thawed FRESH FROZEN PLASMA|CPD/450mL/refg|ResLeu:<1log6,WB filtr', N'FFP Thaw CPD LUKOPR', N'E011', N'@03 DA', 225, N'E6517', 24, 0, 0, 1, NULL, N'A', '20091109 15:19:05.993', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'ad76fe7a-dc1a-4f6c-ae19-288dce3d8415', N'Thawed FRESH FROZEN PLASMA DIVIDED IRRADIATED (by pheresis)(-65C or colder)(Part G or 7)', N'FFP AFR Thaw None IRD', N'E013', N'@AS C2 HB', 450, N'48717', 24, 0, 0, 0, NULL, N'A', '20100514 15:01:54.953', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'ada51e9c-ccfb-4549-b881-11e3bac8781e', N'POOLED PLATELETS|CPD/XX/20-24C|Irradiated|ResLeu:<1log6|Buffy coat plts prep|From 7 donors', N'PLT Pool CPD IRD LUKOPR BUFCT 7DNR', N'E022', N'@A7 C2 D5 G2 J7', 200, N'E6268', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:37.963', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'adf38f46-dcd7-4608-8de2-bf35346a83ff', N'POOLED PLATELETS|CPD/XX/20-24C|From 2 donors', N'PLT Pool CPD 2DNR', N'E022', N'@A7 J2', 200, N'E6222', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:23.307', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'ae0976a0-8785-48c1-baa9-b682744a0a48', N'Thawed POOLED CRYOPRECIPITATE|CPD/XX/rt|Quar:>=112d/retested', N'CRYO Pool Thaw CPD QUAR', N'E031', N'@BT I4', 100, N'E6182', 4, 0, 0, 1, NULL, N'A', '20091109 15:22:26.077', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'ae65ec70-697c-486b-be46-9493039b355e', N'Apheresis RED BLOOD CELLS|ACD-A>AS1/XX/refg|Open|Irradiated|ResLeu:<5log6|Supernat reduced|1st container', N'RBC AFR ACD-A>AS1 OPN IRD LUKOPR SUPRed', N'E009', N'@AY B2 C2 D4 EA H3', 350, N'E6388', 24, 0, 0, 1, NULL, N'A', '20091109 15:18:36.150', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'ae721b66-08ed-4b3f-a80e-55c0f3b2c439', N'CRYOPRECIPITATE|CPDA-1/450mL/<-25C', N'CRYO CPDA-1', N'E028', N'@CV', 15, N'E6295', 8760, 0, 0, 1, NULL, N'A', '20091109 15:21:55.357', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'af94de91-7dd2-43e3-b058-a635b9ce9d58', N'POOLED PLATELETS|CPD/XX/<37C|For mnf:noninjectable|Irradiated|ResLeu:<5log6', N'PLT Pool CPD MNFNI IRD LUKOPR', N'E022', N'@61 A3 C2 D4', 200, N'E6341', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:37.963', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'afde8d40-e3ff-4bc7-a5f4-5988164da4ad', N'PLASMA|CPDA-1/XX/<=-20C|For mnf:injectable restr use|Cryo reduced|Frozen <=72h', N'PLASMA CPDA-1 MNFRI CRYORed', N'E010', N'@BR A6 E3 GD', 225, N'E6488', 8760, 0, 0, 1, NULL, N'A', '20091109 15:18:54.163', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'b00576f6-360a-442a-bc4d-e46b4ea0dedc', N'Washed POOLED PLATELETS|None/XX/20-24C|Irradiated|ResLeu:<1log6|From 7 donors', N'PLT Pool Wash None IRD LUKOPR 7DNR', N'E023', N'@71 C2 D5 J7', 200, N'E6275', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:37.963', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'b04a97f9-845b-4160-9096-fa9f3ce5a8c6', N'Thawed Apheresis PLATELETS|DMSO/XX/20-24C|Open|Irradiated|ResLeu:<1log6|Supernat rem/Plasma added', N'PLT AFR Thaw DMSO OPN IRD LUKOPR SR/PA', N'E026', N'@77 B2 C2 D5 E8', 200, N'E6292', 4, 0, 0, 1, NULL, N'A', '20091109 15:20:06.887', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'b09ebdcb-2e3a-427e-9a3b-5c9f48c63ea7', N'Thawed FRESH FROZEN PLASMA|CPD/XX/refg|ResLeu:<5log6|Methylene blue-treated', N'FFP Thaw CPD LUKOPR Methyl Blue', N'E011', N'@06 D4 K3', 225, N'E6527', 24, 0, 0, 1, NULL, N'A', '20091109 15:19:05.993', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'b0da80e0-b6c4-44e9-b8cb-c230e551e1f0', N'Apheresis PLATELETS|ACD-A/XX/20-24C|ResLeu:<5log6|Plasma reduced/Plasma added|2nd container', N'PLT AFR ACD-A LUKOPR PLS Red/PA', N'E024', N'@73 D4 EE H4', 200, N'E6331', 120, 0, 0, 1, NULL, N'A', '20091109 15:19:52.137', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'b18436a0-b67e-4cae-8476-e98f721715e4', N'Washed POOLED PLATELETS|None/XX/20-24C|Open|Irradiated|ResLeu:<1log6|Buffy coat plts prep|From 2 donors', N'PLT Pool Wash None OPN IRD LUKOPR BUFCT 2DNR', N'E023', N'@71 B2 C2 D5 G2 J2', 200, N'E6349', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:52.137', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'b277063f-ed0d-4ec2-9d55-dabbbbafdd93', N'Thawed FRESH FROZEN PLASMA DIVIDED (-18C or colder)(Part F or 6)', N'FFP Thaw None', N'E011', N'@AS HA', 225, N'48206', 24, 0, 0, 0, NULL, N'A', '20100514 15:01:54.953', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'b2809fa2-39f2-4349-b235-1f5cac1104b0', N'FRESH FROZEN PLASMA|CPD/450mL/<-25C|For mnf:noninjectable|Frozen <=8h', N'FFP CPD MNFNI', N'E010', N'@A2 A3 GB', 225, N'E6306', 8760, 0, 0, 1, NULL, N'A', '20091109 15:18:54.163', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'b2d83bed-0390-467a-9faa-0eab816dadfa', N'Apheresis PLATELETS|ACD-A/XX/20-24C|For mnf:noninjectable|Irradiated|ResLeu:<5log6|2nd container', N'PLT AFR ACD-A MNFNI IRD LUKOPR', N'E024', N'@73 A3 C2 D4 H4', 200, N'E6449', 120, 0, 0, 1, NULL, N'A', '20091109 15:19:52.150', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'b3a3868e-a796-43e7-930d-8da975dc68b6', N'Thawed FRESH FROZEN PLASMA DIVIDED IRRADIATED (by pheresis)(-65C or colder)(Part A or 1)', N'FFP AFR Thaw None IRD', N'E013', N'@AS C2 H3', 450, N'48711', 24, 0, 0, 0, NULL, N'A', '20100514 15:01:54.953', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'b3ddbb16-0257-4d6d-a8f3-0b1fbaec3225', N'FRESH FROZEN PLASMA|CPDA-1/XX/<-25C|Riboflavin-treated', N'FFP CPDA-1 Ribo', N'E010', N'@38 K6', 225, N'E6542', 8760, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'b4069f16-d8f8-4a38-882d-a3d710b19d47', N'POOLED PLATELETS|PAS-E/XX/20-24C|ResLeu:<1log6|Buffy coat plts prep|Psoralen-treated', N'PLT Pool PAS-E LUKOPR BUFCT Psoraln', N'E022', N'@D5 D5 G2 K5', 200, N'E6642', 4, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'b44ebf1a-d3a6-4791-bbe9-bced6a28233b', N'Thawed FRESH FROZEN PLASMA DIVIDED IRRADIATED (-18C)(Part C or 3)', N'FFP Thaw None IRD', N'E011', N'@AS C2 H5', 225, N'48603', 24, 0, 0, 0, NULL, N'A', '20100514 15:01:54.953', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'b4bb3ed2-4876-4aa9-a4b0-c624bc63d274', N'Thawed POOLED FRESH FROZEN PLASMA|CPDA-1/XX/refg', N'FFP Pool Thaw CPDA-1', N'E011', N'@10', 500, N'E6177', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:05.993', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'b5ae9a72-2847-486b-9b5e-94f48e0af5a3', N'Washed Apheresis PLATELETS|None/XX/20-24C|Open|Irradiated|ResLeu:<5log6|1st container|Approx 300 log9 plts', N'PLT AFR Wash None OPN IRD LUKOPR', N'E027', N'@71 B2 C2 D4 H3 JC', 200, N'E6425', 4, 0, 0, 1, NULL, N'A', '20091109 15:20:32.810', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'b5ba11a0-7880-4782-9597-557101f3ed4c', N'Washed POOLED PLATELETS|None/XX/20-24C|Irradiated|ResLeu:<1log6|Buffy coat plts prep|From 4 donors', N'PLT Pool Wash None IRD LUKOPR BUFCT 4DNR', N'E023', N'@71 C2 D5 G2 J4', 200, N'E6279', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:52.137', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'b6207df4-5510-4f49-9a63-d71283d5bee6', N'POOLED PLATELETS|CPD/XX/20-24C|ResLeu:<1log6|From 6 donors', N'PLT Pool CPD LUKOPR 6DNR', N'E022', N'@A7 D5 J6', 200, N'E6232', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:23.307', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'b656dc06-4024-4330-a73b-cd95dd832a85', N'Apheresis FRESH FROZEN PLASMA|NaCitrate/XX/<-25C|Frozen <=6h|Psoralen-treated', N'FFP AFR NaCit Psoraln', N'E012', N'@CQ G4 K5', 450, N'E6537', 8760, 0, 0, 1, NULL, N'A', '20100514 14:47:38.847', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'b6735782-bfdc-493c-8a6f-af24dd4c3881', N'Thawed Apheresis FRESH FROZEN PLASMA|CPD-50/XX/refg|ResLeu:<1log6|2nd container|Psoralen-treated', N'FFP AFR Thaw CPD-50 LUKOPR Psoraln', N'E013', N'@AX D5 H4 K5', 450, N'E6359', 24, 0, 0, 1, NULL, N'A', '20100514 14:47:38.847', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'b69ae40f-13dd-4611-8aa4-be0a6a2b5021', N'Apheresis PLATELETS|ACD-A/XX/20-24C|Open|Irradiated|2nd container|<3log11 plts', N'PLT AFR ACD-A OPN IRD', N'E024', N'@73 B2 C2 H4 JI', 200, N'E6413', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:52.150', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'b716e8cc-fcab-4ae4-92e3-c98e3e731f69', N'Washed Apheresis PLATELETS|None/XX/20-24C|Open|Irradiated|ResLeu:<5log6|<3log11 plts', N'PLT AFR Wash None OPN IRD LUKOPR', N'E027', N'@71 B2 C2 D4 JI', 200, N'E6407', 4, 0, 0, 1, NULL, N'A', '20091109 15:20:06.887', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'b744fd73-93ba-42c5-8c99-30dded18c1b5', N'Apheresis PLATELETS|ACD-A/XX/20-24C|Open|Irradiated|ResLeu:<5log6|Plasma reduced|<3log11 plts', N'PLT AFR ACD-A OPN IRD LUKOPR PLS Red', N'E024', N'@73 B2 C2 D4 E5 JI', 200, N'E6554', 4, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'b7bf34f5-b50d-456f-8035-6fb4389e94c2', N'Thawed PLASMA|CPD/500mL/refg|ResLeu:NS|Frozen <=24h', N'PLASMA Thaw CPD LUKOPR', N'E011', N'@04 D2 G7', 225, N'E6440', 120, 0, 0, 1, NULL, N'A', '20091109 15:19:05.993', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'b7c263df-45f9-4336-bbda-a1bd17470733', N'PLATELETS|CPDA-1/500mL/20-24C|Open|Irradiated|ResLeu:<8.3log5', N'PLT CPDA-1 OPN IRD LUKOPR', N'E020', N'@67 B2 C2 D6', 50, N'E6160', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:23.290', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'b8929f1a-ece8-4014-9440-f41992a44698', N'Thawed FRESH FROZEN PLASMA DIVIDED IRRADIATED (by pheresis)(-65C or colder)(Part D or 4)', N'FFP AFR Thaw None IRD', N'E013', N'@AS C2 H6', 450, N'48714', 24, 0, 0, 0, NULL, N'A', '20100514 15:01:54.953', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'b8ae4e5f-f0df-4d64-aabb-b06a31ca50e6', N'Apheresis PLATELETS|ACD-A/XX/20-24C|Plasma reduced/Plasma added|2nd container', N'PLT AFR ACD-A PLS Red/PA', N'E024', N'@73 EE H4', 200, N'E6475', 120, 0, 0, 1, NULL, N'A', '20091109 15:19:52.150', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'b9816195-3860-4042-9856-1080df66694a', N'Apheresis PLATELETS|ACD-A/XX/20-24C|Plasma reduced/Plasma added', N'PLT AFR ACD-A PLS Red/PA', N'E024', N'@73 EE', 200, N'E6473', 120, 0, 0, 1, NULL, N'A', '20091109 15:19:52.150', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'b9825717-ca09-4408-b9a8-045f0e4de9bd', N'Thawed FRESH FROZEN PLASMA DIVIDED IRRADIATED (by pheresis)(-18C or colder)(Part C or 3)', N'FFP AFR Thaw None IRD', N'E013', N'@AS C2 H5', 450, N'48613', 24, 0, 0, 0, NULL, N'A', '20100514 15:01:54.953', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'ba63468d-7aab-41bb-bac4-fce0678854a1', N'Apheresis RED BLOOD CELLS|CPD-50>SAGM/XX/refg|ResLeu:<5log6|2nd container', N'RBC AFR CPD-50>SAGM LUKOPR', N'E009', N'@CX D4 H4', 350, N'E6442', 1008, 0, 0, 1, NULL, N'A', '20100514 14:47:38.847', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'bad49838-d4ed-4778-8879-3ba290039f8c', N'Apheresis PLATELETS|PAS-E/XX/20-24C|ResLeu:<1log6|Riboflavin-treated', N'PLT AFR PAS-E LUKOPR Ribo', N'E024', N'@D5 D5 K6', 200, N'E6641', 120, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'bc977374-fffb-4024-a3c4-65f34faa0e31', N'WHOLE BLOOD|CPD/450mL/refg|ResLeu:<1log6,WB filtr', N'WB CPD LUKOPR', N'E001', N'@03 DA', 450, N'E6468', 504, 0, 0, 1, NULL, N'A', '20091109 15:17:58.943', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'bd2130f9-fa8a-4315-9dc4-aea8772f8584', N'PLATELETS|CP2D/XX/20-24C|Open|ResLeu:<8.3log5|Plasma reduced', N'PLT CP2D OPN LUKOPR PLS Red', N'E020', N'@B9 B2 D6 E5', 50, N'E6360', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:23.290', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'be8ae03a-b86f-4a27-b207-21993338db8c', N'Thawed PLASMA|CP2D/XX/refg|ResLeu:NS|Frozen <=72h', N'PLASMA Thaw CP2D LUKOPR', N'E011', N'@13 D2 GD', 225, N'E6561', 120, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'bf3976fe-b4cc-4ca5-b4ce-5d292ea8209d', N'Thawed FRESH FROZEN PLASMA DIVIDED (by pheresis)(-65C)(Part E or 5)', N'FFP AFR Thaw None', N'E013', N'@AS H9', 450, N'48315', 24, 0, 0, 0, NULL, N'A', '20100514 15:01:54.953', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'bf962f05-b825-43cc-9f8e-f2360470aa28', N'Thawed FRESH FROZEN PLASMA DIVIDED IRRADIATED (-18C)(Part E or 5)', N'FFP Thaw None IRD', N'E011', N'@AS C2 H9', 225, N'48605', 24, 0, 0, 0, NULL, N'A', '20100514 15:01:54.953', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'bfed680a-3ecc-424d-b3a6-fa65c58238f0', N'Thawed PLASMA IRRADIATED DONOR RETESTED (from 250 ml Whole Blood)(Storage -18C or colder)', N'PLASMA Thaw None IRD', N'E011', N'@AS C2', 225, N'17831', 120, 0, 0, 0, NULL, N'A', '20100514 15:01:54.953', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'c0a3a73f-3d63-4e54-9842-4ff7671d7ba7', N'FRESH FROZEN PLASMA|CPDA-1/450mL/<-25C|Frozen <=8h|Quar:>=112d/retested', N'FFP CPDA-1 QUAR', N'E010', N'@CV GB I4', 225, N'E6305', 8760, 0, 0, 1, NULL, N'A', '20091109 15:18:54.163', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'c116ffbc-2503-469d-940c-72d13ad6569c', N'POOLED PLATELETS|CPD/XX/20-24C|Irradiated|Buffy coat plts prep|From 5 donors', N'PLT Pool CPD IRD BUFCT 5DNR', N'E022', N'@A7 C2 G2 J5', 200, N'E6252', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:37.947', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'c1603e97-7d4a-4dda-86b2-1e76f151b58f', N'POOLED PLATELETS|CPD/XX/20-24C|ResLeu:<1log6|Buffy coat plts prep|From 2 donors', N'PLT Pool CPD LUKOPR BUFCT 2DNR', N'E022', N'@A7 D5 G2 J2', 200, N'E6256', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:37.963', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'c17f6252-7ad9-49d5-b2d1-7d8efd681822', N'RED BLOOD CELLS|CPD>SAGM/500mL/refg|Open|ResLeu:<5log6|Supernat rem/Plasma added', N'RBC CPD>SAGM OPN LUKOPR SR/PA', N'E002', N'@CM B2 D4 E8', 350, N'E6374', 24, 0, 0, 1, NULL, N'A', '20091109 15:17:58.943', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'c1a0ff76-67dd-4b82-b51e-31a65bb816a4', N'PLATELETS|CPDA-1/500mL/20-24C|Open|ResLeu:<8.3log5', N'PLT CPDA-1 OPN LUKOPR', N'E020', N'@67 B2 D6', 50, N'E6159', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:23.290', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'c1bb8eca-a9fa-4787-83a3-03ad2f4c933e', N'Thawed PLASMA IRRADIATED (from 250 ml Whole Blood)(Storage -18C or colder)', N'PLASMA Thaw None IRD', N'E011', N'@AS C2', 225, N'18831', 120, 0, 0, 0, NULL, N'A', '20100514 15:01:54.953', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'c2320e10-18ea-4d95-b954-12bcd5d1c93f', N'Thawed FRESH FROZEN PLASMA DIVIDED (by pheresis)(-18C)(Part D or 4)', N'FFP AFR Thaw None', N'E013', N'@AS H6', 450, N'48214', 24, 0, 0, 0, NULL, N'A', '20100514 15:01:54.953', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'c24828f7-42fa-41b3-b9c2-6907b1902d8a', N'Apheresis PLATELETS|ACD-A/XX/20-24C|Open|Irradiated|ResLeu:<5log6|1st container|<3log11 plts', N'PLT AFR ACD-A OPN IRD LUKOPR', N'E024', N'@73 B2 C2 D4 H3 JI', 200, N'E6405', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:52.137', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'c2807677-07e0-4a51-aa2e-dc81843a08a2', N'Thawed PLASMA CRYOPRECIPITATE REDUCED DONOR RETESTED IRRADIATED', N'PLASMA Thaw None IRD CRYORed', N'E011', N'@AS C2 E3', 225, N'17436', 120, 0, 0, 0, NULL, N'A', '20100514 15:01:54.953', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'c36492a3-87dd-4918-a635-4601482f27c4', N'RED BLOOD CELLS|CPD>AS5/500mL/refg|Not for tx or mnf|ResLeu:<5log6', N'RBC CPD>AS5 NMT LUKOPR', N'E002', N'@23 A4 D4', 350, N'E6403', 1008, 0, 0, 1, NULL, N'A', '20091109 15:17:58.943', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'c37d5970-2259-467a-bb4d-3394c9cc9e7c', N'POOLED PLATELETS|CPD/XX/20-24C|From 7 donors', N'PLT Pool CPD 7DNR', N'E022', N'@A7 J7', 200, N'E6226', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:23.307', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'c403b836-a23f-4f5d-999c-5da3165c3925', N'Washed POOLED PLATELETS|None/XX/20-24C|Irradiated|ResLeu:<1log6|From 3 donors', N'PLT Pool Wash None IRD LUKOPR 3DNR', N'E023', N'@71 C2 D5 J3', 200, N'E6271', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:37.963', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'c46c2732-9961-407a-977b-c00fb55a2d5f', N'POOLED PLATELETS|PASIIIMgK/XX/20-24C|Irradiated|ResLeu:<1log6|Buffy coat plts prep', N'PLT Pool PASIIIMgK IRD LUKOPR BUFCT', N'E022', N'@CI C2 D5 G2', 200, N'E6565', 4, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'c47c7cc2-6c6b-4366-860c-9ac0b297e208', N'Thawed Apheresis PLATELETS|DMSO/XX/20-24C|Open|Irradiated|ResLeu:<1log6|Supernat rem/Plasma added|1st container', N'PLT AFR Thaw DMSO OPN IRD LUKOPR SR/PA', N'E026', N'@77 B2 C2 D5 E8 H3', 200, N'E6293', 4, 0, 0, 1, NULL, N'A', '20091109 15:20:06.887', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'c5053122-bb91-4dfa-b724-9321556f174e', N'RED BLOOD CELLS|CPD>SAGM/500mL/refg|Open|ResLeu:<5log6', N'RBC CPD>SAGM OPN LUKOPR', N'E002', N'@CM B2 D4', 350, N'E6427', 24, 0, 0, 1, NULL, N'A', '20091109 15:17:58.943', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'c57f3f9a-7521-41e1-a55c-9607f5f0584b', N'FRESH FROZEN PLASMA|CPDA-1/450mL/<-25C|For mnf:injectable|Frozen <=8h', N'FFP CPDA-1 MNFI', N'E010', N'@CV A2 GB', 225, N'E6312', 8760, 0, 0, 1, NULL, N'A', '20091109 15:18:54.163', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'c7f9fa32-185d-40d7-b108-84fa4d22f195', N'POOLED PLATELETS|PASIIIMgK/XX/20-24C|ResLeu:<1log6|Buffy coat plts prep', N'PLT Pool PASIIIMgK LUKOPR BUFCT', N'E022', N'@CI D5 G2', 200, N'E6564', 4, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'c8b96355-46f6-44bf-b643-5530bdbc8fbd', N'POOLED PLATELETS|CPD/XX/20-24C|Irradiated|Buffy coat plts prep|From 7 donors', N'PLT Pool CPD IRD BUFCT 7DNR', N'E022', N'@A7 C2 G2 J7', 200, N'E6254', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:37.963', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'c9a74e0a-2dc8-4d51-a4a4-59ae429bf110', N'Apheresis FRESH FROZEN PLASMA|CP2D/XX/<=-18C|2nd container', N'FFP AFR CP2D', N'E012', N'@37 H4', 450, N'E6461', 8760, 0, 0, 1, NULL, N'A', '20100514 14:47:38.847', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'ca21d05c-2c3a-476f-ae4d-b57abc5f6f75', N'Thawed PLASMA|CPDA-1/XX/refg|ResLeu:<5log6', N'PLASMA Thaw CPDA-1 LUKOPR', N'E011', N'@10 D4', 225, N'E6623', 120, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'ca7e127a-cdb2-493a-b4e3-53064f1c5f00', N'Apheresis PLATELETS|ACD-A/XX/20-24C|Open|Irradiated|Plasma reduced|1st container|<3log11 plts', N'PLT AFR ACD-A OPN IRD PLS Red', N'E024', N'@73 B2 C2 E5 H3 JI', 200, N'E6416', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:52.150', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'cab3ee57-501b-4ba2-9309-b587988843c9', N'PLASMA|CP2D/XX/<=-18C|For mnf:noninjectable restr use|Cryo reduced', N'PLASMA CP2D MNFRNI CRYORed', N'E010', N'@37 A5 E3', 225, N'E6609', 8760, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'cb56b7a7-c664-4491-b368-fa1217a7291e', N'POOLED PLATELETS|CPD/XX/20-24C|Irradiated|ResLeu:<1log6|From 7 donors', N'PLT Pool CPD IRD LUKOPR 7DNR', N'E022', N'@A7 C2 D5 J7', 200, N'E6247', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:23.307', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'cbb1f262-d57d-4478-af51-d450574739f6', N'Thawed FRESH FROZEN PLASMA DIVIDED (by pheresis)(-18C)(Part F or 6)', N'FFP AFR Thaw None', N'E013', N'@AS HA', 450, N'48216', 24, 0, 0, 0, NULL, N'A', '20100514 15:01:54.953', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'cbf1046e-759d-4a67-80d8-2b8cc51f72f2', N'Apheresis RED BLOOD CELLS|SAGM/XX/refg|ResLeu:<1log6|Supernat rem/Plasma added|2nd container', N'RBC AFR SAGM LUKOPR SR/PA', N'E009', N'@A9 D5 E8 H4', 350, N'E6541', 1008, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'cc1bbe7e-6e5e-4575-8e80-691de88b5d5a', N'Washed Apheresis PLATELETS|None/XX/20-24C|Open|Irradiated|1st container|<3log11 plts', N'PLT AFR Wash None OPN IRD', N'E027', N'@71 B2 C2 H3 JI', 200, N'E6423', 4, 0, 0, 1, NULL, N'A', '20091109 15:20:06.887', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'cc3f0c5e-92e2-45ea-b4a7-d59a7746a2dc', N'Washed Apheresis PLATELETS|None/XX/20-24C|Open|Irradiated|ResLeu:<5log6|2nd container|<3log11 plts', N'PLT AFR Wash None OPN IRD LUKOPR', N'E027', N'@71 B2 C2 D4 H4 JI', 200, N'E6378', 4, 0, 0, 1, NULL, N'A', '20091109 15:20:06.887', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'cc6c8a93-4fba-406d-ace8-3339e9137cb0', N'POOLED PLATELETS|CPD/XX/20-24C|ResLeu:<5log6|Bacterial monitoring', N'PLT Pool CPD LUKOPR BacMtr', N'E022', N'@A7 D4 N2', 200, N'E6338', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:37.963', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'cd57b7a8-3a40-4226-b2bb-189308bc9215', N'POOLED PLATELETS|CPD/XX/20-24C|Irradiated|ResLeu:<1log6|From 3 donors', N'PLT Pool CPD IRD LUKOPR 3DNR', N'E022', N'@A7 C2 D5 J3', 200, N'E6243', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:23.307', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'ce4f25a6-e77a-4755-87e7-0bf2ba0b2b1f', N'POOLED PLATELETS|PASIIIMgK/XX/20-24C|ResLeu:<1log6|Buffy coat plts prep|Bacterial monitoring', N'PLT Pool PASIIIMgK LUKOPR BUFCT BacMtr', N'E022', N'@CI D5 G2 N2', 200, N'E6566', 4, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'ce75e0b5-cd9c-4ca5-832a-605f336f6e0c', N'Thawed FRESH FROZEN PLASMA DIVIDED (-18C or colder)(Part E or 5)', N'FFP Thaw None', N'E011', N'@AS H9', 225, N'48205', 24, 0, 0, 0, NULL, N'A', '20100514 15:01:54.953', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'cebd8c49-d484-4a04-9212-efa2db066be2', N'Apheresis PLATELETS|PASIIIMgK/XX/20-24C|ResLeu:<1log6|4th container|Bacterial monitoring', N'PLT AFR PASIIIMgK LUKOPR BacMtr', N'E024', N'@CI D5 H6 N2', 200, N'E6585', 120, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'cf4b84cd-d0a8-40cc-9a9c-1feefeebc8ab', N'Thawed FRESH FROZEN PLASMA DIVIDED (-65C or colder)(Part B or 2)', N'FFP Thaw None', N'E011', N'@AS H4', 225, N'48302', 24, 0, 0, 0, NULL, N'A', '20100514 15:01:54.953', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'cf9ba0cb-7766-4f78-aa33-9b48d0a9a7f3', N'RED BLOOD CELLS|CPD>AS1/450mL/refg|Open|Irradiated|ResLeu:<1log6|Supernat rem/Plasma added', N'RBC CPD>AS1 OPN IRD LUKOPR SR/PA', N'E002', N'@18 B2 C2 D5 E8', 350, N'E6221', 24, 0, 0, 1, NULL, N'A', '20091109 15:17:58.943', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'cfacf611-2af2-47a3-9cd1-ce4728bdb327', N'PLATELETS|CP2D/450mL/20-24C|Open|ResLeu:<8.3log5|Plasma reduced', N'PLT CP2D OPN LUKOPR PLS Red', N'E020', N'@68 B2 D6 E5', 50, N'E6161', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:23.290', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'cfc0d582-a277-4e1c-a4ae-d46bd95cf5b0', N'Washed POOLED PLATELETS|None/XX/20-24C|Irradiated|ResLeu:<1log6|Buffy coat plts prep|From 2 donors', N'PLT Pool Wash None IRD LUKOPR BUFCT 2DNR', N'E023', N'@71 C2 D5 G2 J2', 200, N'E6277', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:37.963', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'cfddfd2e-d14e-4846-98a8-a856f133c35b', N'Frozen Apheresis PLATELETS|DMSO/XX/<-65C|Open|ResLeu:<1log6|1st container', N'PLT AFR Froz DMSO OPN LUKOPR', N'E025', N'@76 B2 D5 H3', 200, N'E6285', 8760, 0, 0, 1, NULL, N'A', '20091109 15:20:06.887', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'd1235e8c-6ecd-48ae-ad79-d7052fee3fd6', N'Liquid PLASMA|CPD/XX/<37C|For mnf:noninjectable restr use|Cryo reduced', N'PLASMA Liq CPD MNFRNI CRYORed', N'E011', N'@61 A5 E3', 225, N'E6484', 624, 0, 0, 1, NULL, N'A', '20091109 15:19:05.993', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'd1353044-df22-458a-8037-acfa9bb77fef', N'RED BLOOD CELLS|CPD>AS5/450mL/refg|Open|ResLeu:<5log6|Plasma added', N'RBC CPD>AS5 OPN LUKOPR PA', N'E002', N'@22 B2 D4 E4', 350, N'E6511', 24, 0, 0, 1, NULL, N'A', '20091109 15:17:58.960', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'd1e89fe1-3ad5-47c5-8843-f3f580a2b565', N'RED BLOOD CELLS|CPD>SAGM/500mL/refg|Open|Irradiated|ResLeu:<5log6|Plasma reduced', N'RBC CPD>SAGM OPN IRD LUKOPR PLS Red', N'E002', N'@CM B2 C2 D4 E5', 350, N'E6429', 24, 0, 0, 1, NULL, N'A', '20091109 15:17:58.943', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'd306d78f-1475-4e07-9093-354ecbb6d77b', N'FRESH FROZEN PLASMA|CPD/350mL/<-30C|Frozen <=6h', N'FFP CPD', N'E010', N'@CZ G4', 225, N'E6505', 8760, 0, 0, 1, NULL, N'A', '20091109 15:18:54.163', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'd38a0e08-3dcc-4754-85e3-44a5b16ec011', N'Apheresis PLATELETS|PASIIIMgK/XX/20-24C|ResLeu:<1log6|4th container|Bacterial test', N'PLT AFR PASIIIMgK LUKOPR BacTest', N'E024', N'@CI D5 H6 N3', 200, N'E6593', 120, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'd3f92eef-2e7f-44d9-9bc2-9d18e0d9de0a', N'Thawed PLASMA|CP2D/XX/refg|Open|Irradiated|ResLeu:<5log6', N'PLASMA Thaw CP2D OPN IRD LUKOPR', N'E011', N'@13 B2 C2 D4', 225, N'E6628', 24, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'd4f71d31-a292-4c41-afc6-55745719e83c', N'FRESH FROZEN PLASMA|CPDA-1/450mL/<-25C|Frozen <=6h|Quar:>=112d/retested', N'FFP CPDA-1 QUAR', N'E010', N'@CV G4 I4', 225, N'E6180', 8760, 0, 0, 1, NULL, N'A', '20091109 15:18:36.150', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'd50e2c47-26f5-40fa-a497-b8db0a86d70d', N'Apheresis RED BLOOD CELLS|SAGM/XX/refg|ResLeu:<1log6', N'RBC AFR SAGM LUKOPR', N'E009', N'@A9 D5', 350, N'E6549', 1008, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'd62e38e0-83be-4bef-bafb-5f33c64debca', N'Apheresis PLASMA|NaCitrate/XX/<=-18C|Cryo reduced', N'PLASMA AFR NaCit CRYORed', N'E012', N'@48 E3', 450, N'E6496', 8760, 0, 0, 1, NULL, N'A', '20100514 14:47:38.847', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'd64560a2-2592-4f17-965a-edd1513f8bea', N'FRESH FROZEN PLASMA|CPDA-1/450mL/<-25C|For mnf:noninjectable|Frozen <=8h|Quar:>=112d/retested', N'FFP CPDA-1 MNFNI QUAR', N'E010', N'@CV A3 GB I4', 225, N'E6309', 8760, 0, 0, 1, NULL, N'A', '20091109 15:18:54.163', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'da23f3e8-e7a0-495c-883c-2561cba8b752', N'Thawed PLASMA|CP2D/XX/refg|Open|ResLeu:<5log6', N'PLASMA Thaw CP2D OPN LUKOPR', N'E011', N'@13 B2 D4', 225, N'E6629', 24, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'da2a0c89-f968-4ddd-97e7-dde99eaaf411', N'Thawed PLASMA|CPD/500mL/refg|ResLeu:NS', N'PLASMA Thaw CPD LUKOPR', N'E011', N'@04 D2', 225, N'E6434', 120, 0, 0, 1, NULL, N'A', '20091109 15:19:05.993', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'dad4f466-4835-4838-b851-2560504a7548', N'Washed Apheresis PLATELETS|PASIIIMgK/XX/20-24C|Irradiated|ResLeu:<1log6|3rd container', N'PLT AFR Wash PASIIIMgK IRD LUKOPR', N'E027', N'@CI C2 D5 H5', 200, N'E6606', 4, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'dbbbcc07-701b-40b2-960a-06771b6b2aa1', N'Apheresis RED BLOOD CELLS|ACD-A>AS3/XX/refg|For mnf:noninjectable|ResLeu:<5log6|1st container', N'RBC AFR ACD-A>AS3 MNFNI LUKOPR', N'E009', N'@AZ A3 D4 H3', 350, N'E6491', 1008, 0, 0, 1, NULL, N'A', '20091109 15:18:36.150', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'dbe88b1a-42e4-4b2e-becd-57f61b43bb87', N'Thawed Apheresis PLASMA|ACD-A/XX/refg|4th container', N'PLASMA AFR Thaw ACD-A', N'E013', N'@54 H6', 450, N'E6393', 120, 0, 0, 1, NULL, N'A', '20100514 14:47:38.847', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'dd1e983e-46e1-409a-a6a7-73ebdbbaf191', N'Thawed Apheresis PLATELETS|DMSO/XX/20-24C|Open|Irradiated|ResLeu:<1log6|2nd container', N'PLT AFR Thaw DMSO OPN IRD LUKOPR', N'E026', N'@77 B2 C2 D5 H4', 200, N'E6288', 4, 0, 0, 1, NULL, N'A', '20091109 15:20:06.887', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'dd1fac0c-0999-4486-9ab2-bc07d3cb7620', N'Apheresis RED BLOOD CELLS|ACD-A>AS3/XX/refg|For mnf:noninjectable|ResLeu:<5log6|2nd container', N'RBC AFR ACD-A>AS3 MNFNI LUKOPR', N'E009', N'@AZ A3 D4 H4', 350, N'E6492', 1008, 0, 0, 1, NULL, N'A', '20091109 15:18:36.150', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'de1c4d0c-2eaf-45a0-9f75-61823f2af174', N'Thawed FRESH FROZEN PLASMA DIVIDED IRRADIATED (by pheresis)(-65C or colder)(Part H or 8)', N'FFP AFR Thaw None IRD', N'E013', N'@AS C2 HC', 450, N'48718', 24, 0, 0, 0, NULL, N'A', '20100514 15:01:54.953', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'de2d2628-8a38-4085-b90f-5201390471b4', N'PLATELETS|CPDA-1/450mL/20-24C|Open|ResLeu:<8.3log5|Plasma reduced', N'PLT CPDA-1 OPN LUKOPR PLS Red', N'E020', N'@66 B2 D6 E5', 50, N'E6165', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:23.290', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'dea08d2c-3bb5-4961-99c4-aa6a015b3204', N'Apheresis RED BLOOD CELLS|CPD>SAGM/XX/refg|Open|ResLeu:<5log6', N'RBC AFR CPD>SAGM OPN LUKOPR', N'E009', N'@CL B2 D4', 350, N'E6557', 24, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'deaef843-9b9a-4196-ae5e-fbc5db6f3892', N'Apheresis PLATELETS|ACD-A/XX/20-24C|ResLeu:<5log6|Plasma reduced/Plasma added|3rd container', N'PLT AFR ACD-A LUKOPR PLS Red/PA', N'E024', N'@73 D4 EE H5', 200, N'E6332', 120, 0, 0, 1, NULL, N'A', '20091109 15:19:52.137', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'decb38ba-e006-4d17-8c3e-187062d0024b', N'POOLED PLATELETS|CP2D/XX/20-24C|Irradiated|ResLeu:<5log6|<3log11 plts|Bacterial test', N'PLT Pool CP2D IRD LUKOPR BacTest', N'E022', N'@B9 C2 D4 JI N3', 200, N'E6213', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:23.307', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'df2ecab9-1f31-4fc0-a8b8-3e1c80e44ad7', N'RED BLOOD CELLS|CPD>SAGM/450mL/refg|Buffy coat removed', N'RBC CPD>SAGM BuF Rem', N'E002', N'@CY ED', 350, N'E6467', 1008, 0, 0, 1, NULL, N'A', '20091109 15:17:58.943', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'df3c69c7-8458-4c5c-92d2-02af68631d53', N'Thawed Apheresis PLATELETS|DMSO/XX/20-24C|Open|ResLeu:<1log6|Supernat rem/Plasma added|1st container', N'PLT AFR Thaw DMSO OPN LUKOPR SR/PA', N'E026', N'@77 B2 D5 E8 H3', 200, N'E6290', 4, 0, 0, 1, NULL, N'A', '20091109 15:20:06.887', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'dfc25e64-5eee-44cb-98de-fa7af4f1c6f4', N'Thawed FRESH FROZEN PLASMA DIVIDED (-65C or colder)(Part F or 6)', N'FFP Thaw None', N'E011', N'@AS HA', 225, N'48306', 24, 0, 0, 0, NULL, N'A', '20100514 15:01:54.953', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'dfd5b59d-6522-403a-a971-65133add5aaf', N'Thawed PLASMA DONOR RETESTED (from 250 ml Whole Blood)(Storage -18C or colder)', N'PLASMA Thaw None LowVol', N'E011', N'@AS F3', 225, N'17431', 120, 0, 0, 0, NULL, N'A', '20100514 15:01:54.953', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'e025852a-1180-49e7-91b7-aacb5f2af51c', N'Thawed PLASMA CRYOPRECIPITATE REDUCED DONOR RETESTED', N'PLASMA Thaw None CRYORed', N'E011', N'@AS E3', 225, N'17435', 120, 0, 0, 0, NULL, N'A', '20100514 15:01:54.953', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'e072df26-884e-4126-9c88-78df2e54fe46', N'Thawed CRYOPRECIPITATE|None/XX/rt|ResLeu:<5log6', N'CRYO Thaw None LUKOPR', N'E029', N'@83 D4', 15, N'E6611', 6, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'e13044e2-1ed9-4a36-ae7f-8d414dfecbe6', N'Thawed FRESH FROZEN PLASMA DIVIDED IRRADIATED (by pheresis)(-65C or colder)(Part E or 5)', N'FFP AFR Thaw None IRD', N'E013', N'@AS C2 H9', 450, N'48715', 24, 0, 0, 0, NULL, N'A', '20100514 15:01:54.953', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'e19ce0b1-5324-4948-b927-38ca0f2d1e86', N'Apheresis GRANULOCYTES|NaCitrate-HES-ACD-A/XX/rt|Open|Irradiated', N'GRAN AFR NaCit-HES-ACD-A OPN IRD', N'E035', N'@CC B2 C2', 150, N'E6392', 24, 0, 0, 1, NULL, N'A', '20091109 15:22:26.077', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'e1c6f1d3-aabe-49da-b125-85c1665cf577', N'Apheresis RED BLOOD CELLS|CP2D>AS3/XX/refg|For mnf:noninjectable|ResLeu:<5log6|1st container', N'RBC AFR CP2D>AS3 MNFNI LUKOPR', N'E009', N'@33 A3 D4 H3', 350, N'E6207', 1008, 0, 0, 1, NULL, N'A', '20091109 15:18:36.150', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'e35f164d-b2bc-4a0e-b01b-ac11ac92e828', N'PLASMA|CPD/XX/<=-20C|For mnf:injectable restr use|Cryo reduced|Frozen <=72h', N'PLASMA CPD MNFRI CRYORed', N'E010', N'@BN A6 E3 GD', 225, N'E6487', 8760, 0, 0, 1, NULL, N'A', '20091109 15:18:54.163', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'e43e905a-5633-4e2d-b725-cd4d7dfe86fa', N'Deglycerolized Apheresis RED BLOOD CELLS|None/XX/refg|Irradiated|ResLeu:<5log6|1st container', N'RBC AFR Deg None IRD LUKOPR', N'E051', N'@AS C2 D4 H3', 200, N'E6194', 336, 0, 0, 1, NULL, N'A', '20100514 14:47:38.847', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'e48a1ae4-b15b-4c0c-bf5e-cf453f09cd0f', N'Apheresis PLASMA|NaCitrate/XX/<-25C|For mnf:noninjectable|Frozen <=6h|Quar:>=112d/retested', N'PLASMA AFR NaCit MNFNI QUAR', N'E012', N'@CQ A3 G4 I4', 450, N'E6317', 8760, 0, 0, 1, NULL, N'A', '20100514 14:47:38.847', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'e4fd4fcf-ed76-4f06-91e6-a8ffde33f5d7', N'POOLED PLATELETS|CPD/XX/20-24C|ResLeu:<1log6|From 7 donors', N'PLT Pool CPD LUKOPR 7DNR', N'E022', N'@A7 D5 J7', 200, N'E6233', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:23.307', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'e517ffe4-f803-40bb-9a50-8f32df9a71d4', N'Apheresis PLATELETS|ACD-A/XX/20-24C|Open|Irradiated|1st container|<3log11 plts', N'PLT AFR ACD-A OPN IRD', N'E024', N'@73 B2 C2 H3 JI', 200, N'E6412', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:52.137', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'e535d02f-b71b-4285-b20e-61e49c08cd96', N'RED BLOOD CELLS|CPD>SAGM/500mL/refg|Open|Irradiated|ResLeu:<5log6|Supernat rem', N'RBC CPD>SAGM OPN IRD LUKOPR SR', N'E002', N'@CM B2 C2 D4 E7', 350, N'E6373', 24, 0, 0, 1, NULL, N'A', '20091109 15:17:58.943', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'e69fa0c2-84b5-4922-9d07-229f39788164', N'Apheresis PLATELETS|ACD-A/XX/20-24C|Irradiated|ResLeu:<5log6|Plasma reduced|2nd container|<3log11 plts', N'PLT AFR ACD-A IRD LUKOPR PLS Red', N'E024', N'@73 C2 D4 E5 H4 JI', 200, N'E6337', 120, 0, 0, 1, NULL, N'A', '20091109 15:19:52.137', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'e75d67e7-8397-4c79-9660-33bcf9998ce0', N'POOLED PLATELETS|CPD/XX/20-24C|Irradiated|ResLeu:<1log6|From 6 donors', N'PLT Pool CPD IRD LUKOPR 6DNR', N'E022', N'@A7 C2 D5 J6', 200, N'E6246', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:23.307', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'e7df13a8-ca7d-4488-9062-75e0692eceef', N'Apheresis PLATELETS|ACD-A/XX/20-24C|ResLeu:<1log6|Approx 180 log9 plts', N'PLT AFR ACD-A LUKOPR', N'E024', N'@73 D5 JA', 200, N'E6382', 120, 0, 0, 1, NULL, N'A', '20091109 15:19:52.137', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'e9456980-a270-4742-abfc-bb2e57b990e7', N'POOLED PLATELETS|CPD/XX/20-24C|ResLeu:<1log6|From 5 donors', N'PLT Pool CPD LUKOPR 5DNR', N'E022', N'@A7 D5 J5', 200, N'E6231', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:23.307', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'e9fc0168-94d9-48f9-8069-cb0d58d46f4e', N'Washed Apheresis PLATELETS|None/XX/20-24C|Open|Irradiated|ResLeu:<5log6|1st container|<3log11 plts', N'PLT AFR Wash None OPN IRD LUKOPR', N'E027', N'@71 B2 C2 D4 H3 JI', 200, N'E6364', 4, 0, 0, 1, NULL, N'A', '20091109 15:20:06.887', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'ea00554d-5abe-4fad-86a0-37405c6e9fa0', N'Thawed FRESH FROZEN PLASMA DIVIDED (by pheresis)(-65C)(Part B or 2)', N'FFP AFR Thaw None', N'E013', N'@AS H4', 450, N'48312', 24, 0, 0, 0, NULL, N'A', '20100514 15:01:54.953', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'ea09b039-2d34-4fc1-b834-85056d0fbbc9', N'Thawed Apheresis PLATELETS|DMSO/XX/20-24C|Open|ResLeu:<1log6|Supernat rem/Plasma added', N'PLT AFR Thaw DMSO OPN LUKOPR SR/PA', N'E026', N'@77 B2 D5 E8', 200, N'E6289', 4, 0, 0, 1, NULL, N'A', '20091109 15:20:06.887', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'ea14c650-3d07-4a27-b54d-ee790ce4fcba', N'Thawed FRESH FROZEN PLASMA DIVIDED (by pheresis)(-18C)(Part E or 5)', N'FFP AFR Thaw None', N'E013', N'@AS H9', 450, N'48215', 24, 0, 0, 0, NULL, N'A', '20100514 15:01:54.953', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'ead13efd-1a9f-4857-9d1c-8003b1a279b9', N'Apheresis RED BLOOD CELLS|ACD-A/XX/refg|Open|Irradiated|ResLeu:<5log6|Plasma added', N'RBC AFR ACD-A OPN IRD LUKOPR PA', N'E009', N'@54 B2 C2 D4 E4', 350, N'E6458', 24, 0, 0, 1, NULL, N'A', '20091109 15:18:36.150', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'ebcc651e-7193-4dc5-bcc7-96a797f69b0b', N'RED BLOOD CELLS|CPD>SAGM/450mL/refg|Irradiated|ResLeu:<5log6', N'RBC CPD>SAGM IRD LUKOPR', N'E002', N'@CY C2 D4', 350, N'E6515', 672, 0, 0, 1, NULL, N'A', '20091109 15:17:58.960', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'ebe2d846-9f38-4495-a61e-87ed3cd95cd3', N'Apheresis PLATELETS|PASIIIMgK/XX/20-24C|ResLeu:<1log6|1st container|Bacterial monitoring', N'PLT AFR PASIIIMgK LUKOPR BacMtr', N'E024', N'@CI D5 H3 N2', 200, N'E6582', 120, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'ebfb222d-56bf-4ce8-a3db-a82103b8105b', N'FRESH FROZEN PLASMA|CPDA-1/450mL/<-30C|Methylene blue-treated', N'FFP CPDA-1 Methyl Blue', N'E010', N'@BQ K3', 225, N'E6156', 8760, 0, 0, 1, NULL, N'A', '20091109 15:18:36.150', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'ec0e17f2-a2df-441e-abcb-a21a107e2860', N'Washed Apheresis RED BLOOD CELLS|None/XX/refg|ResLeu:<5log6|1st container', N'RBC AFR Wash None LUKOPR', N'E049', N'@AS D4 H3', 200, N'E6185', 24, 0, 0, 1, NULL, N'A', '20091109 15:22:26.077', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'ec2f9d73-7ed0-4031-a358-02868e0ef257', N'Thawed POOLED FRESH FROZEN PLASMA|CPD/XX/refg', N'FFP Pool Thaw CPD', N'E011', N'@06', 500, N'E6175', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:05.993', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'ec4e956f-4462-476d-8d9b-e3127e57b86a', N'Thawed FRESH FROZEN PLASMA DIVIDED IRRADIATED (by pheresis)(-18C or colder)(Part B or 2)', N'FFP AFR Thaw None IRD', N'E013', N'@AS C2 H4', 450, N'48612', 24, 0, 0, 0, NULL, N'A', '20100514 15:01:54.953', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'ec97c46d-7c5e-4248-9f52-a075d1268789', N'Thawed PLASMA CRYOPRECIPITATE REDUCED', N'PLASMA Thaw None CRYORed', N'E011', N'@AS E3', 225, N'18435', 120, 0, 0, 0, NULL, N'A', '20100514 15:01:54.953', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'ecb6df3f-570e-4add-8b56-b063394e3588', N'Thawed CRYOPRECIPITATE|None/XX/rt|Open|ResLeu:<5log6', N'CRYO Thaw None OPN LUKOPR', N'E029', N'@83 B2 D4', 15, N'E6614', 4, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'ecd9149e-71f7-4d75-a703-8549eff4873f', N'Thawed POOLED PLASMA|CP2D/XX/refg|Open|ResLeu:<5log6', N'PLASMA Pool Thaw CP2D OPN LUKOPR', N'E011', N'@13 B2 D4', 500, N'E6621', 4, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'ed150191-9c4f-4321-959c-f23b726dad4d', N'PLASMA|CPDA-1/XX/<=-18C|For mnf:noninjectable restr use|Frozen <=24h', N'PLASMA CPDA-1 MNFRNI', N'E010', N'@36 A5 G7', 225, N'E6483', 8760, 0, 0, 1, NULL, N'A', '20091109 15:18:54.163', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'ed71d383-4b81-48d4-b1ce-be42122326e8', N'Thawed FRESH FROZEN PLASMA DIVIDED IRRADIATED (-18C)(Part A or 1)', N'FFP Thaw None IRD', N'E011', N'@AS C2 H3', 225, N'48601', 24, 0, 0, 0, NULL, N'A', '20100514 15:01:54.953', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'ee2384a8-5a26-4762-8706-3e94bf81439c', N'PLATELETS|CPDA-1/500mL/20-24C|Open|ResLeu:<8.3log5|Plasma reduced', N'PLT CPDA-1 OPN LUKOPR PLS Red', N'E020', N'@67 B2 D6 E5', 50, N'E6167', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:23.290', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'eef0c10e-c48e-4e81-aba4-60de68923267', N'POOLED PLATELETS|CPDA-1/XX/20-24C|ResLeu:<1log6|Buffy coat plts prep|Riboflavin-treated', N'PLT Pool CPDA-1 LUKOPR BUFCT Ribo', N'E022', N'@B8 D5 G2 K6', 200, N'E6560', 4, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'ef00b131-e55a-4a4f-9397-ee83bb2a5a70', N'Apheresis FRESH FROZEN PLASMA|NaCitrate/XX/<-25C|Frozen <=6h|Methylene blue-treated', N'FFP AFR NaCit Methyl Blue', N'E012', N'@CQ G4 K3', 450, N'E6539', 8760, 0, 0, 1, NULL, N'A', '20100514 14:47:38.847', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'ef19105a-5852-4227-b260-acf0a9c403c4', N'POOLED PLATELETS|CPD/XX/20-24C|Irradiated|From 2 donors', N'PLT Pool CPD IRD 2DNR', N'E022', N'@A7 C2 J2', 200, N'E6236', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:23.307', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'ef406166-e93a-4d8d-a172-97716a5e78ca', N'RED BLOOD CELLS|CPDA-1/450mL/refg|ResLeu:<5log6|Plasma reduced/Plasma added|>0.7', N'RBC CPDA-1 LUKOPR PLS Red/PA >0.7', N'E002', N'@07 D4 EE L5', 250, N'E6396', 840, 0, 0, 1, NULL, N'A', '20091109 15:17:58.943', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'ef41b0e2-3039-410c-894e-91190f9d268d', N'RED BLOOD CELLS|CPDA-1/450mL/refg|Open|Irradiated|ResLeu:<1log6|Plasma reduced/Plasma added', N'RBC CPDA-1 OPN IRD LUKOPR PLS Red/PA', N'E002', N'@07 B2 C2 D5 EE', 250, N'E6320', 24, 0, 0, 1, NULL, N'A', '20091109 15:17:58.943', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'ef4e90e5-79a5-4a6b-82c6-84d7b64a34ab', N'Deglycerolized Rejuvenated RED BLOOD CELLS|None/XX/refg|Open|Irradiated|ResLeu:<5log6|Plasma added', N'RBC Deg Rej None OPN IRD LUKOPR PA', N'E007', N'@AS B2 C2 D4 E4', 200, N'E6457', 24, 0, 0, 1, NULL, N'A', '20091109 15:18:36.150', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'ef7bca2b-58e0-4db2-8fcd-ce0f4f4e3491', N'POOLED PLATELETS|CPD/XX/20-24C|Irradiated|From 7 donors', N'PLT Pool CPD IRD 7DNR', N'E022', N'@A7 C2 J7', 200, N'E6240', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:23.307', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'ef8d03cd-28d5-420c-8c06-269a8190a463', N'Washed POOLED PLATELETS|PASIIIMgK/XX/20-24C|ResLeu:<1log6|Buffy coat plts prep', N'PLT Pool Wash PASIIIMgK LUKOPR BUFCT', N'E023', N'@CI D5 G2', 200, N'E6572', 4, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'f0260a0c-f25a-40ae-9d36-41fd8c174125', N'RED BLOOD CELLS|CPDA-1/450mL/refg|Open|ResLeu:<5log6|Plasma added', N'RBC CPDA-1 OPN LUKOPR PA', N'E002', N'@07 B2 D4 E4', 250, N'E6397', 24, 0, 0, 1, NULL, N'A', '20091109 15:17:58.943', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'f0c8367b-58ac-449a-8c42-750c78d9817b', N'Thawed POOLED FRESH FROZEN PLASMA|CP2D/XX/refg', N'FFP Pool Thaw CP2D', N'E011', N'@13', 500, N'E6176', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:05.993', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'f15e3565-e50f-4536-8a0e-1c3fd616d205', N'CRYOPRECIPITATE|CPD/450mL/<=-18C', N'CRYO CPD', N'E028', N'@AM', 15, N'E6524', 8760, 0, 0, 1, NULL, N'A', '20091109 15:21:16.200', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'f1605b3f-ef1e-46f3-91b8-7d4460f17b35', N'Washed RED BLOOD CELLS|None/450mL/refg|Irradiated', N'RBC Wash None IRD', N'E003', N'@17 C2', 200, N'E6319', 24, 0, 0, 1, NULL, N'A', '20091109 15:17:58.960', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'f1ad5191-75bf-4efb-a5dd-15bf8f91c06c', N'Apheresis CRYOPRECIPITATE|ACD-A/XX/<-25C|Quar:>=112d/retested', N'CRYO AFR ACD-A QUAR', N'E032', N'@AI I4', 100, N'E6299', 8760, 0, 0, 1, NULL, N'A', '20091109 15:22:26.077', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'f2da28ed-b309-4593-914f-549fadd4d492', N'CRYOPRECIPITATE|CPDA-1/450mL/<-25C|Quar:>=112d/retested', N'CRYO CPDA-1 QUAR', N'E028', N'@CV I4', 15, N'E6297', 8760, 0, 0, 1, NULL, N'A', '20091109 15:22:26.077', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'f399bf1e-f0a3-4d31-8f21-ac7d57dc28f9', N'Thawed FRESH FROZEN PLASMA DIVIDED (-18C or colder)(Part C or 3)', N'FFP Thaw None', N'E011', N'@AS H5', 225, N'48203', 24, 0, 0, 0, NULL, N'A', '20100514 15:01:54.953', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'f40bed02-876a-463e-aea3-5a87d8b40717', N'RED BLOOD CELLS|CPD/XX/refg|Open|LowVol:anticoag adj', N'RBC CPD OPN LowVol', N'E002', N'@06 B2 F8', 250, N'E6469', 24, 0, 0, 1, NULL, N'A', '20091109 15:17:58.943', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'f44980a1-5413-4715-8fd8-f4b1ab842fa4', N'FRESH FROZEN PLASMA|CPD/450mL/<-25C|Frozen <=8h|Methylene blue-treated', N'FFP CPD Methyl Blue', N'E010', N'@A2 GB K3', 225, N'E6538', 8760, 0, 0, 1, NULL, N'A', '20091109 15:19:05.993', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'f59aeac6-65c1-4948-bc78-cadf365d82cd', N'PLATELETS|CPD/450mL/20-24C|Open|ResLeu:<8.3log5', N'PLT CPD OPN LUKOPR', N'E020', N'@64 B2 D6', 50, N'E6519', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:23.290', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'f701b203-5f25-4af6-9889-9f6cc6405ee3', N'Thawed PLASMA|CP2D/450mL/refg|ResLeu:NS|Frozen <=24h', N'PLASMA Thaw CP2D LUKOPR', N'E011', N'@11 D2 G7', 225, N'E6463', 120, 0, 0, 1, NULL, N'A', '20091109 15:19:05.993', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'f7b76312-bf91-4081-a14f-6acfa08322c3', N'Thawed Apheresis PLATELETS|DMSO/XX/20-24C|Open|Irradiated|ResLeu:<1log6|1st container', N'PLT AFR Thaw DMSO OPN IRD LUKOPR', N'E026', N'@77 B2 C2 D5 H3', 200, N'E6287', 4, 0, 0, 1, NULL, N'A', '20091109 15:20:06.887', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'f7daf862-f85c-4a67-b426-e4e1723887aa', N'Thawed FRESH FROZEN PLASMA DIVIDED (-65C or colder)(Part C or 3)', N'FFP Thaw None', N'E011', N'@AS H5', 225, N'48303', 24, 0, 0, 0, NULL, N'A', '20100514 15:01:54.953', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'f8214db0-e42a-4b29-9ae1-86135fc0a5be', N'PLATELETS|CP2D/XX/20-24C|Open|Irradiated|ResLeu:<8.3log5|Plasma reduced', N'PLT CP2D OPN IRD LUKOPR PLS Red', N'E020', N'@B9 B2 C2 D6 E5', 50, N'E6361', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:23.290', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'f82d292d-63a8-49ef-8a2f-63e3362a37bc', N'Liquid Apheresis PLASMA|CPD-50/XX/refg|ResLeu:<1log6|1st container|Psoralen-treated', N'PLASMA AFR Liq CPD-50 LUKOPR Psoraln', N'E011', N'@AX D5 H3 K5', 225, N'E6356', 120, 0, 0, 1, NULL, N'A', '20091109 15:19:05.993', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'f8360009-70cd-4db4-9545-e8d023afa65e', N'Apheresis CRYOPRECIPITATE|NaCitrate/XX/<-25C', N'CRYO AFR NaCit', N'E032', N'@CQ', 100, N'E6300', 8760, 0, 0, 1, NULL, N'A', '20091109 15:22:26.077', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'f85ffe0b-51d5-408d-901a-fc3522832648', N'POOLED PLATELETS|CPDA-1/XX/20-24C|ResLeu:<1log6|Plasma reduced/Plasma added', N'PLT Pool CPDA-1 LUKOPR PLS Red/PA', N'E022', N'@B8 D5 EE', 200, N'E6199', 4, 0, 0, 1, NULL, N'A', '20100210 13:55:15.970', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'f8744c2d-3bb1-4c13-a22b-4551ac41d9f7', N'Apheresis PLATELETS|PASIIIMgK/XX/20-24C|Irradiated|ResLeu:<1log6|Supernat reduced', N'PLT AFR PASIIIMgK IRD LUKOPR SUPRed', N'E024', N'@CI C2 D5 EA', 200, N'E6599', 120, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'f97e0c7b-e73b-4711-8e59-c12bf2357910', N'WHOLE BLOOD|CPD/350mL/refg|ResLeu:<1log6', N'WB CPD LUKOPR', N'E001', N'@D1 D5', 350, N'E6508', 504, 0, 0, 1, NULL, N'A', '20091109 15:17:58.943', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'f99b7544-5720-4917-b464-c398ca1dd75e', N'Thawed FRESH FROZEN PLASMA DIVIDED IRRADIATED (-18C)(Part D or 4)', N'FFP Thaw None IRD', N'E011', N'@AS C2 H6', 225, N'48604', 24, 0, 0, 0, NULL, N'A', '20100514 15:01:54.953', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'f9fce48c-db26-4a03-b74c-b98ab3f29f09', N'Thawed FRESH FROZEN PLASMA DIVIDED IRRADIATED (-18C)(Part F or 6)', N'FFP Thaw None IRD', N'E011', N'@AS C2 HA', 225, N'48606', 24, 0, 0, 0, NULL, N'A', '20100514 15:01:54.953', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'fa0fbbca-1c8e-4d1c-a799-ca8575b8712f', N'Thawed PLASMA|CPD/XX/refg|ResLeu:NS|Frozen <=72h', N'PLASMA Thaw CPD LUKOPR', N'E011', N'@06 D2 GD', 225, N'E6562', 120, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'fa1d1dd7-9d9c-460c-bba0-7ec7fd71a7f9', N'Washed Apheresis RED BLOOD CELLS|None/XX/refg|Irradiated|ResLeu:<5log6|1st container', N'RBC AFR Wash None IRD LUKOPR', N'E049', N'@AS C2 D4 H3', 200, N'E6188', 24, 0, 0, 1, NULL, N'A', '20091109 15:22:26.077', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'fa757f41-5748-45e7-9bdb-7ce64f5686f6', N'Apheresis RED BLOOD CELLS|CP2D>AS3/XX/refg|For mnf:injectable|ResLeu:<5log6|2nd container', N'RBC AFR CP2D>AS3 MNFI LUKOPR', N'E009', N'@33 A2 D4 H4', 350, N'E6205', 1008, 0, 0, 1, NULL, N'A', '20091109 15:18:36.150', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'facd3c29-1a18-4790-8058-4ed5a073ad73', N'Apheresis PLATELETS|ACD-A/XX/20-24C|For mnf:noninjectable|Irradiated|ResLeu:<5log6|1st container', N'PLT AFR ACD-A MNFNI IRD LUKOPR', N'E024', N'@73 A3 C2 D4 H3', 200, N'E6448', 120, 0, 0, 1, NULL, N'A', '20091109 15:19:52.150', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'fb17f9a8-0246-45f2-a571-2257c28c4b1f', N'RED BLOOD CELLS|CPDA-1/500mL/refg|Not for tx or mnf|ResLeu:<5log6', N'RBC CPDA-1 NMT LUKOPR', N'E002', N'@08 A4 D4', 250, N'E6402', 840, 0, 0, 1, NULL, N'A', '20091109 15:17:58.943', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'fb873b72-fba6-4482-9e7d-93207c91ae28', N'POOLED PLATELETS|CPD/XX/20-24C|Irradiated|From 3 donors', N'PLT Pool CPD IRD 3DNR', N'E022', N'@A7 C2 J3', 200, N'E6237', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:23.307', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'fba8ad32-4a80-4399-ae8c-8060c781aab7', N'Washed POOLED PLATELETS|None/XX/20-24C|Open|Irradiated|ResLeu:<5log6|Buffy coat plts prep|From 4 donors', N'PLT Pool Wash None OPN IRD LUKOPR BUFCT 4DNR', N'E023', N'@71 B2 C2 D4 G2 J4', 200, N'E6368', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:52.137', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'fbe33b4b-2fb6-4fd5-81f6-900c39bc9a4d', N'Apheresis PLATELETS|ACD-A/XX/20-24C|Open|ResLeu:<5log6|Plasma reduced|1st container|<3log11 plts', N'PLT AFR ACD-A OPN LUKOPR PLS Red', N'E024', N'@73 B2 D4 E5 H3 JI', 200, N'E6362', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:52.137', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'fc877391-9241-44e9-a7b3-87ba400b6d41', N'Thawed PLASMA IRRADIATED (Storage -18C or colder)', N'PLASMA Thaw None IRD', N'E011', N'@AS C2', 225, N'18801', 120, 0, 0, 0, NULL, N'A', '20100514 15:01:54.953', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'fcbbc5ce-e366-4216-b04a-0f74a99af100', N'Thawed Apheresis PLATELETS|DMSO/XX/20-24C|Open|Irradiated|ResLeu:<1log6|Supernat rem/Plasma added|2nd container', N'PLT AFR Thaw DMSO OPN IRD LUKOPR SR/PA', N'E026', N'@77 B2 C2 D5 E8 H4', 200, N'E6294', 4, 0, 0, 1, NULL, N'A', '20091109 15:20:06.887', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'fd0a9468-90bb-4ad2-a10c-f44de0e3fc2d', N'Liquid PLASMA|CP2D/XX/rt|For mnf:noninjectable', N'PLASMA Liq CP2D MNFNI', N'E011', N'@CU A3', 225, N'E6171', 624, 0, 0, 1, NULL, N'A', '20091109 15:19:05.993', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'fd4dbd3f-3c91-4316-b0ce-d0b9fc5924bb', N'Apheresis RED BLOOD CELLS|SAGM/XX/refg|Irradiated|ResLeu:<1log6|Supernat rem/Plasma added', N'RBC AFR SAGM IRD LUKOPR SR/PA', N'E009', N'@A9 C2 D5 E8', 350, N'E6548', 672, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'fdbcc82e-327c-4dc6-9cb3-42ed3ab9f2ed', N'Washed POOLED PLATELETS|None/XX/20-24C|Irradiated|ResLeu:<1log6|Buffy coat plts prep|From 3 donors', N'PLT Pool Wash None IRD LUKOPR BUFCT 3DNR', N'E023', N'@71 C2 D5 G2 J3', 200, N'E6278', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:37.963', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'fe0aa3c5-35a2-40a6-ba03-0971a9eb3547', N'Apheresis PLATELETS|PASIIIMgK/XX/20-24C|Irradiated|ResLeu:<1log6|3rd container|Bacterial monitoring', N'PLT AFR PASIIIMgK IRD LUKOPR BacMtr', N'E024', N'@CI C2 D5 H5 N2', 200, N'E6588', 120, 0, 0, 1, NULL, N'A', '20100210 10:15:38.380', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'fe3de465-bde8-4ac1-81f6-b8d987dd2561', N'Apheresis FRESH FROZEN PLASMA|ACD-A/XX/<-25C|Frozen <=6h|Quar:>=112d/retested', N'FFP AFR ACD-A QUAR', N'E012', N'@AI G4 I4', 450, N'E6493', 8760, 0, 0, 1, NULL, N'A', '20100514 14:47:38.847', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'feda121d-522e-403e-94ef-d1c4963ccf7b', N'PLATELET-RICH BUFFY COAT|CPDA-1/450mL/20-24C', N'BUFFY PltRch CPDA-1', N'E042', N'@66', 200, N'E6445', 24, 0, 0, 1, NULL, N'A', '20091109 15:22:26.077', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'fedec55e-5e25-45b7-9cff-57d804c56120', N'Deglycerolized RED BLOOD CELLS|None/XX/refg|Open|Irradiated|ResLeu:<5log6|Plasma added', N'RBC Deg None OPN IRD LUKOPR PA', N'E006', N'@AS B2 C2 D4 E4', 200, N'E6455', 24, 0, 0, 1, NULL, N'A', '20091109 15:18:36.150', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'feeaf47f-1b55-435c-913a-069ce3e56d22', N'POOLED PLATELETS|CPD/XX/20-24C|Irradiated|From 8 donors', N'PLT Pool CPD IRD 8DNR', N'E022', N'@A7 C2 J8', 200, N'E6241', 4, 0, 0, 1, NULL, N'A', '20091109 15:19:23.307', N'vhaishsmithm', 0)
INSERT INTO dbo.BloodProduct (BloodProductGuid, ProductName, ProductShortName, ProductTypeCode, ProductAttributeForm, ProductVolume, ProductCode, MaximumStorageTime, CrossmatchRequiredIndicator, ProductModificationIndicator, ProductCodeIndicator, RetireDate, RecordStatusCode, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'ffc93ea9-353b-4e8c-966c-be100588ac15', N'POOLED PLATELETS|CPD/XX/20-24C|Irradiated|ResLeu:<1log6|Plasma reduced/Plasma added|Buffy coat plts prep|From 3 donors', N'PLT Pool CPD IRD LUKOPR PLS Red/PA BUFCT 3DNR', N'E022', N'@A7 C2 D5 EE G2 J3', 200, N'E6343', 4, 0, 0, 1, NULL, N'A', '20100210 13:55:15.970', N'vhaishsmithm', 0)

-- Add 11 rows to dbo.ProductAttribute
INSERT INTO dbo.ProductAttribute (ProductAttributeId, ProductAttributeText, ProductAttributePrintName, RetireDate, SortColumn, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'@CU', N'CP2D/XX/rt', N'CP2D', NULL, 0, '20091113 12:55:07.470', N'vhaishsmithm', 0)
INSERT INTO dbo.ProductAttribute (ProductAttributeId, ProductAttributeText, ProductAttributePrintName, RetireDate, SortColumn, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'@CV', N'CPDA-1/450mL/<-25C', N'CPDA-1', NULL, 0, '20091113 12:55:15.767', N'vhaishsmithm', 0)
INSERT INTO dbo.ProductAttribute (ProductAttributeId, ProductAttributeText, ProductAttributePrintName, RetireDate, SortColumn, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'@CW', N'CP2D/XX/<-25C', N'CP2D', NULL, 0, '20091113 12:55:51.800', N'vhaishsmithm', 0)
INSERT INTO dbo.ProductAttribute (ProductAttributeId, ProductAttributeText, ProductAttributePrintName, RetireDate, SortColumn, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'@CX', N'CPD-50>SAGM/XX/refg', N'CPD-50>SAGM', NULL, 0, '20091113 12:55:51.800', N'vhaishsmithm', 0)
INSERT INTO dbo.ProductAttribute (ProductAttributeId, ProductAttributeText, ProductAttributePrintName, RetireDate, SortColumn, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'@CY', N'CPD>SAGM/450mL/refg', N'CPD>SAGM', NULL, 0, '20091113 12:55:51.800', N'vhaishsmithm', 0)
INSERT INTO dbo.ProductAttribute (ProductAttributeId, ProductAttributeText, ProductAttributePrintName, RetireDate, SortColumn, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'@CZ', N'CPD/350mL/<-30C', N'CPD', NULL, 0, '20091113 12:55:51.800', N'vhaishsmithm', 0)
INSERT INTO dbo.ProductAttribute (ProductAttributeId, ProductAttributeText, ProductAttributePrintName, RetireDate, SortColumn, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'@D0', N'CPD/350mL/20-24C', N'CPD', NULL, 0, '20091113 12:55:51.800', N'vhaishsmithm', 0)
INSERT INTO dbo.ProductAttribute (ProductAttributeId, ProductAttributeText, ProductAttributePrintName, RetireDate, SortColumn, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'@D1', N'CPD/350mL/refg', N'CPD', NULL, 0, '20091113 12:55:51.800', N'vhaishsmithm', 0)
INSERT INTO dbo.ProductAttribute (ProductAttributeId, ProductAttributeText, ProductAttributePrintName, RetireDate, SortColumn, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'@D2', N'AS3/350mL/refg', N'AS3', NULL, 0, '20091113 12:55:51.800', N'vhaishsmithm', 0)
INSERT INTO dbo.ProductAttribute (ProductAttributeId, ProductAttributeText, ProductAttributePrintName, RetireDate, SortColumn, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'@D3', N'AS3/450mL/refg', N'AS3', NULL, 0, '20091113 12:55:51.800', N'vhaishsmithm', 0)
INSERT INTO dbo.ProductAttribute (ProductAttributeId, ProductAttributeText, ProductAttributePrintName, RetireDate, SortColumn, LastUpdateDate, LastUpdateUser, LastUpdateFunctionId) VALUES (N'@D4', N'SAGM/350mL/refg', N'SAGM', NULL, 0, '20091113 12:55:51.800', N'vhaishsmithm', 0)

/*****************************************************
**	Update VbecsVersion
*****************************************************/
DECLARE @SUser	VARCHAR(45)

SET @SUser = (select suser_sname())

INSERT INTO dbo.VbecsVersion
(Version, PatchSuccessfulIndicator, LastUpdateDate, LastUpdateUser)
VALUES('1.5.1.1', 0, getutcdate(), RIGHT(@SUser, LEN(@SUser) - CHARINDEX('\', @SUser)))